      subroutine fmmpart3d(sources, nsources, monocharge, dipstr,
     1      dipvec, pot, potx, poty, potz, work, lenw, iprec,
     2      iflagtype, iderivonoff, close, epsclose, ier, inform)
      implicit real *8(a-h,o-z)
c
c     the following subroutine takes as input an array of source strengths
c     and locations and returns the potential and field (if desired)
c     at each of the source locations on output.
c
c     sources can be either monopoles, dipoles, or a combination of
c     the two.  specification of dipole sources requires both a strength
c     (dipstr) and an orientation (a unit vector, dipvec).
c
c     pot(x_i) = sum (j=1..n, j <> i) monocharge_j * 1 / |x_i - x_j|
c              - dipstr_j * (dipvec_j,(x_i-x_j)) / |x_i - x_j|^3
c
c
c     INPUT PARAMETERS:
c
c     sources(3,nsources) (real *8):  sources(1,i) is the x coordinate of ith
c                                                  source
c                                     sources(2,i) is the y coordinate of ith
c                                                  source
c                                     sources(3,i) is the z coordinate of ith
c                                                  source
c
c     nsources (integer *4):          number of sources
c
c     monocharge(nsources) (real *8): monocharge(i) is the charge of ith
c                                     monopole source
c
c     dipstr(nsources) (real *8):  dipstr(i) is the strength of ith
c                                  dipole source
c
c     dipvec(3,nsources) (real *8):   (dipvec(1,i), dipvec(2,i), dipvec(3,i))
c                                  is the orientation vector for ith dipole
c
c     iprec (integer *4):             user-specified parameter that determines
c                                     the desired precision
c
c                                     (iprec = 0  -> 3  digit accuracy)
c                                     (iprec = 1  -> 6  digit accuracy)
c                                     (iprec = 2  -> 9  digit accuracy)
c                                     (iprec = 3  -> 12 digit accuracy)
c
c     iflagtype (integer *4):         user-specified flag denoting whether
c                                     monopoles, dipoles, or both are present
c
c                                     (iflagtype = 0 -> only monopoles)
c                                     (iflagtype = 1 -> only dipoles)
c                                     (iflagtype = 2 -> monopoles and dipoles)
c
c     NOTE:   Unused arrays do not need to be allocated in full. Thus, if
c     iflagtype = 0, dipstr can be dimensioned as a scalar and dipvec can
c     be dimensioned as dipvec(3) - BUT NOT dipvec(1).  If iflagtype = 1,
c     monocharge can be dimensioned as a scalar.
c
c     work(lenw) (real *8):            real work array
c
c     lenw (integer *4):               length of work
c                                      (must be at least 20 * nsources)
c
c     iderivonoff (integer *4):        user-specified flag denoting whether
c                                      or not the first derivatives are to
c                                      be computed
c
c                                      (iderivonoff = 0 -> don't compute)
c                                      (iderivonoff = 1 -> compute derivatives)
c
c     NOTE:  Unused arrays do not need to be allocated in full. 
c            If iderivonoff = 0, potx, poty, and potz can be
c            dimensioned as scalars.
c
c     epsclose (real *8):
c
c       In many applications, the interaction between particles is
c       Coulombic or gravitational at large distances, but more
c       complicated in the near field. The parameter epsclose determines
c       the cutoff distance at which a user-provided subroutine
c       takes responsibility for computing the pairwise interaction.
c       More precisely, if the distance between two sources is less
c       than epsclose, then their interaction is handled by
c       the  user-provided routine close (see below).
c       An important consequence of this parameter is that the quad-tree
c       created by FMMPART halts when the dimensions of a box are comparable
c       to epsclose. This can result in significant performance
c       degradation if many sources are within a distance epsclose
c       of each other. Thus, if pure Coulomb interactions are desired,
c       the user should set epsclose = 0.
c
c     close subroutine: (see the close.f file)
c
c       A user-provided subroutine evaluating the pairwise
c       interaction between particles when they are closer to each
c       other than the distance epsclose (see above).
c       The user must declare the subroutine being used for
c       close encounters as external in the calling program.
c       The user must also be sure that the calling
c       sequence of close conforms to the example in 
c       the close.f file.
c
c     OUTPUT PARAMETERS:
c
c     pot(nsources) (real *8):          pot(i) is the potential at the
c                                       ith source
c
c     potx(nsources), poty(nsources), potz(nsources) (real *8):
c                                     potx(i) is the x derivative of
c                                       the potential at the ith source
c                                     poty(i) is the y derivative of
c                                       the potential at the ith source
c                                     potz(i) is the z derivative of
c                                       the potential at the ith source
c
c     ier (integer *4) error flag.
c                 (ier = 0  -> normal execution)
c                 (ier = 1  -> normal execution, but epsclose restricts
c                              the amount of division, performance
c                              may be degraded)
c                 (ier = 2  -> one or several input flags not properly
c                              defined, terminal error)
c                 (ier = 3  -> not enough memory provided,
c                              terminal error)
c                 (ier = 4  -> size of box generated for these boxes
c                              is of size zero.  major problem, terminal)
c                 (ier = 5  -> invalid choice of epsclose, solution
c                              not attempted)
c                 (ier = 6  -> invalid nsources value, solution
c                              not attempted)
c                 (ier = 7  -> problem with the license file,
c                              this must be incorporated at the
c                              level of the subroutine riv3dlic)
c
c      inform(5) (integer *4): inform array contains information 
c                              after successful execution of the code
c
c                 (inform(1) = number of refinement levels)
c                 (inform(2) = total number of boxes in the quadtree)
c                 (inform(3) = order of mpole and local expansions)
c                 (inform(4) = order of plane wave expansions)
c                 (inform(5) = total amount of workspace used)
c
c------------------------------------------------------------------------------
c
c
      integer *4  ndigit, ier, inform(1), nums(5), idirect, iflagtype,
     1  iderivonoff, nsources, maxppb, lenw, ninire, nlev, nboxes,
     2  nlambs, nterms, nshort, n22, iernin, laddr(2,200), iflagclose
c
      real *8  epsclose, sources(3,1), monocharge(1), dipstr(1),
     1  dipvec(3,1), cntr00(3), size, work(1), tmppot, tmpfld(3),
     2  pot(1), potx(1), poty(1), potz(1)
      external  close
c
      ier = 0
c
c     initialize the inform array to zero
c
      inform(1) = 0
      inform(2) = 0
      inform(3) = 0
      inform(4) = 0
      inform(5) = 0
c
      if(iprec .ne. 0 .and. iprec .ne. 1 .and.
     2   iprec .ne. -2 .and. iprec .ne. -1 .and.
     1   iprec .ne. 2 .and. iprec .ne. 3)then
        ier = 2
        return
      endif
c
      if(iflagtype .ne. 0 .and.
     1   iflagtype .ne. 1 .and.
     2   iflagtype .ne. 2)then
        ier = 2
        return
      endif
c
      if(iderivonoff .ne. 0 .and.
     1   iderivonoff .ne. 1)then
        ier = 2
        return
      endif
c
      if(epsclose .lt. 0d0)then
        ier = 5
        return
      endif
c
      if(nsources .le. 1)then
        ier = 6
        return
      endif
c
c      call prinf('iflagtype =*',iflagtype,1)
c      call prinf('the number of particles =*',nsources,1)
c      call prin2('the near approach distance is =*',epsclose,1)
c
c ... if the number of particles is small, simply call the direct 
c     subroutine.
c
      idirect = 0
c
      if(iprec .eq. -2 .and. nsources .le. 999)  idirect = 1
      if(iprec .eq. -1 .and. nsources .le. 999)  idirect = 1
      if(iprec .eq. 0 .and. nsources .le. 999)  idirect = 1
      if(iprec .eq. 1 .and. nsources .le. 1499) idirect = 1
      if(iprec .eq. 2 .and. nsources .le. 2199) idirect = 1
      if(iprec .eq. 3 .and. nsources .le. 3199) idirect = 1
c
      if(idirect .eq. 1)then
c
        do 1000 i = 1, nsources
          call direct3d(i, iflagtype, iderivonoff, nsources,
     1        sources, monocharge, dipstr, dipvec,
     2        sources(1,i), tmpfld, tmppot, epsclose, close)
c
          pot(i)  = tmppot
c
          if(iderivonoff .eq. 1)then
            potx(i) = tmpfld(1)
            poty(i) = tmpfld(2)
            potz(i) = tmpfld(3)
          endif
c
 1000   continue
        return
      endif
c
c ... call to get the machine dependent ninire (a number indicates
c     how many interger *4 numbers are stored in a real *8
c     space).
c
      call mkninire(ninire, iernin)
c
      call prinf('ninire =*',ninire,1)
c THIS IS A HACK, TO BE FIXED
      if (iernin .ne. 0) then
         ninire = 2
      endif
c
c ... set the user-provided work array space to integer zero:
c
      do 2000 i = 1, lenw
        work(i) = -7717d0
 2000 continue
c
c ... based on the given precision requirement (number of digits 
c     desired), determining parameters:nterms,n22,nshort,nlambs
c
      call getints(iprec, maxppb, ndigit, nterms,
     1             n22, nshort, nlambs, limap, larr)
c
      call prinf('required digits of accuracy =*',ndigit,1)
      call prinf('maximum number charges per box =*',maxppb,1)
c
c ... call the book keeping subroutine to get the data structures:
c
      maxnbx = nsources
c
      iiz = 1
      niz = nsources/ninire + 7
c
      iiwork = iiz + niz
      liwork = (lenw-iiwork)*ninire
c
      if(liwork .lt. 12*nsources)then
c
c       not enough space left, set
c       error flag and get out
c
        ier = 3
        return
      endif
c
      call d3mstrcr(ierriv, sources, nsources, maxppb, nboxes,
     1    work(iiz), laddr, nlev, cntr00, size,
     2    work(iiwork), liwork, lsd777, epsclose, ninire)
c
      call prinf('after d3mstrcr, ierriv =*',ierriv,1)
      call prinf('after d3mstrcr, nboxes =*',nboxes,1)
      call prinf('after d3mstrcr, nlev =*',nlev,1)
      call prinf('after d3mstrcr, lsd777 =*',lsd777,1)
      call prinf('after d3mstrcr, ninire =*',ninire,1)
c
      if(ierriv .ne. 0)then
        ier = 3
        return
      endif
c
      if(size .eq. 0)then
        ier = 4
        return
      endif
c
      call getflagclose3d(epsclose, iflagclose,
     1    work(iiwork), laddr, nlev, size, maxppb)
c
      call prinf('after getflag, iflagclose =*',iflagclose,1)
c
      if(iflagclose .eq. 1)then
        ier = 1
      endif
c
      call prinf('maxppb =*',maxppb,1)
      call prinf('nboxes =*',nboxes,1)
      call prinf('completed building data structure*',0,0)
      call prin2('the box center is =*',cntr00,3)
      call prin2('length of side of computational domain =*',size,1)
      call prinf('total number of boxes created =*',nboxes,1)
      call prinf('nlev =*',nlev,1)
      call prinf('number of refinement levels =*',nlev+1,1)
      call prinf('laddr structure =*',laddr,2*(nlev+1))
c
c ===== arranging the integer *4 work space and initializing =====
c
      irem=lenw
      inext=1
c
c ... the first block of work stores iz:
c
      iiz=inext
      ithis=nsources/ninire+7
      irem=irem-ithis
      inext=inext+ithis
c
c ... the third block of work stores iwork:
c
      iiiwork=inext
      ithis=lsd777/ninire+7
      irem=irem-ithis
      if (irem .lt. 0) goto 3000
      inext=inext+ithis
c
      if(iiiwork .lt. iiwork)then
        do 2500 i=0,ithis-1
          work(iiiwork+i) = work(iiwork+i)
 2500   continue
      else
        do 2700 i = ithis-1, 0, -1
          work(iiiwork+i) = work(iiwork+i)
 2700   continue
      endif
c
      iiwork=iiiwork
c
c ... this block of work stores numfour:
c
      inumf=inext
      ithis=nlambs/ninire+7
      irem=irem-ithis
      if (irem .lt. 0) goto 3000
      inext=inext+ithis
c
      call ntfour(work(inumf),nlambs,nxtot,nthmax)
c
c ... this block of work stores numphys:
c
      inump=inext
      ithis=nlambs/ninire+7
      irem=irem-ithis
      if (irem .lt. 0) goto 3000
      inext=inext+ithis
c
c
      call nthalf(work(inump),nlambs,nxtotp)
c
c ... this block of work stores imap (for lolo and tata):
c
      iimap=inext
      ithis=limap/ninire+7
      irem=irem-ithis
      if (irem .lt. 0) goto 3000
      inext=inext+ithis
c
      icntrs = inext
      ithis = 3 * nboxes + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis      
c
      call d3mgetcenters(ierriv,nboxes,work(icntrs),work(iiwork))
c
      if(ierriv .ne. 0)then
        ier = 3
        return
      endif
c
c
c ===== arranging the real *8 work space and initializing =====
c
      nrem=irem
      nnext=inext
c
c ... this block stores mpole:
c
      nmpole=nnext
      nthis=(nterms+1)*(nterms+2)*nboxes+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c
c ... this block stores local:
c
      nlocal=nnext
      nthis=(nterms+1)*(nterms+2)*nboxes+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores the square root of binomial coef dc:
c
      ndc=nnext
      nthis=(4*nterms+1)*(4*nterms+1)+7
      nrem=nrem-nthis
      if (nrem .lt. 0) goto 3000
      nnext=nnext+nthis
c
      call bnlcft(work(ndc),work(ndc),4*nterms)
c
c ... this block stores rdplus:
c
      nrdp=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rdminus:
c
      nrdm=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rdsq3:
c
      nrds3=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rdsq3inv:
c
      nrds3inv=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rdmsq3:
c
      nrdms3=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rdmsq3inv:
c
      nrdms3inv=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      if (nrem .lt. 0) goto 3000
      nnext=nnext+nthis
c
      call rotgen(nterms,work(nrdp),work(nrdm),work(nrds3),
     1    work(nrds3inv),work(nrdms3),work(nrdms3inv),work(ndc))
c
c ... this block stores rlams:
c
      nrlams=nnext
      nthis=nlambs+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores whts:
c
      nwhts=nnext
      nthis=nlambs+7
      nrem=nrem-nthis
      if (nrem .lt. 0) goto 3000
      nnext=nnext+nthis
c
      call vwts(work(nrlams),work(nwhts),nlambs)
c
c ... this block stores lexp:
c
      nlexp=nnext
      nthis=2*nxtotp*nboxes+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores arr (used by tata and lolo):
c
      narr=nnext
      nthis=larr+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mexpf1:
c
      nmxf1=nnext
      nthis=2*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mexpp1:
c
      nmxp1=nnext
      nthis=2*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mexppall:
c
      nmxpal=nnext
      nthis=2*8*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores xs:
c
      nxs=nnext
      nthis=2*3*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores ys:
c
      nys=nnext
      nthis=2*3*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores zs:
c
      nzs=nnext
      nthis=3*nxtotp+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mw1:
c
      nmw1=nnext
      nthis=2*(nterms+1)*(nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mw2:
c
      nmw2=nnext
      nthis=2*(nterms+1)*(nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mw3:
c
      nmw3=nnext
      nthis=2*(nterms+1)*(nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mws1:
c
      nmws1=nnext
      nthis=2*(nshort+1)*(nshort+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores pptmp:
c
      npptmp=nnext
      nthis=(n22+2)*(n22+2)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rd:
c
      nrd=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      if (nrem .lt. 0) goto 3000
      nnext=nnext+nthis
c
c ... this block stores w:
c
      nw = nnext
c
      nthis = (4 * (nterms+1) + 2) * (2*nterms+1)
     1      +  4 * (nshort+1) * (2*nshort+1) + 200
c
      nrem = nrem - nthis
c
      lwrem = nthis
c
      if(nrem .lt. 0) goto 3000 
c
      nnext = nnext + nthis
c
c
      nfinal = nnext - 1
c
      call prinf('nfinal =*',nfinal,1)
c
c ... create the inform array:
c
      inform(1) = nlev+1
      inform(2) = nboxes
      inform(3) = nterms
      inform(4) = nxtotp
      inform(5) = nfinal
c
c ... get some tables:
c
      call mkexps3d(work(nrlams), nlambs, work(inump), nxtotp,
     1              work(nxs), work(nys), work(nzs))
      call lolget(ndigit, work(narr), work(iimap))
c
c ... call the main fmm subroutine:
c
      call adapfmmpart3d(ieradap, iflagtype, iderivonoff, nlev,
     1    nsources, nterms, nshort, n22, maxppb, nboxes, nlambs,
     2    work(inumf), work(inump), nxtot, nxtotp, nthmax, work(iimap),
     3    sources, monocharge, dipstr, dipvec, pot, potx, poty, potz,
     4    work(icntrs), size, work(nmpole), work(nlocal), work(ndc),
     5    work(nrdp), work(nrdm), work(nrds3), work(nrds3inv),
     6    work(nrdms3), work(nrdms3inv), work(nwhts), work(nrlams),
     7    work(nlexp), work(narr), work(nmxf1), work(nmxp1),
     8    work(nmxpal), work(nxs), work(nys), work(nzs), work(nmw1),
     9    work(nmw2), work(nmw3), work(nmws1), work(npptmp),
     1    work(nrd), epsclose, ndigit, close, work(nw), lwrem,
     2    work(iiz), work(iiwork), laddr)
c
      if(ieradap .ne. 0)then
        ier = 7
        return
      endif
c
      return
c
 3000 continue
c
      ier = 3
c
      return
      end
c
c
c
c
c
      subroutine fmmparttarg3d(sources, nsources, targets, ntargets,
     1      monocharge, dipstr, dipvec, pot, potx, poty, potz,
     2      pottar, pottarx, pottary, pottarz, work, lenw, iprec,
     3      iflagtype, iderivonoff, itargflag, idivideon,
     4      close, epsclose, ier, inform)
      implicit real *8(a-h,o-z)
c
c     the following subroutine takes as input an array of source strengths
c     and locations and returns the potential and field (if desired)
c     at each of the source locations on output.
c
c     sources can be either monopoles, dipoles, or a combination of
c     the two.  specification of dipole sources requires both a strength
c     (dipstr) and an orientation (a unit vector, dipvec).
c
c     pottar(y_i) = sum (j=1..n) monocharge_j * 1 / |y_i - x_j|
c                 - dipstr_j * (dipvec_j,(y_i-x_j)) / |y_i - x_j|^3
c
c            (y_i denotes target locations and x_j source locations)
c
c     pot(x_i) = sum (j=1..n, j <> i) monocharge_j * 1 / |x_i - x_j|
c              - dipstr_j * (dipvec_j,(x_i-x_j)) / |x_i - x_j|^3
c
c
c     INPUT PARAMETERS:
c
c     sources(3,nsources) (real *8):  sources(1,i) is the x coordinate of ith
c                                                  source
c                                     sources(2,i) is the y coordinate of ith
c                                                  source
c                                     sources(3,i) is the z coordinate of ith
c                                                  source
c
c     nsources (integer *4):          number of sources
c
c     targets(3,ntargets) (real *8):  targets(1,i) is the x coordinate of ith
c                                                  target
c                                     targets(2,i) is the y coordinate of ith
c                                                  target
c                                     targets(3,i) is the z coordinate of ith
c                                                  target
c
c     ntargets (integer *4):          number of targets
c
c     monocharge(nsources) (real *8): monocharge(i) is the charge of ith
c                                     monopole source
c
c     dipstr(nsources) (real *8):  dipstr(i) is the strength of ith
c                                  dipole source
c
c     dipvec(3,nsources) (real *8):   (dipvec(1,i), dipvec(2,i), dipvec(3,i))
c                                  is the orientation vector for ith dipole
c
c     iprec (integer *4):             user-specified parameter that determines
c                                     the desired precision
c
c                                     (iprec = 0  -> 3 digit accuracy)
c                                     (iprec = 1  -> 6 digit accuracy)
c                                     (iprec = 2  -> 9 digit accuracy)
c                                     (iprec = 3  -> 14 digit accuracy)
c
c     iflagtype (integer *4):         user-specified flag denoting whether
c                                     monopoles, dipoles, or both are present
c
c                                     (iflagtype = 0 -> only monopoles)
c                                     (iflagtype = 1 -> only dipoles)
c                                     (iflagtype = 2 -> monopoles and dipoles)
c
c     NOTE:   Unused arrays do not need to be allocated in full. Thus, if
c     iflagtype = 0, dipstr can be dimensioned as a scalar and dipvec can
c     be dimensioned as dipvec(3) - BUT NOT dipvec(1).
c
c     itargflag (integer *4)          user-specified flag that indicates
c                                     if the solution is to be computed
c                                     at the sources and targets or at
c                                     the targets only.
c
c                    (itargflag = 0 just compute the solution at the targets)
c                    (itargflag = 1 compute the solution at targets and sources)
c
c     NOTE:   Unused arrays do not need to be allocated in full.  If
c     itargflag = 0, then pot, potx, poty, and potz can be dimensioned
c     as scalars.
c
c     idivideon (integer *4):         user-specified flag that indicates
c                                     if the riverdale tree should be
c                                     formed by dividing on the sources,
c                                     targets, or both
c
c                      (idivideon = 0 just divide on the sources)
c                      (idivideon = 1 just divide on the targets)
c                      (idivideon = 2 divide on both sources and targets)
c
c     work(lenw) (real *8):            real work array
c
c     lenw (integer *4):               length of work
c                                      (must be at least 20 * nsources)
c
c     iderivonoff (integer *4):        user-specified flag denoting whether
c                                      or not the first derivatives are to
c                                      be computed
c
c                                      (iderivonoff = 0 -> don't compute)
c                                      (iderivonoff = 1 -> compute derivatives)
c
c     NOTE:   Unused arrays do not need to be allocated in full. 
c     If iderivonoff = 0, potx, poty, and potz can be dimensioned as scalars.
c
c     epsclose (real *8):
c
c       In many applications, the interaction between particles is
c       Coulombic or gravitational at large distances, but more
c       complicated in the near field. The parameter epsclose determines
c       the cutoff distance at which a user-provided subroutine
c       takes responsibility for computing the pairwise interaction.
c       More precisely, if the distance between two sources is less
c       than epsclose, then their interaction is handled by
c       the  user-provided routine close (see below).
c       An important consequence of this parameter is that the quad-tree
c       created by FMMPART halts when the dimensions of a box are comparable
c       to epsclose. This can result in significant performance
c       degradation if many sources are within a distance epsclose
c       of each other. Thus, if pure Coulomb interactions are desired,
c       the user should set epsclose = 0.
c
c     close subroutine: (see the close.f file)
c
c       A user-provided subroutine evaluating the pairwise
c       interaction between particles when they are closer to each
c       other than the distance epsclose (see above).
c       The user must declare the subroutine being used for
c       close encounters as external in the calling program.
c       The user must also be sure that the calling
c       sequence of close conforms to the description in
c       the describe file.
c
c     OUTPUT PARAMETERS:
c
c     pot(nsources) (real *8):          pot(i) is the potential at the
c                                       ith source
c
c     potx(nsources), poty(nsources), potz(nsources) (real *8):
c                                     potx(i) is the x derivative of
c                                       the potential at the ith source
c                                     poty(i) is the y derivative of
c                                       the potential at the ith source
c                                     potz(i) is the z derivative of
c                                       the potential at the ith source
c
c     pottar(nsources) (real *8):     pottar(i) is the potential at the
c                                     ith target
c
c     pottarx(nsources), pottary(nsources), pottarz(nsources) (real *8):
c                                     pottarx(i) is the x derivative of
c                                       the potential at the ith target
c                                     pottary(i) is the y derivative of
c                                       the potential at the ith target
c                                     pottary(i) is the z derivative of
c                                       the potential at the ith target
c
c     ier (integer *4) error flag.
c                 (ier = 0  -> normal execution)
c                 (ier = 1  -> normal execution, but epsclose restricts
c                              the amount of division, performance
c                              may be degraded)
c                 (ier = 2  -> one or several input flags not properly
c                              defined, terminal error)
c                 (ier = 3  -> not enough memory provided,
c                              terminal error)
c                 (ier = 4  -> size of box generated for these boxes
c                              is of size zero.  major problem, terminal)
c                 (ier = 5  -> invalid choice of epsclose, solution
c                              not attempted)
c                 (ier = 6  -> invalid nsources value, solution
c                              not attempted)
c
c      inform(5) (integer *4): inform array contains information 
c                              after successful execution of the code
c
c                 (inform(1) = number of refinement levels)
c                 (inform(2) = total number of boxes in the quadtree)
c                 (inform(3) = order of mpole and local expansions)
c                 (inform(4) = order of plane wave expansions)
c                 (inform(5) = total amount of workspace used)
c
c------------------------------------------------------------------------------
c
c
      integer *4  ndigit, ier, inform(1), nums(5), idirect,
     1      iflagtype, iderivonoff, itargflag, idivideon, nsources,
     2      nlev, nboxes, nlambs, nterms, nshort, n22, iernin, maxppb,
     3      laddr(2,200), iflagclose, lenw, ninire, ntargets, nall,
     4      ifempty, maxlevel, ieradap
c
      real *8  epsclose, sources(3,1), monocharge(1), dipstr(1),
     1      targets(3,1), dipvec(3,1), cntr00(3), size, work(1),
     2      tmppot, tmpfld(3), pot(1), potx(1), poty(1), potz(1),
     3      pottar(1), pottarx(1), pottary(1), pottarz(1)
      external  close
c
c     maxppb is the maximum number of points per leaf box allowed.
c     it is based on ndigit. the user can vary mildly from the number
c     giveing below to get optimal run time.
c               iprec=0  --> maxppb=40
c               iprec=1  --> maxppb=100
c               iprec=2  --> maxppb=180
c               iprec=3  --> maxppb=300
c
      ier = 0
c
c     initialize the inform array to zero
c
      inform(1) = 0
      inform(2) = 0
      inform(3) = 0
      inform(4) = 0
      inform(5) = 0
c
      if(iprec .ne. 0 .and. iprec .ne. 1 .and.
     2   iprec .ne. -2 .and. iprec .ne. -1 .and.
     1   iprec .ne. 2 .and. iprec .ne. 3)then
        ier = 2
        return
      endif
c
      if(iflagtype .ne. 0 .and.
     1   iflagtype .ne. 1 .and.
     2   iflagtype .ne. 2)then
        ier = 2
        return
      endif
c
      if(iderivonoff .ne. 0 .and.
     1   iderivonoff .ne. 1)then
        ier = 2
        return
      endif
c
      if(idivideon .ne. 0 .and.
     1   idivideon .ne. 1 .and.
     2   idivideon .ne. 2)then
        ier = 2
        return
      endif
c
      if(epsclose .lt. 0d0)then
        ier = 5
        return
      endif
c
      if(nsources .le. 1)then
        ier = 6
        return
      endif
c
      call prinf('iflagtype =*',iflagtype,1)
      call prinf('the number of particles =*',nsources,1)
      call prin2('the near approach distance is =*',epsclose,1)
c
c ... if the number of particles is small, simply call the direct 
c     subroutine.
c
      idirect = 0
c
      nall = nsources + ntargets
c
      if(iprec .eq.-2 .and. nall .le. 999)  idirect = 1
      if(iprec .eq.-1 .and. nall .le. 999)  idirect = 1
      if(iprec .eq. 0 .and. nall .le. 999)  idirect = 1
      if(iprec .eq. 1 .and. nall .le. 1499) idirect = 1
      if(iprec .eq. 2 .and. nall .le. 2199) idirect = 1
      if(iprec .eq. 3 .and. nall .le. 3199) idirect = 1
c
      if(idirect .eq. 1)then
c
c       Compute potential at sources only if itargflag is 1
c
	if (itargflag .eq. 1) then
          do 1000 i = 1, nsources
            call direct3d(i, iflagtype, iderivonoff, nsources,
     1          sources, monocharge, dipstr, dipvec,
     2          sources(1,i), tmpfld, tmppot, epsclose, close)
c
            pot(i)  = tmppot
c
            if(iderivonoff .eq. 1)then
              potx(i) = tmpfld(1)
              poty(i) = tmpfld(2)
              potz(i) = tmpfld(3)
            endif
c
 1000     continue
	endif
c
        do 1500 i = 1, ntargets
          call directtarg3d(iflagtype, iderivonoff, nsources,
     1        sources, monocharge, dipstr, dipvec,
     2        targets(1,i), i, tmpfld, tmppot, epsclose, close)
c
          pottar(i)  = tmppot
c
          if(iderivonoff .eq. 1)then
            pottarx(i) = tmpfld(1)
            pottary(i) = tmpfld(2)
            pottarz(i) = tmpfld(3)
          endif
c
 1500   continue
c
        return
      endif
c
c ... call to get the machine dependent ninire (a number indicates
c     how many interger *4 numbers are stored in a real *8
c     space).
c
      call mkninire(ninire, iernin)
c THIS IS A HACK, TO BE FIXED
      if (iernin .ne. 0) then
          ninire = 2
      endif
c
      call prinf('ninire =*',ninire,1)
c
c ... set the user-provided work array space to integer zero:
c
      do 2000 i = 1, lenw
        work(i) = -7717d0
 2000 continue
c
c ... based on the given precision requirement (number of digits 
c     desired), determining parameters:nterms,n22,nshort,nlambs
c
      call getints(iprec, maxppb, ndigit, nterms,
     1             n22, nshort, nlambs, limap, larr)
c
      call prinf('required digits of accuracy =*',ndigit,1)
      call prinf('maximum number charges per box =*',maxppb,1)
c
c ... call the book keeping subroutine to get the data structures:
c
      maxnbx = nall
c
      irem = lenw
      inext = 1
c
      mall = inext
      ithis = 3*nall + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      iiz = inext
ccc      niz = nsources/ninire + 7
      niz = nall / ninire + 7
c
      iiwork = iiz + niz
      liwork = (lenw - iiwork) * ninire
c
c ... the first block of work stores all source locations:
c
      call setupall3d(sources, nsources, targets,
     1      ntargets, work(mall), nall, idivideon)
c
      call prinf('nall is =*',nall,1)
c
      if(idivideon .eq. 0 .or. idivideon .eq. 1)then
c
        ifempty = 1
        maxlevel = 200
c
        call d3mstrcrem(ierriv, work(mall), nall, maxppb, nboxes,
     1      work(iiz), laddr, nlev, cntr00, size,
     2      work(iiwork), liwork, lsd777, epsclose, ninire,
     3      ifempty, maxlevel)
      endif
c
      if(idivideon .eq. 2)then 
        call d3mstrcr(ierriv, work(mall), nall, maxppb, nboxes,
     1      work(iiz), laddr, nlev, cntr00, size,
     2      work(iiwork), liwork, lsd777, epsclose, ninire)
      endif
c
c ... the next block of work stores iz:
c
      iiz = inext
ccc      ithis = nsources/ninire + 7
      ithis = nall/ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
c ... the third block of work stores iwork:
c
      iiiwork = inext
      ithis = lsd777/ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      if(iiiwork .lt. iiwork)then
        do 2500 i=0,ithis-1
          work(iiiwork+i) = work(iiwork+i)
 2500   continue
      else
        do 2700 i = ithis-1, 0, -1
          work(iiiwork+i) = work(iiwork+i)
 2700   continue
      endif
c
      iiwork=iiiwork
c
c ... this block of work stores numfour:
c
      inumf = inext
      ithis = nlambs/ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      call ntfour(work(inumf),nlambs,nxtot,nthmax)
c
c ... this block of work stores numphys:
c
      inump = inext
      ithis = nlambs/ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      call nthalf(work(inump),nlambs,nxtotp)
c
c ... this block of work stores imap (for lolo and tata):
c
      iimap = inext
      ithis = limap/ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      mzboxsour = inext
      ithis = (2 * nboxes + 1) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      mzboxtarg = inext
      ithis = (2 * nboxes + 1) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      mizsour = inext
      ithis = (nsources + 1) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      miztarg = inext
      ithis = (ntargets + 1) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      miworktarg = inext
      ithis = (ntargets + 10) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      miworksour = inext
      ithis = (nsources + 10) / ninire + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      icntrs = inext
      ithis = 3 * nboxes + 7
      irem = irem - ithis
      if (irem .lt. 0) goto 3000
      inext = inext + ithis
c
      call d3malltl(ierriv, sources, nsources, work(mizsour),
     1    work(mzboxsour), work(iiwork), nboxes, laddr, nlev,
     2    cntr00, size, work(miworksour))
c
      call d3malltl(ierriv, targets, ntargets, work(miztarg),
     1    work(mzboxtarg), work(iiwork), nboxes, laddr, nlev,
     2    cntr00, size, work(miworktarg))
c
      if(ierriv .ne. 0)then
        ier = 3
        return
      endif
c
      if(size .eq. 0)then
        ier = 4
        return
      endif
c
      call getflagclose3d(epsclose, iflagclose,
     1    work(iiwork), laddr, nlev, size, maxppb)
c
      call prinf('after getflag, iflagclose =*',iflagclose,1)
c
      if(iflagclose .eq. 1)then
        ier = 1
      endif
c
      call d3mgetcenters(ierriv,nboxes,work(icntrs),work(iiwork))
c
      if(ierriv .ne. 0)then
        ier = 3
        return
      endif
c
      call prinf('maxppb =*',maxppb,1)
      call prinf('nboxes =*',nboxes,1)
      call prinf('completed building data structure*',0,0)
      call prin2('the box center is =*',cntr00,3)
      call prin2('length of side of computational domain =*',size,1)
      call prinf('total number of boxes created =*',nboxes,1)
      call prinf('nlev =*',nlev,1)
      call prinf('number of refinement levels =*',nlev+1,1)
      call prinf('laddr structure =*',laddr,2*(nlev+1))
c
c ===== arranging the real *8 work space and initializing =====
c
      nrem = irem
      nnext = inext
c
c ... this block stores mpole:
c
      nmpole = nnext
      nthis = (nterms+1)*(nterms+2)*nboxes + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores local:
c
      nlocal = nnext
      nthis = (nterms+1)*(nterms+2)*nboxes + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores the square root of binomial coef dc:
c
      ndc = nnext
      nthis = (4*nterms+1)*(4*nterms+1) + 7
      nrem = nrem - nthis
      if (nrem .lt. 0) goto 3000
      nnext = nnext + nthis
c
      call bnlcft(work(ndc),work(ndc),4*nterms)
c
c ... this block stores rdplus:
c
      nrdp = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores rdminus:
c
      nrdm = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores rdsq3:
c
      nrds3 = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores rdsq3inv:
c
      nrds3inv = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores rdmsq3:
c
      nrdms3 = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores rdmsq3inv:
c
      nrdms3inv = nnext
      nthis = (nterms+1)*(nterms+1)*(2*nterms+1) + 7
      nrem = nrem - nthis
      if (nrem .lt. 0) goto 3000
      nnext = nnext + nthis
c
      call rotgen(nterms,work(nrdp),work(nrdm),work(nrds3),
     *    work(nrds3inv),work(nrdms3),work(nrdms3inv),work(ndc))
c
c ... this block stores rlams:
c
      nrlams = nnext
      nthis = nlambs + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores whts:
c
      nwhts = nnext
      nthis = nlambs + 7
      nrem = nrem - nthis
      if (nrem .lt. 0) goto 3000
      nnext = nnext + nthis
c
      call vwts(work(nrlams),work(nwhts),nlambs)
c
c ... this block stores lexp:
c
      nlexp = nnext
      nthis = 2*nxtotp*nboxes + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores arr (used by tata and lolo):
c
      narr = nnext
      nthis = larr + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores mexpf1:
c
      nmxf1 = nnext
      nthis = 2*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores mexpp1:
c
      nmxp1 = nnext
      nthis = 2*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores mexppall:
c
      nmxpal = nnext
      nthis = 2*8*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores xs:
c
      nxs = nnext
      nthis = 2*3*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores ys:
c
      nys = nnext
      nthis = 2*3*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores zs:
c
      nzs = nnext
      nthis = 3*nxtotp + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores mw1:
c
      nmw1 = nnext
      nthis = 2*(nterms+1)*(nterms+1) + 7
      nrem = nrem - nthis
      nnext = nnext + nthis
c
c ... this block stores mw2:
c
      nmw2 = nnext
      nthis = 2*(nterms+1)*(nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mw3:
c
      nmw3=nnext
      nthis=2*(nterms+1)*(nterms+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores mws1:
c
      nmws1=nnext
      nthis=2*(nshort+1)*(nshort+1)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores pptmp:
c
      npptmp=nnext
      nthis=(n22+2)*(n22+2)+7
      nrem=nrem-nthis
      nnext=nnext+nthis
c
c ... this block stores rd:
c
      nrd=nnext
      nthis=(nterms+1)*(nterms+1)*(2*nterms+1)+7
      nrem=nrem-nthis
      if (nrem .lt. 0) goto 3000
      nnext=nnext+nthis
c
c ... this block stores w:
c
ccc      nw=nnext
ccc      lwrem=nrem
c
      nw = nnext
c
      nthis = (4 * (nterms+1) + 2) * (2*nterms+1)
     1      +  4 * (nshort+1) * (2*nshort+1) + 200
c
      nrem = nrem - nthis
c
      lwrem = nthis
c
      if(nrem .lt. 0) goto 3000
c
      nnext = nnext + nthis
c
c
      nfinal = nnext - 1
c
      call prinf('nfinal =*',nfinal,1)
c
c ... create the inform array:
c
      inform(1) = nlev+1
      inform(2) = nboxes
      inform(3) = nterms
      inform(4) = nxtotp
      inform(5) = nfinal
c
c ... get some tables:
c
      call mkexps3d(work(nrlams),nlambs,work(inump),nxtotp,work(nxs),
     1     work(nys),work(nzs))
      call lolget(ndigit,work(narr),work(iimap))
c
c ... call the main fmm subroutine:
c
c      write(*,*)'calling adapfmmparttarg3d'
c
      call adapfmmparttarg3d(ieradap, iflagtype, iderivonoff, itargflag,
     1    nlev, nsources, ntargets, nterms, nshort, n22, maxppb, nboxes,
     2    nlambs, work(inumf), work(inump), nxtot, nxtotp, nthmax,
     3    work(iimap), sources, targets, monocharge, dipstr, dipvec,
     4    pot, potx, poty, potz, pottar, pottarx, pottary, pottarz,
     5    work(icntrs), size, work(nmpole), work(nlocal), work(ndc),
     6    work(nrdp), work(nrdm), work(nrds3), work(nrds3inv),
     7    work(nrdms3), work(nrdms3inv), work(nwhts), work(nrlams),
     8    work(nlexp), work(narr), work(nmxf1), work(nmxp1),
     9    work(nmxpal), work(nxs), work(nys), work(nzs), work(nmw1),
     1    work(nmw2), work(nmw3), work(nmws1), work(npptmp),
     2    work(nrd), epsclose, ndigit, close, work(nw), lwrem,
     3    work(iiwork), laddr, work(mzboxsour),
     4    work(mizsour), work(mzboxtarg), work(miztarg))
c
      if(ieradap .ne. 0)then
        ier = 7
        return
      endif
c
c
	return
c
 3000 continue
c
        ier = 3
c
	return
	end
c
c
c
c
c
      subroutine adapfmmpart3d(ierout, iflagtype, iderivonoff,
     1     nlev, nsources, nterms, nshort, n22, maxppb, nboxes,
     2     nlambs, numfor, numpys, nxtot, nxtotp, nthmax, imap,
     3     sources, monocharge, dipstr, dipvec, pot, potx, poty, potz,
     4     centrs, size, mpole, local, dc, rdplus, rdminu, rdsq3,
     5     rdsq3inv, rdmsq3, rdmsq3inv, whts, rlams, lexp1, arr,
     6     mexpf1, mexpp1, mxpall, xs, ys, zs, mw1, mw2, mw3, mws1,
     7     pptmp, rd, eps, ndigit, close, w, lw, iz, iw, laddr)
c
      implicit real *8 (a-h,o-z)
      save
c
c Purpose:
c	This is the MAIN subroutine of the Laplace FMM, based upon 
c	multipole and exponential expansions. Two passes are executed. 
c	In the first pass, multipole expansions for all boxes at all 
c	levels are computed. In the second pass, interactions are 
c	computed at successively finer levels.
c
c Inputs:
c	nlev: number of level of refining of the unit cube
c	nsources: number of charged sources
c	nterms: the order of the multipole expansion
c
c	sources(3,*): the charge distribution locations (in unit cube)
c	monocharge(*): the monocharge strength
c	dipstr(*): the dipstr strength (if provided)
c
c
c
c Outputs:
c	pot(*): the computed potentials at each points
c	field(3,*): the field at each points (if desired)
c
c
c Workspace:
c
c----------------------------------------------------------------------------
c
c
      integer *4  nlev, nterms, nsources, imap(1), nboxes, lw,
     1     iflagtype, iderivonoff, iz(1), iw(1), laddr(2,1), ierout,
     2     numfor(1), numpys(1)
c
      real *8  centrs(3,1), size, centr0(3), arr(1), sources(3,1),
     1    monocharge(1), dipstr(1), dipvec(3,1), zs(3,nxtotp), w(1),
     2    zrot(8), scale(0:201), pot(1), potx(1), poty(1), potz(1),
     3    rdplus(0:nterms,0:nterms,-nterms:nterms),
     4    rdminu(0:nterms,0:nterms,-nterms:nterms),
     5    rdsq3(0:nterms,0:nterms,-nterms:nterms),
     6    rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     7    rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     8    rdmsq3inv(0:nterms,0:nterms,-nterms:nterms),
     9    rd(0:nterms,0:nterms,-nterms:nterms), whts(nlambs),
     1    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2))
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1    local((nterms+1)*(nterms+2)/2,*),
     2    lexp1(nxtotp,*), mexpf1(nxtot), mexpp1(nxtotp),
     3    mxpall(nxtotp,8), xs(3,nxtotp), ys(3,nxtotp),
     4    mw1(0:nterms,0:nterms), mw2(0:nterms,0:nterms),
     5    mw3(0:nterms,0:nterms), mws1(0:nshort,0:nshort)
      external close
c
c ... initialize multipole and local expansions to zero.
c ... get the z-rotation angles:
c
c
        call initializepart3d(nboxes, nterms, nsources, nlev,
     1      mpole, local, pot, potx, poty, potz, scale, size,
     2      zrot, iderivonoff)
c
        call prinf('    BEGIN UPWARD PASS ... *',0,0)
c
        ierout = 0
c
        call uppassriv3d(ierout, nboxes, nterms, n22, iflagtype,
     1      centr0, sources, monocharge, dipstr, dipvec, pptmp,
     2      dc, mw3, scale, mpole, nlev, mws1, nshort,
     3      lw, w, imap, arr, rdsq3inv, rdsq3, mw1, zrot,
     4      rdmsq3inv, rdmsq3, iz, laddr, iw)
c
        if(ierout .ne. 0) return
c
c       return if the error flag is not appropriate value
c
        call prinf('    ... FINISHED UPWARD PASS * ',0,0)
c
        call prinf('    BEGIN DOWNWARD PASS ... *',0,0)
c
        call downpassriv3d(iflagtype, iderivonoff, nlev, nterms,
     1      ndigit, imap, nlambs, nxtotp, nxtot, n22, nshort, 
     2      w, lw, nthmax, numpys, numfor, centrs, centr0, sources,
     3      monocharge, dipstr, dipvec, eps, rlams,
     4      pot, potx, poty, potz, arr, zs, rdplus, rdminu, rdsq3,
     5      rdsq3inv, rdmsq3, rdmsq3inv, rd, dc, whts, pptmp, scale,
     6      zrot, mpole, local, lexp1, mexpf1, mexpp1, mxpall, xs, ys,
     7      mw1, mw2, mw3, mws1, iz, laddr, iw, maxppb, nboxes)
c
        call prinf('    ... FINISHED DOWNWARD PASS *',0,0)
c
        call prinf('    BEGIN LOCAL EXPANSION EVALUATION ... *',0,0)
c
        call localevalriv3d(nboxes, iderivonoff, pot, potx, poty, potz,
     1      nterms, scale, dc, pptmp, n22, sources, local, iz, iw)
c
        call prinf('    ... FINISHED LOCAL EXPANSION EVALUATION*',0,0)
c
        call prinf('    BEGIN LOCAL INTERACTION PHASE ... *',0,0)
c
        call localintriver3d(iflagtype, iderivonoff, nlev, nboxes,
     1      centr0, sources, monocharge, dipstr, dipvec,
     2      pot, potx, poty, potz, eps, close, iz, iw)
c
        call prinf('    ... FINISHED LOCAL INTERACTION PHASE * ',0,0)
c
      return
      end
c
c
c
c
c
      subroutine adapfmmparttarg3d(ierout, iflagtype, iderivonoff, 
     1   itargflag, nlev, nsources, ntargets, nterms, nshort, n22,
     2   maxppb, nboxes, nlambs, numfor, numpys, nxtot, nxtotp, nthmax,
     3   imap, sources, targets, monocharge, dipstr, dipvec, pot, potx,
     4   poty, potz, pottar, pottarx, pottary, pottarz, centrs, size,
     5   mpole, local, dc, rdplus, rdminu, rdsq3, rdsq3inv, rdmsq3,
     6   rdmsq3inv, whts, rlams, lexp1, arr, mexpf1, mexpp1, mxpall,
     7   xs, ys, zs, mw1, mw2, mw3, mws1, pptmp, rd, eps, ndigit,
     8   close, w, lw, iw, laddr, zboxsour, izsour, zboxtarg, iztarg)
      implicit real *8 (a-h,o-z)
      save
c
c Purpose:
c	This is the MAIN subroutine of the Laplace FMM, based upon 
c	multipole and exponential expansions. Two passes are executed. 
c	In the first pass, multipole expansions for all boxes at all 
c	levels are computed. In the second pass, interactions are 
c	computed at successively finer levels.
c
c Inputs:
c	nlev: number of level of refining of the unit cube
c	nsources: number of charged sources
c	nterms: the order of the multipole expansion
c
c	sources(3,*): the charge distribution locations (in unit cube)
c	monocharge(*): the monocharge strength
c	dipstr(*): the dipstr strength (if provided)
c
c
c
c Outputs:
c	pot(*): the computed potentials at each points
c	field(3,*): the field at each points (if desired)
c
c
c Workspace:
c
c----------------------------------------------------------------------------
c
c
      integer *4  nlev, nterms, nsources, imap(1), nboxes, w(1), lw,
     1  iflagtype, iderivonoff, itargflag, zboxsour(2,1), iw(1), ierout,
     2  izsour(1), ntargets, zboxtarg(2,1), iztarg(1), laddr(2,1)
c
      real *8  centrs(3,1), size, centr0(3), arr(1), sources(3,1),
     1  monocharge(1), dipstr(1), dipvec(3,1), zs(3,nxtotp), zrot(8),
     2  rdplus(0:nterms,0:nterms,-nterms:nterms),
     3  rdminu(0:nterms,0:nterms,-nterms:nterms), 
     4  rdsq3(0:nterms,0:nterms,-nterms:nterms),
     5  rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     6  rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     7  rdmsq3inv(0:nterms,0:nterms,-nterms:nterms),
     8  rd(0:nterms,0:nterms,-nterms:nterms), targets(3,1),
     9  dc(0:4*nterms,0:4*nterms), whts(nlambs), scale(0:201),
     1  pptmp((n22+2)*(n22+2)), pot(1), potx(1), poty(1), potz(1),
     2  pottar(1), pottarx(1), pottary(1), pottarz(1)
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*), lexp1(nxtotp,*),
     1  local((nterms+1)*(nterms+2)/2,*), mexpf1(nxtot),
     2  mexpp1(nxtotp), mxpall(nxtotp,8), xs(3,nxtotp), ys(3,nxtotp),
     3  mw1(0:nterms,0:nterms), mw2(0:nterms,0:nterms),
     4  mw3(0:nterms,0:nterms), mws1(0:nshort,0:nshort)
      external  close
c
c ... initialize multipole and local expansions to zero.
c ... get the z-rotation angles:
c
      call initializeparttarg3d(nboxes, nterms, nsources, ntargets,
     1    nlev, mpole, local, pot, potx, poty, potz,
     2    pottar, pottarx, pottary, pottarz,
     3    scale, size, zrot, iderivonoff, itargflag)
c
      ierout = 0
c
      call prinf('    BEGIN UPWARD PASS ... *',0,0)
c
      call uppassrivtarg3d(ierout, nboxes, nterms, n22, iflagtype,
     1    centr0, sources, monocharge, dipstr, dipvec, pptmp,
     2    dc, mw3, scale, mpole, nlev, mws1, nshort,
     3    lw, w, imap, arr, rdsq3inv, rdsq3, mw1, zrot,
     4    rdmsq3inv, rdmsq3, laddr, iw, izsour, zboxsour)
c
	if (ierout .ne. 0) return
c
      call prinf('    ... FINISHED UPWARD PASS * ',0,0)
c
      call prinf('    BEGIN DOWNWARD PASS ... *',0,0)
c
      call downpassrivtarg3d(iflagtype, iderivonoff, nlev, nterms,
     1    ndigit, imap, nlambs, nxtotp, nxtot, n22, nshort, 
     2    w, lw, nthmax, numpys, numfor, centrs, centr0, sources,
     3    monocharge, dipstr, dipvec, eps, rlams, pot, potx,
     4    poty, potz, targets, pottar, pottarx, pottary, pottarz,
     5    arr, zs, rdplus, rdminu, rdsq3, rdsq3inv, rdmsq3, rdmsq3inv,
     6    rd, dc, whts, pptmp, scale, zrot, mpole, local, lexp1,
     7    mexpf1, mexpp1, mxpall, xs, ys, mw1, mw2, mw3, mws1, 
     8    laddr, iw, izsour, zboxsour, iztarg, zboxtarg, itargflag)
c
      call prinf('    ... FINISHED DOWNWARD PASS *',0,0)
c
      call prinf('    BEGIN LOCAL EXPANSION EVALUATION ... *',0,0)
c
      call localevalrivtarg3d(nboxes, iderivonoff, pot, potx, poty,
     1    potz, pottar, pottarx, pottary, pottarz, nterms, scale,
     2    dc, pptmp, n22, sources, targets, local, iw,
     3    izsour, zboxsour, iztarg, zboxtarg, itargflag)
c
      call prinf('    ... FINISHED LOCAL EXPANSION EVALUATION*',0,0)
c
      call prinf('    BEGIN LOCAL INTERACTION PHASE ... *',0,0)
c
      call localintrivtarg3d(iflagtype, iderivonoff, nterms, nlev,
     1    nboxes, maxppb, n22, centr0, sources, monocharge,
     2    dipstr, dipvec, pot, potx, poty, potz, targets,
     3    pottar, pottarx, pottary, pottarz, dc, pptmp, scale,
     4    eps, mpole, mw3, close, iw, izsour, zboxsour,
     5    iztarg, zboxtarg, itargflag)
c
      call prinf('    ... FINISHED LOCAL INTERACTION PHASE * ',0,0)
c
      return
      end
c
c
c
c
c
      subroutine close1(i, j, eps, xinfo1, xinfo2, iflag, xout)
      implicit real *8(a-h,o-z)
c
c     the following is a sample subroutine that can be
c     provided for handling the close interactions.
c     while the content of the subroutie is determined
c     by the user, the calling sequence must remain the same.
c
c     INPUT PARAMETERS:
c     i (integer*4) index of target
c     j (integer*4) index of source
c
c     eps (real *8) the distance that determines when this
c              subroutine needs to be called
c
c     xinfo1(8) (real *8) vector containing the information
c              for the first (incoming) point in the interaction
c           xinfo1(1) x position of incoming point
c           xinfo1(2) y position of incoming point
c           xinfo1(3) z position of incoming point
c           xinfo1(4) the monopole charge at the incoming point
c           xinfo1(5) the dipole charge at the incoming point
c           xinfo1(6) x part of dipole vector at incoming point
c           xinfo1(7) y part of dipole vector at incoming point
c           xinfo1(8) z part of dipole vector at incoming point
c
c     xinfo2(8) (real *8) vector containing the information
c              for the second (outgoing) point in the interaction
c           xinfo2(1) x position of outgoing point
c           xinfo2(2) y position of outgoing point
c           xinfo2(3) z position of outgoing point
c           xinfo2(4) the monopole charge at the outgoing point
c           xinfo2(5) the dipole charge at the outgoing point
c           xinfo2(6) x part of dipole vector at outgoing point
c           xinfo2(7) y part of dipole vector at outgoing point
c           xinfo2(8) z part of dipole vector at outgoing point
c
c     Note: For cases with targets, xinfo1 entries 1-3 contain
c           the coordinates of the targets and the other entries
c           are blank.  xinfo2 contains the information on the source.
c
c     iflag(2) (integer *4) the array of all flags that must be
c           specified when calling the fmmpart subroutine
c            iflag(1) is iflagtype
c              (indicates whether monopoles, dipoles,
c              or both are present)
c            iflag(2) is iderivonoff
c              (indicates whether or not to compute the
c              derivatives.  1 yes, 0 no)
c
c     OUTPUT PARAMETERS:
c
c     xout(4) (real *8) array of output computed using the
c            techniques specified in the subroutine
c
c           xout(1) will be added to the potential term
c           xout(2) will be added to the x derivative
c           xout(3) will be added to the y derivative
c           xout(4) will be added to the z derivative
c
c     all of these output terms are added to the array positions
c     for particles corresponding to the data in xinfo1
c
c--------------------------------------------------------------------------
c
c
      integer *4  iflag(2), i, j
c
      real *8  eps, xinfo1(8), xinfo2(8), xout(4)
      integer *4  ncntr, ncntr2, ncntr7, nwriteflag
c
      integer *4  nflag
      if (nwriteflag .eq. 1) then
c       -- ap -- replaced with prin2
c       write(14,*)'close routine invoked ',ncntr,' times.'
c       write(14,*)' '
       call prinf('close routine invoke times is *', ncntr, 1)
       nwriteflag = 0
      endif
c
      ncntr = ncntr + 1
c
        xout(1) = 0d0
        xout(2) = 0d0
        xout(3) = 0d0
        xout(4) = 0d0
c
      return
c
      entry closeinit(ncntr7)
         ncntr = ncntr7
         ncntr2 = ncntr7
      return
c
      entry setwriteflag(nflag)
         nwriteflag = nflag
      return
c
      end
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c        This is the 3-d adaptive box data structure code
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c
c
        subroutine d3mstrcrem(ier,z,n,nbox,nboxes,iz,laddr,nlev,
     1    center,size,iwork,lw,lused777,epsclose,ninire,
     2    ifempty,maxlevel)
        implicit real *8 (a-h,o-z)
        save
c
c       Purpose: This subroutine constructs the logical structure for
c       the fully adaptive FMM in three dimensions and stores it in the
c       array w in the form of a link-list.  After that, the user can
c       obtain the information about various boxes and lists in it by
c       calling the entries d3mgetb, d3mgetl, d3mlinfo of this
c       subroutine (see).  Including, a quad-tree of boxes formed, an
c       array of has_kid indicators, and all lists.
c
c Input:
c          z(3,n) - the user-specified points in the space
c          n - the number of elements in array z
c          nbox - the maximum number of points allowed in a childless box
c          lw - the amount of memory in the array w (in integer*4 elements)
c        epsclose - the smallest size a box can be (the length of sides).
c
c  ifempty - keep empty boxes if the user requested so
c     ifempty=0 means that the empty boxes must be removed from the quad-tree.
c     ifempty=1 means that the empty boxes are always kept in the quad-tree,
c           i.e. all boxes are subdivided into 8 smaller boxes
c  maxlevel - the maximum of levels in the quad-tree.
c
c Output:
c          ier - error return code
c               ier=0   means successful execution
c               ier=16 means that the subroutine attempted to construct more
c                  than 199 levels of subdivision; the code will PAUSE
c                 and one should stop to check, for any physically
c                  meaningful distribution of points, it should NOT go
c                  higher than that.
c               ier=32  means that the amount lw of space in array w
c                 is insufficient
c          nboxes - the total number of boxes created
c          iz(n) - the integer array addressing the particles in
c           all boxes. Explanation: for a box ibox, the particles living
c                in it are:
c             (z(1,j),z(2,j),z(3,j)),(z(1,j+1),z(2,j+1),z(3,j+1)),
c             (z(1,j+2),z(2,j+2),z(3,j+3)), . . .
c             (z(1,j+nj-1),z(2,j+nj-1),z(3,j+nj-1)),
c             (z(1,j+nj),z(2,j+nj),z(3,j+nj)),
c           with j=boxes(14,ibox), and nj=boxes(15,ibox)-1
c          laddr(2,200) - an integer array (2,nlev), describing the
c           numbers of boxes on various levels of subdivision, so that
c           the first box on level (i-1) has sequence number laddr(1,i),
c           and there are laddr(2,i) boxes on level i-1
c          nlev - the maximum level number on which any boxes have
c           been created. the maximim number possible is 200.
c           it is recommended that the array laddr above be dimensioned
c           at least (2,200), in case the user underestimates
c           the number of levels required.
c          center(3) - the center of the box on the level 0, containing
c           the whole simulation
c          size - the side of the box on the level 0
c          iwork(lw) - the array containing all tables describing boxes,
c            lists, etc. It is a link-list (for the most part), and can
c            only be accessed via the entries d3mgetb, d3mgetl, d3mlinfo,
c            of this subroutine (see below). The first lused777 integer*4
c           locations of this array should not be altered between the
c           call to this entry and subsequent calls to the entries
c           d3mgetb, d3mgetl, d3mlinfo, of this  subroutine
c          lused777 - the amount of space in the array w (in integer*4
c            words) that is occupied by various tables on exit from this
c           subroutine. this space should not be altered between the
c           call to this entry and subsequent calls to entries d3mgetb,
c           d3mgetl, d3mlinfo, of this  subroutine (see below).
c
c
        integer iz(1),iwork(1),laddr(2,1),box(1),nums(1),list(1)
        dimension z(3,1),center(3),center0(3)
c
c ... First construct the quad-tree structure for given set of points:
c
        data iiboxes/1/,iicenters/2/,iicorners/3/,iiwlists/4/,iikids/5/
        if( lw .lt. 20*n ) then
c
c       the array is simply too small,
c       don't even try the solution
c
        ier=32
        return
        endif
c
        do i=1,lw
          iwork(i)=0
        enddo
c
        iiwork = 1
        liwork = n+4
c
        iboxes = iiwork+liwork
        lboxes = lw-n-5
        maxboxes = lboxes/15-1
c
        call d3mallbem(ier,z,n,nbox,iwork(iboxes),maxboxes,
     1    nboxes,iz,laddr,nlev,center,size,iwork(iiwork),epsclose,
     2    ifempty,maxlevel)
c
c ... If the memory is insufficient - bomb
c
        if (ier .eq. 4) then
cccc         call prinf('FATAL: NOT ENOUGH MEMORY IN D3MALLB, IER=*',IER,1)
           ier = 32
           return
        endif
c
c ... Compress the array w: so the first block of w (of size nboxes*15
c      + 16 and starts from iboxes) is for quad-tree.
c
c     compress, while allocating extra space for the following
c     pointers: iboxes, icenters, icorners, iwlists, ikids.
c
        nn = nboxes*15
        do 1200 i = 1,nn
          iwork(i + 5) = iwork(iboxes+i-1)
 1200 continue
c
        iboxes = 1 + 5
        lboxes = nboxes*15+16
        iwork(iiboxes)=iboxes
c
c ... Construct the array has_kid for all boxes: store it in the second
c        block of w(starts at ikids, of length lkids).
c
        ikids = iboxes+lboxes
        lkids = nboxes+1
        iwork(iikids)=ikids
c
cccc        iwlists = ikids+lkids
cccc        lwlists = lw-iwlists-6
cccc        iwork(iiwlists)=iwlists
c
c
c ... Construct the centers for all boxes in the quad-tree: so the
c       third block of w ( starts at icenters, of size lcenters) stores
c        the center coordinates for all boxes (NOTE: we are storing
c        real *8 numbers in integer*4 storage space, not good, but for
c        simplicity)
c
        icenters = ikids+lkids
        lcenters = (nboxes*3+2)*ninire
        iwork(iicenters)=icenters
cccc
        icorners = icenters+lcenters
        lcorners = (nboxes+2)*ninire
        iwork(iicorners)=icorners
cccc
        iwlists = icorners+lcorners
        lwlists = lw-iwlists-6
        iwork(iiwlists)=iwlists
c
ccc        call prinf('Before d3haskid, lwlists = *',lwlists,1)
        call d3mhaskid(iwork(iwork(iiboxes)),
     $     nboxes,iwork(iwork(iikids)))
ccc        call prinf('After d3haskid, lwlists = *',lwlists,1)
c
ccc        call prinf('Before d3mcentc, lwlists = *',lwlists,1)
c
        call d3mcentc(center,size,iwork(iwork(iiboxes)),nboxes,
     $     iwork(iwork(iicenters)),iwork(iwork(iicorners)))
c
c ... Now, construct all lists for all boxes
c
ccc        call prinf('Before d3mcrealists, available work space:
ccc     1    lwlists = *',lwlists,1)
        call d3mcrealists(ier,iwork(iwork(iiboxes)),nboxes,size,
     1    iwork(iwork(iicenters)),
     2    iwork(iwork(iikids)),iwork(iwork(iiwlists)),lwlists,lused)
c
ccc        lused777 = lused+iwlists+nboxes*3*ninire
        lused777 = lused+iwlists
        if (ier .eq. 32) then
cccc        call prinf('FATAL: Not enough memory in d3mcrealists, ier=*',
cccc     2     ier,1)
        endif
c
        nboxes7 = nboxes
c
        return
        end
c
c
c
c
c
c
c
c
        subroutine d3mallbem(ier,z,npts,nbox,boxes,maxbxs,
     1    nboxes,iz,laddr,nlev,center0,size,iwork,epsclose,
     2    ifempty,maxlevel)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c   This subroutine constructs a quad-tree corresponding to the
c   user-specified collection of points in space.
c
c Input:
c   z(3,npts) - the set of given points.
c   npts - the number of elements in z
c   nbox - the maximum number of points permitted in a box on
c        the finest level. in other words, a box will be further
c        subdivided if it contains more than nbox points.
c   maxbxs - the maximum total number of boxes the subroutine
c        is permitted to create.
c
c  ifempty - keep empty boxes if the user requested so
c     ifempty=0 means that the empty boxes must be removed from the quad-tree.
c     ifempty=1 means that the empty boxes are always kept in the quad-tree,
c           i.e. all boxes are subdivided into 8 smaller boxes
c  maxlevel - the maximum of levels in the quad-tree.
c
c Output:
c   ier - the error return mode:
c             ier=0 means successful execution
c             ier=4 means that the subroutine attempted to create more
c        than maxbxs boxes
c             ier=16 means that the subroutine attempted to construct more
c        than 199 levels of subdivision.
c
c   boxes - main output, an integer array dimensioned (15,nboxes).
c        Each 15-element column describes one box, as follows:
c
c       1 - the level of subdivision on which this box
c             was constructed;
c       2,3,4 - the coordinates of this box among  all
c             boxes on this level
c       5 - the daddy of this box, identified by its address
c             in array boxes
c       6,7,8,9,10,11,12,13 - the  list of children of this box
c             (eight of them, and the child is identified by its address
c             in the array boxes; if a box has only one child, only the
c             first of the four child entries is non-zero, etc.)
c       14 - the location in the array iz of the particles
c             living in this box
c       15 - the number of particles living in this box
c
c   nboxes - the total number of boxes created
c
c   iz - the integer array addressing the particles in all boxes.
c       Explanation: for a box ibox, the particles living in it are:
c         (z(1,j),z(2,j),z(3,j)),(z(1,j+1),z(2,j+1),z(3,j+1)),
c         (z(1,j+2),z(2,j+2),z(3,j+3)), . . .
c         (z(1,j+nj-1),z(2,j+nj-1),z(3,j+nj-1)),
c         (z(1,j+nj),z(2,j+nj),z(3,j+nj)),
c         with j=boxes(14,ibox), and nj=boxes(15,ibox)-1
c
c   laddr - an integer array dimensioned (2,numlev), containing
c         the map of array boxes, as follows:
c       laddr(1,i) is the starting location in array boxes of the
c         information pertaining to level=i-1
c       laddr(2,i) is the number of boxes created on the level i-1
c
c   nlev - the maximum level number on which any boxes have
c         been created. the maximim number possible is 200.
c         it is recommended that the array laddr above be
c         dimensioned at least (2,200), in case the user underestimates
c         the number of levels required.
c
c   center0 - the center of the box on the level 0, containing
c         the whole simulation
c
c   size - the side of the box on the level 0
c
c Working arrays:
c   iwork - must be at least n+2 integer*4 elements long.
c
c
        integer boxes(15,1),iz(1),laddr(2,1),iwork(1),
     1      is(8),ns(8),iisons(8),jjsons(8),kksons(8)
        dimension z(3,1),center0(1),center(3)
c
c
c Execution starts:
c
        data iisons/1,2,1,2,1,2,1,2/,jjsons/1,1,2,2,1,1,2,2/,
     1      kksons/1,1,1,1,2,2,2,2/
        ier = 0
        idadson = 5
c
c ... First find the smallest cubic box containing all points:
c
        xmin = 1.0d50
        xmax = -xmin
        ymin = 1.0d50
        ymax = -ymin
        zmin = 1.0d50
        zmax = -zmin
c
        do 1020 i=1, npts
          if(z(1,i) .lt. xmin) xmin=z(1,i)
          if(z(1,i) .gt. xmax) xmax=z(1,i)
          if(z(2,i) .lt. ymin) ymin=z(2,i)
          if(z(2,i) .gt. ymax) ymax=z(2,i)
          if(z(3,i) .lt. zmin) zmin=z(3,i)
          if(z(3,i) .gt. zmax) zmax=z(3,i)
 1020 continue
c
c ... Get the biggest side length:
c
      size = xmax-xmin
      sizey = ymax-ymin
      sizez = zmax-zmin
      if(sizey .gt. size) size=sizey
      if(sizez .gt. size) size=sizez
ccc      SIZE = 1.0d0
c
c ... Get the center location for the whole box:
c
      center0(1) = (xmin+xmax)/2
      center0(2) = (ymin+ymax)/2
      center0(3) = (zmin+zmax)/2
ccc      center0(1) = 0.0d0
ccc      center0(2) = 0.0d0
ccc      center0(3) = 0.0d0
c
c ... First box is the whole box itself, initialize its 15 elements:
c
      boxes(1,1) = 0
      boxes(2,1) = 1
      boxes(3,1) = 1
      boxes(4,1) = 1
      boxes(5,1) = 0
      do 1040 i = 6, 13
         boxes(i,1) = 0
 1040 continue
      boxes(14,1) = 1
      boxes(15,1) = npts
c
c ... For level 0, laddr(*,1) is obvious:
c
      laddr(1,1) = 1
      laddr(2,1) = 1
c
c ... First let the order of points be as given:
c
      do 1060 i = 1,npts
         iz(i) = i
 1060 continue
c
c ... This is the MAIN loop of the subroutine:
c       recursively (one level after another) subdivide all
c       boxes till none are left with more than nbox particles
c
      maxson = maxbxs
c
      maxlev = 200
      ison = 1
      nlev = 0
c
c
c       now, use the size of the box and the user specification
c       for epsclose in order to find out the maximum number of
c       levels allowed here.
c
        if(epsclose .ne. 0d0)then
          xlev = dlog(size/epsclose) / dlog(2d0)
          maxlev = int(xlev) - 1
          maxlev = min(int(xlev)-1,200)
          maxlev = min(maxlev,maxlevel-1)
        else
          maxlev = 200
          maxlev = min(maxlev,maxlevel-1)
        endif
c
c
      do 3000 level = 0, maxlev
C
         laddr(1,level+2) = laddr(1,level+1)+laddr(2,level+1)
         nlevson = 0
         idad0 = laddr(1,level+1)
         idad1 = idad0+laddr(2,level+1)-1
c
c ... For each box in dad's level, do subdivision:
c
         do 2000 idad = idad0,idad1
c
c ...... Number of points in this box:
c
            numpdad = boxes(15,idad)
c
c ...... If number of points in this box is less than nbox, no need to
c        further divide it:
c
            if (numpdad .le. nbox) goto 2000
c
c ...... Numbering of the box idad at this level:
c
            ii = boxes(2,idad)
            jj = boxes(3,idad)
            kk = boxes(4,idad)
c
c ...... Get the center of this box:
c
            call d3mcentf(center0,size,level,ii,jj,kk,center)
c
c ...... Reorder the points in this box according to its eight children:
c
            iiz = boxes(14,idad)
            nz  = boxes(15,idad)
            call d3msepa1em(center,z,iz(iiz),nz,iwork,is,ns,ifempty)
c
c ...... For the eight children just created by the routine d3msepa1,
c         check to see if they were empty, if not, put it in the array
c         boxes appropriately:
c
            do 1000 i = 1, 8
c
c ...... If this child is empty, it shall be forgotten:
c
ccccccc               if (ns(i) .eq. 0) goto 1000
            if((ifempty .eq. 0) .and. (ns(i) .eq. 0)) goto 1000
c
               nlevson = nlevson+1
               ison = ison+1
               nlev = level+1
c
c ...... If I had created too many boxes, bomb out:
c
               if (ison .gt. maxson) then
                  ier = 4
                  return
               endif
c
c ...... Store in array boxes all information about this son:
c
               boxes(1,ison) = level+1
               boxes(2,ison) = (ii-1)*2+iisons(i)
               boxes(3,ison) = (jj-1)*2+jjsons(i)
               boxes(4,ison) = (kk-1)*2+kksons(i)
               boxes(5,ison) = idad
c
               do lll = 6, 13
                  boxes(lll,ison) = 0
               enddo
c
               boxes(14,ison) = is(i)+iiz-1
               boxes(15,ison) = ns(i)
c
c ...... Rewrite the dad-son information to dad's place:
c
               boxes(idadson+i,idad) = ison
c
 1000 continue
c
 2000 continue
         laddr(2,level+2) = nlevson
         if (nlevson .eq. 0) goto 4000
 3000 continue
c
c ... If the previous loop ends natually and coming to here, it means
c     that we have attempted to divide deep into maxlev = 200, bomb!
c
cccc        pause 'Attempted to go deeper than 200 levels, stop here!'
ccc        if(maxlev .eq. 200)   ier=16
ccc        return
 4000 continue
c
c ... Total number of boxes:
c
        nboxes = ison
c
        return
        end
c
c
c
c
c
c
c
c
        subroutine d3msepa1em(cent,z,iz,n,iwork,is,ns,ifempty)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c        This subroutine subdivides a box into 8 child boxes and
c         reorders the particles in a box, so that each of the 8
c          children occupies a contigious chunk of array iz.
c
c        Note that we are using a strange numbering convention
c        for the children:
c
c             3,4     7,8
c    
c                                     <- looking down the z-axis
c             1,2     5,6
c
c 
c             z
c             ^
c             |         y
c             |        /
c             |      7/    8
c             |      /
c             |    5/    6
c             |----/-----------
c             |   /
c             |  /   3     4
c             | /
c             |/   1     2
c             |-------------------------> x
c
c
c Input:
c          cent - the center of the box to be subdivided
c          z - the list of all points in the box to be subdivided
c          iz - the integer array specifying the transposition already
c          applied to the points z, before the subdivision of
c          the box into children
c          n - the total number of points in array z
c
c Output:
c          iz - the integer array specifying the transposition already
c          applied to the points z, after the subdivision of
c          the box into children
c          is - an integer array of length 8 containing the locations
c          of the sons in array iz
c          ns - an integer array of length 8 containig the numbers of
c          elements in the sons
c
c Working arrays:
c          iwork - must be n integer elements long
c
        integer iz(1),iwork(1),is(1),ns(1)
        integer n1,n2,n3,n4,n5,n6,n7,n8,n12,n34,n56,n78,n1234,n5678
        dimension cent(1),z(3,1)
c
c Execution starts:
c
        n1 = 0
        n2 = 0
        n3 = 0
        n4 = 0
        n5 = 0
        n6 = 0
        n7 = 0
        n8 = 0
        n12 = 0
        n34 = 0
        n56 = 0
        n78 = 0
        n1234 = 0
        n5678 = 0
c
c ... Divide in the z-direction:
c
        idir=3
        thresh=cent(3)
        call d3msepa0(z,iz,n,idir,thresh,iwork,n1234)
        n5678=n-n1234
c
c ... Divide in the y-direction:
c
        idir=2
        thresh=cent(2)
        ifsplit=1
        if(n1234 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz,n1234,idir,thresh,iwork,n12)
        n34=n1234-n12
c
        ifsplit=1
        if(n5678 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz(n1234+1),n5678,idir,thresh,iwork,n56)
        n78=n5678-n56
c
c ... Divide in the x-direction:
c
        idir=1
        thresh=cent(1)
        ifsplit=1
        if(n12 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz,n12,idir,thresh,iwork,n1)
        n2=n12-n1
c
        ifsplit=1
        if(n34 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz(n12+1),n34,idir,thresh,iwork,n3)
        n4=n34-n3
c
        ifsplit=1
        if(n56 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz(n1234+1),n56,idir,thresh,iwork,n5)
        n6=n56-n5
c
        ifsplit=1
        if(n78 .eq. 0) ifsplit=0
        if(ifempty .eq. 1) ifsplit=1
        if(ifsplit .ne. 0)
     1    call d3msepa0(z,iz(n1234+n56+1),n78,idir,thresh,iwork,n7)
        n8=n78-n7
c
c ... Write to is(8) and ns(8):
c
        is(1)=1
        ns(1)=n1
c
        is(2)=is(1)+ns(1)
        ns(2)=n2
c
        is(3)=is(2)+ns(2)
        ns(3)=n3
c
        is(4)=is(3)+ns(3)
        ns(4)=n4
c
        is(5)=is(4)+ns(4)
        ns(5)=n5
c
        is(6)=is(5)+ns(5)
        ns(6)=n6
c
        is(7)=is(6)+ns(6)
        ns(7)=n7
c
        is(8)=is(7)+ns(7)
        ns(8)=n8
c
        return
        end
c
c
c
c
c
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c        This is the 3-d adaptive box data structure code
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c       Important notes:
c
c       1) This is NOT the original FMM tree code,
c       it has been heavily modified (see e.g. d3mgetb, d3mgetbk)
c       
c       2) In three-dimensional Riverdale, ordering of chidren is different
c       
c          2d:          
c                2 4                      
c                1 3         
c
c          3d:
c       
c                3 4  |  7 8
c                1 2  |  5 6
c
c       3) In three-dimensional Riverdale, the list of chidren may
c       contain holes
c
c          2d: if a box has only one child, only 
c              first of the four child entries is non-zero.
c       
c          3d: the list of children of this box may contain holes.
c
c          i.e. if 6,7,8,9,10,11,12,13 - the list of children of the box ibox
c             (eight of them, and the child is identified by its address
c             in the array boxes), then the 6,7,8,9-th elements may be zero
c             and 10,11,12,13-th elements may be non-zero. 
c
c       4) corners array currently stores the sides of the boxes only
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c
        subroutine d3mstrcr(ier,z,n,nbox,nboxes,iz,laddr,nlev,
     1    center,size,iwork,lw,lused777,epsclose,ninire)
        implicit real *8 (a-h,o-z)
        save
c
c Purpose:
c       This subroutine constructs the logical structure for the
c       fully adaptive FMM in three dimensions and stores it in the
c       array w in the form of a link-list. Including, a quad-tree
c        of boxes formed, an array of has_kid indicaters, an arrary
c        of centers for all boxes, and all (5 among them 4 will be used
c        by FMM) lists.
c        The user can access the information about various boxes and
c        lists in it by calling the entries d3mgetb, d3mgetl, d3mlinfo
c       of this subroutine (see).
c
c Input:
c          z(3,n) - the user-specified points in the space
c          n - the number of elements in array z
c          nbox - the maximum number of points allowed in a childless box
c          lw - the amount of memory in the array w (in integer*4 elements)
c        epsclose - the smallest size a box can be (the length of sides).
c
c Output:
c          ier - error return code
c               ier=0   means successful execution
c               ier=16 means that the subroutine attempted to construct more
c                  than 199 levels of subdivision; the code will PAUSE
c                 and one should stop to check, for any physically
c                  meaningful distribution of points, it should NOT go
c                  higher than that.
c               ier=32  means that the amount lw of space in array w
c                 is insufficient
c          nboxes - the total number of boxes created
c          iz(n) - the integer array addressing the particles in
c           all boxes. Explanation: for a box ibox, the particles living
c                in it are:
c             (z(1,j),z(2,j),z(3,j)),(z(1,j+1),z(2,j+1),z(3,j+1)),
c             (z(1,j+2),z(2,j+2),z(3,j+3)), . . .
c             (z(1,j+nj-1),z(2,j+nj-1),z(3,j+nj-1)),
c             (z(1,j+nj),z(2,j+nj),z(3,j+nj)),
c           with j=boxes(14,ibox), and nj=boxes(15,ibox)-1
c          laddr(2,200) - an integer array (2,nlev), describing the
c           numbers of boxes on various levels of subdivision, so that
c           the first box on level (i-1) has sequence number laddr(1,i),
c           and there are laddr(2,i) boxes on level i-1
c          nlev - the maximum level number on which any boxes have
c           been created. the maximim number possible is 200.
c           it is recommended that the array laddr above be dimensioned
c           at least (2,200), in case the user underestimates
c           the number of levels required.
c          center(3) - the center of the box on the level 0, containing
c           the whole simulation
c          size - the side of the box on the level 0
c          iwork(lw) - the array containing all tables describing boxes,
c            lists, etc. It is a link-list (for the most part), and can
c            only be accessed via the entries d3mgetb, d3mgetl, d3mlinfo,
c            of this subroutine (see below). The first lused777 integer*4
c           locations of this array should not be altered between the
c           call to this entry and subsequent calls to the entries
c           d3mgetb, d3mgetl, d3mlinfo, of this  subroutine
c          centers(3,nboxes) - the array containing centers for all boxes.
c          lused777 - the amount of space in the array w (in integer*4
c            words) that is occupied by various tables on exit from this
c           subroutine. this space should not be altered between the
c           call to this entry and subsequent calls to entries d3mgetb,
c           d3mgetl, d3mlinfo, of this  subroutine (see below).
c
c
        integer iz(1),iwork(1),laddr(2,1),box(1),nums(1),list(1)
        dimension centers(3,1)
        dimension z(3,1),center(3),center0(3)
c
c ... First construct the quad-tree structure for given set of points:
c
c
        data iiboxes/1/,iicenters/2/,iicorners/3/,iiwlists/4/,iikids/5/
        if( lw .lt. 20*n ) then
c
c       the array is simply too small,
c       don't even try the solution
c
        ier=32
        return
        endif
c
c        do i=1,lw
c          iwork(i)=0
c        enddo
c
        iiwork = 1
        liwork = n+4
c
        iboxes = iiwork+liwork
        lboxes = lw-n-5
        maxboxes = lboxes/15-1
c
        call d3mallb(ier,z,n,nbox,iwork(iboxes),maxboxes,
     1    nboxes,iz,laddr,nlev,center,size,iwork(iiwork),epsclose)
c
c ... If the memory is insufficient - bomb
c
        if (ier .eq. 4) then
         call prinf('FATAL: NOT ENOUGH MEMORY IN D3MALLB, IER=*',IER,1)
           ier = 32
           return
        endif
c
c ... Compress the array w: so the first block of w (of size nboxes*15
c      + 16 and starts from iboxes) is for quad-tree.
c
c     compress, while allocating extra space for the following
c     pointers: iboxes, icenters, icorners, iwlists, ikids.
c
        nn = nboxes*15
        do 1200 i = 1,nn
          iwork(i + 5) = iwork(iboxes+i-1)
 1200 continue
c
        iboxes = 1 + 5
        lboxes = nboxes*15+16
        iwork(iiboxes)=iboxes
c
c ... Construct the array has_kid for all boxes: store it in the second
c        block of w(starts at ikids, of length lkids).
c
        ikids = iboxes+lboxes
        lkids = nboxes+1
        iwork(iikids)=ikids
c
cccc        iwlists = ikids+lkids
cccc        lwlists = lw-iwlists-6
cccc        iwork(iiwlists)=iwlists
c
c
c ... Construct the centers for all boxes in the quad-tree: so the
c       third block of w ( starts at icenters, of size lcenters) stores
c        the center coordinates for all boxes (NOTE: we are storing
c        real *8 numbers in integer*4 storage space, not good, but for
c        simplicity)
c
        icenters = ikids+lkids
        lcenters = (nboxes*3+2)*ninire
        iwork(iicenters)=icenters
cccc
        icorners = icenters+lcenters
        lcorners = (nboxes+2)*ninire
        iwork(iicorners)=icorners
cccc
        iwlists = icorners+lcorners
        lwlists = lw-iwlists-6
        iwork(iiwlists)=iwlists
c
ccc        call prinf('Before d3haskid, lwlists = *',lwlists,1)
        call d3mhaskid(iwork(iwork(iiboxes)),
     $     nboxes,iwork(iwork(iikids)))
ccc        call prinf('After d3haskid, lwlists = *',lwlists,1)
c
ccc        call prinf('Before d3mcentc, lwlists = *',lwlists,1)
ccccc        call d3mcentc(center,size,iwork(iwork(iiboxes)),nboxes,centers)
c
        call d3mcentc(center,size,iwork(iwork(iiboxes)),nboxes,
     $     iwork(iwork(iicenters)),iwork(iwork(iicorners)))
c
c ... Now, construct all lists for all boxes
c
ccc        call prinf('Before d3mcrealists, available work space:
ccc     1    lwlists = *',lwlists,1)
        call d3mcrealists(ier,iwork(iwork(iiboxes)),nboxes,size,
     1    iwork(iwork(iicenters)),
     1    iwork(iwork(iikids)),iwork(iwork(iiwlists)),lwlists,lused)
c
ccc        lused777 = lused+iwlists+nboxes*3*ninire
        lused777 = lused+iwlists
        if (ier .eq. 32)
     1  call prinf('FATAL: Not enough memory in d3mcrealists, ier=*',
     2     ier,1)
c
        nboxes7 = nboxes
c
        return
        end
c
c
c
c
c
c
        subroutine d3mgetb(ier,ibox,box,center,corners,iwork)
        implicit real *8 (a-h,o-z)
        integer iwork(1),box(15)
        dimension centers(3,1), center(3),corners(3,8)
        save
c
c Purpose:
c        This entry returns to the user the characteristics of
c        user-specified box  ibox.
c
c Input:
c          ibox - the box number for which the information is desired
c          w - storage area as created by the entry d3mstrcr (see above)
c
c Output:
c          ier - the error return code.
c               ier=0 means successful execution
c               ier=4 means that ibox is either greater than the number of
c                boxes in the structure or less than 1.
c          box - an integer array dimensioned box(15). Its elements
c           describe the box number ibox, as explained in d3mallb.
c          nkids - number of kids box ibox has
c          center - the center of the box number ibox
c
c ... Return to the user all information about the box ibox
c
        data iiboxes/1/,iicenters/2/,iicorners/3/,iiwlists/4/,iikids/5/
        ier = 0
c        if ((ibox .lt. 1) .or. (ibox .gt. nboxes7)) then
c           ier = 4
c           return
c        endif
c
        ibox0 = iwork(iiboxes)+(ibox-1)*15-1
        do 4400 i = 1,15
           box(i) = iwork(ibox0+i)
 4400 continue
c
c ... Return to the user the center and number of kids of the box ibox
c
        call d3mgetcentr(iwork(iwork(iicenters)),ibox,center)
c
        call d3mgetside(iwork(iwork(iicorners)),ibox,side)
c
        corners(1,1)=center(1)-side/2
        corners(1,2)=corners(1,1)
        corners(1,3)=corners(1,1)
        corners(1,4)=corners(1,1)
c
        corners(1,5)=corners(1,1)+side
        corners(1,6)=corners(1,5)
        corners(1,7)=corners(1,5)
        corners(1,8)=corners(1,5)
c
        corners(2,1)=center(2)-side/2
        corners(2,2)=corners(2,1)
        corners(2,5)=corners(2,1)
        corners(2,6)=corners(2,1)
c
        corners(2,3)=corners(2,1)+side
        corners(2,4)=corners(2,3)
        corners(2,7)=corners(2,3)
        corners(2,8)=corners(2,3)
c
        corners(3,1)=center(3)-side/2
        corners(3,3)=corners(3,1)
        corners(3,5)=corners(3,1)
        corners(3,7)=corners(3,1)
c
        corners(3,2)=corners(3,1)+side
        corners(3,4)=corners(3,2)
        corners(3,6)=corners(3,2)
        corners(3,8)=corners(3,2)
c
        return
c
c
c
c
c
c
        entry d3mgetbk(ier,ibox,box,center,nkids,iwork)
c
c Purpose:
c        This entry returns to the user the characteristics of
c        user-specified box  ibox.
c
c Input:
c          ibox - the box number for which the information is desired
c          w - storage area as created by the entry d3mstrcr (see above)
c
c Output:
c          ier - the error return code.
c               ier=0 means successful execution
c               ier=4 means that ibox is either greater than the number of
c                boxes in the structure or less than 1.
c          box - an integer array dimensioned box(15). Its elements
c           describe the box number ibox, as explained in d3mallb.
c          nkids - number of kids box ibox has
c          center - the center of the box number ibox
c
c ... Return to the user all information about the box ibox
c
        ier = 0
c        if ((ibox .lt. 1) .or. (ibox .gt. nboxes7)) then
c           ier = 4
c           return
c        endif
c
        ibox0 = iwork(iiboxes)+(ibox-1)*15-1
        do 3400 i = 1,15
           box(i) = iwork(ibox0+i)
 3400 continue
c
c ... Return to the user the center and number of kids of the box ibox
c
        ikid0 = iwork(iikids)+ibox-1
        nkids = iwork(ikid0)
c
        call d3mgetcentr(iwork(iwork(iicenters)),ibox,center)
c
        return
c
c
c
c
c
c
        entry d3mgetcenters(ier,nboxes,centers,iwork)
c
c Purpose:
c        This entry returns to the user the characteristics of
c        user-specified box  ibox.
c
c Input:
c          nboxes - the total number of boxes in the quad tree
c          w - storage area as created by the entry d3mstrcr (see above)
c
c Output:
c          ier - the error return code.
c               ier=0 means successful execution
c               ier=4 means that ibox is either greater than the number of
c                boxes in the structure or less than 1.
c          center - the centers of the boxes in the quad tree
c
c ... Return to the user all information about the box ibox
c
        ier = 0
c
        do 4200 i=1,nboxes
        call d3mgetcentr(iwork(iwork(iicenters)),i,centers(1,i))
 4200   continue
c
        return
c
c
c
c
c
c
        entry d3mgetl(ier,ibox,itype,list,nlist,iwork)
c
c Purpose:
c          Return to the user the specified list of boxes for box 'ibox'.
c
c Input:
c          ibox - the box number for which the information is desired
c          itype - the type of the desired list for the box ibox
c          w - storage area as created by the entry d3mstrcr (see above)
c
c Output:
c          ier - the error return code.
c          ier=0 means successful execution
c          ier=4 means that the list itype for the box 'ibox  is empty
c          list - the list  itype  for the box  ibox
c          nlist - the number of elements in array  list
c
c
c ... Return to the user the list number itype for the box ibox
c
        call d3mlinkretr(ier,itype,ibox,list,nlist,
     $     iwork(iwork(iiwlists)),lused)
c
        return
c
c
c
c
c
c
        entry d3minfo(iwork,lused77,nums)
c
c Purpose:
c       This entry returns to the user some of the information
c       about the storage area. namely, it returns the total amount
c       lused777 of memory utilized in the array w (in integer
c       locations), and the integer array nums containing the numbers
c       of elements in each of the lists
c
ccc        call d3mlinkinfo(iwork(iwork(iiwlists)),lused77,nums)
c
        return
        end
c
c
c
c
c
c
        subroutine d3mcrealists(ier,boxes,nboxes,size,centers,haskid,
     $     w,lw,lused)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c        This subroutine constructs all lists for all boxes
c        and stores them in the storage area w in the form
c        of a link list. The resulting data can be accessed
c        by calls to various entries of the subroutine d3mlinkinit (see).
c
c Input:
c          boxes - an integer array dimensioned (15,nboxes), as created by
c               the subroutine d3mallb (see).
c          nboxes - the total number of boxes created
c        size - the side length of whole box
c          centers - the center of all boxes
c          haskid - an array of flag indicate if box has kid or not
c          lw - the total amount of storage in array w(in integer*4 words)
c
c Output:
c          ier - the error return code.
c           ier=0 means successful execution
c           ier=32 means that the amount lw of space in array w is
c                  insufficient. It is a fatal error.
c          w - storage area containing all lists for all boxes in
c           the form of link-lists, accessible by the subroutine
c           d3mlinkretr (see).
c          lused - the amount of space in the array w (in integer*4 words)
c           that is occupied by various tables on exit from this
c           subroutine. This space should not be altered between the
c           call to this subroutine and subsequent calls to the
c           entries d3mlinkretr, etc. of the subroutine d3mlinkinit (see).
c
c Note on the list conventions:
c
c    list 1 of the box ibox - the list of all boxes with which the
c           box ibox interacts directly, including the boxes on the
c           same level as ibox, boxes on the finer levels, and boxes
c           on the coarser levels. Obviously, list 1 is empty for any
c           box that is not childless. All boxes in list 1 must also
c            be childless.
c
c    list 2 of the box ibox - the list of all boxes with which the
c           box ibox interacts in the regular multipole fashion, i.e.
c           boxes on the same level as ibox that are separated from it
c           but whose daddies are not separated from the daddy of ibox.
c
c    list 3 of the box ibox - for a childless ibox, the list of all
c           boxes on the levels finer than that of ibox, which are
c           separated from ibox, and whose daddys are not separated
c           from ibox. For a box with children, list 3 is empty.
c
c    list 4 is dual to list 3, i.e. jbox is on the list 4 of ibox if
c           and only if ibox is on the list 3 of jbox. All boxes in list
c            4 are of higher level and are childless.
c
c    list 5 is the colleages of box ibox - adjacent boxes on the same
c            level.
c
c    list 6 of the box ibox - for a childless ibox, the list of all
c           boxes on the levels finer than that of ibox, which touch
c           the box ibox, and which have children. For a box jbox 
c           with children, the list of all childless boxes on the 
c           coarser levels, which touch the box jbox. Obviously, this 
c           is a generalization of list 1 for the boxes with children.
c
        integer boxes(15,1),w(1),haskid(1)
        integer collkids(5000),dadcolls(200),list5(2000),stack(6000)
        dimension centers(3,1)
c
c Execution starts:
c
c ... Initialize the storage-retrieval routine for all boxes:
c
        lused = 0
        lused2 = 0
cccc
        ier = 0
cccc        ntypes = 5
        ntypes = 6
        call d3mlinkinit(ier,nboxes,ntypes,w,lw)
c
c ... First construct lists 5, 2 for all boxes:
c     ========================================
c
        do 2000 ibox = 2,nboxes
           idad = boxes(5,ibox)
c
c ... Retrieve daddy's collegues, including daddy himself:
c
           dadcolls(1) = idad
           itype5 = 5
           itype2 = 2
           call d3mlinkretr(ier,itype5,idad,dadcolls(2),ncolls,w,lused)
           ncolls = ncolls+1
c
c ... Find the children of the daddy's collegues:
c
           nkids = 0
         do 1600 i = 1,ncolls
            icoll = dadcolls(i)
            if (haskid(icoll) .le. 0) goto 1600
         do 1400 j = 6,13
            kid = boxes(j,icoll)
            if (kid .gt. 0) then
               if (kid .eq. ibox) goto 1400
                nkids = nkids+1
                collkids(nkids) = kid
            endif
 1400 continue
 1600 continue
c
c ... Sort the kids of the daddy's collegues into the
c       lists 2, 5 of the box ibox
c
         nlist1 = 1
         do 1800 i = 1,nkids
c
c ... Check if this kid is touching the box ibox, if touching, this kid
c        belongs to list 5 of box ibox, if not, it belongs to list 2
c        of box ibox:
c
            kid = collkids(i)
            call d3minters(size,centers(1,ibox),boxes(1,ibox),
     1         centers(1,kid),boxes(1,kid),ifinter)
            if (ifinter .eq. 1)
     1         call d3mlinkstor(ier,itype5,ibox,kid,nlist1,w,lused)
            if (ifinter .eq. 0)
     1         call d3mlinkstor(ier,itype2,ibox,kid,nlist1,w,lused)
 1800 continue
c
c ... Possible error exiting, not enough memory space:
c
         if (ier .eq. 32) then
c            call prinf('FATAL: memory exhausted in building lists 2,5,
c     1         ier=*',ier,1)
            return
         endif
c
 2000 continue
c
***      call prinf('constructed lists 2,5, lused = *',lused,1)
c
c ... Second, construct lists 1, 3:
c     ============================
c
      do 3000 i = 1,nboxes
c
c ... If this box has kids - its lists 1, 3 are empty, so skip it,
c        otherwise get its list 5, from which to construct lists 1,3:
c
         if (haskid(i) .gt. 0) goto 3000
         call d3mlinkretr(jer,itype5,i,list5,nlist,w,lused)
c
c ... If list 5 is empty, skip, otherwise call the list 1, 3 maker:
c
         if(jer .eq. 4) goto 3000
         do 3200 j = 1,nlist
            jbox = list5(j)
            call d3mlists31(ier,i,jbox,boxes,nboxes,size,centers,
     1         haskid,w,stack,lused)
c
c ... Possible error exiting, not enough memory space:
c
            if (ier .eq. 32) then
               call prinf('FATAL: memory exhausted in building
     1           lists 1,3, ier=*',ier,1)
               return
            endif
 3200 continue
 3000 continue
c
***      call prinf('constructed lists 1,3, lused=*',lused,1)
c
c ... Copy all elements of lists 1, 2, 3, 5, 6while skipping list 4:
c     =========================================================
c
ccc      ntypes4 = 4
      ntypes4 = 6
      call d3mlinkinit(ier,nboxes,ntypes4,w(lused+1),lw-(lused+5))
      do 3600 ibox = 1,nboxes
ccc         do 2400 itype = 1,3
         do 2400 itype = 1,6
            call d3mlinkretr(jer,itype,ibox,list5,nlist,w,lused)
            if (jer .eq. 4) goto 2400
            call d3mlinkstor
     1          (ier,itype,ibox,list5,nlist,w(lused+1),lused2)
            if (ier .eq. 32) then
               call prinf('FATAL: memory exhausted in realigning lists
     1                1,2,3, ier=*',ier,1)
               return
            endif
 2400    continue
 3600 continue
c
c ... Compress array w:
c
      do i = 1,lused2
         w(i) = w(lused+i)
      enddo
      lused = lused2
c
c ... Finally, construct the lists 4 for all boxes that need them:
c     ===========================================================
c
      itype3 = 3
      itype4 = 4
      nlist1 = 1
      do 4000 ibox = 1,nboxes
         call d3mlinkretr(jer,itype3,ibox,list5,nlist,w,lused)
         if (jer .eq. 4) goto 4000
         do j = 1,nlist
            call d3mlinkstor(ier,itype4,list5(j),ibox,nlist1,w,lused2)
            if (ier .eq. 32) then
               call prinf('FATAL: memory exhausted in building
     1           list 4, ier=*',ier,1)
               return
            endif
         enddo
 4000 continue
        lused = lused2
c
ccc      call prinf('Finished list 4, exit d3mcrealists, lused=*',lused,1)
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlists31(ier,ibox,jbox0,boxes,nboxes,size,centers,
     1    haskid,w,stack,lused)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This subroutine constructs all elements of lists 1 and 3
c       resulting from the subdivision of one element of list 5
c       of the box ibox. All these elements of lists 1, 3 are
c       stored in the link-lists by the subroutine linstro (see)
c
c Input:
c          ibox - the box whose lists are being constructed
c          jbox0 - the element of list 5 of the box ibox that is being
c          subdivided
c          boxes - the array boxes as created by d3mallb
c          nboxes - the number of boxes in array boxes
c        size - the side length of whole box
c          centers - the array of centers of all the boxes
c          haskid - the array of indicaters of how many kid each box has
c          w - the storage area formatted by the subroutine d3mlinkinit (see)
c          to be used to store the elements of lists 1, 3 constructed
c          by this subroutine. Obviously, by this time, it contains
c          plenty of other lists.
c
c Output:
c          ier - the error return code.
c               =0 means successful execution
c               =32 means that the amount lw of space in array w is
c           insufficient. it is a fatal error.
c          w - the augmented storage area, containing all the boxes just
c          created, in addition to whatever had been stored previously
c          lused - the total length of array w (in integer words) used
c          on exit from this subroutine
c
c Working Arrays:
c          stack - must be at least 600 integer locations long
c
        integer  boxes(15,1),haskid(1)
        integer  stack(3,1)
        dimension w(1),centers(3,1)
c
c
c ... Initialization: jbox0 is put in as the first stack member
c
        data itype1/1/,itype2/2/,itype3/3/,itype4/4/,itype5/5/,nlist1/1/
        jbox = jbox0
        istack = 1
        stack(1,1) = 1
        stack(2,1) = jbox
c
        nsons = haskid(jbox)
        stack(3,1) = nsons
c
c ... Process the stack until it's empty:
c
        do 5000 while (istack .gt. 0)
c
c ... Check to see if this box is separated from ibox, if yes -
c        store it in list 3, continue to previous stack member;
c        if not - further checking based on if it has kid or not:
c
           call d3minters(size,centers(1,ibox),boxes(1,ibox),
     1      centers(1,jbox),boxes(1,jbox),ifinter)
           if (ifinter .eq. 0) then
              call d3mlinkstor(ier,itype3,ibox,jbox,nlist1,w,lused)
              if(ier .eq. 32) return
c
              istack = istack-1
              stack(3,istack) = stack(3,istack)-1
              jbox = stack(2,istack)
              goto 5000
           endif
c
c ... This box is touching box ibox: check to see if it is childless,
c       if yes - enter it in list 1, go on to previous stack member,
c         if not - check to see if it still has unprocessed kids:
c
           if (haskid(jbox) .le. 0) then
c
c ...... Enters jbox in the list1 of ibox; if jbox is on the finer
c         level than ibox - also enter ibox in the list 1 of jbox
c
            call d3mlinkstor(ier,itype1,ibox,jbox,nlist1,w,lused)
            if (ier .eq. 32) return
            if (boxes(1,jbox) .gt. boxes(1,ibox)) then
               call d3mlinkstor(ier,itype1,jbox,ibox,nlist1,w,lused)
               if (ier .eq. 32) return
            endif
c
c ...... If we have processed the whole box jbox0, get out
c        of the subroutine
c
            if (jbox .eq. jbox0) return
c
            istack = istack-1
            stack(3,istack) = stack(3,istack)-1
            jbox = stack(2,istack)
            goto 5000
         endif
c
c ...... This box is touching box ibox, and has kids. Check to see if
c        the number of unprocessed sons of this box is zero,
c        if yes - continue to previous stack member,
c         if not - contruct the stack member for the son, and process it
c
        nsons = stack(3,istack)
        if (nsons .lt. 1) then
c
           if (jbox .eq. jbox0) return
c
c
c       this box is not separated from ibox, and has children,
c       store this box in list 6
c
        itype6=6
        call d3mlinkstor(ier,itype6,ibox,jbox,nlist1,w,lused)
        call d3mlinkstor(ier,itype6,jbox,ibox,nlist1,w,lused)
c
           istack = istack-1
           stack(3,istack) = stack(3,istack)-1
           jbox = stack(2,istack)
           goto 5000
        endif
c
c ...... This box is touching box ibox and has unprocessed kids,
c        construct a stack element for next unprocessed son, and
c         process that son instead:
c
***        jbox = boxes(5+nsons,jbox)
        nnsons = 0
        do kk = 6, 13
           if (boxes(kk,jbox) .gt. 0) nnsons = nnsons + 1
           if (nnsons .eq. nsons) goto 555
        enddo
 555    jbox = boxes(kk,jbox)
c
        istack = istack+1
        nsons = haskid(jbox)
        stack(1,istack) = istack
        stack(2,istack) = jbox
        stack(3,istack) = nsons
c
 5000 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3minters(size,c1,level1,c2,level2,ifinter)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c            This subroutine determines if two boxes intersect (or touch).
c
c Input:
c        size - the side length of the whole box
c          c1 - the center of the first box
c          level1 - level of the first box
c          c2 - the center of the second box
c          level2 - level of the second box
c
c Output:
c          ifinter - the indicator.
c          ifinter=1 means that the boxes intersect
c          ifinter=0 means that the boxes do not intersect
c
c
c ... Find the side length for both boxes:
c
        real *8 c1(3),c2(3),size
        side1 = size/2**level1
        side1h = side1/2
        side2 = size/2**level2
        side2h = side2/2
c
c ... Find the maximum and minimum coordinates for both boxes:
c
        xmin1=c1(1) - side1h
        ymin1=c1(2) - side1h
        zmin1=c1(3) - side1h
c
        xmax1=c1(1) + side1h
        ymax1=c1(2) + side1h
        zmax1=c1(3) + side1h
c
        xmin2=c2(1) - side2h
        ymin2=c2(2) - side2h
        zmin2=c2(3) - side2h
c
        xmax2=c2(1) + side2h
        ymax2=c2(2) + side2h
        zmax2=c2(3) + side2h
c
c ... Decide if the boxes intersect:
c
        eps=xmax1-xmin1
        if (eps .gt. ymax1-ymin1) eps=ymax1-ymin1
        if (eps .gt. zmax1-zmin1) eps=zmax1-zmin1
c
        if (eps .gt. xmax2-xmin2) eps=xmax2-xmin2
        if (eps .gt. ymax2-ymin2) eps=ymax2-ymin2
        if (eps .gt. zmax2-zmin2) eps=zmax2-zmin2
c
ccc        eps=eps/100
        eps=eps/10000
c
        ifinter=1
c
c ... The code defaults the two boxes as touching, but if any of
c     the following happens, it means they are seperated:
c
        if (xmin1 .gt. xmax2+eps) ifinter=0
        if (xmin2 .gt. xmax1+eps) ifinter=0
c
        if (ymin1 .gt. ymax2+eps) ifinter=0
        if (ymin2 .gt. ymax1+eps) ifinter=0
c
        if (zmin1 .gt. zmax2+eps) ifinter=0
        if (zmin2 .gt. zmax1+eps) ifinter=0
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mallb(ier,z,npts,nbox,boxes,maxbxs,
     1    nboxes,iz,laddr,nlev,center0,size,iwork,epsclose)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c   This subroutine constructs a quad-tree corresponding to the
c   user-specified collection of points in space.
c
c Input:
c   z(3,npts) - the set of given points.
c   npts - the number of elements in z
c   nbox - the maximum number of points permitted in a box on
c        the finest level. in other words, a box will be further
c        subdivided if it contains more than nbox points.
c   maxbxs - the maximum total number of boxes the subroutine
c        is permitted to create.
c
c Output:
c   ier - the error return mode:
c             ier=0 means successful execution
c             ier=4 means that the subroutine attempted to create more
c        than maxbxs boxes
c             ier=16 means that the subroutine attempted to construct more
c        than 199 levels of subdivision.
c
c   boxes - main output, an integer array dimensioned (15,nboxes).
c        Each 15-element column describes one box, as follows:
c
c       1 - the level of subdivision on which this box
c             was constructed;
c       2,3,4 - the coordinates of this box among  all
c             boxes on this level
c       5 - the daddy of this box, identified by its address
c             in array boxes
c       6,7,8,9,10,11,12,13 - the  list of children of this box
c             (eight of them, and the child is identified by its address
c             in the array boxes)
c       14 - the location in the array iz of the particles
c             living in this box
c       15 - the number of particles living in this box
c
c   nboxes - the total number of boxes created
c
c   iz - the integer array addressing the particles in all boxes.
c       Explanation: for a box ibox, the particles living in it are:
c         (z(1,j),z(2,j),z(3,j)),(z(1,j+1),z(2,j+1),z(3,j+1)),
c         (z(1,j+2),z(2,j+2),z(3,j+3)), . . .
c         (z(1,j+nj-1),z(2,j+nj-1),z(3,j+nj-1)),
c         (z(1,j+nj),z(2,j+nj),z(3,j+nj)),
c         with j=boxes(14,ibox), and nj=boxes(15,ibox)-1
c
c   laddr - an integer array dimensioned (2,numlev), containing
c         the map of array boxes, as follows:
c       laddr(1,i) is the starting location in array boxes of the
c         information pertaining to level=i-1
c       laddr(2,i) is the number of boxes created on the level i-1
c
c   nlev - the maximum level number on which any boxes have
c         been created. the maximim number possible is 200.
c         it is recommended that the array laddr above be
c         dimensioned at least (2,200), in case the user underestimates
c         the number of levels required.
c
c   center0 - the center of the box on the level 0, containing
c         the whole simulation
c
c   size - the side of the box on the level 0
c
c Working arrays:
c   iwork - must be at least n+2 integer*4 elements long.
c
c
        integer boxes(15,1),iz(1),laddr(2,1),iwork(1),
     1      is(8),ns(8),iisons(8),jjsons(8),kksons(8)
        dimension z(3,1),center0(1),center(3)
c
c
c Execution starts:
c
        data iisons/1,2,1,2,1,2,1,2/,jjsons/1,1,2,2,1,1,2,2/,
     1      kksons/1,1,1,1,2,2,2,2/
        ier = 0
        idadson = 5
c
c ... First find the smallest cubic box containing all points:
c
        xmin = 1.0d50
        xmax = -xmin
        ymin = 1.0d50
        ymax = -ymin
        zmin = 1.0d50
        zmax = -zmin
c
        do 1020 i=1, npts
          if(z(1,i) .lt. xmin) xmin=z(1,i)
          if(z(1,i) .gt. xmax) xmax=z(1,i)
          if(z(2,i) .lt. ymin) ymin=z(2,i)
          if(z(2,i) .gt. ymax) ymax=z(2,i)
          if(z(3,i) .lt. zmin) zmin=z(3,i)
          if(z(3,i) .gt. zmax) zmax=z(3,i)
 1020 continue
c
c ... Get the biggest side length:
c
      size = xmax-xmin
      sizey = ymax-ymin
      sizez = zmax-zmin
      if(sizey .gt. size) size=sizey
      if(sizez .gt. size) size=sizez
ccc      SIZE = 1.0d0
c
c ... Get the center location for the whole box:
c
      center0(1) = (xmin+xmax)/2
      center0(2) = (ymin+ymax)/2
      center0(3) = (zmin+zmax)/2
ccc      center0(1) = 0.0d0
ccc      center0(2) = 0.0d0
ccc      center0(3) = 0.0d0
c
c ... First box is the whole box itself, initialize its 15 elements:
c
      boxes(1,1) = 0
      boxes(2,1) = 1
      boxes(3,1) = 1
      boxes(4,1) = 1
      boxes(5,1) = 0
      do 1040 i = 6, 13
         boxes(i,1) = 0
 1040 continue
      boxes(14,1) = 1
      boxes(15,1) = npts
c
c ... For level 0, laddr(*,1) is obvious:
c
      laddr(1,1) = 1
      laddr(2,1) = 1
c
c ... First let the order of points be as given:
c
      do 1060 i = 1,npts
         iz(i) = i
 1060 continue
c
c ... This is the MAIN loop of the subroutine:
c       recursively (one level after another) subdivide all
c       boxes till none are left with more than nbox particles
c
      maxson = maxbxs
c
      maxlev = 200
c
c
c       now, use the size of the box and the user specification
c       for epsclose in order to find out the maximum number of
c       levels allowed here.
c
        if(epsclose .ne. 0d0)then
          xlev = dlog(size/epsclose) / dlog(2d0)
          maxlev = int(xlev) - 1
          maxlev = min(int(xlev)-1,200)
        else
          maxlev = 200
        endif
c
      ison = 1
      nlev = 0
c
      do 3000 level = 0, maxlev
C
c
         laddr(1,level+2) = laddr(1,level+1)+laddr(2,level+1)
         nlevson = 0
         idad0 = laddr(1,level+1)
         idad1 = idad0+laddr(2,level+1)-1
c
c ... For each box in dad's level, do subdivision:
c
         do 2000 idad = idad0,idad1
c
c ...... Number of points in this box:
c
            numpdad = boxes(15,idad)
c
c ...... If number of points in this box is less than nbox, no need to
c        further divide it:
c
            if (numpdad .le. nbox) goto 2000
c
c ...... Numbering of the box idad at this level:
c
            ii = boxes(2,idad)
            jj = boxes(3,idad)
            kk = boxes(4,idad)
c
c ...... Get the center of this box:
c
            call d3mcentf(center0,size,level,ii,jj,kk,center)
c
c ...... Reorder the points in this box according to its eight children:
c
            iiz = boxes(14,idad)
            nz  = boxes(15,idad)
            call d3msepa1(center,z,iz(iiz),nz,iwork,is,ns)
c
c ...... For the eight children just created by the routine d3msepa1,
c         check to see if they were empty, if not, put it in the array
c         boxes appropriately:
c
            do 1000 i = 1, 8
c
c ...... If this child is empty, it shall be forgotten:
c
               if (ns(i) .eq. 0) goto 1000
c
               nlevson = nlevson+1
               ison = ison+1
               nlev = level+1
c
c ...... If I had created too many boxes, bomb out:
c
               if (ison .gt. maxson) then
                  ier = 4
                  return
               endif
c
c ...... Store in array boxes all information about this son:
c
               boxes(1,ison) = level+1
               boxes(2,ison) = (ii-1)*2+iisons(i)
               boxes(3,ison) = (jj-1)*2+jjsons(i)
               boxes(4,ison) = (kk-1)*2+kksons(i)
               boxes(5,ison) = idad
c
               do lll = 6, 13
                  boxes(lll,ison) = 0
               enddo
c
               boxes(14,ison) = is(i)+iiz-1
               boxes(15,ison) = ns(i)
c
c ...... Rewrite the dad-son information to dad's place:
c
               boxes(idadson+i,idad) = ison
c
 1000 continue
c
 2000 continue
         laddr(2,level+2) = nlevson
         if (nlevson .eq. 0) goto 4000
 3000 continue
c
c ... If the previous loop ends natually and coming to here, it means
c     that we have attempted to divide deep into maxlev = 200, bomb!
c
cccc        pause 'Attempted to go deeper than 200 levels, stop here!'
ccc        ier = 16
ccc        return
 4000 continue
c
c ... Total number of boxes:
c
        nboxes = ison
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mcentf(center0,size,level,i,j,k,center)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This subroutine finds the center of the box
c       number (i,j,k) on the level level. Note that the
c       box on level 0 is assumed to have the center
c       center0, and the side size.
c
c Input:
c       center0(3): center of the whole box.
c        size: side length of the whole box.
c        level: current level.
c        i,j,k: the box numbering at current level.
c
c Output:
c        center(3): center of box (i,j,k) at level level.
c
c
c
        real *8 center(1),center0(1)
c
c Execution starts:
c
c ... Initialize the corner:
c
c        if (level0 .eq. -1) then
c           x0 = center0(1)-size/2
c           y0 = center0(2)-size/2
c           z0 = center0(3)-size/2
c        endif
c
c ... Initialize for level 'level':
c
c        if (level .ne. level0) then
c           side = size/2**level
c           side2 = side/2
c           level0 = level
c        endif
c
        data level0/-1/
           side = size/2.0d0**level
           side2 = side/2
           x0 = center0(1)-size/2
           y0 = center0(2)-size/2
           z0 = center0(3)-size/2
        center(1) = x0+(i-1)*side+side2
        center(2) = y0+(j-1)*side+side2
        center(3) = z0+(k-1)*side+side2
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3msepa1(cent,z,iz,n,iwork,is,ns)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c        This subroutine subdivides a box into 8 child boxes and
c         reorders the particles in a box, so that each of the 8
c          children occupies a contigious chunk of array iz.
c
c        Note that we are using a strange numbering convention
c        for the children:
c
c             z
c             ^
c             |         y
c             |        /
c             |      7/    8
c             |      /
c             |    5/    6
c             |----/-----------
c             |   /
c             |  /   3     4
c             | /
c             |/   1     2
c             |-------------------------> x
c
c Input:
c          cent - the center of the box to be subdivided
c          z - the list of all points in the box to be subdivided
c          iz - the integer array specifying the transposition already
c          applied to the points z, before the subdivision of
c          the box into children
c          n - the total number of points in array z
c
c Output:
c          iz - the integer array specifying the transposition already
c          applied to the points z, after the subdivision of
c          the box into children
c          is - an integer array of length 8 containing the locations
c          of the sons in array iz
c          ns - an integer array of length 8 containig the numbers of
c          elements in the sons
c
c Working arrays:
c          iwork - must be n integer elements long
c
        integer iz(1),iwork(1),is(1),ns(1)
        integer n1,n2,n3,n4,n5,n6,n7,n8,n12,n34,n56,n78,n1234,n5678
        dimension cent(1),z(3,1)
c
c Execution starts:
c
        n1 = 0
        n2 = 0
        n3 = 0
        n4 = 0
        n5 = 0
        n6 = 0
        n7 = 0
        n8 = 0
        n12 = 0
        n34 = 0
        n56 = 0
        n78 = 0
        n1234 = 0
        n5678 = 0
c
c ... Divide in the z-direction:
c
        idir=3
        thresh=cent(3)
        call d3msepa0(z,iz,n,idir,thresh,iwork,n1234)
        n5678=n-n1234
c
c ... Divide in the y-direction:
c
        idir=2
        thresh=cent(2)
        if(n1234 .ne. 0)
     1    call d3msepa0(z,iz,n1234,idir,thresh,iwork,n12)
        n34=n1234-n12
c
        if(n5678 .ne. 0)
     1    call d3msepa0(z,iz(n1234+1),n5678,idir,thresh,iwork,n56)
        n78=n5678-n56
c
c ... Divide in the x-direction:
c
        idir=1
        thresh=cent(1)
        if(n12 .ne. 0)
     1    call d3msepa0(z,iz,n12,idir,thresh,iwork,n1)
        n2=n12-n1
c
        if(n34 .ne. 0)
     1    call d3msepa0(z,iz(n12+1),n34,idir,thresh,iwork,n3)
        n4=n34-n3
c
        if(n56 .ne. 0)
     1    call d3msepa0(z,iz(n1234+1),n56,idir,thresh,iwork,n5)
        n6=n56-n5
c
        if(n78 .ne. 0)
     1    call d3msepa0(z,iz(n1234+n56+1),n78,idir,thresh,iwork,n7)
        n8=n78-n7
c
c ... Write to is(8) and ns(8):
c
        is(1)=1
        ns(1)=n1
c
        is(2)=is(1)+ns(1)
        ns(2)=n2
c
        is(3)=is(2)+ns(2)
        ns(3)=n3
c
        is(4)=is(3)+ns(3)
        ns(4)=n4
c
        is(5)=is(4)+ns(4)
        ns(5)=n5
c
        is(6)=is(5)+ns(5)
        ns(6)=n6
c
        is(7)=is(6)+ns(6)
        ns(7)=n7
c
        is(8)=is(7)+ns(7)
        ns(8)=n8
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3msepa0(z,iz,n,idir,thresh,iwork,n1)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       Subdivide the points in this box according to the directional
c       parameter idir = 1 (x), 2 (y), 3 (z).
c
c Input:
c        z(n): array of points in this box.
c        iz(*): old ordering of points.
c        idir: which direction to divide.
c        thresh: middle point of this box in this direction.
c
c Output:
c        iz(*): rearranged ordering of points.
c        n1: number of points in the lower half of the box.
c
c Working arrays:
c        iwork(*)
c
        integer iz(1),iwork(1)
c
c Execution starts:
c
        real *8 z(3,1)
        i1 = 0
        i2 = 0
        do 1400 i = 1,n
           j = iz(i)
           if (z(idir,j) .le. thresh) then
              i1 = i1+1
              iz(i1) = j
           else
              i2 = i2+1
              iwork(i2) = j
           endif
 1400 continue
c
c ... Copy over from temperary work space the upper half.
c
        do 1600 i = 1,i2
          iz(i1+i) = iwork(i)
 1600 continue
c
        n1 = i1
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mhaskid(boxes,nboxes,haskid)
        implicit real *8 (a-h,o-z)
c
c
c Purpose:
c        This subroutine produces an integer array indicates
c        whether a box has kid or not.
c
c Input:
c        boxes(15,nboxes) - see d3mallb.
c        nboxes - number of boxes.
c
c Output:
c        haskid(nboxes) - an array of flag indicates if a box has a kid
c                =0 childless
c                >0 has "haskid" kids
c
        integer nboxes
c
c ... Initialize to childless:
c
        integer boxes(15,1), haskid(1)
        do 1200 i = 1, nboxes
           haskid(i) = 0
 1200 continue
c
c ... checking one by one:
c
        do 1600 i = 1, nboxes
        do 1400 j = 6, 13
          if (boxes(j,i) .gt. 0) haskid(i) = haskid(i) + 1
 1400 continue
 1600 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mcentc(center0,size,boxes,nboxes,centers,sides)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This subroutine produces arrays of centers for all boxes
c        in the quad-tree structure.
c
c Input:
c          center0 - the center of the box on the level 0, containing
c                 the whole simulation
c          size - the side of the box on the level 0
c          boxes - an integer array dimensioned (15,nboxes), as produced
c               by the subroutine d3mallb (see)
c          nboxes - the total number of boxes created
c
c Output:
c          centers - the centers of all boxes in the array boxes
c
c
c
        integer boxes(15,1)
        dimension centers(3,1),sides(1),center0(3)
c
c Execution starts:
c
        x00 = center0(1)-size/2
        y00 = center0(2)-size/2
        z00 = center0(3)-size/2

        do 1200 i = 1,nboxes
           level = boxes(1,i)
           side = size/2**level
           side2 = side/2

           ii = boxes(2,i)
           jj = boxes(3,i)
           kk = boxes(4,i)

           centers(1,i) = x00+(ii-1)*side+side2
           centers(2,i) = y00+(jj-1)*side+side2
           centers(3,i) = z00+(kk-1)*side+side2
           sides(i)=side
 1200 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkinit(ier,nboxes,ntypes,w,lw)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c        This is the initialization entry point for the link-list
c        storage-retrieval facility. it formats the array w, to
c        be used by the entries d3mlinkstor, d3mlinkretr, linkrem,
c        d3mlinkinfo below.
c
c Input:
c          nboxes - the number of boxes total
c          ntypes - the number of types of lists that will be stored
c          lw - the total amount of space in the area w to be used for
c           storage (in integer locations)
c
c Output:
c          ier - error return code;
c          ier=0 means successful execution
c          ier=1024 means that the amount of space in array w is grossly
c              insufficient
c          w - the formatted area for storage
c
c
        integer w(1),inums(20)
c
c ... Allocate memory for the storage facility
c
        data iilistad/1/,iilists/2/,inumele/3/,inboxes/4/,intypes/5/,
     1     ilw/6/,iltot/7/, inums/11,12,13,14,15,16,17,18,19,20,21,
     2      22,23,24,25,26,27,28,29,30/
        ier = 0
c
        ilistadd = 32
        nlistadd = nboxes*ntypes+10
c
        ilists = ilistadd+nlistadd
        numele = 0
        ltot = ilists+numele*2+10
c
c ... If storage is not enough, bomb and exit:
c
        if (ltot+100 .ge. lw) then
           ier = 1024
           return
        endif
c
        do 1200 i = 1,20
           w(inums(i)) = 0
 1200 continue
c
        w(iilistad) = ilistadd
        w(iilists) = ilists
        w(inumele) = numele
        w(inboxes) = nboxes
        w(intypes) = ntypes
        w(ilw) = lw
        w(iltot) = ltot
c
        call d3mlinkini0(w(ilistadd),nboxes,ntypes)
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkstor(ier,itype,ibox,list,nlist,w,lused)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This entry stores dynamically a chunk of infomation for lists
c        (ibox,itype) into the linked lists in the storage array w.
c
c Input:
c          itype - the type of the elements being stored
c          ibox - the box to which these elements corresponds
c          list - the list of positive integer elements to be stored
c          nlist - the number of elements in the array list
c          w - the storage area used by this subroutine; must be first
c          formatted by the entry d3mlinkinit of this subroutine(see above)
c
c Output:
c          ier - error return code;
c          =0 means successful execution
c          =32 means that the storage area w would be exceeded
c                 by this storage request
c          w - the storage area used by this subroutine
c          lused - the number of integer elements used in array
c          w after this call.
c
c
        integer w(1),inums(20),list(1)
c
c Execution starts:
c
        data iilistad/1/,iilists/2/,inumele/3/,inboxes/4/,intypes/5/,
     1     ilw/6/,iltot/7/, inums/11,12,13,14,15,16,17,18,19,20,21,
     2      22,23,24,25,26,27,28,29,30/
        ier=0
c
c ... If memory not enough, bomb:
c
        if (w(iilists)+w(inumele)*2+nlist*2 .ge. w(ilw) ) then
           ier=32
           return
        endif
c
c ... Otherwise, store the user-specified list in array w
c
        call d3mlinksto0(itype,ibox,list,nlist,w(w(iilistad)),
     1      w(inboxes),w(w(iilists)),w(inumele),w(inums(itype)) )
c
c ... Update the amount of storege used
c
        lused=w(iilists)+w(inumele)*2+10
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkretr(ier,itype,ibox,list,nlist,w,lused)
        implicit real *8 (a-h,o-z)
c
c
c Purpose:
c       This entry retrieves from the storage area  w
c       a list of type (ibox,itype): meaning the interaction lists type
c        'itype' for box 'ibox'.
c
c Input:
c          itype - the type of the elements to be retrieved
c          ibox - the box to which these elements correspond
c          w - the storage area from which the information is to be
c          retrieved
c
c Output:
c          ier - error return code;
c           =0 means successful execution, nothing to report
c           =4 means that no elements are present of the type
c                  itype and the box ibox
c          list - the list of positive integer elements retrieved
c          nlist - the number of elements in the array list
c          lused - the number of integer elements used in array
c          w after this call.
c
c
        integer  w(1),inums(20),list(1)
c
c Execution starts:
c
        data iilistad/1/,iilists/2/,inumele/3/,inboxes/4/,intypes/5/,
     1     ilw/6/,iltot/7/, inums/11,12,13,14,15,16,17,18,19,20,21,
     2      22,23,24,25,26,27,28,29,30/
        call d3mlinkret0(ier,itype,ibox,w(w(iilistad)),
     1      w(w(iilists)),list,w(inboxes),nlist)
c
        lused=w(iilists)+w(inumele)*2+10
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkinfo(w,lused,nums)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This entry returns to the user some of the information
c       about the storage area. namely, it returns the total
c       amount lused of memory utilized in the array w (in integer
c       locations), and the integer array nums containing the numbers
c       of elements in each of the lists
c
        integer  w(1),nums(1),inums(20)
c
c Execution starts:
c
        data iilistad/1/,iilists/2/,inumele/3/,inboxes/4/,intypes/5/,
     1     ilw/6/,iltot/7/, inums/11,12,13,14,15,16,17,18,19,20,21,
     2      22,23,24,25,26,27,28,29,30/
        return
c
        lused=w(iilists)+w(inumele)*2+10
        ntypes7=w(intypes)
ccc        call prinf('in d3mlinkinfo, lused=*',lused,1)
ccc        call prinf('in d3mlinkinfo, ntypes7=*',ntypes7,1)
ccc        call prinf('in w(inumele)=*',w(inumele),1)
c
        do 1200 i=1,ntypes7
           nums(i)=w(inums(i))
 1200 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinksto0(itype,ibox,list,nlist,listaddr,
     1      nboxes,lists,numele,numtype)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This entry stores dynamically a list of box numbers of list
c        type 'itype' for box 'ibox'. This list is inputed in 'list',
c        there are 'nlist' members (however, in list building code,
c        we are only adding one at a time, effectively nlist is always
c        1). This list is to be stored in global storage space 'lists',
c        which is consisted of (ntypes = 5 x nboxes) linked lists. The
c        appropriate link handle for each type and each box is stored in
c        'listaddr'.
c
c Input:
c          itype - the type of lists being stored
c          ibox - the box to which these elements corresponds
c          list - the list to be stored
c          nlist - the number of elements in the array list
c          nboxes - the total number of boxes indexing the elements
c          in array lists
c          listaddr - the addressing array for the main storage array
c           lists; it is assumed that it has been formatted by a call
c          to the entry d3mlinkini0 of this subroutine (see below).
c          lists - the main storage area used by this subroutine
c          numele - the number of elements of type itype for box ibox
c           already stored in array lists on entry to this subroutine
c          numtype - the number of elements of type itype for all boxes
c           stored in array lists on entry to this subroutine
c
c Output:
c          listaddr - the addressing array for the main storage array
c           lists; it is assumed that it has been formatted by a call
c          to the entry d3mlinkini0 of this subroutine (see below).
c          lists - the main storage area used by this subroutine
c          numele - the number of elements stored in array lists on exit
c          from this subroutine
c          numtype - the total number of elements in all lists of the
c          type itype AFTER this call
c
c Explanation:
c          lists(1,i) - the pointer points to the preceding element in
c           the list with (box,type) combination as the user-supplied
c           (ibox,itype). lists(1,i) < 0 means that this is the head of
c           the link list of its type,
c          lists(2,i) - the box number on the interaction list.
c
c          listaddr(ibox,itype) - the handle for the link list with (ibox,
c           itype), i.e. the tail address for the link list.
c          listaddr(ibox,itype) < 0 means that there are no elements
c          in the list of this type for this box.
c
c
c Execution starts:
c
c ... Get the handle for the link list (ibox, itype):
c
        integer listaddr(nboxes,1),lists(2,1),list(1)
        ilast = listaddr(ibox,itype)
c
c ... Add new member to the link list:
c
        do 1200 i = 1,nlist
           numele = numele+1
           numtype = numtype+1
           lists(1,numele) = ilast
           lists(2,numele) = list(i)
           ilast = numele
 1200 continue
c
c ... Update the new handle:
c
        listaddr(ibox,itype) = ilast
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkret0(ier,itype,ibox,listaddr,lists,list,
     1      nboxes,nlist)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This entry retrieves from the main storage array lists
c       the list of type itype for box ibox.
c
c Input:
c          itype - the type of the elements being to be retrieved
c          ibox - the box to which these element corresponds
c          listaddr - the array of handles for the array lists;
c          nboxes - the total number of boxes indexing the elements
c           in array lists
c          lists - the main storage area used by this subroutine
c
c Output:
c          ier - error return code;
c          ier=0 means successful execution, nothing to report
c          ier=4 means that no elements are present of the type
c                  itype and the box ibox
c          list - the list of (ibox,itype) being retrived
c          nlist - the number of elements in the array list
c
c
c Execution starts:
c
        integer listaddr(nboxes,1),lists(2,1),list(1)
        ier=0
c
c ... Get the handle:
c
        ilast=listaddr(ibox,itype)
c
c ... If handle indicates no such lists, so be it:
c
        if (ilast .le. 0) then
           nlist=0
           ier=4
           return
        endif
c
c ... Now retrieve one by one until the whole list has been retrieved:
c     (Note: the if statement inside the loop is unlikely to happen,
c        I left it in there just for insurance)
c
        nlist=0
        do 2400 while (ilast .gt .0)
           if (lists(2,ilast) .gt. 0) then
              nlist=nlist+1
              list(nlist)=lists(2,ilast)
           endif
           ilast=lists(1,ilast)
 2400 continue
c
c ... If I did not get anything from above, quit empty handed:
c
        if (nlist .le. 0) then
          ier=4
          return
        endif
c
c ... The retrieved array needs to fliped to get the old ordering:
c
        if(nlist .eq. 1) return
        do 2700 i=1,nlist/2
           j=list(i)
           list(i)=list(nlist-i+1)
           list(nlist-i+1)=j
 2700 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkini0(listaddr,nboxes,ntypes)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       This subroutine initializes the array listaddr to be used
c       later by d3mlinksto0.
c
c Input:
c          nboxes - the number of boxes
c          ntypes - the number of types of lists that will be stored
c
c Output:
c          listaddr - the array of handles for all link lists in
c           the main storage array lists; it is initialized to -1 here
c           so it does not points to anywhere.
c
c
c Execution starts:
c
        integer listaddr(nboxes,1)
        do 1400 k = 1,ntypes
        do 1200 i = 1,nboxes
           listaddr(i,k) = -1
 1200 continue
 1400 continue
c
        return
        end
c
c
c
c
c
c
c
c
c
        subroutine d3mlinkrem0(ier,itype,ibox,list,nlist,listaddr,
     1      nboxes,lists,numtype)
        implicit real *8 (a-h,o-z)
c
c       this entry deletes elements in array lists corresponding
c       the user-specified list  list. actually, it does not
c       delete anything, but rather marks these elements for
c       future destruction by making them negative.
c
c                      input parameters:
c
c  itype - the type of the elements to be destroyed
c  ibox - the box to which these elements correspond
c  list - the list of positive integer elements to be destroyed
c  nlist - the number of elements in the array list
c  listaddr - the addressing array for the main storage array lists;
c             it is assumed that it has been formatted by a call
c             to the entry d3mlinkini0 of this subroutine (see below).
c  nboxes - the total number of boxes indexing the elements
c           in array lists
c  lists - the main storage area used by this subroutine
c
c                      output parameters:
c
c  ier - error return code;
c          ier=0 means successful execution, nothing to report
c          ier=4*k means that k of the elements on the user-specified
c                   list  list were not present
c          ier=22 means that  no elements whatsoever were present
c                   for the type  itype   and the box  ibox
c  listaddr - the addressing array for the main storage array lists;
c             it is assumed that it has been formatted by a call
c             to the entry d3mlinkini0 of this subroutine (see below).
c  lists - the main storage area used by this subroutine
c
c
c       . . . mark for destruction the elements of type (itype,ibox)
c             that are in the list  list.
c
        integer listaddr(nboxes,1),lists(2,1),list(1)
        ier=0
        do 4000 i=1,nlist
           ilast=listaddr(ibox,itype)
           if(ilast. gt. 0) goto 3200
           ier=22
           return
 3200 continue
c
           iffound=0
        do 3600 j=1,10000000
c
           if(ilast .le. 0) goto 3800
           if(lists(2,ilast) .ne. list(i)) goto 3400
           lists(2,ilast)=-lists(2,ilast)
           numtype=numtype-1
           iffound=1
 3400 continue
           ilast=lists(1,ilast)
 3600 continue
c
 3800 continue
            if(iffound .eq. 0) ier=ier+4
c
 4000 continue
c
        return
        end
c
c
c
c
c
c
        subroutine d3mgetcentr(centers,ibox,center)
        implicit real *8 (a-h,o-z)
c
        dimension centers(3,1),center(3)
c
        center(1)=centers(1,ibox)
        center(2)=centers(2,ibox)
        center(3)=centers(3,ibox)
c
        return
        end
c
c
c
c
c
        subroutine d3mgetside(sides,ibox,side)
        implicit real *8 (a-h,o-z)
c
        dimension sides(1)
c
        side=sides(ibox)
c
        return
        end
c
c
c
c
c
      subroutine d3malltl(ier,z,n,iz,zboxes,
     1     w,nboxes,laddr,nlev,center0,size,iwork)
      implicit real *8 (a-h,o-z)
c
      real *8 z(3,1)
c
      integer *4 iz(1),zboxes(2,1),
     1      w(1),laddr(2,1),
     2      iwork(1),is(8),ns(8),kid(8)
c
      real *8 center0(3),center(3)
      save
c
      data iiboxes/1/,iicenters/2/,iicorners/3/,iiwlists/4/,iikids/5/
      call d3mallt(ier,z,n,iz,zboxes,
     1     w(w(iiboxes)),nboxes,laddr,nlev,center0,size,iwork)

      return
      end
c
c
c
c
c
c
      subroutine d3mallt(ier,z,n,iz,zboxes,
     1     boxes,nboxes,laddr,nlev,center0,size,iwork)
      implicit real *8 (a-h,o-z)
c
      real *8 z(3,1)
c
      integer *4 iz(1),zboxes(2,1),
     1      boxes(15,1),laddr(2,1),
     2      iwork(1),is(8),ns(8),kid(8)
c
c
c     this subroutine sorts the set of target points z with respect to
c     the quad-tree structure {boxes,nboxes,laddr,nlev,center0,size},
c     created by a preceding call to d3mallb.
c
c     Note: It is assumed that all target points are in the main
c     computation box.
c
c     input parameters:
c
c  z - the set of target points in the space
c  n - the number of elements in z
c
c  boxes - an integer array dimensioned (15,nboxes). each 15-element
c        column describes one box, as follows:
c
c
c   boxes - main output, an integer array dimensioned (15,nboxes).
c        Each 15-element column describes one box, as follows:
c
c       1 - the level of subdivision on which this box
c             was constructed;
c       2,3,4 - the coordinates of this box among  all
c             boxes on this level
c       5 - the daddy of this box, identified by its address
c             in array boxes
c       6,7,8,9,10,11,12,13 - the  list of children of this box
c             (eight of them, and the child is identified by its address
c             in the array boxes)
c       14 - the location in the array iz of the particles
c             living in this box
c       15 - the number of particles living in this box
c
c  nboxes - the total number of boxes created
c
c  laddr - an integer array dimensioned (2,numlev<), containing
c         the map of array boxes, as follows:
c       laddr(1,i) is the location in array boxes of the information
c         pertaining to level=i-1
c       laddr(2,i) is the number of boxes created on the level i-1
c
c  nlev - the maximum level number on which any boxes have
c         been created. the maximim number possible is 200.
c         it is recommended that the array laddr above be
c         dimensioned at least (2,200), in case the user underestimates
c         the number of levels required.
c  center0 - the center of the box on the level 0, containing
c         the whole simulation
c  size - the side of the box on the level 0
c
c     output parameters:
c
c  zboxes - an integer array dimensioned (2,nboxes). each 2-element
c        column describes one box, as follows:
c
c     1 - the location in the array iz of the target points
c     living in this box
c
c     2 - the number of target points living in this box
c
c
c  iz - the integer array addressing the target points in
c     all boxes. Explanation: for a box ibox, the target points living
c     in it are:
c
c         (z(1,j),z(2,j),z(3,j)),(z(1,j+1),z(2,j+1),z(3,j+1)),
c         (z(1,j+2),z(2,j+2),z(3,j+2)),
c         . . . (z(1,j+nj-1),z(2,j+nj-1),z(3,j+nj-1)),
c               (z(1,j+nj),z(2,j+nj),z(3,j+nj)),
c
c         with j=zboxes(1,ibox), and nj=zboxes(2,ibox)
c
c
c     work arrays:
c
c  iwork - must be at least n+2 integer*4 elements long.
c
c     first set everything to zero
c
      real *8 center0(3),center(3)
       do 1000 i = 1, nboxes
         zboxes(1,i) = 0
         zboxes(2,i) = 0
 1000  continue
c
c     assign all target points to the main computational box
c
        do 1200 i=1,n
        iz(i)=i
 1200 continue
        zboxes(1,1)=1
        zboxes(2,1)=n


c
c     recursively (one level after another) subdivide all
c     boxes and sort the points
c

cccc        call prinf('in d2malls, nlev=*',nlev,1)
c
        do 3000 level=0,nlev
c
        ibox0=laddr(1,level+1)
        ibox1=ibox0+laddr(2,level+1)-1
c
cccc        call prinf('in d2malls, ibox0=*',ibox0,1)
cccc        call prinf('in d2malls, ibox1=*',ibox1,1)
c
c
        do 2000 ibox=ibox0,ibox1
c
cccc        call prinf('in d2malls, box=*',boxes(1,ibox),10)
c
c     now, check if the box ibox is childless
c
cccccccc        if(boxes(6,ibox) .eq. 0) goto 2000
        if(boxes( 6,ibox) .eq. 0 .and. 
     1     boxes( 7,ibox) .eq. 0 .and. 
     2     boxes( 8,ibox) .eq. 0 .and. 
     3     boxes( 9,ibox) .eq. 0 .and. 
     4     boxes(10,ibox) .eq. 0 .and. 
     4     boxes(11,ibox) .eq. 0 .and. 
     6     boxes(12,ibox) .eq. 0 .and. 
     7     boxes(13,ibox) .eq. 0 ) goto 2000
c
c     sort the points
c
        ii=boxes(2,ibox)
        jj=boxes(3,ibox)
        kk=boxes(4,ibox)
        call d3mcentf(center0,size,level,ii,jj,kk,center)
c
        iiz=zboxes(1,ibox)
        nz=zboxes(2,ibox)
        call d3msepa1(center,z,iz(iiz),nz,iwork,is,ns)


c
c     find the non-empty boxes in the quad-tree corresponding
c     to the box ibox
c

        jj=1
        ikidx=2*boxes(2,ibox)-1
        ikidy=2*boxes(3,ibox)-1
        ikidz=2*boxes(4,ibox)-1
c
        do 1220 i=1,8
        kid(i)=0
 1220   continue
c
        do 1400 i=1,8
        ikid=boxes(6+i-1,ibox)
        if(ikid.ne.0) then
           if( boxes(2,ikid).eq.ikidx   .and.
     1         boxes(3,ikid).eq.ikidy   .and.
     2         boxes(4,ikid).eq.ikidz     ) then
              kid(1)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx+1   .and.
     1         boxes(3,ikid).eq.ikidy   .and.
     2         boxes(4,ikid).eq.ikidz     ) then
              kid(2)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx   .and.
     1         boxes(3,ikid).eq.ikidy+1   .and.
     2         boxes(4,ikid).eq.ikidz     ) then
              kid(3)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx+1   .and.
     1         boxes(3,ikid).eq.ikidy+1   .and.
     2         boxes(4,ikid).eq.ikidz     ) then
              kid(4)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx   .and.
     1         boxes(3,ikid).eq.ikidy   .and.
     2         boxes(4,ikid).eq.ikidz+1     ) then
              kid(5)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx+1   .and.
     1         boxes(3,ikid).eq.ikidy   .and.
     2         boxes(4,ikid).eq.ikidz+1     ) then
              kid(6)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx   .and.
     1         boxes(3,ikid).eq.ikidy+1   .and.
     2         boxes(4,ikid).eq.ikidz+1     ) then
              kid(7)=ikid
              goto 1400
           endif
           if( boxes(2,ikid).eq.ikidx+1   .and.
     1         boxes(3,ikid).eq.ikidy+1   .and.
     2         boxes(4,ikid).eq.ikidz+1     ) then
              kid(8)=ikid
              goto 1400
           endif
         endif
 1400 continue

c
c     assign points to the non-empty boxes in the quad-tree
c    
        do 1600 i=1,8
        if(ns(i) .eq. 0) goto 1600
        if(kid(i) .eq. 0) goto 1600
        zboxes(1,kid(i))=is(i)+iiz-1
        zboxes(2,kid(i))=ns(i)
 1600 continue
c
 2000 continue
 3000 continue
c
      return
      end
c
c
c
c
c
      subroutine downpassriv3d(iflagtype, iderivonoff, nlev,
     1     nterms, ndigit, imap, nlambs, nxtotp, nxtot, n22,
     2     nshort, w, lw, nthmax, numpys, numfor, centrs,
     3     centr0, sources, monocharge, dipstr, dipvec, eps, rlams,
     4     pot, potx, poty, potz, arr, zs, rdplus, rdminu, rdsq3,
     5     rdsq3inv, rdmsq3, rdmsq3inv, rd, dc, whts, pptmp, scale,
     6     zrot, mpole, local, lexp1, mexpf1, mexpp1, mxpall,
     7     xs, ys, mw1, mw2, mw3, mws1, iz, laddr, iw,
     8     maxppb, nboxes)
      implicit none
c
c
c
c-----------------------------------------------------------------------
c
c
      integer *4  nlev, nterms, ndigit, imap(1), nlambs, n22, nxtot,
     1   nxtotp, nshort, iilev, ifirstbx, ilastbx, lw, nthmax, iw(1),
     2   numpys, numfor, iflagtype, iderivonoff, iz(1), laddr(2,1),
     3   maxppb, nboxes, box(15), npts, istart, mybox, nkids, ier
c
      real *8  centrs(3,1), centr0(3), sources(3,1), monocharge(1),
     1   dipstr(1), eps, rlams, dipvec(3,1), arr(1), w(1),
     2   rdplus(0:nterms,0:nterms,-nterms:nterms),
     3   rdminu(0:nterms,0:nterms,-nterms:nterms),
     4   rdsq3(0:nterms,0:nterms,-nterms:nterms),
     5   rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     6   rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     7   rdmsq3inv(0:nterms,0:nterms,-nterms:nterms),
     8   rd(0:nterms,0:nterms,-nterms:nterms),
     9   dc(0:4*nterms,0:4*nterms), whts(nlambs),
     1   pptmp((n22+2)*(n22+2)), scale(0:201), zrot(8),
     2   zs(3,nxtotp), pot(1), potx(1), poty(1), potz(1)
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1   local((nterms+1)*(nterms+2)/2,*), lexp1(nxtotp,*),
     2   mexpf1(nxtot), mexpp1(nxtotp), mxpall(nxtotp,8),
     3   xs(3,nxtotp), ys(3,nxtotp),
     4   mw1(0:nterms,0:nterms), mw2(0:nterms,0:nterms),
     5   mw3(0:nterms,0:nterms), mws1(0:nshort,0:nshort)
        do 1000 iilev = 0, nlev-1
c
          ifirstbx = laddr(1,iilev+1)
          ilastbx = ifirstbx + laddr(2,iilev+1) - 1
c
c-----------------------------------------------------------------------
c step 6: this portion of the code handles list 4:
c         forming local expansions due to not well seperated list 4 box.
c-----------------------------------------------------------------------
c
          call btosfarpart3d(ifirstbx, ilastbx, centrs, centr0, nterms,
     1        mw3, local, iflagtype, iderivonoff, pptmp, dc, n22,
     2        scale, eps, sources, pot, potx, poty, potz,
     3        dipstr, dipvec, monocharge, iilev, iz, iw)
c
c-----------------------------------------------------------------------
c step 7: this portion of the code handles tata:
c         shifting local expansions from mybox to his kids.
c-----------------------------------------------------------------------
c
          call handletata(w, lw, ifirstbx, ilastbx, centr0, nterms,
     1        mw3, local, imap, arr, rdsq3inv, rdsq3, mws1,
     2        nshort, zrot, rdmsq3inv, rdmsq3, iw)
c
c-----------------------------------------------------------------------
c step 8: here begins the code that handles list 2:
c         be aware of that lota is done at son's level, so if mybox is 
c         childless, it is skipped.
c-----------------------------------------------------------------------
c
          call handlelist2(nterms, n22, nlambs, numfor, numpys,
     1        nxtot, nxtotp, nthmax, centrs, mpole, local, dc,
     2        rdplus, rdminu, whts, rlams, lexp1, mexpf1, mexpp1,
     3        mxpall, xs, ys, zs, mw1, mw2, mw3, rd, ndigit,
     4        ifirstbx, ilastbx, scale, iilev, laddr, iw)
c
 1000   continue
c
c-----------------------------------------------------------------------
c step 6a: this portion of the code handles part of list 4 which are
c     unaccounted in above downward pass sweep.
c-----------------------------------------------------------------------
c
        if(nlev .eq. 0) return
c
        iilev = nlev
c
        ifirstbx = laddr(1,nlev+1)
        ilastbx = ifirstbx + laddr(2,nlev+1) - 1
c
        call btosfarpart3d(ifirstbx, ilastbx, centrs, centr0, nterms,
     1      mw3, local, iflagtype, iderivonoff, pptmp, dc, n22,
     2      scale, eps, sources, pot, potx, poty, potz,
     3      dipstr, dipvec, monocharge, iilev, iz, iw)
c
        do 2000 mybox = 1, nboxes
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .ge. 1) goto 2000
c
          npts = box(15)
c
          istart = box(14) - 1
c
          if(nlev .eq. 0) goto 2000
c
c-----------------------------------------------------------------------
c step 5: treat the list 3 interaction:
c-----------------------------------------------------------------------
c
          call stobfarpart3d(npts, istart, eps, sources,
     1        pot, potx, poty, potz, nterms, mw3, mpole, n22,
     2        scale, mybox, centr0, maxppb, iflagtype, iderivonoff,
     3        monocharge, dipstr, dipvec, dc, pptmp, iz, iw)
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine handlelist2(nterms, n22, nlambs, numfor, numpys,
     1    nxtot, nxtotp, nthmax, centrs, mpole, local, dc, rdplus,
     2    rdminu, whts, rlams, lexp1, mexpf1, mexpp1, mxpall,
     3    xs, ys, zs, mw1, mw2, mw3, rd, ndigit,
     4    ifirstbx, ilastbx, scale, iilev, laddr, iw)
      implicit none
c
c
c
c---------------------------------------------------------------------------
c
c
      integer *4  nterms, nlist, ndigit,
     1    i1(36), n1, ix1(36), iy1(36),
     2    i2(16), n2, ix2(16), iy2(16), n22, numpys(1),
     3    i3(4), n3, ix3(4), iy3(4), jj, mbc, nkids,
     4    i4(4), n4, ix4(4), iy4(4), numfor(1),
     5    i5(4), n5, ix5(4), iy5(4), ikid,
     6    i6(4), n6, ix6(4), iy6(4), nxtot, nxtotp,
     7    i7(4), n7, ix7(4), iy7(4), nlambs, nxtlvl,
     8    i8(4), n8, ix8(4), iy8(4), ier, nthmax,
     9    box(15), kk, mychld, mytype, list(2000),
     1    ifirstbx, ilastbx, iilev, i1stkb, ilstkb,
     2    itbox, mybox, laddr(2,1), iw(1)
c
      real *8 centrs(3,1), centr0(3), rlams, zs(3,nxtotp),
     1    rdplus(0:nterms,0:nterms,-nterms:nterms),
     2    rdminu(0:nterms,0:nterms,-nterms:nterms),
     3    rd(0:nterms,0:nterms,-nterms:nterms), scale(0:201),
     4    dc(0:4*nterms,0:4*nterms), whts(nlambs), sc
c
c	This is the slow point-and-shoot LOTA. It's here for debugging
c	purpose only.
c
      complex *16 mpole((nterms+1)*(nterms+2)/2,*),
     1    local((nterms+1)*(nterms+2)/2,*), lexp1(nxtotp,*),
     2    mexpf1(nxtot), mexpp1(nxtotp), mxpall(nxtotp,8),
     3    xs(3,nxtotp), ys(3,nxtotp), mw1(0:nterms,0:nterms),
     4    mw2(0:nterms,0:nterms), mw3(0:nterms,0:nterms)
         if (1 .lt. 2) goto 2500
         do 2000 mybox = ifirstbx, ilastbx
c
            call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
            nxtlvl = box(1)+1
            sc = scale(nxtlvl)

            if (nkids .gt. 0) then
            do 1500 ikid = 1, 8
               mychld = box(5+ikid)
               if (mychld .gt. 0) then
               call maptmp3d(mpole(1,mychld),mw3,nterms)
               mytype = 2
               call d3mgetl(ier,mychld,mytype,list,nlist,iw)
               do 1000 kk = 1, nlist
                  itbox = list(kk)
                  call d3lota(centrs(1,mychld),centrs(1,itbox),
     1                        mw3,mw1,mw2,nterms,sc,sc,dc,rd)
                  call addx123d(mw1,nterms,local(1,itbox),nterms)
 1000          continue
               endif
 1500       continue
            endif
c
 2000    continue
         return

 2500    continue

c-----------------------------------------------------------------------
c ... instead of lota directly, the diagonal translation scheme
c     consists of 6 sweeps (up, down, north, south, east and west):
c-----------------------------------------------------------------------

         i1stkb = laddr(1,iilev+2)
         ilstkb = i1stkb + laddr(2,iilev+2) - 1
c
c-----------------------------------------------------------------------
c step 8 up:
c-----------------------------------------------------------------------
c
         do 3500 mbc = i1stkb, ilstkb
           do 3000 jj = 1,nxtotp
             lexp1(jj,mbc) = 0.0d0
 3000      continue
 3500    continue
c
         do 4000 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 4000
           if (box(4) .ge. 2**box(1)) goto 4000
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mkuexp(mybox,box,nterms,n22,mpole,mw3,rlams,nlambs,
     1         ndigit,numfor,numpys,nthmax,nxtot,nxtotp,mexpf1,
     2         mexpp1,mxpall(1,1),mxpall(1,2),xs,ys,zs)
c
           call mkulst3d(mybox,box,i1,n1,ix1,iy1,
     1              i2,n2,ix2,iy2,centrs,iw,list)
           call prcssu(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,mxpall(1,1),mxpall(1,2),xs,ys,zs,nxtotp)
 4000    continue
c
         do 4500 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (box(4) .gt. 2) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call addexp3d(mw1,local(1,mybox),nterms)
           endif
 4500    continue
c
c-----------------------------------------------------------------------
c step 8 down:
c-----------------------------------------------------------------------
c
         do 5000 mbc = i1stkb, ilstkb
           do 4700 jj = 1,nxtotp
             lexp1(jj,mbc) = 0.0d0
 4700      continue
 5000    continue
c
         do 5200 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 5200
           if (box(4) .le. 1) goto 5200
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mkdexp(mybox,box,nterms,n22,mpole,rlams,nlambs,
     1         ndigit,numfor,numpys,nthmax,nxtot,nxtotp,
     2         mexpf1,mexpp1,mxpall(1,3),mxpall(1,4),
     3         xs,ys,zs,mw1,mw2,mw3,rdplus,rdminu)
c
           call mkdlst3d(mybox,box,i1,n1,ix1,iy1,
     1              i2,n2,ix2,iy2,centrs,iw,list)
           call prcssd(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,mxpall(1,3),mxpall(1,4),xs,ys,zs,nxtotp)
c
 5200    continue
c
         do 5500 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (box(4) .lt. 2**box(1)-1) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call mprttb('d',mw1,nterms,n22,mw2,mw3,rdplus,rdminu)
             call addexp3d(mw2,local(1,mybox),nterms)
           endif
 5500    continue
c
c-----------------------------------------------------------------------
c step 8 north:
c-----------------------------------------------------------------------
c
         do 6000 mbc = i1stkb, ilstkb
           do 5700 jj = 1,nxtotp
             lexp1(jj,mbc) = 0.0d0
 5700      continue
 6000    continue
c
         do 6100 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 6100
           if (box(3) .ge. 2**box(1)) goto 6100
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mknexp(mybox,box,nterms,n22,mpole,mw1,mw2,mw3,
     1         rlams,nlambs,ndigit,numfor,numpys,nthmax,nxtot,nxtotp,
     2         mexpf1,mexpp1,rdplus,rdminu,mxpall(1,1),
     3         mxpall(1,2),mxpall(1,3),mxpall(1,4),xs,ys,zs)
c
           call mknlst3d(mybox,box,i1,n1,ix1,iy1,i2,n2,ix2,iy2,
     1         i3,n3,ix3,iy3,i4,n4,ix4,iy4,centrs,iw,list)
c
           call prcssn(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,
     2         mxpall(1,1),mxpall(1,2),mxpall(1,3),
     3         mxpall(1,4),xs,ys,zs,nxtotp)
c
 6100    continue
c
         do 6300 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (box(3) .gt. 2) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call mprttb('n',mw1,nterms,n22,mw2,mw3,rdplus,rdminu)
             call addexp3d(mw2,local(1,mybox),nterms)
           endif
 6300    continue
c
c-----------------------------------------------------------------------
c step 8 south:
c-----------------------------------------------------------------------
c
         do 6700 mbc = i1stkb, ilstkb
           do 6500 jj = 1,nxtotp
              lexp1(jj,mbc) = 0.0d0
 6500      continue
 6700    continue
c
         do 6800 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 6800
           if (box(3) .le. 1) goto 6800
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mksexp(mybox,box,nterms,n22,mpole,mw1,mw2,mw3,
     1         rlams,nlambs,ndigit,numfor,numpys,nthmax,nxtot,nxtotp,
     2         mexpf1,mexpp1,rdplus,rdminu,
     3         mxpall(1,5),mxpall(1,6),mxpall(1,7),
     4         mxpall(1,8),xs,ys,zs)
c
           call mkslst3d(mybox,box,i1,n1,ix1,iy1,i2,n2,ix2,iy2,
     1         i3,n3,ix3,iy3,i4,n4,ix4,iy4,centrs,iw,list)
c
           call prcsss(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,
     2         mxpall(1,5),mxpall(1,6),mxpall(1,7),
     3         mxpall(1,8),xs,ys,zs,nxtotp)
c
 6800    continue
c
         do 7000 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if(box(3) .lt. 2**box(1)-1) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call mprttb('s',mw1,nterms,n22,mw2,mw3,rdplus,rdminu)
             call addexp3d(mw2,local(1,mybox),nterms)
           endif
 7000    continue
c
c-----------------------------------------------------------------------
c step 8 east:
c-----------------------------------------------------------------------
c
         do 7500 mbc = i1stkb, ilstkb
           do 7200 jj = 1,nxtotp
             lexp1(jj,mbc) = 0.0d0
 7200      continue
 7500    continue
c
         do 7700 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 7700
           if (box(2) .ge. 2**box(1)) goto 7700
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mkeexp(mybox,box,nterms,n22,mpole,mw1,mw2,mw3,rlams,
     1         nlambs,ndigit,numfor,numpys,nthmax,nxtot,nxtotp,
     2         mexpf1,mexpp1,rdplus,rdminu,mxpall(1,1),
     3         mxpall(1,2),mxpall(1,3),mxpall(1,4),
     4         mxpall(1,5),mxpall(1,6),mxpall(1,7),
     5         mxpall(1,8),xs,ys,zs)
c
           call mkelst3d(mybox,box,i1,n1,ix1,iy1,
     1         i2,n2,ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,
     2         i5,n5,ix5,iy5,i6,n6,ix6,iy6,i7,n7,ix7,iy7,
     3         i8,n8,ix8,iy8,centrs,iw,list)
c
           call prcsse(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,i5,n5,ix5,iy5, 
     2         i6,n6,ix6,iy6,i7,n7,ix7,iy7,i8,n8,ix8,iy8,
     3         mxpall(1,1),mxpall(1,2),mxpall(1,3),
     4         mxpall(1,4),mxpall(1,5),mxpall(1,6),
     5         mxpall(1,7),mxpall(1,8),xs,ys,zs,nxtotp)
c
 7700    continue
c
         do 7800 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (box(2) .gt. 2) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call mprttb('e',mw1,nterms,n22,mw2,mw3,rdplus,rdminu)
             call addexp3d(mw2,local(1,mybox),nterms)
           endif
 7800    continue
c
c-----------------------------------------------------------------------
c step 8 west:
c-----------------------------------------------------------------------
c
         do 8200 mbc = i1stkb, ilstkb
           do 8000 jj = 1,nxtotp
             lexp1(jj,mbc) = 0.0d0
 8000      continue
 8200    continue
c
         do 8400 mybox = ifirstbx, ilastbx
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (nkids .le. 0) goto 8400
           if (box(2) .le. 1) goto 8400
           nxtlvl = box(1)+1
           sc = scale(nxtlvl)
c
           call mkwexp(mybox,box,nterms,n22,mpole,mw1,mw2,mw3,rlams,
     1         nlambs,ndigit,numfor,numpys,nthmax,nxtot,nxtotp,
     2         mexpf1,mexpp1,rdplus,rdminu, mxpall(1,1),mxpall(1,2),
     3         mxpall(1,3),mxpall(1,4),mxpall(1,5),
     4         mxpall(1,6),mxpall(1,7),mxpall(1,8), xs,ys,zs)
c
           call mkwlst3d(mybox,box,i1,n1,ix1,iy1,
     1         i2,n2,ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,
     2         i5,n5,ix5,iy5,i6,n6,ix6,iy6,i7,n7,ix7,iy7,
     3         i8,n8,ix8,iy8,centrs,iw,list)
c
           call prcssw(sc,lexp1,i1,n1,ix1,iy1,i2,n2,
     1         ix2,iy2,i3,n3,ix3,iy3,i4,n4,ix4,iy4,i5,n5,ix5,iy5,
     2         i6,n6,ix6,iy6,i7,n7,ix7,iy7,i8,n8,ix8,iy8,
     3         mxpall(1,1),mxpall(1,2),mxpall(1,3),
     4         mxpall(1,4),mxpall(1,5),mxpall(1,6),
     5         mxpall(1,7),mxpall(1,8),xs,ys,zs,nxtotp)
c
 8400    continue
c
         do 8500 mybox = i1stkb, ilstkb
           call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
           if (box(2) .lt. 2**box(1)-1) then
             sc = scale(box(1))
             call phystf(ndigit,mexpf1,nlambs,rlams,numfor,numpys,
     1                   nthmax,lexp1(1,mybox))
             call xftota(ndigit,mw1,nterms,rlams,whts,nlambs,numfor,
     1                   nthmax,nxtot,mexpf1,sc)
             call mprttb('w',mw1,nterms,n22,mw2,mw3,rdplus,rdminu)
             call addexp3d(mw2,local(1,mybox),nterms)
           endif
 8500    continue
c
      return
      end
c
c
c
c
c
      subroutine btosfarpart3d(ifirstbx, ilastbx, centrs, centr0,
     1    nterms, mw3, local, iflagtype, iderivonoff, pptmp,
     2    dc, n22, scale, eps, sources, pot, potx, poty,
     3    potz, dipstr, dipvec, monocharge, iilev, iz, iw)
      implicit none
c
c step 6: this portion of the code handles list 4:
c         forming local expansions due to not well seperated list 4 box.
c
c-----------------------------------------------------------------------
c
c
      integer *4  mybox, ier, box(15), ifirstbx, ilastbx, nkids,
     1    box1(15), n22, iilev, mybxlv, mylstt,nlist, mykids,
     2    il, ilbox, npts, istart, mystrt, mypts, jat, kk, nterms,
     3    list(2000), iflagtype, iderivonoff, iz(1), iw(1)
c
      real *8  centrs(3,1), centr0(3), eps, sources(3,1),
     1    monocharge(1), dipstr(1), tmppot, tmpfld(3), scale(0:201),
     2    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2)),
     3    pot(1), potx(1), poty(1), potz(1), dipvec(3,1)
c
      complex *16  local((nterms+1)*(nterms+2)/2,*),
     1             mw3(0:nterms,0:nterms)
        mybxlv = iilev
        do 3000 mybox = ifirstbx, ilastbx
c
          mylstt = 4
c
          call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
c
          call d3mgetbk(ier,mybox,box1,centr0,mykids,iw)
c
          do 2000 il = 1, nlist
            ilbox = list(il)
c
            call d3mgetbk(ier,ilbox,box,centr0,nkids,iw)
c
            npts = box(15)
            istart = box(14) - 1
c
            if (mykids .gt. 0) then
c
              call formta3d(iflagtype, centrs(1,mybox),
     1            sources, monocharge, dipstr, dipvec, npts, mw3,
     2            nterms, n22, scale(mybxlv), dc, pptmp, iz, istart)
              call addx123d(mw3,nterms,local(1,mybox),nterms)
c
            endif
c
            if (mykids .le. 0) then
c
              mypts = box1(15)
              mystrt = box1(14) - 1
              do 1000 kk = 1, mypts
                jat = iz(mystrt+kk)
c
                call directcont3d(iflagtype, iderivonoff,
     1              npts, sources, monocharge, dipstr, dipvec,
     2              sources(1,jat), tmpfld, tmppot, eps,
     3              iz, jat, istart)
c
                pot(jat) = pot(jat) + tmppot
c
                if(iderivonoff .eq. 1)then
                  potx(jat) = potx(jat) + tmpfld(1)
                  poty(jat) = poty(jat) + tmpfld(2)
                  potz(jat) = potz(jat) + tmpfld(3)
                endif
c
 1000         continue
c
            endif

 2000     continue
 3000   continue
c
      return
      end
c
c
c
c
c
      subroutine handletata(w, lw, ifirstbx, ilastbx, centr0,
     1       nterms, mw3, local, imap, arr, rdsq3inv, rdsq3,
     2       mws1, nshort, zrot, rdmsq3inv, rdmsq3, iw)
      implicit none
c
c step 7: this portion of the code handles tata:
c         shifting local expansions from mybox to his kids.
c
c-----------------------------------------------------------------------
c

      integer *4  mybox, ier, box(15), lw, ifirstbx, ilastbx, k,
     1    mychld, jer, nkids, nshort, nterms, imap(1), iw(1)

      real *8  centr0(3), arr(1), zrot(8), w(1),
     1    rdsq3(0:nterms,0:nterms,-nterms:nterms),
     2    rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     3    rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     4    rdmsq3inv(0:nterms,0:nterms,-nterms:nterms)
c
      complex *16  local((nterms+1)*(nterms+2)/2,*),
     1    mw3(0:nterms,0:nterms), mws1(0:nshort,0:nshort)
        do 3000 mybox = ifirstbx, ilastbx
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .le. 0) goto 3000
c
          call maptmp3d(local(1,mybox),mw3,nterms)
c
          do 1000 k = 1,4
            mychld = box(5+k)
            if(mychld .le. 0) goto 1000
c
            call lcshft(jer,zrot(k),nterms,mw3,nshort,mws1,
     1                  rdsq3,rdsq3inv,arr,imap,w,lw)
            call addx123d(mws1,nshort,local(1,mychld),nterms)
c
 1000     continue
c
          do 2000 k = 5,8
            mychld = box(5+k)
            if(mychld .le. 0) goto 2000
c
            call lcshft(jer,zrot(k),nterms,mw3,nshort,mws1,
     1                  rdmsq3,rdmsq3inv,arr,imap,w,lw)
            call addx123d(mws1,nshort,local(1,mychld),nterms)
c
 2000     continue
c
 3000   continue
c
      return
      end
c
c
c
c
c
      subroutine stobfarpart3d(npts, istart, eps, sources,
     1    pot, potx, poty, potz, nterms, mw3, mpole, n22, scale,
     2    mybox, centr0, maxppb, iflagtype, iderivonoff, monocharge,
     3    dipstr, dipvec, dc, pptmp, iz, iw)
      implicit none
c
c     this subroutine computes the small to big far interactions.
c
c     pot, potx, poty, and potz are altered on output
c     to reflect the contributions computed here.
c
c-----------------------------------------------------------------------
c
c
      integer *4  npts, kk, istart, iat , iilvl, nterms, n22, nlist,
     1    mylstt, list(2000), ier, il, ilbox, box1(15), ikids, ipts,
     2    maxppb, mybox, iistrt, iflagtype, iderivonoff, iz(1), iw(1)
c
      real *8  eps, tmppot, tmpfld(3), sources(3,1), centr0(3),
     1    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2)),
     2    scale(0:201), monocharge(1), dipstr(1), dipvec(3,1),
     3    pot(1), potx(1), poty(1), potz(1)
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1             mw3(0:nterms,0:nterms)
        mylstt = 3
        call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
        do 3000 il = 1, nlist
c
          ilbox = list(il)
          call d3mgetbk(ier,ilbox,box1,centr0,ikids,iw)
          ipts = box1(15)
c
          if(ipts .le. maxppb)then
c
            iistrt = box1(14) - 1
c
            do 1000 kk = 1, npts
              iat = iz(istart+kk)
c
              call directcont3d(iflagtype, iderivonoff, ipts,
     1            sources, monocharge, dipstr, dipvec,
     2            sources(1,iat), tmpfld, tmppot, eps,
     3            iz, iat, iistrt)
c
              pot(iat) = pot(iat) + tmppot
c
              if(iderivonoff .eq. 1)then
                potx(iat) = potx(iat) + tmpfld(1)
                poty(iat) = poty(iat) + tmpfld(2)
                potz(iat) = potz(iat) + tmpfld(3)
              endif
c
 1000       continue
c
          endif
c
          if(ipts .gt. maxppb)then
c
            iilvl = box1(1)
            call maptmp3d(mpole(1,ilbox),mw3,nterms)
            do 2000 kk = 1, npts
c
              iat = iz(istart+kk)
              call mpeval3d(iderivonoff, mw3, centr0,
     1            sources(1,iat), nterms, n22, tmppot,
     2            tmpfld, scale(iilvl), dc, pptmp)
c
              pot(iat) = pot(iat) + tmppot
c
              if(iderivonoff .eq. 1)then
                potx(iat) = potx(iat) + tmpfld(1)
                poty(iat) = poty(iat) + tmpfld(2)
                potz(iat) = potz(iat) + tmpfld(3)
              endif
c
 2000       continue
c
          endif
c
 3000   continue
c
      return
      end
c
c
c
c
c
      subroutine downpassrivtarg3d(iflagtype, iderivonoff, nlev, nterms,
     1    ndigit, imap, nlambs, nxtotp, nxtot, n22, nshort, w, lw,
     2    nthmax, numpys, numfor, centrs, centr0, sources, monocharge,
     3    dipstr, dipvec, eps, rlams, pot, potx, poty, potz, targets,
     4    pottar, pottarx, pottary, pottarz, arr, zs, rdplus, rdminu,
     5    rdsq3, rdsq3inv, rdmsq3, rdmsq3inv, rd, dc, whts, pptmp,
     6    scale, zrot, mpole, local, lexp1, mexpf1, mexpp1, mxpall,
     7    xs, ys, mw1, mw2, mw3, mws1, laddr, iw, izsour, zboxsour,
     8    iztarg, zboxtarg, itargflag)
      implicit none
c
c
      integer *4  nlev, nterms, ndigit, imap(1), nlambs, n22, nxtot,
     1   nxtotp, nshort, iilev, ifirstbx, ilastbx, w(1), lw, nthmax,
     2   numpys, numfor, iflagtype, iderivonoff, laddr(2,1), iw(1),
     3   izsour(1), zboxsour(2,1), iztarg(1), zboxtarg(2,1), itargflag
c
      real *8  centrs(3,1), centr0(3), sources(3,1), monocharge(1),
     1   dipstr(1), dipvec(3,1), eps, rlams, arr(1), targets(3,1),
     2   rdplus(0:nterms,0:nterms,-nterms:nterms), pot(1),
     3   rdminu(0:nterms,0:nterms,-nterms:nterms), potx(1),
     4   rdsq3(0:nterms,0:nterms,-nterms:nterms), poty(1),
     5   rdsq3inv(0:nterms,0:nterms,-nterms:nterms), potz(1),
     6   rdmsq3(0:nterms,0:nterms,-nterms:nterms), pottar(1),
     7   rdmsq3inv(0:nterms,0:nterms,-nterms:nterms), pottarx(1),
     8   rd(0:nterms,0:nterms,-nterms:nterms), pottary(1),
     9   dc(0:4*nterms,0:4*nterms), whts(nlambs), pottarz(1),
     1   pptmp((n22+2)*(n22+2)), scale(0:201), zrot(8), zs(3,nxtotp)
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1   local((nterms+1)*(nterms+2)/2,*),
     2   lexp1(nxtotp,*), mexpf1(nxtot), mexpp1(nxtotp),
     3   mxpall(nxtotp,8), xs(3,nxtotp), ys(3,nxtotp),
     4   mw1(0:nterms,0:nterms), mw2(0:nterms,0:nterms),
     5   mw3(0:nterms,0:nterms), mws1(0:nshort,0:nshort)
        do 1000 iilev = 0, nlev-1
          ifirstbx = laddr(1,iilev+1)
          ilastbx = ifirstbx + laddr(2,iilev+1) - 1
c
c-----------------------------------------------------------------------
c step 6: this portion of the code handles list 4:
c         forming local expansions due to not well seperated list 4 box.
c-----------------------------------------------------------------------
c
          call btosfarparttarg3d(ifirstbx, ilastbx, centrs, centr0,
     1        nterms, mw3, local, iflagtype, iderivonoff, pptmp, dc,
     2        n22, scale, eps, sources, pot, potx, poty, potz,
     3        pottar, pottarx, pottary, pottarz, dipstr, dipvec,
     4        monocharge, iilev, iw, izsour, zboxsour,
     5        iztarg, zboxtarg, targets, itargflag)
c
c-----------------------------------------------------------------------
c step 7: this portion of the code handles tata:
c         shifting local expansions from mybox to his kids.
c-----------------------------------------------------------------------
c
          call handletata(w, lw, ifirstbx, ilastbx, centr0, nterms,
     1        mw3, local, imap, arr, rdsq3inv, rdsq3, mws1,
     2        nshort, zrot, rdmsq3inv, rdmsq3, iw)
c
c-----------------------------------------------------------------------
c step 8: here begins the code that handles list 2:
c         be aware of that lota is done at son's level, so if mybox is 
c         childless, it is skipped.
c-----------------------------------------------------------------------
c
          call handlelist2(nterms, n22, nlambs, numfor, numpys,
     1        nxtot, nxtotp, nthmax, centrs, mpole, local, dc,
     2        rdplus, rdminu, whts, rlams, lexp1, mexpf1, mexpp1,
     3        mxpall, xs, ys, zs, mw1, mw2, mw3, rd, ndigit, 
     4        ifirstbx, ilastbx, scale, iilev, laddr, iw)
c
 1000   continue
c
c-----------------------------------------------------------------------
c step 6a: this portion of the code handles part of list 4 which are
c     unaccounted in above downward pass sweep.
c-----------------------------------------------------------------------
c
        if(nlev .eq. 0) return
c
        iilev = nlev
c
        ifirstbx = laddr(1,nlev+1)
        ilastbx = ifirstbx + laddr(2,nlev+1) - 1
c
        call btosfarparttarg3d(ifirstbx, ilastbx, centrs, centr0,
     1      nterms, mw3, local, iflagtype, iderivonoff, pptmp, dc,
     2      n22, scale, eps, sources, pot, potx, poty, potz,
     3      pottar, pottarx, pottary, pottarz, dipstr, dipvec,
     4      monocharge, iilev, iw, izsour, zboxsour,
     5      iztarg, zboxtarg, targets, itargflag)
c
      return
      end
c
c
c
c
c
      subroutine btosfarparttarg3d(ifirstbx, ilastbx, centrs, centr0,
     1     nterms, mw3, local, iflagtype, iderivonoff, pptmp, dc, n22,
     2     scale, eps, sources, pot, potx, poty, potz, pottar, pottarx,
     3     pottary, pottarz, dipstr, dipvec, monocharge, iilev, iw,
     4     izsour, zboxsour, iztarg, zboxtarg, targets, itargflag)
      implicit none
c
c-----------------------------------------------------------------------
c step 6: this portion of the code handles list 4:
c         forming local expansions due to not well seperated list 4 box.
c-----------------------------------------------------------------------
c
c
      integer *4  mybox, ier, box(15), ifirstbx, ilastbx, nkids,
     1    box1(15), n22, iilev, mybxlv, mylstt,nlist, mykids,
     2    il, ilbox, npts, istart, mystrt, mypts, jat, kk, nterms,
     3    list(2000), iflagtype, iderivonoff, iw(1), izsour(1),
     4    zboxsour(2,1), iskip, iztarg(1), zboxtarg(2,1), itargflag
c
      real *8  centrs(3,1), centr0(3), eps, sources(3,1),
     1    monocharge(1), dipstr(1), tmppot, tmpfld(3), scale(0:201),
     2    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2)),
     3    pot(1), potx(1), poty(1), potz(1), dipvec(3,1),
     4    pottar(1), pottarx(1), pottary(1), pottarz(1), targets(3,1)
c
      complex *16  local((nterms+1)*(nterms+2)/2,*),
     1    mw3(0:nterms,0:nterms)
        mybxlv = iilev
        do 4000 mybox = ifirstbx, ilastbx
c
          mylstt = 4
c
          call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
c
          call d3mgetbk(ier,mybox,box1,centr0,mykids,iw)
c
          do 3000 il = 1, nlist
            ilbox = list(il)
c
            call d3mgetbk(ier,ilbox,box,centr0,nkids,iw)
c
            npts = zboxsour(2,ilbox)
            istart = zboxsour(1,ilbox) - 1
c
            if (mykids .gt. 0) then
c
              call formtatarg3d(iflagtype, centrs(1,mybox),
     1            sources, monocharge, dipstr, dipvec, mw3,
     2            nterms, n22, scale(mybxlv), dc, pptmp,
     3            izsour, zboxsour, ilbox)
c
              call addx123d(mw3,nterms,local(1,mybox),nterms)
c
            endif
c
            if (mykids .le. 0) then
c
              if(itargflag .eq. 1)then
c
                mypts = zboxsour(2,mybox)
                mystrt = zboxsour(1,mybox) - 1
c
                do 1000 kk = 1, mypts
                  jat = izsour(mystrt+kk)
c
                  call directcont3d(iflagtype, iderivonoff,
     1                npts, sources, monocharge, dipstr, dipvec,
     2                sources(1,jat), tmpfld, tmppot, eps,
     3                izsour, jat, istart)
c
                  pot(jat) = pot(jat) + tmppot
c
                  if(iderivonoff .eq. 1)then
                    potx(jat) = potx(jat) + tmpfld(1)
                    poty(jat) = poty(jat) + tmpfld(2)
                    potz(jat) = potz(jat) + tmpfld(3)
                  endif
c
 1000           continue
c
              endif
c
              mypts = zboxtarg(2,mybox)
              mystrt = zboxtarg(1,mybox) - 1
c
              do 2000 kk = 1, mypts
                jat = iztarg(mystrt+kk)
c
                iskip = 0
c
                call directconttarg3d(iflagtype, iderivonoff,
     1              npts, sources, monocharge, dipstr, dipvec,
     2              targets(1,jat), tmpfld, tmppot, eps,
     3              izsour, iskip, istart)
c
                pottar(jat) = pottar(jat) + tmppot
c
                if(iderivonoff .eq. 1)then
                  pottarx(jat) = pottarx(jat) + tmpfld(1)
                  pottary(jat) = pottary(jat) + tmpfld(2)
                  pottarz(jat) = pottarz(jat) + tmpfld(3)
                endif
c
 2000         continue
c
            endif
c
 3000     continue
 4000   continue
c
      return
      end
c
C///////////////////////////////////////////////////////////////////////
      subroutine ftophys12(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1)
      real *8     rlams(nlambs),pi
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      complex *16 ztmp,ztheta,eye
C-----------------------------------------------------------------------
      data eye/(0.0d0,1.0d0)/
      pi=4.0d0*datan(1.0d0)
      nftot = 1
      nptot  = 1
C_lambda_1
      call ftp8to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+4
C_lambda_2
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_3
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_4
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_5
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_6
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_7
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_8
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_9
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_10
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_11
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_12
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_13
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_14
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_15
      call ftpnnto72fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+36
C_lambda_16
      call ftpnnto72fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+36
C_lambda_17
      call ftpnnto80fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+40
C_lambda_18
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+44
C_lambda_19
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+44
C_lambda_20
      call ftpnnto96fft(mexpf(nftot),mexpphys(nptot),23)
cc      do iii = 1, 23
cc         print *, mexpf(nftot+iii-1)
cc      enddo
cc      print *, 'out physical modes:***'
cc      do iii = 1, 48
cc         print *, mexpphys(nptot+iii-1)
cc      enddo
cc      pause 'check'
      nftot = nftot+23
      nptot = nptot+48
C_lambda_21
      call ftpnnto96fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+48
C_lambda_22
      call ftpnnto104fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_23
      call ftpnnto104fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_24
      call ftpnnto104fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_25
      call ftpnnto124fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_26
      call ftpnnto124fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_27
      call ftpnnto124fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_28
      call ftpnnto124fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_29
      call ftpnnto132fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_30
      call ftpnnto132fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_31
      call ftpnnto132fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_32
      call ftpnnto124fft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_33
      call ftpnnto104fft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+52
C_lambda_34
ccc      call ftpnnto4fft(mexpf(nftot),mexpphys(nptot),16)
      do i = 0, 1
         ztheta=i*pi/2*eye
         ztmp = mexpf(nftot)
         do j = 1, 15, 2
            ztmp = ztmp+2*eye*dimag(mexpf(nftot+j)*cdexp(j*ztheta))
c            ztmp = ztmp+2*eye*dimag(mexpf(nftot+j)*cdexp((j-1)*ztheta))
         enddo
         do j = 2, 15, 2
            ztmp = ztmp+2*dreal(mexpf(nftot+j)*cdexp(j*ztheta))
c            ztmp = ztmp+2*dreal(mexpf(nftot+j)*cdexp((j-1)*ztheta))
         enddo
         mexpphys(nptot+i) = ztmp
      enddo
      nftot = nftot+16
      nptot = nptot+2
C_lambda_35
      do i = 0, 1
         mexpphys(nptot+i) = mexpf(nftot)
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto96fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 48)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto104fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 52)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto124fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 62)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto132fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 66)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
c
c///////////////////////////////////////////////////////////////////////
      subroutine ftophys1(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine evaluates the fourier expansion of the
c     exponential moment function m(\lambda,\alpha) at equispaced
c     nodes.
c
c input:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2  etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows.
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)).
c         etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer *4  nlambs, nmfour(nlambs), nmphys(nlambs), nthmax
c
      real *8  rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      mxphys(1)=mexpf(1)
      mxphys(2)=mexpf(1)
      nftot = nftot+1
      nptot = nptot+2
c_lambda_2
      call fp2t4(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_3
      call fp2t4(mexpf(nftot),mxphys(nptot))
ccc      nftot = nftot+2
ccc      nptot = nptot+2
c=======================================================================
      return
      end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine ftophys2(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine evaluates the fourier expansion of the
c     exponential moment function m(\lambda,\alpha) at equispaced
c     nodes.
c
c input:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2  etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows.
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)).
c         etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer *4  nlambs, nmfour(nlambs), nmphys(nlambs), nthmax
c
      real *8  rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      call fp2t4(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_2
      call fp2t8(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+4
c_lambda_3
      call fp3t8(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_4
      call fp3t8(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_5
ccc      call fp1t4(mexpf(nftot),mxphys(nptot))
      mxphys(nptot)=mexpf(nftot)
      mxphys(nptot+1)=mexpf(nftot)
c=======================================================================
      return
      end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp2t8(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,2), mxphys(2,4)
c
      data sq2/1.4142135623731d0/
      xa = mexpf(1,1)
c
      mxphys(1,1) = xa
      mxphys(2,1) = 2*mexpf(2,2)
c
      mxphys(1,2) = xa
      mxphys(2,2) = sq2*(mexpf(1,2)+mexpf(2,2))
c
      mxphys(1,3) = xa
      mxphys(2,3) = 2*mexpf(1,2)
c
      mxphys(1,4) = xa
      mxphys(2,4) = sq2*(mexpf(1,2)-mexpf(2,2))
c=======================================================================
      return
      end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine ftophys3(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine evaluates the fourier expansion of the
c     exponential moment function m(\lambda,\alpha) at equispaced
c     nodes.
c
c input:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2  etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows.
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)).
c         etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer *4  nlambs, nmfour(nlambs), nmphys(nlambs), nthmax
c
      real *8  rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      call fp2t4(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_2
      call fp3t8(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_3
      call fp4t16(mexpf(nftot),mxphys(nptot))
      nftot = nftot+4
      nptot = nptot+8
c_lambda_4
      call fp4t16(mexpf(nftot),mxphys(nptot))
      nftot = nftot+4
      nptot = nptot+8
c_lambda_5
      call fp5t24(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+12
c_lambda_6
      call fp5t24(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+12
c_lambda_7
      call fp5t8(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+4
c_lambda_8
      call fp3t4(mexpf(nftot),mxphys(nptot))
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp2t4(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      real *8  mexpf(2,2), mxphys(2,2)
      xa = mexpf(1,1)
c
      mxphys(1,1) = xa
      mxphys(2,1) = 2*mexpf(2,2)
c
      mxphys(1,2) = xa
      mxphys(2,2) = 2*mexpf(1,2)
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp3t4(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      real *8  mexpf(2,3), mxphys(2,2)
      xa = mexpf(1,1)
      xb = 2*mexpf(1,3)
c
      mxphys(1,1) = xa+xb
      mxphys(2,1) = 2*mexpf(2,2)
c
      mxphys(1,2) = xa-xb
      mxphys(2,2) = 2*mexpf(1,2)
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp3t8(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,3), mxphys(2,4)
c
      data sq2/1.4142135623731d0/
      xa = mexpf(1,1)
      xb = 2*mexpf(1,3)
      xc = 2*mexpf(2,3)
c
      mxphys(1,1) = xa+xb
      mxphys(2,1) = 2*mexpf(2,2)
c
      mxphys(1,2) = xa-xc
      mxphys(2,2) = sq2*(mexpf(1,2)+mexpf(2,2))
c
      mxphys(1,3) = xa-xb
      mxphys(2,3) = 2*mexpf(1,2)
c
      mxphys(1,4) = xa+xc
      mxphys(2,4) = sq2*(mexpf(1,2)-mexpf(2,2))
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp5t8(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,5), mxphys(2,4)
c
      data hsq2/0.70710678118655d0/
      x25=2*mexpf(1,5)
      xa = mexpf(1,1)+x25
      xc = mexpf(1,1)-x25
      xb = 2*mexpf(1,3)
      xd = 2*mexpf(2,3)
c
      x1=2*mexpf(1,2)
      x2=2*mexpf(1,4)
      x12 = x1+x2
c
      x3=2*mexpf(2,2)
      x4=2*mexpf(2,4)
      x34=x3-x4
c
      mxphys(1,1) = xa+xb
      mxphys(2,1) = x3+x4
c
      mxphys(1,2) = xc-xd
      mxphys(2,2) = hsq2*(x12+x34)
c
      mxphys(1,3) = xa-xb
      mxphys(2,3) = x1-x2
c
      mxphys(1,4) = xc+xd
      mxphys(2,4) = hsq2*(x12-x34)
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp4t16(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,4), mexp2(2,4),
     1         mxphys(2,8), exps16(2,8)
c
c
      data hsq2/0.70710678118655d0/
      data exps16/1.0d0,             0.d0,
     1            0.92387953251129d0,0.38268343236509d0,
     2            0.70710678118655d0,0.70710678118655d0,
     3            0.38268343236509d0,0.92387953251129d0,
     4            0.0d0,             1.0d0,
     5           -0.38268343236509d0,0.92387953251129d0,
     6           -0.70710678118655d0,0.70710678118655d0,
     7           -0.92387953251129d0,0.38268343236509d0/
      call fft4t4(mexpf,mxphys(1,1),mxphys(1,3),
     1       mxphys(1,5),mxphys(1,7))
c
      mexp2(1,1) = mexpf(1,1)
      do 101 i = 2, 4
         mexp2(1,i) = exps16(1,i)*mexpf(1,i)-exps16(2,i)*mexpf(2,i)
         mexp2(2,i) = exps16(1,i)*mexpf(2,i)+exps16(2,i)*mexpf(1,i)
 101  continue
c
      call fft4t4(mexp2,mxphys(1,2),mxphys(1,4),
     1       mxphys(1,6),mxphys(1,8))
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine fp5t24(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,5), mexp2(2,5),
     1  mxphys(2,12), exps24(2,8)
c
      data exps24/1.0d0,      0.d0,
     1     0.96592582628907d0,0.25881904510252d0,
     2     0.86602540378444d0,0.50000000000000d0,
     3     0.70710678118655d0,0.70710678118655d0,
     4     0.50000000000000d0,0.86602540378444d0,
     5     0.25881904510252d0,0.96592582628907d0,
     6     0.0d0,             1.0d0,
     7    -0.25881904510252d0,0.96592582628907d0/
      call fft5t4(mexpf,mxphys(1,1),mxphys(1,4),
     1       mxphys(1,7),mxphys(1,10))
c
      mexp2(1,1) = mexpf(1,1)
      do 101 i = 2, 4
         xa = mexpf(1,i)
         xb = mexpf(2,i)
         xc = exps24(1,i)
         xd = exps24(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
 101  continue
      mexp2(1,5) = exps24(1,5)*mexpf(1,5)-exps24(2,5)*mexpf(2,5)
c
      call fft5t4(mexp2,mxphys(1,2),mxphys(1,5),
     1       mxphys(1,8),mxphys(1,11))
c
      do 102 i = 2, 4
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps24(1,i)
         xd = exps24(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
 102  continue
      mexp2(1,5) = exps24(1,5)*mexpf(1,5)-exps24(2,5)*mexpf(2,5)
c
      call fft5t4(mexp2,mxphys(1,3),mxphys(1,6),
     1       mxphys(1,9),mxphys(1,12))
c=======================================================================
      return
      end
c 
c///////////////////////////////////////////////////////////////////////
      subroutine fft4t4(mexpf,w1,w2,w3,w4)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,4), w1(2), w2(2), w3(2), w4(2)
c
      data sq2/1.4142135623731d0/
      x1 = mexpf(1,2)
      x2 = mexpf(1,4)
      xa = x1+x2
c
      x3 = mexpf(2,2)
      x4 = mexpf(2,4)
      xb = x3-x4
c
      xd = 2*mexpf(1,3)
      xe = 2*mexpf(2,3)
c
      xf = mexpf(1,1)
c
      w1(1) = xf+xd
      w1(2) = 2*(x3+x4)
c
      w2(1) = xf-xe
      w2(2) = sq2*(xa+xb)
c
      w3(1) = xf-xd
      w3(2) = 2*(x1-x2)
c
      w4(1) = xf+xe
      w4(2) = sq2*(xa-xb)
c=======================================================================
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine fft5t4(mexpf,w1,w2,w3,w4)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,5), w1(2), w2(2), w3(2), w4(2)
c
      data sq2/1.4142135623731d0/
      x1 = mexpf(1,2)
      x2 = mexpf(1,4)
      xa = x1+x2
c
      x3 = mexpf(2,2)
      x4 = mexpf(2,4)
      xb = x3-x4
c
      xd = 2*mexpf(1,3)
      xe = 2*mexpf(2,3)
c
      xx15 = 2*mexpf(1,5)
      xf = mexpf(1,1)+xx15
      xg = mexpf(1,1)-xx15
c
      w1(1) = xf+xd
      w1(2) = 2*(x3+x4)
c
      w2(1) = xg-xe
      w2(2) = sq2*(xa+xb)
c
      w3(1) = xf-xd
      w3(2) = 2*(x1-x2)
c
      w4(1) = xg+xe
      w4(2) = sq2*(xa-xb)
c
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftophys6(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C Purpose:
C     This subroutine evaluates the Fourier expansion of the
C     exponential moment function M(\lambda,\alpha) at equispaced
C     nodes.
C
C Input:
C     MEXPF(*):     Fourier coefficients of the function 
C                   MEXP(lambda,alpha) for discrete lambda values. 
C                   They are ordered as follows:
C               MEXPF(1,...,NUMFOUR(1)) = Fourier modes for lambda_1
C               MEXPF(NUMFOUR(1)+1,...,NUMFOUR(2)) = Fourier modes
C                                              for lambda_2  etc.
C     NLAMBS:        number of discretization pts. in lambda integral
C     RLAMS(NLAMBS): discretization points in lambda integral.
C     NUMFOUR(j):   number of Fourier modes in the expansion
C                      of the function M(\lambda_j,\alpha)
C     NTHMAX =      max_j NUMFOUR(j)
C
C Output:
C     MEXPPHYS(*):  Discrete values of the moment function 
C                   M(\lambda,\alpha), ordered as follows.
C         MEXPPHYS(1),...,MEXPPHYS(NUMPHYS(1)) = M(\lambda_1,0),..., 
C              M(\lambda_1, 2*PI*(NUMPHYS(1)-1)/NUMPHYS(1)).
C         MEXPPHYS(NUMPHYS(1)+1),...,MEXPPHYS(NUMPHYS(2)) = 
C              M(\lambda_2,0),...,
C                  M(\lambda_2, 2*PI*(NUMPHYS(2)-1)/NUMPHYS(2)).
C         etc.
C
C-----------------------------------------------------------------------
      implicit real *8 (a-h,o-z)
c
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      real *8     rlams(nlambs)
      complex *16 mexpf(1)
c
      complex *16 mexpphys(1)
      nftot = 1
      nptot  = 1
C
      call ftp3to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
C
      call ftp4to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+4
      nptot = nptot+4
C
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C
      call ftp8to24(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+12
C
      call ftp8to32(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+16
C
      call ftp11to32fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+16
C
      call ftp11to32fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+16
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp11to48(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ftp8to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+4
C
      do i = 0, 1
         mexpphys(nptot+i) = mexpf(nftot)
      enddo
c=======================================================================
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp3to8(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,3)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data sq2/1.4142135623731d0/
      xa = mexpf(1,1)
      xb = 2*mexpf(1,3)
      xc = 2*mexpf(2,3)
C
      mexpphys(1,1) = xa+xb
      mexpphys(2,1) = 2*mexpf(2,2)
C
      mexpphys(1,2) = xa-xc
      mexpphys(2,2) = sq2*(mexpf(1,2)+mexpf(2,2))
C
      mexpphys(1,3) = xa-xb
      mexpphys(2,3) = 2*mexpf(1,2)
C
      mexpphys(1,4) = xa+xc
      mexpphys(2,4) = sq2*(mexpf(1,2)-mexpf(2,2))
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp8to8(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data hsq2/0.70710678118655d0/
      x25=2*mexpf(1,5)
      xa = mexpf(1,1)+x25
      xc = mexpf(1,1)-x25
      xb = 2*(mexpf(1,3)+mexpf(1,7))
      xd = 2*(mexpf(2,3)-mexpf(2,7))
C
      x1=2*(mexpf(1,2)-mexpf(1,8))
      x2=2*(mexpf(1,4)-mexpf(1,6))
      x12 = x1+x2
C
      x3=2*(mexpf(2,2)+mexpf(2,8))
      x4=2*(mexpf(2,4)+mexpf(2,6))
      x34=x3-x4
C
      mexpphys(1,1) = xa+xb
      mexpphys(2,1) = x3+x4
C
      mexpphys(1,2) = xc-xd
      mexpphys(2,2) = hsq2*(x12+x34)
C
      mexpphys(1,3) = xa-xb
      mexpphys(2,3) = x1-x2
C
      mexpphys(1,4) = xc+xd
      mexpphys(2,4) = hsq2*(x12-x34)
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp4to8(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,4)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data sq2/1.4142135623731d0/
      xa = mexpf(1,1)
      xb = 2*mexpf(1,3)
      xc = 2*mexpf(2,3)
      xd = mexpf(1,2) + mexpf(1,4)
      xe = mexpf(2,2) - mexpf(2,4)
C
      mexpphys(1,1) = xa+xb
      mexpphys(2,1) = 2*(mexpf(2,2)+mexpf(2,4))
C
      mexpphys(1,2) = xa-xc
      mexpphys(2,2) = sq2*(xd+xe)
C
      mexpphys(1,3) = xa-xb
      mexpphys(2,3) = 2*(mexpf(1,2)-mexpf(1,4))
C
      mexpphys(1,4) = xa+xc
      mexpphys(2,4) = sq2*(xd-xe)
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp8to16(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 mexp2(2,8)
      real *8 mexpphys(2,8)
      real *8 exps16(2,8)
C***********************************************************************
C
      data hsq2/0.70710678118655d0/
      data exps16/1.0d0,             0.d0,
     1            0.92387953251129d0,0.38268343236509d0,
     2            0.70710678118655d0,0.70710678118655d0,
     3            0.38268343236509d0,0.92387953251129d0,
     4            0.0d0,             1.0d0,
     5           -0.38268343236509d0,0.92387953251129d0,
     6           -0.70710678118655d0,0.70710678118655d0,
     7           -0.92387953251129d0,0.38268343236509d0/
      call fft8to4(mexpf,mexpphys(1,1),mexpphys(1,3),
     1       mexpphys(1,5),mexpphys(1,7))
C
      mexp2(1,1) = mexpf(1,1)
      do i = 2, 8
         mexp2(1,i) = exps16(1,i)*mexpf(1,i)-exps16(2,i)*mexpf(2,i)
         mexp2(2,i) = exps16(1,i)*mexpf(2,i)+exps16(2,i)*mexpf(1,i)
      enddo
C
      call fft8to4(mexp2,mexpphys(1,2),mexpphys(1,4),
     1       mexpphys(1,6),mexpphys(1,8))
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp8to24(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 mexp2(2,8)
      real *8 mexpphys(2,12)
      real *8 exps24(2,8)
C***********************************************************************
C
      data exps24/1.0d0,      0.d0,
     1     0.96592582628907d0,0.25881904510252d0,
     2     0.86602540378444d0,0.50000000000000d0,
     3     0.70710678118655d0,0.70710678118655d0,
     4     0.50000000000000d0,0.86602540378444d0,
     5     0.25881904510252d0,0.96592582628907d0,
     6     0.0d0,             1.0d0,
     7    -0.25881904510252d0,0.96592582628907d0/
      call fft8to4(mexpf,mexpphys(1,1),mexpphys(1,4),
     1       mexpphys(1,7),mexpphys(1,10))
C
      mexp2(1,1) = mexpf(1,1)
      do i = 2, 8
         xa = mexpf(1,i)
         xb = mexpf(2,i)
         xc = exps24(1,i)
         xd = exps24(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft8to4(mexp2,mexpphys(1,2),mexpphys(1,5),
     1       mexpphys(1,8),mexpphys(1,11))
C
      do i = 2, 8
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps24(1,i)
         xd = exps24(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft8to4(mexp2,mexpphys(1,3),mexpphys(1,6),
     1       mexpphys(1,9),mexpphys(1,12))
C
      return
      end
C 
C///////////////////////////////////////////////////////////////////////
      subroutine ftp8to32(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 mexp2(2,8)
      real *8 mexpphys(2,16)
      real *8 exps32(2,8)
C***********************************************************************
C
      data exps32/1.0d0,     0.d0,
     2    0.98078528040323d0,0.19509032201613d0,
     3    0.92387953251129d0,0.38268343236509d0,
     4    0.83146961230255d0,0.55557023301960d0,
     5    0.70710678118655d0,0.70710678118655d0,
     6    0.55557023301960d0,0.83146961230255d0,
     7    0.38268343236509d0,0.92387953251129d0,
     8    0.19509032201613d0,0.98078528040323d0/
      call fft8to4(mexpf,mexpphys(1,1),mexpphys(1,5),
     1       mexpphys(1,9),mexpphys(1,13))
C
      mexp2(1,1) = mexpf(1,1)
      do i = 2, 8
         xa = mexpf(1,i)
         xb = mexpf(2,i)
         xc = exps32(1,i)
         xd = exps32(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft8to4(mexp2,mexpphys(1,2),mexpphys(1,6),
     1       mexpphys(1,10),mexpphys(1,14))
C
      do i = 2, 8
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps32(1,i)
         xd = exps32(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft8to4(mexp2,mexpphys(1,3),mexpphys(1,7),
     1       mexpphys(1,11),mexpphys(1,15))
C
      do i = 2, 8
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps32(1,i)
         xd = exps32(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft8to4(mexp2,mexpphys(1,4),mexpphys(1,8),
     1       mexpphys(1,12),mexpphys(1,16))
C
      return
      end
C 
C///////////////////////////////////////////////////////////////////////
      subroutine ftp11to36(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,11)
      real *8 mexp2(2,11)
      real *8 mexpphys(2,18)
      real *8 exps36(2,11)
C***********************************************************************
C
      data exps36/ 1.000000d0,   0.d0,
     2     0.98480775301221d0,    0.17364817766693d0,
     3     0.93969262078591d0,    0.34202014332567d0,
     4     0.86602540378444d0,    0.50000000000000d0,
     5     0.76604444311898d0,    0.64278760968654d0,
     6     0.64278760968654d0,    0.76604444311898d0,
     7     0.50000000000000d0,    0.86602540378444d0,
     8     0.34202014332567d0,    0.93969262078591d0,
     9     0.17364817766693d0,    0.98480775301221d0,
     1     0.0d0,                  1.0000000000000d0,
     2    -0.17364817766693d0,    0.98480775301221d0/
      call fft11to6(mexpf,mexpphys(1,1),mexpphys(1,4),mexpphys(1,7),
     1    mexpphys(1,10),mexpphys(1,13),mexpphys(1,16))
C
      mexp2(1,1) = mexpf(1,1)
      do i = 2, 11
         xa = mexpf(1,i)
         xb = mexpf(2,i)
         xc = exps36(1,i)
         xd = exps36(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft11to6(mexp2,mexpphys(1,2),mexpphys(1,5),mexpphys(1,8),
     1    mexpphys(1,11),mexpphys(1,14),mexpphys(1,17))
C
      do i = 2, 11
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps36(1,i)
         xd = exps36(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft11to6(mexp2,mexpphys(1,3),mexpphys(1,6),mexpphys(1,9),
     1    mexpphys(1,12),mexpphys(1,15),mexpphys(1,18))
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp11to48(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,11)
      real *8 mexp2(2,11)
      real *8 mexpphys(2,24)
      real *8 exps48(2,11)
C***********************************************************************
C
      data exps48/1.0000d0,    0.d0,
     2    0.99144486137381d0,    0.13052619222005d0,
     3    0.96592582628907d0,    0.25881904510252d0,
     4    0.92387953251129d0,    0.38268343236509d0,
     5    0.86602540378444d0,    0.50000000000000d0,
     6    0.79335334029124d0,    0.60876142900872d0,
     7    0.70710678118655d0,    0.70710678118655d0,
     8    0.60876142900872d0,    0.79335334029124d0,
     9    0.50000000000000d0,    0.86602540378444d0,
     1    0.38268343236509d0,    0.92387953251129d0,
     2    0.25881904510252d0,    0.96592582628907d0/
      call fft11to6(mexpf,mexpphys(1,1),mexpphys(1,5),mexpphys(1,9),
     1    mexpphys(1,13),mexpphys(1,17),mexpphys(1,21))
C
      mexp2(1,1) = mexpf(1,1)
      do i = 2, 11
         xa = mexpf(1,i)
         xb = mexpf(2,i)
         xc = exps48(1,i)
         xd = exps48(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft11to6(mexp2,mexpphys(1,2),mexpphys(1,6),mexpphys(1,10),
     1    mexpphys(1,14),mexpphys(1,18),mexpphys(1,22))
C
      do i = 2, 11
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps48(1,i)
         xd = exps48(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft11to6(mexp2,mexpphys(1,3),mexpphys(1,7),mexpphys(1,11),
     1    mexpphys(1,15),mexpphys(1,19),mexpphys(1,23))
C
      do i = 2, 11
         xa = mexp2(1,i)
         xb = mexp2(2,i)
         xc = exps48(1,i)
         xd = exps48(2,i)
         mexp2(1,i) = xc*xa-xd*xb
         mexp2(2,i) = xc*xb+xa*xd
      enddo
      call fft11to6(mexp2,mexpphys(1,4),mexpphys(1,8),mexpphys(1,12),
     1    mexpphys(1,16),mexpphys(1,20),mexpphys(1,24))
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine fft8to4(mexpf,w1,w2,w3,w4)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 w1(1), w2(1), w3(1), w4(1)
C***********************************************************************
C
      data sq2/1.4142135623731d0/
      x1 = mexpf(1,2)-mexpf(1,8)
      x2 = mexpf(1,4)-mexpf(1,6)
      xa = x1+x2
C
      x3 = mexpf(2,2)+mexpf(2,8)
      x4 = mexpf(2,4)+mexpf(2,6)
      xb = x3-x4
C
      xd = 2*(mexpf(1,3)+mexpf(1,7))
      xe = 2*(mexpf(2,3)-mexpf(2,7))
C
      xx15 = 2*mexpf(1,5)
      xf = mexpf(1,1)+xx15
      xg = mexpf(1,1)-xx15
C
      w1(1) = xf+xd
      w1(2) = 2*(x3+x4)
C
      w2(1) = xg-xe
      w2(2) = sq2*(xa+xb)
C
      w3(1) = xf-xd
      w3(2) = 2*(x1-x2)
C
      w4(1) = xg+xe
      w4(2) = sq2*(xa-xb)
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine fft11to6(mexpf,w1,w2,w3,w4,w5,w6)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,11)
      real *8 w1(1),w2(1),w3(1),w4(1),w5(1),w6(1)
C***********************************************************************
C
      data sq3/1.7320508075689d0/
      xa1=mexpf(1,3)+mexpf(1,11)
      xa2=mexpf(1,5)+mexpf(1,9)
      xa=xa1+xa2
      xc=xa1-xa2
C
      xb1=mexpf(2,3)-mexpf(2,11)
      xb2=mexpf(2,5)-mexpf(2,9)
      xb=sq3*(xb1-xb2)
      xd=sq3*(xb1+xb2)
C
      xx7=2*mexpf(1,7)
      xe=mexpf(1,1)+xx7
      xf=mexpf(1,1)-xx7
C
      y1=mexpf(1,6)-mexpf(1,8)
      x1=mexpf(1,2)+y1
      x3=sq3*(mexpf(1,2)-y1)
C
      y2=mexpf(2,6)+mexpf(2,8)
      x2=sq3*(mexpf(2,2)-y2)
      x4=mexpf(2,2)+y2
C
      x5=2*(mexpf(1,4)-mexpf(1,10))
      x6=2*(mexpf(2,4)+mexpf(2,10))
C
      w1(1)=xe+2*xa
      w1(2)=2*x4+x6
C
      xfc=xf+xc
      x15=x1+x5
      w2(1)=xfc-xd
      w2(2)=x15+x2
C
      xea=xe-xa
      x46=x4-x6
      w3(1)=xea-xb
      w3(2)=x3+x46
C
      w4(1)=xf-2*xc
      w4(2)=2*x1-x5
C
      w5(1)=xea+xb
      w5(2)=x3-x46
C
      w6(1)=xfc+xd
      w6(2)=x15-x2
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp11to48fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 11)
      parameter (MM = 24)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,13) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,13) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+13) = x4-x2
         mexpphys(1,25-j) = x44+x22
         mexpphys(1,13-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,25-j) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftp11to32fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 11)
      parameter (MM = 16)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftophys9(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1)
      real *8     rlams(nlambs)
C-----------------------------------------------------------------------
C
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      nftot = 1
      nptot  = 1
C_lambda_1
      call ftp3to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
C_lambda_2
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_3
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_4
      call ftp8to16(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_5
      call ftp8to24(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+12
C_lambda_6
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),10)
      nftot = nftot+10
      nptot = nptot+16
C_lambda_7
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),10)
      nftot = nftot+10
      nptot = nptot+16
C_lambda_8
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),12)
      nftot = nftot+12
      nptot = nptot+16
C_lambda_9
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),12)
      nftot = nftot+12
      nptot = nptot+24
C_lambda_10
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),13)
      nftot = nftot+13
      nptot = nptot+24
C_lambda_11
      call ftpnnto48fft(mexpf(nftot),mexpphys(nptot),14)
      nftot = nftot+14
      nptot = nptot+24
C_lambda_12
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),14)
      nftot = nftot+14
      nptot = nptot+32
C_lambda_13
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),15)
      nftot = nftot+15
      nptot = nptot+32
C_lambda_14
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+32
C_lambda_15
      call ftpnnto64fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+32
C_lambda_16
      call ftpnnto72fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_17
      call ftpnnto72fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_18
      call ftpnnto80fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+40
C_lambda_19
      call ftpnnto80fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+40
C_lambda_20
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_21
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_22
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_23
      call ftpnnto88fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_24
      call ftpnnto72fft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_25
      call ftpnnto32fft(mexpf(nftot),mexpphys(nptot),13)
      nftot = nftot+13
      nptot = nptot+16
C_lambda_26
      do i = 0, 1
         mexpphys(nptot+i) = mexpf(nftot)
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto48fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 24)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,13) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,13) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+13) = x4-x2
         mexpphys(1,25-j) = x44+x22
         mexpphys(1,13-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,25-j) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto32fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 16)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto64fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 32)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto72fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 36)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto80fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 40)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ftpnnto88fft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 44)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
      save
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
      mhm = mm/2+1
C
C   code for mexpphys(*,1) and mexpphys(*,M/4+1):
C
      x2 = 0.0d0
      do i = 3, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 5, nn, 4
         x22 = x22 + mexpf(1,i)
      enddo
      mexpphys(1,1) = mexpf(1,1) + 2*(x2+x22)
      mexpphys(1,mhm) = mexpf(1,1) + 2*(x22-x2)
C
      x2 = 0.0d0
      do i = 2, nn, 2
         x2 = x2 + mexpf(2,i)
      enddo
      mexpphys(2,1) = 2*x2
C
      x2 = 0.0d0
      do i = 2, nn, 4
         x2 = x2 + mexpf(1,i)
      enddo
      x22 = 0.0d0
      do i = 4, nn, 4
         x22 = x22 - mexpf(1,i)
      enddo
      mexpphys(2,mhm) =2*(x22+x2)
C
C**** the real part:
C
      do j = 1, mm/4
         x2 = 0.0d0
         x22 = 0.0d0
         do i = 3, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x2 = x2+tmp1-tmp2
            x22 = x22+tmp1+tmp2
         enddo
         x2 = 2*x2
         x22 = 2*x22
C
         x4 = 0.0d0
         x44 = 0.0d0
         do i = 5, nn, 4
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(1,ij)
            tmp2 = mexpf(2,i)*exps48(2,ij)
            x4 = x4+tmp1-tmp2
            x44 = x44+tmp1+tmp2
         enddo
         x4 = mexpf(1,1) + 2*x4
         x44 = mexpf(1,1) + 2*x44
C
         mexpphys(1,j+1) = x4+x2
         mexpphys(1,j+mhm) = x4-x2
         mexpphys(1,mm-j+1) = x44+x22
         mexpphys(1,mhm-j) = x44-x22
      enddo
C
C**** the imaginary part:
C
      do j = 1, mm/2-1
         x1 = 0.0d0
         x11 = 0.0d0
         do i = 2, nn, 2
            ij = (i-1)*j
            tmp1 = mexpf(1,i)*exps48(2,ij)
            tmp2 = mexpf(2,i)*exps48(1,ij)
            x1 = x1+tmp1+tmp2
            x11 = x11+tmp1-tmp2
         enddo
C
         mexpphys(2,j+1) = 2*x1
         mexpphys(2,mm-j+1) = 2*x11
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      SUBROUTINE FTPHYS(NDIGIT,MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,
     $                  MXPHYS)
C///////////////////////////////////////////////////////////////////////
C
      IMPLICIT REAL *8 (A-H,O-Z)
C
      INTEGER *4 NDIGIT,NLAMBS,NMFOUR(NLAMBS),NMPHYS(NLAMBS),NTHMAX
      REAL *8 RLAMS(NLAMBS)
      COMPLEX *16 MEXPF(1)
C
      COMPLEX *16 MXPHYS(1)
      IF (NDIGIT .EQ. 1) THEN
         CALL FTOPHYS1(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
**         CALL FTOPHYSSL(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      IF (NDIGIT .EQ. 2) THEN
         CALL FTOPHYS2(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
**         CALL FTOPHYSSL(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      IF (NDIGIT .EQ. 3) THEN
         CALL FTOPHYS3(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
cc         CALL FTOPHYSSL(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      IF (NDIGIT .EQ. 6) THEN
         CALL FTOPHYS6(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      IF (NDIGIT .EQ. 9) THEN
         CALL FTOPHYS9(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      IF (NDIGIT .EQ. 12) THEN
**         CALL FTOPHYSSL(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         CALL FTOPHYS12(MEXPF,NLAMBS,RLAMS,NMFOUR,NMPHYS,NTHMAX,MXPHYS)
         RETURN
      ENDIF
C
      RETURN
      END
C
C
c
c
c
c
c
      subroutine getints(iprec, maxppb, ndigit, nterms,
     1                   n22, nshort, nlambs, limap, larr)
      implicit real *8 (a-h,o-z)
c
c     Purpose:
c     Based on the given precision requirement (number of digits 
c     desired), determining parameters:nterms,n22,nshort,nlambs
c
c     maxppb is the maximum number of points per leaf box allowed.
c     it is based on ndigit. the user can vary mildly from the number
c     giveing below to get optimal run time.
c               iprec=0  --> maxppb=40
c               iprec=1  --> maxppb=100
c               iprec=2  --> maxppb=180
c               iprec=3  --> maxppb=300
c
c--------------------------------------------------------------------------
c
        if(iprec .eq. -2)then
          ndigit = 1
          nterms = 2
          n22    = 2
          nshort = 1
          nlambs = 3
          limap  = 1
          larr   = 6
          maxppb = 10
        endif
c
        if(iprec .eq. -1)then
          ndigit = 2
          nterms = 3
          n22    = 3
          nshort = 2
          nlambs = 5
          limap  = 2
          larr   = 18
          maxppb = 20
        endif
c
        if(iprec .eq. 0)then
          ndigit = 3
          nterms = 10
          n22    = 7
          nshort = 5
          nlambs = 8
          limap  = 5
          larr   = 200
          maxppb = 40
        endif
c
        if(iprec .eq. 1)then
          ndigit = 6
          nterms = 19
          n22    = 15
          nshort = 10
          nlambs = 17
          limap  = 11
          larr   = 1105
          maxppb = 100
        endif
c
        if(iprec .eq. 2)then
          ndigit = 9
          nterms = 29
          n22    = 24
          nshort = 17
          nlambs = 26
          limap  = 17
          larr   = 4200
          maxppb = 180
        endif
c
        if(iprec .eq. 3)then
          ndigit = 12
          nterms = 40
          n22    = 34
          nshort = 23
          nlambs = 35
          limap  = 24
          larr   = 10000
          maxppb = 300
        endif
c
      return
      end
c
c
c
c
c
      subroutine getflagclose3d(epsclose, iflagclose,
     1              w, laddr, llev, size, ninbox)
      implicit none
c
c     The following subroutine returns a parameter that
c     denotes whether or not the epsclose parameter
c     has effected how much the quad-tree can be refined.
c     If this is the case, the speed of the code may be
c     degraded significantly.
c
c     INPUT PARAMETERS:
c
c     epsclose (real *8) user given parameter that denotes when
c              the close subroutine has to be invoked
c
c     w(1) (integer *4) array precomputed by riverdale structure,
c               contains all of the list information for each box
c
c     laddr(2,1) (integer *4) array precompute by riverdale structure,
c               contains information of how boxes are arranged by level
c
c     llev (integer *4) denotes the number of levels in the quad-tree
c
c     size (real *8) the dimension of one side of the square that the
c               sources are contained in
c
c     ninbox (integer *4) the maximum number of particles that
c                can be contained in a box for it not to be
c                subdivided.  (up to the maximum level dictated
c                by the epsclose parameter)
c
c     OUTPUT PARAMETERS:
c
c     iflagclose (integer *4) denotes whether or not the user
c                specified close parameter had effected the quad-tree
c                generation
c               (iflagclose = 0 -> epsclose did not effect quad-tree)
c               (iflagclose = 1 -> epsclose restricted quadtree)
c
c----------------------------------------------------------------------------
c
c
      integer *4  iflagclose, w(1), laddr(2,1), llev,
     1    maxlev, j, istart, iend, box(15), ier, ninbox
c
      real *8  epsclose, size, center(2), corner(2,4), xlev
        iflagclose = 0
c
        if(epsclose .ne. 0d0)then
          xlev = dlog(size/epsclose) / dlog(2d0)
          maxlev = min(int(xlev)-1,200)
        else
          maxlev = 200
        endif
c
        maxlev = maxlev + 1
c
        if(llev .lt. maxlev) return
c
        istart = laddr(1,maxlev+1)
        iend = laddr(1,maxlev+1) + laddr(2,maxlev+1) - 1
c
        do 1000 j = istart, iend
c
          call d3mgetbk(ier, j, box, center, corner, w)
c
          if(box(15) .gt. ninbox)then
            iflagclose = 1
            return
          endif
c
 1000   continue
c
      return
      end
c
c
c
c
c
      subroutine initializepart3d(nboxes, nterms, natoms,
     1     nlev, mpole, local, pot, potx, poty, potz,
     2     scale, size, zrot, iderivonoff)
      implicit none
c
c
c------------------------------------------------------------------------
c
c
      integer *4  i, j, nboxes, nterms, natoms, nlev, iderivonoff
c
      real *8  pot(1), potx(1), poty(1), potz(1),
     1         scale(0:201), size, zrot(8)
c
c ..... initialize multipole and local expansions to zero.
c
      complex *16 mpole((nterms+1)*(nterms+2)/2,*),
     1            local((nterms+1)*(nterms+2)/2,*)
        do 2000 i = 1, nboxes
          do 1000 j = 1, (nterms+1)*(nterms+2)/2
            mpole(j,i) = 0.0d0
            local(j,i) = 0.0d0
 1000     continue
 2000   continue
c
c ..... initialize pot and field:
c
        do 3000 i = 1, natoms
          pot(i) = 0.0d0
c
          if(iderivonoff .eq. 1)then
            potx(i) = 0d0
            poty(i) = 0d0
            potz(i) = 0d0
          endif
c
 3000   continue
c
c ..... set scale factors for all levels.
c
        do 4000 i = 0, nlev+1
          scale(i) = 2.0d0**i/size
 4000   continue
c
c ..... get the z-rotation angles:
c
        call getzrot(zrot)
c
      return
      end
c
c
c
c
c
        subroutine getzrot(zrot)
        implicit real *8 (a-h,o-z)
c
c Purpose:
c       Create the rotation angles for all 8 children
c
c Inputs:
c       (none)
c
c Outputs:
c       zrot(8): the angles
c
c------------------------------------------------------------------------
c
c
        real *8  zrot(1)
          done  = 1d0
          pio4  = datan(done)
          pi3o4 = 3d0 * pio4
c
          zrot(1) = -pio4
          zrot(2) = -pi3o4
          zrot(3) =  pio4
          zrot(4) =  pi3o4
c
          zrot(5) = -pio4
          zrot(6) = -pi3o4
          zrot(7) =  pio4
          zrot(8) =  pi3o4
c
        return
        end
c
c
c
c
c
      subroutine initializeparttarg3d(nboxes, nterms, nsources,
     1     ntargets, nlev, mpole, local, pot, potx, poty, potz,
     2     pottar, pottarx, pottary, pottarz, scale, size, zrot,
     3     iderivonoff, itargflag)
      implicit none
c
c
c-----------------------------------------------------------------------------
c
c
      integer *4  i, iderivonoff, itargflag, j, nboxes,
     1         nlev, nsources, ntargets, nterms
c
      real *8  pot(1), potx(1), poty(1), potz(1), pottar(1), pottarx(1),
     1         pottary(1), pottarz(1), scale(0:201), size, zrot(8)
c
c ..... initialize multipole and local expansions to zero.
c
      complex *16  local((nterms+1)*(nterms+2)/2,*),
     1             mpole((nterms+1)*(nterms+2)/2,*)
        do 2000 i = 1, nboxes
          do 1000 j = 1, (nterms+1)*(nterms+2)/2
            mpole(j,i) = 0.0d0
            local(j,i) = 0.0d0
 1000     continue
 2000   continue
c
c ..... initialize pot and field:
c
        if(itargflag .eq. 1)then
c
          do 3000 i = 1, nsources
            pot(i) = 0.0d0
c
            if(iderivonoff .eq. 1)then
              potx(i) = 0d0
              poty(i) = 0d0
              potz(i) = 0d0
            endif
c
 3000     continue
c
        endif
c
        do 4000 i = 1, ntargets
          pottar(i) = 0.0d0
c
          if(iderivonoff .eq. 1)then
            pottarx(i) = 0d0
            pottary(i) = 0d0
            pottarz(i) = 0d0
          endif
c
 4000   continue
c
c ..... set scale factors for all levels.
c
        do 5000 i = 0, nlev+1
          scale(i) = 2.0d0**i/size
 5000   continue
c
c ..... get the z-rotation angles:
c
        call getzrot(zrot)
c
      return
      end
	subroutine vwts(x,w,n)
	implicit real*8 (a-h,o-z)
	dimension w(n),x(n)
c
c
c This routine returns a set of Gaussian nodes and weights for
c integrating the functions J0(r*x)*exp(z*x)dx over the range x=0 to
c x=infinity.  
c They work only for values of z within the range [1,4] and r within
c the range [0,4*sqrt(2)].
c
c
c Input arguments:
c	n - number of weights and nodes in the quadrature.  This must
c	  be an integer in the range [2,39].
c
c Output arguments:
c	w - weights
c	x - nodes
c
c
c Approximate accuracies of the quadrature:
c
c	N	maximum error
c
c        2     0.15318d+00
c        3     0.76505d-01
c        4     0.32149d-01
c        5     0.15630d-01
c        6     0.75110d-02
c        7     0.35030d-02
c        8     0.16243d-02
c        9     0.72230d-03
c       10     0.33074d-03
c       11     0.15035d-03
c       12     0.70952d-04
c       13     0.31751d-04
c       14     0.14589d-04
c       15     0.64300d-05
c       16     0.29477d-05
c       17     0.13222d-05
c       18     0.61488d-06
c       19     0.27435d-06
c       20     0.12534d-06
c       21     0.55324d-07
c       22     0.25257d-07
c       23     0.11293d-07
c       24     0.52063d-08
c       25     0.23256d-08
c       26     0.10580d-08
c       27     0.46835d-09
c       28     0.21286d-09
c       29     0.95164d-10
c       30     0.43599d-10
c       31     0.19516d-10
c       32     0.88491d-11
c       33     0.39313d-11
c       34     0.17821d-11
c       35     0.79603d-12
c       36     0.36460d-12
c       37     0.16331d-12
c       38     0.73497d-13
c       39     0.31530d-13
c
c
	if(n.lt.2 .or. n.gt.39) stop 'n out of bounds in vwts()'

	if(n.eq.  2) then
	  x(1)=0.31283512406199648347993047536874656d+00
	  x(2)=0.10894076617764414383060511681833304d+01
	  w(1)=0.76974593066577023936503110235207714d+00
	  w(2)=0.84374978799072331003827684980933554d+00
	endif
	if(n.eq.  3) then
	  x(1)=0.23817561600133754784458517406164901d+00
	  x(2)=0.90437226188379571389930333680240437d+00
	  x(3)=0.17511910669445907018371144658885896d+01
	  w(1)=0.55695724078723707339833026708220132d+00
	  w(2)=0.79531004550917117068564721193979494d+00
	  w(3)=0.93703416373547598894333532371092588d+00
	endif
	if(n.eq.  4) then
	  x(1)=0.21626008006106806069723802465887275d+00
	  x(2)=0.85186788888114162165976495089125820d+00
	  x(3)=0.16705322595388429895990611839806661d+01
	  x(4)=0.25585029089804702806532077374868095d+01
	  w(1)=0.50471599046036208502385989049798809d+00
	  w(2)=0.76071728649476022532383012730861083d+00
	  w(3)=0.87370748029129807754600278713041916d+00
	  w(4)=0.93475133313404745738495194018469192d+00
	endif
	if(n.eq.  5) then
	  x(1)=0.17368350550918876251671463251113892d+00
	  x(2)=0.71973899919337358532800408283947036d+00
	  x(3)=0.14665863986721390244127860569278710d+01
	  x(4)=0.23283854455252543935728226642822847d+01
	  x(5)=0.32597538486988750783268642408074811d+01
	  w(1)=0.40839334293432694167336194368544966d+00
	  w(2)=0.67016366313130026899358426817343570d+00
	  w(3)=0.81673864902764081730168754802434705d+00
	  w(4)=0.91106425433364368604571836840477772d+00
	  w(5)=0.97880305318787497181887147235102020d+00
	endif
	if(n.eq.  6) then
	  x(1)=0.14624625076566644121811577861080877d+00
	  x(2)=0.63832297842729379677706447182572447d+00
	  x(3)=0.13388327339170913443666677267174236d+01
	  x(4)=0.21582290084516078110254966304637492d+01
	  x(5)=0.30493033990054105863976019463734701d+01
	  x(6)=0.39906171458431614063044889917364344d+01
	  w(1)=0.34993298510539821988274411523889285d+00
	  w(2)=0.61733000302790996816071356079191901d+00
	  w(3)=0.77195750484413483416545886939275078d+00
	  w(4)=0.86303057957197659710857351456070319d+00
	  w(5)=0.92540796896975519025829726160736755d+00
	  w(6)=0.98300735313837050988183818844845518d+00
	endif
	if(n.eq.  7) then
	  x(1)=0.12110405743821943402860341620908002d+00
	  x(2)=0.56002252219580128667075769044458866d+00
	  x(3)=0.12107447642184836489320787222823128d+01
	  x(4)=0.19939530286622262345019862550543621d+01
	  x(5)=0.28652677773020815976678932202048600d+01
	  x(6)=0.37987093416333359563452631846303120d+01
	  x(7)=0.47769841417427238994264371285680681d+01
	  w(1)=0.29698283202048353368596167456416879d+00
	  w(2)=0.56247171144261287611954003295977600d+00
	  w(3)=0.72718448482782827024806238114251755d+00
	  w(4)=0.83360054399649463618970912648364902d+00
	  w(5)=0.90833570000297958468848946722573601d+00
	  w(6)=0.96486190247307246359298460447462276d+00
	  w(7)=0.10169919877814406206084640871267766d+01
	endif
	if(n.eq.  8) then
	  x(1)=0.10934746769000448785025270126425312d+00
	  x(2)=0.51769741015341219636525238456670195d+00
	  x(3)=0.11330659161119163158559786097612232d+01
	  x(4)=0.18813501511074042227278368955012411d+01
	  x(5)=0.27178540960120538549915636394871399d+01
	  x(6)=0.36165027490744909854925026593264192d+01
	  x(7)=0.45627105330382127235111511254217476d+01
	  x(8)=0.55490088534852830548516067210584879d+01
	  w(1)=0.27107502662773547141839003415952902d+00
	  w(2)=0.52769158843946417647430280339904130d+00
	  w(3)=0.69151504413879483212923560131457634d+00
	  w(4)=0.79834400406452044052230121451430023d+00
	  w(5)=0.87164160121353972954238997772336006d+00
	  w(6)=0.92643839116924142640385753111331724d+00
	  w(7)=0.97294622259483076742725415897439234d+00
	  w(8)=0.10241386584468554765692260843934491d+01
	endif
	if(n.eq.  9) then
	  x(1)=0.99273996739714473469540223504736787d-01
	  x(2)=0.47725674637049431137114652301534079d+00
	  x(3)=0.10553366138218296388373573790886439d+01
	  x(4)=0.17675934335400844688024335482623428d+01
	  x(5)=0.25734262935147067530294862081063911d+01
	  x(6)=0.34482433920158257478760788217186928d+01
	  x(7)=0.43768098355472631055818055756390095d+01
	  x(8)=0.53489575720546005399569367000367492d+01
	  x(9)=0.63576578531337464283978988532908261d+01
	  w(1)=0.24776441819008371281185532097879332d+00
	  w(2)=0.49188566500464336872511239562300034d+00
	  w(3)=0.65378749137677805158830324216978624d+00
	  w(4)=0.76433038408784093054038066838984378d+00
	  w(5)=0.84376180565628111640563702167128213d+00
	  w(6)=0.90445883985098263213586733400006779d+00
	  w(7)=0.95378613136833456653818075210438110d+00
	  w(8)=0.99670261613218547047665651916759089d+00
	  w(9)=0.10429422730252668749528766056755558d+01
	endif
	if(n.eq. 10) then
	  x(1)=0.92181119494357380284021985517028952d-01
	  x(2)=0.44689957388438356078452784458932001d+00
	  x(3)=0.99485853124047674000962615536991507d+00
	  x(4)=0.16757226616017673048730785012594424d+01
	  x(5)=0.24510992450330819636405976780224591d+01
	  x(6)=0.32961838574354240805064364394638687d+01
	  x(7)=0.41949178113509839604944318125490099d+01
	  x(8)=0.51371729038633668906754792260471731d+01
	  x(9)=0.61167060097997145717840794532094151d+01
	  x(10)=0.71305602574974669138896388176362962d+01
	  w(1)=0.23083073738461035162572443368844688d+00
	  w(2)=0.46385202776449724337837210441648494d+00
	  w(3)=0.62235404858126219806990775396116078d+00
	  w(4)=0.73321467536730178249371192578109913d+00
	  w(5)=0.81362306975392817420811297779437155d+00
	  w(6)=0.87427212844441348771340472012525424d+00
	  w(7)=0.92246427999726521296253167747636326d+00
	  w(8)=0.96346501535401229965316360903671011d+00
	  w(9)=0.10015863043245734065322949390974827d+01
	  w(10)=0.10469665614659515728845917692524381d+01
	endif
	if(n.eq. 11) then
	  x(1)=0.83947754993541900958575752156320959d-01
	  x(2)=0.41116156884118149061890790108009242d+00
	  x(3)=0.92412911280064913288612160613411106d+00
	  x(4)=0.15697112352606923391107329734950326d+01
	  x(5)=0.23129015267322943216754538298118860d+01
	  x(6)=0.31300036645182620631544523348566145d+01
	  x(7)=0.40050323813231880620833180728368461d+01
	  x(8)=0.49273172978328521054436350823380053d+01
	  x(9)=0.58896866519437089948496577562764287d+01
	  x(10)=0.68870955302308018985968374181538820d+01
	  x(11)=0.79164395304058903235500110895372927d+01
	  w(1)=0.21096619809745237317244459518406074d+00
	  w(2)=0.43092534827878592462724327560863458d+00
	  w(3)=0.58635954971056480911073549577849917d+00
	  w(4)=0.69913461337603133305407254738383926d+00
	  w(5)=0.78339916419475752462631135131232440d+00
	  w(6)=0.84830422968296659291809191927313805d+00
	  w(7)=0.90031891956613319116797811147989705d+00
	  w(8)=0.94389939178410831033261274569667876d+00
	  w(9)=0.98221287456430605988799698025104590d+00
	  w(10)=0.10179988215575410670510336785810068d+01
	  w(11)=0.10599575740381281807600544198066927d+01
	endif
	if(n.eq. 12) then
	  x(1)=0.76855224482364675742118720336293336d-01
	  x(2)=0.38022716855965127402683378932124469d+00
	  x(3)=0.86295016672459190498756242959643714d+00
	  x(4)=0.14774065742425332992127096076728776d+01
	  x(5)=0.21905930725126028235649755515623838d+01
	  x(6)=0.29791885550546846062047734449151903d+01
	  x(7)=0.38268052131682357419606432813452557d+01
	  x(8)=0.47221812142851433691248530521988869d+01
	  x(9)=0.56578288522785102898637887847144157d+01
	  x(10)=0.66290084039626417933277480187825859d+01
	  x(11)=0.76329115194492631601974608201999217d+01
	  x(12)=0.86692585676959215135184422251768410d+01
	  w(1)=0.19378032292424979265987872167897876d+00
	  w(2)=0.40247808945013635595344680950802285d+00
	  w(3)=0.55512328548655365256792038053390570d+00
	  w(4)=0.66840122968153037330552024286589585d+00
	  w(5)=0.75414462244054158990280711805098690d+00
	  w(6)=0.82039053613530976694079299704753794d+00
	  w(7)=0.87310177781587317014100335654802620d+00
	  w(8)=0.91671095974371530346047620696481317d+00
	  w(9)=0.95457288752598756786937883589416742d+00
	  w(10)=0.98937097491594594433905740515911020d+00
	  w(11)=0.10238743680564139637567677709739655d+01
	  w(12)=0.10678249338234333531971742559107952d+01
	endif
	if(n.eq. 13) then
	  x(1)=0.70687308611330559870999934446444968d-01
	  x(2)=0.35322227031870156999104892747709528d+00
	  x(3)=0.80956306466728034099133992640418001d+00
	  x(4)=0.13969368075858923372578601629356854d+01
	  x(5)=0.20843093180753342608113598544150591d+01
	  x(6)=0.28492369286741880962665618426399305d+01
	  x(7)=0.36755557385319534979828404175350443d+01
	  x(8)=0.45518102122361847605702678265515715d+01
	  x(9)=0.54700092351619344910318432084750384d+01
	  x(10)=0.64246720832453547700424678623676300d+01
	  x(11)=0.74121271804332247157276469806674868d+01
	  x(12)=0.84299356852023183961364338756538928d+01
	  x(13)=0.94776462234869871537057406385429204d+01
	  w(1)=0.17879600056265629315355170092516346d+00
	  w(2)=0.37763057118432419301257141341920942d+00
	  w(3)=0.52791576609439927469935582848847844d+00
	  w(4)=0.64173473833746008665457338793203235d+00
	  w(5)=0.72931281728819530307816876302240416d+00
	  w(6)=0.79789045633520616629397181895910762d+00
	  w(7)=0.85289957189509402191163189854705706d+00
	  w(8)=0.89839690889403756024478298058966175d+00
	  w(9)=0.93736682912526381183937473906553350d+00
	  w(10)=0.97206402733131802573751656382228248d+00
	  w(11)=0.10043560920792620194674782396759838d+01
	  w(12)=0.10363376029237720832298919049208052d+01
	  w(13)=0.10772868663681449685753932499210350d+01
	endif
	if(n.eq. 14) then
	  x(1)=0.66213023807563053946267928040469997d-01
	  x(2)=0.33302518940702452443503034373861738d+00
	  x(3)=0.76814378543799699539107450618757866d+00
	  x(4)=0.13320738699370830993018444132758304d+01
	  x(5)=0.19952905542395280580336702769272961d+01
	  x(6)=0.27361894979680170258973248564871028d+01
	  x(7)=0.35389332083102940096352995169581845d+01
	  x(8)=0.43920171385366097993596667947713286d+01
	  x(9)=0.52872133930334470619527564849704504d+01
	  x(10)=0.62187865433268365578101111168507487d+01
	  x(11)=0.71829341316549317753015202470123768d+01
	  x(12)=0.81773810009317156044517105328850448d+01
	  x(13)=0.92010945943890938281128910603001714d+01
	  x(14)=0.10255597561090382896509254351258278d+02
	  w(1)=0.16782217858320716552533724552631611d+00
	  w(2)=0.35834278682050713094042748707579449d+00
	  w(3)=0.50524782135037205055283493493334390d+00
	  w(4)=0.61774741033421598501718108309432864d+00
	  w(5)=0.70512340043420818069819233642192557d+00
	  w(6)=0.77406410364509525834364467300474644d+00
	  w(7)=0.82953851602330785919292566177318804d+00
	  w(8)=0.87530868438704301226493953436147422d+00
	  w(9)=0.91423294730365067817245972037198953d+00
	  w(10)=0.94853481721964949535674804792506620d+00
	  w(11)=0.98004492543042398544628213130636141d+00
	  w(12)=0.10104582738217686710413545370101929d+01
	  w(13)=0.10420257056214121682558015891117975d+01
	  w(14)=0.10848830289657354075671946702641435d+01
	endif
	if(n.eq. 15) then
	  x(1)=0.62494006208776084476674839152110508d-01
	  x(2)=0.31580001757481546142969364154851064d+00
	  x(3)=0.73196261825059882877297923187143169d+00
	  x(4)=0.12745096769359307575797402023454197d+01
	  x(5)=0.19156615424369782818558860526536591d+01
	  x(6)=0.26349779278743241661686624865978956d+01
	  x(7)=0.34172786238081047649473021010635421d+01
	  x(8)=0.42512905564487253329275517899077386d+01
	  x(9)=0.51287187209510305407889063644688576d+01
	  x(10)=0.60435472353063381945048604393377900d+01
	  x(11)=0.69915157252578845614721103629563004d+01
	  x(12)=0.79697454656597592759226245107129216d+01
	  x(13)=0.89764624126137402271297105471603572d+01
	  x(14)=0.10010758126582684823802082973998040d+02
	  x(15)=0.11073815811281715326686025946401060d+02
	  w(1)=0.15862394244419067423912395042862045d+00
	  w(2)=0.34142839128318125396788218495203182d+00
	  w(3)=0.48472220331313015106999841918877792d+00
	  w(4)=0.59578598263167215076663296713377349d+00
	  w(5)=0.68314771258188122793342245131498203d+00
	  w(6)=0.75297871300677499117881552592734806d+00
	  w(7)=0.80976432197984060668005668048863299d+00
	  w(8)=0.85690189548240613959251277265138924d+00
	  w(9)=0.89699396665012665064153907223953865d+00
	  w(10)=0.93204514056719467429701353466953151d+00
	  w(11)=0.96364174051181383795494639343814924d+00
	  w(12)=0.99312923342960057748740609895321541d+00
	  w(13)=0.10218026886214661708152107166824862d+01
	  w(14)=0.10514581504829776381626516013056971d+01
	  w(15)=0.10915651423913341755422834467026405d+01
	endif
	if(n.eq. 16) then
	  x(1)=0.59273387891186600506809867283664062d-01
	  x(2)=0.30052912864803243975231339391029906d+00
	  x(3)=0.69913214785198229961338256543967873d+00
	  x(4)=0.12212613306065938090227973589207977d+01
	  x(5)=0.18407022301918960494049315457232296d+01
	  x(6)=0.25380134246042680423727233574027196d+01
	  x(7)=0.32985714197429576444164922577328980d+01
	  x(8)=0.41112958629313363090318489412311465d+01
	  x(9)=0.49678340339823749971515098877716810d+01
	  x(10)=0.58619693058738864266388191026635468d+01
	  x(11)=0.67891769853120012001568284176755697d+01
	  x(12)=0.77463043528356614331187302013859153d+01
	  x(13)=0.87313537759783503844346341793425381d+01
	  x(14)=0.97433360522222471900022355839610100d+01
	  x(15)=0.10782205113039477595293647027574480d+02
	  x(16)=0.11850487340578309769512088678311557d+02
	  w(1)=0.15059862886412836435745532526198076d+00
	  w(2)=0.32605002595383431041042854303668719d+00
	  w(3)=0.46540860398333899761169618614076171d+00
	  w(4)=0.57451518283541402887237836694112048d+00
	  w(5)=0.66116138075584618416513649208354764d+00
	  w(6)=0.73104478829065544509546725748805329d+00
	  w(7)=0.78823951974329575786981649798690341d+00
	  w(8)=0.83583181691010888236803566542221233d+00
	  w(9)=0.87622783297370820942973068667924963d+00
	  w(10)=0.91132442140861513735217158682644367d+00
	  w(11)=0.94264787385567350153081633834517561d+00
	  w(12)=0.97148379898864845038986004510661587d+00
	  w(13)=0.99900986222142706960624991552322172d+00
	  w(14)=0.10264744781310688459541324846213683d+01
	  w(15)=0.10558364249820026969928221660666168d+01
	  w(16)=0.10972184518756178395193501273752190d+01
	endif
	if(n.eq. 17) then
	  x(1)=0.55990025317491039225092919195958530d-01
	  x(2)=0.28485138101968032753319448602269404d+00
	  x(3)=0.66535367065853057155777605657931417d+00
	  x(4)=0.11666790480529627416217408608645201d+01
	  x(5)=0.17644302741343080853653191297780722d+01
	  x(6)=0.24402983223637999543598198215477169d+01
	  x(7)=0.31803218099151462361362519004615024d+01
	  x(8)=0.39737171577719276882589838351123035d+01
	  x(9)=0.48121679941063382202059983683284372d+01
	  x(10)=0.56893231451148746913304421468637884d+01
	  x(11)=0.66004047944437740369494349579326808d+01
	  x(12)=0.75419049746991051463851363223511726d+01
	  x(13)=0.85113656929809931028785285889171064d+01
	  x(14)=0.95072324275912780677799673867411911d+01
	  x(15)=0.10528748096509671583476119849365205d+02
	  x(16)=0.11575870196028841263569120201282203d+02
	  x(17)=0.12650781639685202861755897174589336d+02
	  w(1)=0.14239483712193726216987954558135243d+00
	  w(2)=0.31017671029270804661237548316421453d+00
	  w(3)=0.44557516683708542348796299847890623d+00
	  w(4)=0.55303383994158716863154268139624037d+00
	  w(5)=0.63944903363522653805262052628677338d+00
	  w(6)=0.70997911214019127079666304780403152d+00
	  w(7)=0.76828253949732216998569356292136945d+00
	  w(8)=0.81713201141707436647720896871760488d+00
	  w(9)=0.85872191623337057464482313662301749d+00
	  w(10)=0.89480789582390418690494016118464060d+00
	  w(11)=0.92680189417317260236472975520882756d+00
	  w(12)=0.95586282708095549054405637434683740d+00
	  w(13)=0.98299145008229538156285798322642222d+00
	  w(14)=0.10091339538570300859987582953181118d+01
	  w(15)=0.10353177460050846381278688568272628d+01
	  w(16)=0.10631842791396344249932326420093887d+01
	  w(17)=0.11023210952108835058993463462684304d+01
	endif
	if(n.eq. 18) then
	  x(1)=0.52788527661177607475107009804560221d-01
	  x(2)=0.26949859838931256028615734976483509d+00
	  x(3)=0.63220353174689392083962502510985360d+00
	  x(4)=0.11130756427760852833586113774799742d+01
	  x(5)=0.16893949614021379623807206371566281d+01
	  x(6)=0.23437620046953044905535534780938178d+01
	  x(7)=0.30626998290780611533534738555317745d+01
	  x(8)=0.38356294126529686394633245072327554d+01
	  x(9)=0.46542473432156272750148673367220908d+01
	  x(10)=0.55120938659358147404532246582675725d+01
	  x(11)=0.64042126837727888499784967279992998d+01
	  x(12)=0.73268800190617540124549122992902994d+01
	  x(13)=0.82774009925823861522076185792684555d+01
	  x(14)=0.92539718060248947750778825138695538d+01
	  x(15)=0.10255602723746401139237605093512684d+02
	  x(16)=0.11282088297877740146191172243561596d+02
	  x(17)=0.12334067909676926788620221486780792d+02
	  x(18)=0.13414920240172401477707353478763252d+02
	  w(1)=0.13438265914335215112096477696468355d+00
	  w(2)=0.29457752727395436487256574764614925d+00
	  w(3)=0.42607819361148618897416895379137713d+00
	  w(4)=0.53189220776549905878027857397682965d+00
	  w(5)=0.61787306245538586857435348065337166d+00
	  w(6)=0.68863156078905074508611505734734237d+00
	  w(7)=0.74749099381426187260757387775811367d+00
	  w(8)=0.79699192718599998208617307682288811d+00
	  w(9)=0.83917454386997591964103548889397644d+00
	  w(10)=0.87570092283745315508980411323136650d+00
	  w(11)=0.90792943590067498593754180546966381d+00
	  w(12)=0.93698393742461816291466902839601971d+00
	  w(13)=0.96382546688788062194674921556725167d+00
	  w(14)=0.98932985769673820186653756536543369d+00
	  w(15)=0.10143828459791703888726033255807124d+01
	  w(16)=0.10400365437416452252250564924906939d+01
	  w(17)=0.10681548926956736522697610780596733d+01
	  w(18)=0.11090758097553685690428437737864442d+01
	endif
	if(n.eq. 19) then
	  x(1)=0.49949579666168537894765933060625684d-01
	  x(2)=0.25587785751621588969939580238133203d+00
	  x(3)=0.60285193295998951157343981321901083d+00
	  x(4)=0.10657983137580619992235142490244471d+01
	  x(5)=0.16235028084630112044095540113630705d+01
	  x(6)=0.22593565245709532618434423056896776d+01
	  x(7)=0.29603306461544551808628966682590544d+01
	  x(8)=0.37160847801044232241451936715748161d+01
	  x(9)=0.45183959543781595513678439601790160d+01
	  x(10)=0.53607645945685540311842487426474690d+01
	  x(11)=0.62381054190685949478734073636587709d+01
	  x(12)=0.71464949862225219945344178995583206d+01
	  x(13)=0.80829720193041367792829987592995167d+01
	  x(14)=0.90453910811754347776059148600324988d+01
	  x(15)=0.10032329160512597709953297453466803d+02
	  x(16)=0.11043040453225657415714522358030081d+02
	  x(17)=0.12077441113209841816455991647671908d+02
	  x(18)=0.13136150656231230016146582784131169d+02
	  x(19)=0.14222379224644413397982134483754635d+02
	  w(1)=0.12727479585254397598248488066019490d+00
	  w(2)=0.28074654471419330237225153723557014d+00
	  w(3)=0.40890957644635866907734111919126008d+00
	  w(4)=0.51344857052912906691943817349965684d+00
	  w(5)=0.59921282467118286430007856324664317d+00
	  w(6)=0.67033798789497855974417461766279303d+00
	  w(7)=0.72989603646689105165279443099279888d+00
	  w(8)=0.78024834204579218699393550195964053d+00
	  w(9)=0.82329643252275364062597873271442950d+00
	  w(10)=0.86059894129480551949740174677572213d+00
	  w(11)=0.89343570954146100948634057203889824d+00
	  w(12)=0.92286139944663625467313750050379895d+00
	  w(13)=0.94976012738946247182525439711753279d+00
	  w(14)=0.97490342742485036620081473301979713d+00
	  w(15)=0.99901486587368271141684772373992018d+00
	  w(16)=0.10228499282064815734116791645647027d+01
	  w(17)=0.10473249251926426417469428997719660d+01
	  w(18)=0.10741045635513459810539416139363311d+01
	  w(19)=0.11134033950443573690591847480391152d+01
	endif
	if(n.eq. 20) then
	  x(1)=0.47543727637248914263956578452052781d-01
	  x(2)=0.24422020867640242824947449662431609d+00
	  x(3)=0.57738735420750131321909748294274323d+00
	  x(4)=0.10241481132215648486294412577990443d+01
	  x(5)=0.15644872035736114845860811328748241d+01
	  x(6)=0.21824433236293536708672036183997989d+01
	  x(7)=0.28653954538190715695122889883350581d+01
	  x(8)=0.36032679528582369776756877399748191d+01
	  x(9)=0.43879813157233691356395866023376584d+01
	  x(10)=0.52130765667652978478940895001869649d+01
	  x(11)=0.60734306526893613309425745683256537d+01
	  x(12)=0.69650271185981909027873371087480336d+01
	  x(13)=0.78847726403958340313238295493647456d+01
	  x(14)=0.88303579521578470234999258536845446d+01
	  x(15)=0.98001630879826002740173862548545003d+01
	  x(16)=0.10793207610765842119349144923035055d+02
	  x(17)=0.11809146586022226443901672610081732d+02
	  x(18)=0.12848309996690652212691929889842868d+02
	  x(19)=0.13911859887638442501156532671302557d+02
	  x(20)=0.15003974288984196050478203687816858d+02
	  w(1)=0.12123489815809705694160669509074069d+00
	  w(2)=0.26876608765865678263295990291226190d+00
	  w(3)=0.39364274681026828472951706316962373d+00
	  w(4)=0.49653435789152050583439290676324163d+00
	  w(5)=0.58149909773786201405698648159159347d+00
	  w(6)=0.65232326071962210001231596834259108d+00
	  w(7)=0.71191063049174330146229294769000262d+00
	  w(8)=0.76249393422317224278117464564274997d+00
	  w(9)=0.80586118795410766058040508141857572d+00
	  w(10)=0.84347981485805434420655046778847463d+00
	  w(11)=0.87656332288607641256561464615515433d+00
	  w(12)=0.90611967404999338437932010492659174d+00
	  w(13)=0.93299649036540077684520611001062207d+00
	  w(14)=0.95792683395701161419566460608621128d+00
	  w(15)=0.98157794960527799954519423408783041d+00
	  w(16)=0.10046090612120206486679308000020683d+01
	  w(17)=0.10277523675616564435841837621410377d+01
	  w(18)=0.10519663093854307867047737090615556d+01
	  w(19)=0.10791179202989034102699861250584945d+01
	  w(20)=0.11199933499526084634823064334341325d+01
	endif
	if(n.eq. 21) then
	  x(1)=0.45571106583094517228360587068891618d-01
	  x(2)=0.23456924197771603091133840734983096d+00
	  x(3)=0.55605074355978634237374080839799717d+00
	  x(4)=0.98886226211903260896463052631588653d+00
	  x(5)=0.15140517506819852755484134831931442d+01
	  x(6)=0.21163084058946690646507704514078796d+01
	  x(7)=0.27834664049554236342487456568051130d+01
	  x(8)=0.35057749223342495881183822348248214d+01
	  x(9)=0.42753582277771142727829101204406470d+01
	  x(10)=0.50858504213438919805412297137081623d+01
	  x(11)=0.59321299588987201900636136997491121d+01
	  x(12)=0.68101102326376521389761364844162017d+01
	  x(13)=0.77165699408569325967732766002882272d+01
	  x(14)=0.86490189544857720704840176040306687d+01
	  x(15)=0.96055990356413225583764869952574372d+01
	  x(16)=0.10585019994373375595841935137286782d+02
	  x(17)=0.11586532698006379860089509747922421d+02
	  x(18)=0.12609939047089179453564611321780831d+02
	  x(19)=0.13655630902209903609900720766745508d+02
	  x(20)=0.14724711974343017928390509041491896d+02
	  x(21)=0.15821115878987425773516406479757279d+02
	  w(1)=0.11626932798637451549339516532199923d+00
	  w(2)=0.25873576304378226309310662145435344d+00
	  w(3)=0.38059684744358213137616075982805341d+00
	  w(4)=0.48185261255750905240446968491596635d+00
	  w(5)=0.56598645649837764359801894897827879d+00
	  w(6)=0.63651204484922907500532573976670392d+00
	  w(7)=0.69618766407552234998235007878975011d+00
	  w(8)=0.74712267140691357436566022443003021d+00
	  w(9)=0.79098736463667274065869605692569166d+00
	  w(10)=0.82914708606812959068577129073673859d+00
	  w(11)=0.86273418493909082016557476890739053d+00
	  w(12)=0.89269289742930946207621900612139143d+00
	  w(13)=0.91981614271009970451586923445574939d+00
	  w(14)=0.94478093124118001089328799935174175d+00
	  w(15)=0.96818477444619643890177940193098038d+00
	  w(16)=0.99058577205436648682734812609851360d+00
	  w(17)=0.10125517975529727543460012384457514d+01
	  w(18)=0.10347297124769503362529121659463271d+01
	  w(19)=0.10579732423280954201061376807047054d+01
	  w(20)=0.10839601118832196124941447124001570d+01
	  w(21)=0.11232230992403440250626545093837194d+01
	endif
	if(n.eq. 22) then
	  x(1)=0.43730571482595376187063607176241931d-01
	  x(2)=0.22546314061070582557277930391137488d+00
	  x(3)=0.53562452322468856458215213933726773d+00
	  x(4)=0.95459967559048286567247032508021221d+00
	  x(5)=0.14644503885175594870560189519892447d+01
	  x(6)=0.20505129898819740574822390044573694d+01
	  x(7)=0.27010747244419337498300137667683885d+01
	  x(8)=0.34067100069124638395123838563449681d+01
	  x(9)=0.41597567284511374197109034867025912d+01
	  x(10)=0.49539626251771764486875326838344336d+01
	  x(11)=0.57842378614529854630177396757062525d+01
	  x(12)=0.66464658921597612462051074544433504d+01
	  x(13)=0.75373509780144951619718085567001253d+01
	  x(14)=0.84542953579871529257161455461755395d+01
	  x(15)=0.93953045914506567726220964686945081d+01
	  x(16)=0.10358921378680195246602124825585634d+02
	  x(17)=0.11344189462364381526526813104283065d+02
	  x(18)=0.12350651043352140590059207170270383d+02
	  x(19)=0.13378382354647602170416575972922146d+02
	  x(20)=0.14428071458844170749102886475156993d+02
	  x(21)=0.15501228719971146929879068920854479d+02
	  x(22)=0.16602530548254346598469055606983602d+02
	  w(1)=0.11162205199242761222144793009647401d+00
	  w(2)=0.24914697542128799723215593076020014d+00
	  w(3)=0.36780722045157282495964068402827252d+00
	  w(4)=0.46713432561546514021344478351238649d+00
	  w(5)=0.55013206743428866296596879692515358d+00
	  w(6)=0.62005292437552328443928217893699184d+00
	  w(7)=0.67950829126698175652876443564309739d+00
	  w(8)=0.73049097850935695852570006536552683d+00
	  w(9)=0.77456446199081319115009591769194230d+00
	  w(10)=0.81300220581189297508473146081087179d+00
	  w(11)=0.84686488163552398056310721585759893d+00
	  w(12)=0.87704436975849753288514421001309529d+00
	  w(13)=0.90429550558952997985073807285516523d+00
	  w(14)=0.92926471016166922733958699609502219d+00
	  w(15)=0.95251860675498312147624346835073084d+00
	  w(16)=0.97457439022305569764625943207647651d+00
	  w(17)=0.99593510961900155731285622096038423d+00
	  w(18)=0.10171365736308934923926017290796153d+01
	  w(19)=0.10388201977843312118210405969875865d+01
	  w(20)=0.10618816874131427052674325750558637d+01
	  w(21)=0.10881609252151220879056836565723643d+01
	  w(22)=0.11286083536458515474976138648344204d+01
	endif
	if(n.eq. 23) then
	  x(1)=0.41972147681820962117349438358360203d-01
	  x(2)=0.21672584044775683453920578358520288d+00
	  x(3)=0.51594567024719162340318234782898799d+00
	  x(4)=0.92153380268569184963212137517984957d+00
	  x(5)=0.14166238549372345278953844172065146d+01
	  x(6)=0.19872569198613749819060103618539870d+01
	  x(7)=0.26222049588938287634221069311024621d+01
	  x(8)=0.33123818279738364012132478819694370d+01
	  x(9)=0.40503474579712408498721742944326252d+01
	  x(10)=0.48299708035495152458338452561292797d+01
	  x(11)=0.56462005126847056857286588638089597d+01
	  x(12)=0.64948944390679841376368131022900343d+01
	  x(13)=0.73726825911123006207503749465104192d+01
	  x(14)=0.82768541685341041613810375565662980d+01
	  x(15)=0.92052664234629180128877123934216797d+01
	  x(16)=0.10156275473759043492805176356341690d+02
	  x(17)=0.11128690172219716458812399650923908d+02
	  x(18)=0.12121751229071891842181685206014663d+02
	  x(19)=0.13135139174255273886160466645378619d+02
	  x(20)=0.14169014559581503576168870495166630d+02
	  x(21)=0.15224088692195556049568949674721807d+02
	  x(22)=0.16301795992929449141684017376974225d+02
	  x(23)=0.17406564924714970743480080273002386d+02
	  w(1)=0.10717641518184028992521916734403931d+00
	  w(2)=0.23990532697980757048661359931429615d+00
	  w(3)=0.35542521636035206977766165437060408d+00
	  w(4)=0.45291831233090568131771647131245118d+00
	  w(5)=0.53494156757723620998490332567598671d+00
	  w(6)=0.60446400516340048625352210365235806d+00
	  w(7)=0.66392601599188527661254966005799361d+00
	  w(8)=0.71519317335927368173287277386407368d+00
	  w(9)=0.75971995941075953773236051347339526d+00
	  w(10)=0.79868765250436368763331529407878406d+00
	  w(11)=0.83308373888879982960276038284064271d+00
	  w(12)=0.86374448602560738308397958462592214d+00
	  w(13)=0.89138192927548665078774092762614600d+00
	  w(14)=0.91660624149239344760076164675410837d+00
	  w(15)=0.93994758288643587285093872196739540d+00
	  w(16)=0.96187891563469807287845014798222110d+00
	  w(17)=0.98284121163181492608629241658491082d+00
	  w(18)=0.10032739246903483731898631958756596d+01
	  w(19)=0.10236564911929821874991830554790795d+01
	  w(20)=0.10445723165309745983364564381190576d+01
	  w(21)=0.10668357475893164298952342505799606d+01
	  w(22)=0.10921225216001932967202492363867350d+01
	  w(23)=0.11311366331613983415849133962183259d+01
	endif
	if(n.eq. 24) then
	  x(1)=0.40161660870322704597334961817978183d-01
	  x(2)=0.20770303300921480471608049356291303d+00
	  x(3)=0.49556233372164454342723161062167492d+00
	  x(4)=0.88721719544850086158760404941858724d+00
	  x(5)=0.13669313729767131881942532345419750d+01
	  x(6)=0.19214618684060367215238329663407058d+01
	  x(7)=0.25400363129156677821640641923295334d+01
	  x(8)=0.32138670492582850357621282455511391d+01
	  x(9)=0.39357043755757925573846023326041177d+01
	  x(10)=0.46995238977378539502183230069931597d+01
	  x(11)=0.55003147577352873298650592914782465d+01
	  x(12)=0.63339248942996526636761700501665473d+01
	  x(13)=0.71969374920866178158007642196025699d+01
	  x(14)=0.80865680629338196894195789354853332d+01
	  x(15)=0.90005792910157271791149469208903611d+01
	  x(16)=0.99372135842936462069019398768432438d+01
	  x(17)=0.10895144187912299216236533538904041d+02
	  x(18)=0.11873446478870155473828162939753383d+02
	  x(19)=0.12871592488448108326792862499132752d+02
	  x(20)=0.13889473955101772517650715599302202d+02
	  x(21)=0.14927461287658761790453354478813708d+02
	  x(22)=0.15986507931569594376242093858309090d+02
	  x(23)=0.17068406196932564000690035754814744d+02
	  x(24)=0.18178282867325837202088223421014845d+02
	  w(1)=0.10259513445157118771700055503970361d+00
	  w(2)=0.23033172049800118563744888433575397d+00
	  w(3)=0.34254832958013686772247297085414175d+00
	  w(4)=0.43811525059456785102796061437402386d+00
	  w(5)=0.51910931505333612889785399602260441d+00
	  w(6)=0.58816539155050029386018195509677753d+00
	  w(7)=0.64752645162427036051866480192984454d+00
	  w(8)=0.69893183105287592926657680436619557d+00
	  w(9)=0.74374217828666766560985479372902773d+00
	  w(10)=0.78306425368614274162837318726815283d+00
	  w(11)=0.81782751820985366553173889769823290d+00
	  w(12)=0.84882505534139573999397043735370971d+00
	  w(13)=0.87673762348836203894819618653855287d+00
	  w(14)=0.90215211847778098430694626586046070d+00
	  w(15)=0.92557913449000162042779038529261015d+00
	  w(16)=0.94747115349876975809451096210977994d+00
	  w(17)=0.96824218146576768173616756030241959d+00
	  w(18)=0.98829035217221483655691827152622864d+00
	  w(19)=0.10080268468618629462696389964548871d+01
	  w(20)=0.10279180200015789470313620768138207d+01
	  w(21)=0.10485554182563696645758000158821233d+01
	  w(22)=0.10708053477833299194088567674043588d+01
	  w(23)=0.10965139925655209562904701670049690d+01
	  w(24)=0.11368396001481675394728654282516800d+01
	endif
	if(n.eq. 25) then
	  x(1)=0.38544654960740845628386352927918779d-01
	  x(2)=0.19964278415248942755155781014764216d+00
	  x(3)=0.47736849737003589355666122173715848d+00
	  x(4)=0.85665497240449139937368272512685508d+00
	  x(5)=0.13228177791134794194505275299889036d+01
	  x(6)=0.18632649417618365461635221436154097d+01
	  x(7)=0.24676211718997795863117517001228407d+01
	  x(8)=0.31273523012782726837599511782173067d+01
	  x(9)=0.38353727466903011489307573356200010d+01
	  x(10)=0.45857556281779983109458953549619764d+01
	  x(11)=0.53735328549237166839702695142477751d+01
	  x(12)=0.61945499685463563110943141509778798d+01
	  x(13)=0.70453513302110204463701847998891026d+01
	  x(14)=0.79230842038679858418959156551863998d+01
	  x(15)=0.88254179188323949034611359820701182d+01
	  x(16)=0.97504775019799900803718628594651818d+01
	  x(17)=0.10696792232004669997991186392027885d+02
	  x(18)=0.11663260073103119296433760609943420d+02
	  x(19)=0.12649129713037108757589521701447666d+02
	  x(20)=0.13654003334795369539733655983582139d+02
	  x(21)=0.14677865231928679534689763386268169d+02
	  x(22)=0.15721142576564773207792313769459724d+02
	  x(23)=0.16784804136239745986358684604056180d+02
	  x(24)=0.17870594977045829665485143777914345d+02
	  x(25)=0.18983553683850214355288699152879417d+02
	  w(1)=0.98502860786019150185488513216114370d-01
	  w(2)=0.22178069453389132048570786537311506d+00
	  w(3)=0.33108283188094378424182195885805413d+00
	  w(4)=0.42501813294363627315775033821410034d+00
	  w(5)=0.50520938140300153396111682013724931d+00
	  w(6)=0.57396300243312403654982745138113387d+00
	  w(7)=0.63333383047793623266130680349306203d+00
	  w(8)=0.68495226078388837809285405455739237d+00
	  w(9)=0.73010405660473898237228240759577602d+00
	  w(10)=0.76983605703678692488978185792802833d+00
	  w(11)=0.80502788484662313184259119225316681d+00
	  w(12)=0.83643201588340776453378566657193005d+00
	  w(13)=0.86469665126457539994220269363722764d+00
	  w(14)=0.89038188933874184982641963870264590d+00
	  w(15)=0.91397423285270529280666096383356489d+00
	  w(16)=0.93590124596355950270520906997262500d+00
	  w(17)=0.95654701404883446524962664625491016d+00
	  w(18)=0.97626912139202859375330945113091730d+00
	  w(19)=0.99541868057412585812926408834755421d+00
	  w(20)=0.10143665935320542725861514554708265d+01
	  w(21)=0.10335422972866488144916274904971942d+01
	  w(22)=0.10534977717277278497221004727180116d+01
	  w(23)=0.10750429943935644327979161971597932d+01
	  w(24)=0.10999239540083021182681477512232959d+01
	  w(25)=0.11393286143253755771098667537444271d+01
	endif
	if(n.eq. 26) then
	  x(1)=0.37057019538159492733075950354759698d-01
	  x(2)=0.19219683859954905802425173533265479d+00
	  x(3)=0.46045971214896902479196683088957798d+00
	  x(4)=0.82805130101422141919442765356507152d+00
	  x(5)=0.12812122994478714055333057331154123d+01
	  x(6)=0.18079201927629728885449367226101458d+01
	  x(7)=0.23981472807433310556746164365904406d+01
	  x(8)=0.30435901230658175542487242637434974d+01
	  x(9)=0.37373274292409601748943259735824540d+01
	  x(10)=0.44735476894021157789893550216220319d+01
	  x(11)=0.52473551816946653048034931998699903d+01
	  x(12)=0.60546294862094365285543062782380730d+01
	  x(13)=0.68919164879597207828965110820718110d+01
	  x(14)=0.77563386070883817424714834487531334d+01
	  x(15)=0.86455191519599416949404258048161864d+01
	  x(16)=0.95575192961392403390163963194936514d+01
	  x(17)=0.10490787606167046419614052865654230d+02
	  x(18)=0.11444122623412685157973101013340056d+02
	  x(19)=0.12416649553950447781858201778959483d+02
	  x(20)=0.13407813117883241815775363647844642d+02
	  x(21)=0.14417390388944724577413580846041441d+02
	  x(22)=0.15445530168678835991613595979288220d+02
	  x(23)=0.16492828612411702948747915797866881d+02
	  x(24)=0.17560456489260992896106472471728921d+02
	  x(25)=0.18650464841062735388277360470965505d+02
	  x(26)=0.19768476866194163221734925173223019d+02
	  w(1)=0.94733963379001084881281258276430890d-01
	  w(2)=0.21384206006426126345232319181377534d+00
	  w(3)=0.32031528543989479240750029021000955d+00
	  w(4)=0.41254929390710237679940064481343143d+00
	  w(5)=0.49176691815620643399853406663169153d+00
	  w(6)=0.55998309037173654711949666307191364d+00
	  w(7)=0.61909314036708051887103465560358018d+00
	  w(8)=0.67064351982741110536068163128220476d+00
	  w(9)=0.71586567032066061866402151281363331d+00
	  w(10)=0.75576118553096371943667008963529952d+00
	  w(11)=0.79116885492294941606417069124290720d+00
	  w(12)=0.82280556212477184985232270264532417d+00
	  w(13)=0.85129012269432990933637483976781368d+00
	  w(14)=0.87715909928110047388827297254465520d+00
	  w(15)=0.90087981520398463519683218692080118d+00
	  w(16)=0.92286282936149244271462066535605118d+00
	  w(17)=0.94347471535979188228537850591237657d+00
	  w(18)=0.96305166489155957787460238250787370d+00
	  w(19)=0.98191478773736651231018868202227168d+00
	  w(20)=0.10003889128129097585429008177015930d+01
	  w(21)=0.10188284918868633077693175437161699d+01
	  w(22)=0.10376578150755357832224490266526118d+01
	  w(23)=0.10574411346568342029428322348394431d+01
	  w(24)=0.10790382469712218593826946744229645d+01
	  w(25)=0.11043433786820813224949233699589968d+01
	  w(26)=0.11448816650689648266592257641605102d+01
	endif
	if(n.eq. 27) then
	  x(1)=0.35834993247954083361861421508365311d-01
	  x(2)=0.18605352495124757861155728733137948d+00
	  x(3)=0.44642194330546725034025712375296280d+00
	  x(4)=0.80414605853435716653621057048439980d+00
	  x(5)=0.12462239924414626468518463298096322d+01
	  x(6)=0.17611257461239471222569363817456178d+01
	  x(7)=0.23391453785205094106913747964426875d+01
	  x(8)=0.29722080942457780317056403873721138d+01
	  x(9)=0.36535650947301854252202701900387183d+01
	  x(10)=0.43775326951870896508012265258003026d+01
	  x(11)=0.51393010711012010460763121955096722d+01
	  x(12)=0.59347963207816585295972799940500408d+01
	  x(13)=0.67605758319435445002909546019509435d+01
	  x(14)=0.76137438021356000916739503736607730d+01
	  x(15)=0.84918804165657331139982488821260631d+01
	  x(16)=0.93929821745587691594892021385021508d+01
	  x(17)=0.10315412711899460518338855763431638d+02
	  x(18)=0.11257864229560141211550217121839523d+02
	  x(19)=0.12219330080395609527954547957051545d+02
	  x(20)=0.13199089643751765521528795943595469d+02
	  x(21)=0.14196707628360135444722800457384437d+02
	  x(22)=0.15212051628819105886236684455070645d+02
	  x(23)=0.16245334166526408381514556822367013d+02
	  x(24)=0.17297187705846923222452460322529078d+02
	  x(25)=0.18368783996172027173088281415402889d+02
	  x(26)=0.19462114300213894324542707181535661d+02
	  x(27)=0.20582673852051787122263704077340662d+02
	  w(1)=0.91634452557743162337544617912499234d-01
	  w(2)=0.20725798653776011937210910218709614d+00
	  w(3)=0.31128301536359448409285732850548811d+00
	  w(4)=0.40197254484414085551335915624804329d+00
	  w(5)=0.48025776040426659818649568478576839d+00
	  w(6)=0.54793227641803410321585943165700883d+00
	  w(7)=0.60676658418922713167376059573143721d+00
	  w(8)=0.65823842224192508076896501734154299d+00
	  w(9)=0.70353143374483517735740178977721371d+00
	  w(10)=0.74360437862720618618084245099453256d+00
	  w(11)=0.77925510412986809249957786960294470d+00
	  w(12)=0.81116302338313539532776985652162693d+00
	  w(13)=0.83991454783642205406124503497267142d+00
	  w(14)=0.86601910131774351153666202662861906d+00
	  w(15)=0.88992107452719526605733335600234568d+00
	  w(16)=0.91201046747319902685546821885509416d+00
	  w(17)=0.93263337746385499560375365035724826d+00
	  w(18)=0.95210285562789409574691035231808200d+00
	  w(19)=0.97071063776060639849418976154993288d+00
	  w(20)=0.98874065527360133209811010601697490d+00
	  w(21)=0.10064860790234053666836189222522080d+01
	  w(22)=0.10242732841383590525197178067173809d+01
	  w(23)=0.10424992963077313046227345694205724d+01
	  w(24)=0.10616963916554709168593717549811117d+01
	  w(25)=0.10826735650889751649827985602314584d+01
	  w(26)=0.11072236156410122376314575376454741d+01
	  w(27)=0.11468295974452529240039666547090746d+01
	endif
	if(n.eq. 28) then
	  x(1)=0.34649421149527286079017329711859929d-01
	  x(2)=0.18005833416581945582990442744630855d+00
	  x(3)=0.43260408861564048077497091071563773d+00
	  x(4)=0.78038984122852594893515743024181575d+00
	  x(5)=0.12111271013211080127547347728977911d+01
	  x(6)=0.17137747630321893410609845886938274d+01
	  x(7)=0.22789600476402123163666146865580231d+01
	  x(8)=0.28988505738640957254403929255204275d+01
	  x(9)=0.35668835527411730801361500198254362d+01
	  x(10)=0.42775174285095580728466302389279008d+01
	  x(11)=0.50260444316599945935308824118692428d+01
	  x(12)=0.58084554651427726668089235317893326d+01
	  x(13)=0.66213397270308567144070366339292377d+01
	  x(14)=0.74618055548714492530848474416416138d+01
	  x(15)=0.83274148871323045995040956768207252d+01
	  x(16)=0.92161279178902919539950744365341961d+01
	  x(17)=0.10126256754412748861682302958797663d+02
	  x(18)=0.11056427893157508179911019396968186d+02
	  x(19)=0.12005553805399065581127615587320179d+02
	  x(20)=0.12972814335375019823004549834877253d+02
	  x(21)=0.13957649262705848158816479553934187d+02
	  x(22)=0.14959764521043945606493252853397280d+02
	  x(23)=0.15979156486798860470344152417965233d+02
	  x(24)=0.17016161724139383437659489572979510d+02
	  x(25)=0.18071543406684014598795329220592976d+02
	  x(26)=0.19146633395269574862140871118754148d+02
	  x(27)=0.20243668518906520858990916167385876d+02
	  x(28)=0.21368602329962925523432204499840736d+02
	  w(1)=0.88622857693915105259385711633512983d-01
	  w(2)=0.20078714572495373613669755741284462d+00
	  w(3)=0.30226336710228968174263286528002936d+00
	  w(4)=0.39123451482265819700856468443816993d+00
	  w(5)=0.46839451945520893527685757362633012d+00
	  w(6)=0.53534173858832079240244183893082663d+00
	  w(7)=0.59372828885713024860137920768465847d+00
	  w(8)=0.64496316544847820395602866483386606d+00
	  w(9)=0.69018228980436679975696279143448919d+00
	  w(10)=0.73030303949562380694260355085134506d+00
	  w(11)=0.76608442505739382522023106503183953d+00
	  w(12)=0.79817047815891095652318654174450785d+00
	  w(13)=0.82711718964233071904601501955767162d+00
	  w(14)=0.85340904918321747185672165869618766d+00
	  w(15)=0.87747043602075713852883609433774836d+00
	  w(16)=0.89967497620477510089642692037159577d+00
	  w(17)=0.92035435534202525431624053453560919d+00
	  w(18)=0.93980723716479275253732339479029179d+00
	  w(19)=0.95830868989922746159493271989049390d+00
	  w(20)=0.97612065905778322427721604981343262d+00
	  w(21)=0.99350448475457564523338760409387760d+00
	  w(22)=0.10107373633334020279761489291558973d+01
	  w(23)=0.10281364360012410497091650540824048d+01
	  w(24)=0.10460977891287441821077663917094469d+01
	  w(25)=0.10651662838357145446366303076501936d+01
	  w(26)=0.10861931437449714454857030432322063d+01
	  w(27)=0.11110870028665837949688466324005276d+01
	  w(28)=0.11515563125174608227752059974591248d+01
	endif
	if(n.eq. 29) then
	  x(1)=0.33553959839036001655543373090040404d-01
	  x(2)=0.17450396418281238775094266202358995d+00
	  x(3)=0.41975868958520995422034616240125615d+00
	  x(4)=0.75824229731656256348060196614824235d+00
	  x(5)=0.11783521199560875736267462343676016d+01
	  x(6)=0.16695400125587793738191066950093955d+01
	  x(7)=0.22227783087991492827484307781560346d+01
	  x(8)=0.28304848302713394581076045142253861d+01
	  x(9)=0.34862844007039122118385421345010400d+01
	  x(10)=0.41847751598255813476612274826038629d+01
	  x(11)=0.49213473609559184041017942945472896d+01
	  x(12)=0.56920524484299326317682243825402111d+01
	  x(13)=0.64935072997818688023130562214646488d+01
	  x(14)=0.73228202200078840178321115672588348d+01
	  x(15)=0.81775303561968240018131837132386863d+01
	  x(16)=0.90555563983894327151347170001827180d+01
	  x(17)=0.99551529304501737982491249567829072d+01
	  x(18)=0.10874874011268980567024300398770720d+02
	  x(19)=0.11813544104522151201308588497340679d+02
	  x(20)=0.12770236786942932738497802347410470d+02
	  x(21)=0.13744262037156889988409602665342391d+02
	  x(22)=0.14735163540289747174938383977860212d+02
	  x(23)=0.15742728540739239662116233375854790d+02
	  x(24)=0.16767014578429062510167568689212203d+02
	  x(25)=0.17808400110182436293371210922487080d+02
	  x(26)=0.18867668960609286443741439143195748d+02
	  x(27)=0.19946143700718788949188819970004261d+02
	  x(28)=0.21045995786123555149060848634690046d+02
	  x(29)=0.22173033865751079929395928047597408d+02
	  w(1)=0.85838158802988701046032815611397382d-01
	  w(2)=0.19477385901158245085085241043998394d+00
	  w(3)=0.29383621766506690109466148896899540d+00
	  w(4)=0.38117224372587515945909331094298977d+00
	  w(5)=0.45728310074921790784330255519307684d+00
	  w(6)=0.52359020598427119530526852031471208d+00
	  w(7)=0.58162702319516323967718562926165760d+00
	  w(8)=0.63272747067482759675272063759621233d+00
	  w(9)=0.67797436135679445268209519781521522d+00
	  w(10)=0.71824100693600445577402524577337317d+00
	  w(11)=0.75424686608660118647406989111914299d+00
	  w(12)=0.78660066973655529132258834579261020d+00
	  w(13)=0.81582808550718999285322752257343382d+00
	  w(14)=0.84238846687921586919856054009869695d+00
	  w(15)=0.86668565323448476522827377266366966d+00
	  w(16)=0.88907615047281940423573587395367213d+00
	  w(17)=0.90987644549942581218004988841130398d+00
	  w(18)=0.92937024251990218992602876824093983d+00
	  w(19)=0.94781599269424532394623383879661560d+00
	  w(20)=0.96545503882224525948885229809093289d+00
	  w(21)=0.98252089587658952840598658440285362d+00
	  w(22)=0.99925063547801429297834374665399082d+00
	  w(23)=0.10159001898755433135335124461562373d+01
	  w(24)=0.10327670289817463267212360733537935d+01
	  w(25)=0.10502268960351484050619319532415830d+01
	  w(26)=0.10687987121279187707756364034139551d+01
	  w(27)=0.10892886965844568170069806001265533d+01
	  w(28)=0.11135100571950677927901551811373793d+01
	  w(29)=0.11530882719782502565664117355481721d+01
	endif
	if(n.eq. 30) then
	  x(1)=0.32395423845231328952021243594572297d-01
	  x(2)=0.16861844033714026847015077237301739d+00
	  x(3)=0.40611377169029516664977563777938485d+00
	  x(4)=0.73466473057596815010583668481558561d+00
	  x(5)=0.11434056199839885969993247272213921d+01
	  x(6)=0.16223240841225237129918923528748564d+01
	  x(7)=0.21627613886742245163929965201532468d+01
	  x(8)=0.27573919900368202284823837544536218d+01
	  x(9)=0.34000247011207842540159163036150858d+01
	  x(10)=0.40853910479355226570419290510471910d+01
	  x(11)=0.48089751549709580658031882194336504d+01
	  x(12)=0.55668891598344441007384375552646816d+01
	  x(13)=0.63557824365416699663455801783129573d+01
	  x(14)=0.71727723299071382001557140029035509d+01
	  x(15)=0.80153880354211217706961178919300437d+01
	  x(16)=0.88815231304950224000549496849998832d+01
	  x(17)=0.97693948098293734716435210430063307d+01
	  x(18)=0.10677509220347507934434361231978983d+02
	  x(19)=0.11604632899927898037617524096276611d+02
	  x(20)=0.12549770612996521634840974002145231d+02
	  x(21)=0.13512150122572977650747816369403154d+02
	  x(22)=0.14491214826551962246981020143721253d+02
	  x(23)=0.15486625876302246851423660700675100d+02
	  x(24)=0.16498276597704045087766644428484142d+02
	  x(25)=0.17526324055306258031805555219762027d+02
	  x(26)=0.18571245797007211564277895377017558d+02
	  x(27)=0.19633934281183009318283438915386796d+02
	  x(28)=0.20715851636750954867238760925829411d+02
	  x(29)=0.21819391138662258100566759821958840d+02
	  x(30)=0.22950804950088933509277921984903514d+02
	  w(1)=0.82891596110067619629369062295154436d-01
	  w(2)=0.18838810673274555829159737641020911d+00
	  w(3)=0.28485143005306101660067952252575196d+00
	  w(4)=0.37041553715895586540440831413434353d+00
	  w(5)=0.44539043894975510751166325462691020d+00
	  w(6)=0.51100452150290254227371633533039130d+00
	  w(7)=0.56865283856139159368581204034853727d+00
	  w(8)=0.61958013174010084789244956482434645d+00
	  w(9)=0.66481004321965575520891889027552679d+00
	  w(10)=0.70517204769960306620646406372543424d+00
	  w(11)=0.74134967169016696697525503623182885d+00
	  w(12)=0.77392103530415079504223285766784102d+00
	  w(13)=0.80338600122756931298795279872138053d+00
	  w(14)=0.83018277269650053717953142040641978d+00
	  w(15)=0.85469824839953001394121656630886719d+00
	  w(16)=0.87727539085565742205119477148400620d+00
	  w(17)=0.89821948245755822703983994870213792d+00
	  w(18)=0.91780416582368185007823058185749687d+00
	  w(19)=0.93627766216629293438700187834911048d+00
	  w(20)=0.95386940504388062489482535966089927d+00
	  w(21)=0.97079739700556766379690998292062432d+00
	  w(22)=0.98727684670885629270031813575769775d+00
	  w(23)=0.10035311243345927945114226531586610d+01
	  w(24)=0.10198069790571226977959895521053113d+01
	  w(25)=0.10363977445722241110814820785890333d+01
	  w(26)=0.10536819126632297471957144807674922d+01
	  w(27)=0.10721934390392973135419651953270659d+01
	  w(28)=0.10927831816201418746459239628165960d+01
	  w(29)=0.11173737370677914171324118797201663d+01
	  w(30)=0.11578618493114158916057476744754240d+01
	endif
	if(n.eq. 31) then
	  x(1)=0.31354278310343070002019771891355049d-01
	  x(2)=0.16332835712339532907577677178778686d+00
	  x(3)=0.39385199392482811431293043824553024d+00
	  x(4)=0.71349775214722199745409625393222086d+00
	  x(5)=0.11120868650386663833984357552253641d+01
	  x(6)=0.15801071341254320223868035100167617d+01
	  x(7)=0.21092378289133741908756292104953900d+01
	  x(8)=0.26923802662837172938736784999491647d+01
	  x(9)=0.33234998137128841655396627174923196d+01
	  x(10)=0.39974385925377480255349382787244394d+01
	  x(11)=0.47097577456400570028449692472349852d+01
	  x(12)=0.54566190267492231669166358187794685d+01
	  x(13)=0.62346978423822019266253846581093967d+01
	  x(14)=0.70411172062729967535688047064468265d+01
	  x(15)=0.78733946685933355880138151405844837d+01
	  x(16)=0.87293975824146112785228979191742837d+01
	  x(17)=0.96073044951270674118859460577368736d+01
	  x(18)=0.10505571845959279286830678756814450d+02
	  x(19)=0.11422905824103905203514841559808701d+02
	  x(20)=0.12358239542725163673253518936689943d+02
	  x(21)=0.13310715865946766811589441203977913d+02
	  x(22)=0.14279676452924514151732182654086500d+02
	  x(23)=0.15264657976271370998233578575309366d+02
	  x(24)=0.16265397160565473910764922038652003d+02
	  x(25)=0.17281847462814127425190235953778028d+02
	  x(26)=0.18314212155925179814630610053427517d+02
	  x(27)=0.19363001659818237953913921955972910d+02
	  x(28)=0.20429126767095223016212912625633180d+02
	  x(29)=0.21514047061292600915294315200299025d+02
	  x(30)=0.22620126001584271335786979761905968d+02
	  x(31)=0.23753604827909729380053249769844115d+02
	  w(1)=0.80243398875130558800528035590104992d-01
	  w(2)=0.18264806785017626000744428438338218d+00
	  w(3)=0.27678431664690572588938266562763602d+00
	  w(4)=0.36078787836066467109574773530766834d+00
	  w(5)=0.43479728577654619403602964666788466d+00
	  w(6)=0.49985669209612632046813018860120792d+00
	  w(7)=0.55722457082888166013390218722634017d+00
	  w(8)=0.60805777233524505032136175941559486d+00
	  w(9)=0.65332431619085751250963767233770341d+00
	  w(10)=0.69381538132515707673064753180369735d+00
	  w(11)=0.73018463967704683170723001239821315d+00
	  w(12)=0.76298490548565767177535690279910341d+00
	  w(13)=0.79269410213246049856650188303319737d+00
	  w(14)=0.81973162509324370983421204073238187d+00
	  w(15)=0.84446850104307125128855204820865765d+00
	  w(16)=0.86723430801843581772203606305993162d+00
	  w(17)=0.88832273165677944071205729414941743d+00
	  w(18)=0.90799672835074207721817174387979321d+00
	  w(19)=0.92649373188643324716906590765574947d+00
	  w(20)=0.94403111330718736393663448325241916d+00
	  w(21)=0.96081208209329649339025536392000504d+00
	  w(22)=0.97703233520897692088169605995062739d+00
	  w(23)=0.99288801493529488251255088471225463d+00
	  w(24)=0.10085859969498260912956766333081760d+01
	  w(25)=0.10243583939923772696545256621902809d+01
	  w(26)=0.10404848104794099938885665324050933d+01
	  w(27)=0.10573296383546104681983024420333095d+01
	  w(28)=0.10754089559129176301155439432477579d+01
	  w(29)=0.10955423446690406574788312354939990d+01
	  w(30)=0.11196138285621031194239094475051388d+01
	  w(31)=0.11596321256631261231717644477612339d+01
	endif
	if(n.eq. 32) then
	  x(1)=0.30349937742381039029737621603999287d-01
	  x(2)=0.15821530524930957350981941544887377d+00
	  x(3)=0.38196519764129310825495622339076363d+00
	  x(4)=0.69290532029415574655217824329156429d+00
	  x(5)=0.10815000835196373341062781037180685d+01
	  x(6)=0.15387055890220047160710237221792340d+01
	  x(7)=0.20565151130412311353268250968540087d+01
	  x(8)=0.26280393793364540400148143817204982d+01
	  x(9)=0.32473899625462565587952212808886543d+01
	  x(10)=0.39095168843281236092934705084189773d+01
	  x(11)=0.46100629001653583571851413580588996d+01
	  x(12)=0.53452500349782114952290612563956529d+01
	  x(13)=0.61117948249824189943524288537446409d+01
	  x(14)=0.69068439706878734796191565692424774d+01
	  x(15)=0.77279231924730771297049614076968282d+01
	  x(16)=0.85728946088327564467590491403825581d+01
	  x(17)=0.94399201347038257381427683867514133d+01
	  x(18)=0.10327429796843327736155515594873577d+02
	  x(19)=0.11234094613649570959523771307431161d+02
	  x(20)=0.12158804045203877919334445323329419d+02
	  x(21)=0.13100648205518305999817130214069039d+02
	  x(22)=0.14058905194765479507168493000790477d+02
	  x(23)=0.15033034160318033300995921308640391d+02
	  x(24)=0.16022675127681903717302702716551721d+02
	  x(25)=0.17027657384458382949787846882827580d+02
	  x(26)=0.18048019461323221435122832190245390d+02
	  x(27)=0.19084045896883136350652421242557466d+02
	  x(28)=0.20136329387464179774269723566249013d+02
	  x(29)=0.21205872248485881925716967089101672d+02
	  x(30)=0.22294251962151093948705238290131092d+02
	  x(31)=0.23404022785632438541369992890395224d+02
	  x(32)=0.24541777752285696578837814740836620d+02
	  w(1)=0.77687554219704149649494695495377528d-01
	  w(2)=0.17708703705627543145695312887255568d+00
	  w(3)=0.26892445951139809512397960133966990d+00
	  w(4)=0.35134485491478623098160483095853124d+00
	  w(5)=0.42432912048747656319491738940996584d+00
	  w(6)=0.48874675549663260110122564583434723d+00
	  w(7)=0.54572636490278558785149698451277800d+00
	  w(8)=0.59634360129512142822960640842211433d+00
	  w(9)=0.64151835689239933291361239753314294d+00
	  w(10)=0.68201115660547106944733286582049914d+00
	  w(11)=0.71845260343410932701857518623000942d+00
	  w(12)=0.75137547715096031364367945570847951d+00
	  w(13)=0.78123939449719914662750852585304528d+00
	  w(14)=0.80844722185904593914074212079867721d+00
	  w(15)=0.83335551610918434661812170816119760d+00
	  w(16)=0.85628149724405755449652133393101394d+00
	  w(17)=0.87750834620079276593429540298529901d+00
	  w(18)=0.89728986194176141300005156153929420d+00
	  w(19)=0.91585499021399385810582316480576992d+00
	  w(20)=0.93341246626577922818057686527026817d+00
	  w(21)=0.95015572913875601113176116996328346d+00
	  w(22)=0.96626830574334088286292399061494507d+00
	  w(23)=0.98193000412019415534814470447599888d+00
	  w(24)=0.99732451963323776045200474982266314d+00
	  w(25)=0.10126495345374315615316618277574889d+01
	  w(26)=0.10281312953198651349850933911511675d+01
	  w(27)=0.10440474832830413109974188046180643d+01
	  w(28)=0.10607663285146948783932430160348304d+01
	  w(29)=0.10788165311873763041461415923549794d+01
	  w(30)=0.10990633062876840053689875276177190d+01
	  w(31)=0.11234609942681621497229116357630119d+01
	  w(32)=0.11642028453735175919092625917983241d+01
	endif
	if(n.eq. 33) then
	  x(1)=0.29516841548121147686956078359798994d-01
	  x(2)=0.15396436335903893044552148694492644d+00
	  x(3)=0.37204808347099149745673685174551792d+00
	  x(4)=0.67565524712779223559522279174416326d+00
	  x(5)=0.10557709540672579606734871049411595d+01
	  x(6)=0.15037398176183069953282256392412819d+01
	  x(7)=0.20118235591875479606471799343125895d+01
	  x(8)=0.25733186070240368081840642844326794d+01
	  x(9)=0.31824715429064855953811274957843125d+01
	  x(10)=0.38343359509698453635451187437865883d+01
	  x(11)=0.45246356468237429737655475037172437d+01
	  x(12)=0.52496544518904109111190336989238858d+01
	  x(13)=0.60061525587093376188363436085637659d+01
	  x(14)=0.67913031119156554993310237477999181d+01
	  x(15)=0.76026424249740527372409815143328160d+01
	  x(16)=0.84380290860979751954573657712899148d+01
	  x(17)=0.92956091443113493255623325239866972d+01
	  x(18)=0.10173785967015565034898827434517443d+02
	  x(19)=0.11071194190674610524638410424813628d+02
	  x(20)=0.11986677616627256171000226459000260d+02
	  x(21)=0.12919271119546655413046210014726967d+02
	  x(22)=0.13868186777048956415114844276104122d+02
	  x(23)=0.14832804591874367616810559411533177d+02
	  x(24)=0.15812668437981050928442527947481722d+02
	  x(25)=0.16807488298842780949371444876305759d+02
	  x(26)=0.17817150602982401608187501551583409d+02
	  x(27)=0.18841739696439972817643138114362955d+02
	  x(28)=0.19881575591888250187366793397814035d+02
	  x(29)=0.20937275961922320988151113851927221d+02
	  x(30)=0.22009856525751274602953344583511353d+02
	  x(31)=0.23100893760260753140300948871299624d+02
	  x(32)=0.24212906935700107879938514088280499d+02
	  x(33)=0.25352458767932045446968913893215358d+02
	  w(1)=0.75566274379686090845176238417479908d-01
	  w(2)=0.17245090185343961430852743887953693d+00
	  w(3)=0.26232862929412148478292010622681119d+00
	  w(4)=0.34336258354556015159886328547145240d+00
	  w(5)=0.41541767735997026100847051566233858d+00
	  w(6)=0.47922896601846382003131452620436903d+00
	  w(7)=0.53582299405173028361559772747568786d+00
	  w(8)=0.58621072438652011005189024217543192d+00
	  w(9)=0.63127306256395476768972230274812318d+00
	  w(10)=0.67174488823670497339435314643196762d+00
	  w(11)=0.70823651688728472830547389094135724d+00
	  w(12)=0.74126216601389005589339831203687936d+00
	  w(13)=0.77126372355325145679927345554460771d+00
	  w(14)=0.79862744362095428041214972836314701d+00
	  w(15)=0.82369485776729867154699604725465178d+00
	  w(16)=0.84676997408885934515154758628341369d+00
	  w(17)=0.86812447146877491643834900969523005d+00
	  w(18)=0.88800198359922455360049298178637400d+00
	  w(19)=0.90662207006592154812096850946545601d+00
	  w(20)=0.92418416998312613586108454910572618d+00
	  w(21)=0.94087169792305158644296625425340608d+00
	  w(22)=0.95685642254984970556108692107954994d+00
	  w(23)=0.97230333230250642895242663144017570d+00
	  w(24)=0.98737633584223760685461002140073106d+00
	  w(25)=0.10022453993514741643622301126015373d+01
	  w(26)=0.10170961830507487810848488152259961d+01
	  w(27)=0.10321441128244432938743102567968890d+01
	  w(28)=0.10476567228822977195790144833154045d+01
	  w(29)=0.10639899573075621841411475543281995d+01
	  w(30)=0.10816619934110704992491491793771274d+01
	  w(31)=0.11014955209885703979466597957070917d+01
	  w(32)=0.11254225677442042385933973491773941d+01
	  w(33)=0.11656987034000894087881761151948012d+01
	endif
	if(n.eq. 34) then
	  x(1)=0.28692651028194224305245541017939104d-01
	  x(2)=0.14974476358725391511583779902139213d+00
	  x(3)=0.36215242246831369499204811290837824d+00
	  x(4)=0.65833467639295095708007465873379260d+00
	  x(5)=0.10297667251430566714986980514368042d+01
	  x(6)=0.14681718575272575399992547318106517d+01
	  x(7)=0.19660836342145164845618410254246555d+01
	  x(8)=0.25169935589275236331729956873459741d+01
	  x(9)=0.31152944132230948603989872935926542d+01
	  x(10)=0.37561547919856645982861209631664678d+01
	  x(11)=0.44353910610802671499186544679105282d+01
	  x(12)=0.51493605648020599474534719774965197d+01
	  x(13)=0.58948792661202604747927580319810659d+01
	  x(14)=0.66691592755782664880825905129313469d+01
	  x(15)=0.74697603913674583964166231453418732d+01
	  x(16)=0.82945509332970335236723258276470006d+01
	  x(17)=0.91416748168513723982187002548016608d+01
	  x(18)=0.10009523178490880468416435178369284d+02
	  x(19)=0.10896709755369746730480073892977089d+02
	  x(20)=0.11802049726291521380971971666440368d+02
	  x(21)=0.12724541982253466443353318027220666d+02
	  x(22)=0.13663354942079559251055798085872084d+02
	  x(23)=0.14617816153939974910258570162113756d+02
	  x(24)=0.15587406094181691429412239813245833d+02
	  x(25)=0.16571756852068077137118962127715349d+02
	  x(26)=0.17570656852874737552383521688170731d+02
	  x(27)=0.18584063548369215368438744917511940d+02
	  x(28)=0.19612127322511650362457658047787845d+02
	  x(29)=0.20655232129740205948564835125580430d+02
	  x(30)=0.21714061832138220609067502664402127d+02
	  x(31)=0.22789708150232893757447527605108917d+02
	  x(32)=0.23883847152355446752380885300226510d+02
	  x(33)=0.24999160469212206692191102774813771d+02
	  x(34)=0.26142540164298829097333509707823396d+02
	  w(1)=0.73465920097870257565730867099773604d-01
	  w(2)=0.16783021269553297094567767544504022d+00
	  w(3)=0.25568890989410358871580797313072253d+00
	  w(4)=0.33523521193298011500161237563588656d+00
	  w(5)=0.40624063952743300065506559803907294d+00
	  w(6)=0.46932328427959341121677994124183897d+00
	  w(7)=0.52541677947477904986328667291672900d+00
	  w(8)=0.57547077013115410792920556559693068d+00
	  w(9)=0.62032788637594793446083940580138005d+00
	  w(10)=0.66069738134281064123598525839042850d+00
	  w(11)=0.69716940706570784680451424719649367d+00
	  w(12)=0.73023995388151263785658784399856813d+00
	  w(13)=0.76033359683833701136990157465334050d+00
	  w(14)=0.78782036745308980929536346593522467d+00
	  w(15)=0.81302712908770957689341685181716457d+00
	  w(16)=0.83624507863064123647234282543649897d+00
	  w(17)=0.85773495454381520897157997751492076d+00
	  w(18)=0.87773107816218653987050402065506205d+00
	  w(19)=0.89644490268434107171913183265132830d+00
	  w(20)=0.91406842840044344455918690073303878d+00
	  w(21)=0.93077767046171333564785754788317718d+00
	  w(22)=0.94673630331971581064465226518223062d+00
	  w(23)=0.96209962144106575543389681115513667d+00
	  w(24)=0.97701903437855897038843977497890592d+00
	  w(25)=0.99164746386879987216644849468139000d+00
	  w(26)=0.10061462770858133897178277038619854d+01
	  w(27)=0.10206948638656243577571558489580639d+01
	  w(28)=0.10355048992731354928764631040394306d+01
	  w(29)=0.10508431829407769431128372161765583d+01
	  w(30)=0.10670697759020835171384078421397135d+01
	  w(31)=0.10847160169351408587345986234140582d+01
	  w(32)=0.11046428228365237078634208955918439d+01
	  w(33)=0.11288634971393467498756990607944317d+01
	  w(34)=0.11697967629408208001251523455721326d+01
	endif
	if(n.eq. 35) then
	  x(1)=0.27943149453128562909043353101878893d-01
	  x(2)=0.14590069411832473633694462478160858d+00
	  x(3)=0.35311407160938601546007475917576812d+00
	  x(4)=0.64247166668018773627579776075435802d+00
	  x(5)=0.10058950842026235239501374962856062d+01
	  x(6)=0.14354652172354906980444866348989308d+01
	  x(7)=0.19239811948067189195654691502568312d+01
	  x(8)=0.24651294201415425710877116216579452d+01
	  x(9)=0.30534493384161485174388417362933978d+01
	  x(10)=0.36842234616150495440933809732086957d+01
	  x(11)=0.43533578554033427465697059233207256d+01
	  x(12)=0.50572793867785295063299599860329181d+01
	  x(13)=0.57928553206686634879929442831780761d+01
	  x(14)=0.65573322533383304744347697123885155d+01
	  x(15)=0.73482891759340853710114060959313065d+01
	  x(16)=0.81636000582367458378030278254300356d+01
	  x(17)=0.90014027461965540055643941741436720d+01
	  x(18)=0.98600722732568506501138472231104970d+01
	  x(19)=0.10738197612938781944080801622476429d+02
	  x(20)=0.11634561460544686539719805296044797d+02
	  x(21)=0.12548122934780797876896940579172224d+02
	  x(22)=0.13478003249726681289644147909712046d+02
	  x(23)=0.14423474512261989843864284921437502d+02
	  x(24)=0.15383951912487608737478694820310920d+02
	  x(25)=0.16358989743998023413951159454882145d+02
	  x(26)=0.17348281969369558908056205837056041d+02
	  x(27)=0.18351668507278066755361578543670475d+02
	  x(28)=0.19369149191722343061883293557912111d+02
	  x(29)=0.20400908642975103646222123643383384d+02
	  x(30)=0.21447357478426170018792618066072464d+02
	  x(31)=0.22509198895853941735367698129266500d+02
	  x(32)=0.23587535173489076356645455234684050d+02
	  x(33)=0.24684039873950634813581928028725088d+02
	  x(34)=0.25801405524041360450837601092644036d+02
	  x(35)=0.26946472793468675632766462513245642d+02
	  w(1)=0.71555031340840860587526606195751810d-01
	  w(2)=0.16361189172121312629393230508867418d+00
	  w(3)=0.24959951309471137270712404188088840d+00
	  w(4)=0.32775070928790778213013368258543778d+00
	  w(5)=0.39776743234904299306720076856436208d+00
	  w(6)=0.46017034363262798724036883868393488d+00
	  w(7)=0.51581021578199481858462149830302224d+00
	  w(8)=0.56557812294637710426314924916368909d+00
	  w(9)=0.61027751233960847443427155667450279d+00
	  w(10)=0.65059013286410471987863957110675983d+00
	  w(11)=0.68708446304822023975589218025561422d+00
	  w(12)=0.72023748158115508122278924929560162d+00
	  w(13)=0.75045625663456561049713400279870257d+00
	  w(14)=0.77809472328804463181484152300981805d+00
	  w(15)=0.80346529757120999093444879690650851d+00
	  w(16)=0.82684655071315404928355974334408529d+00
	  w(17)=0.84848838411988036778410560145857744d+00
	  w(18)=0.86861583591653057645487479021539912d+00
	  w(19)=0.88743224833632561310281516853137873d+00
	  w(20)=0.90512220720963532105685089845792390d+00
	  w(21)=0.92185446773691992472521405943552963d+00
	  w(22)=0.93778498662542864039437517931219190d+00
	  w(23)=0.95306016086732836534167745412560180d+00
	  w(24)=0.96782040802503321863525798107730225d+00
	  w(25)=0.98220430627346111407405260251834989d+00
	  w(26)=0.99635366284526971636381631469703279d+00
	  w(27)=0.10104201361855729146554949693381786d+01
	  w(28)=0.10245745124422205307723743317183107d+01
	  w(29)=0.10390206451950096955272329068975523d+01
	  w(30)=0.10540178410470131264986548558226787d+01
	  w(31)=0.10699188164138111467593716952251270d+01
	  w(32)=0.10872412754612261753806023989454843d+01
	  w(33)=0.11068318334853040063592288788640872d+01
	  w(34)=0.11307830968943992644426543847657740d+01
	  w(35)=0.11719202724545814131573706617928110d+01
	endif
	if(n.eq. 36) then
	  x(1)=0.27142056328972239548358302840824763d-01
	  x(2)=0.14178681907151427510349606109230081d+00
	  x(3)=0.34342381977838998263763414797722362d+00
	  x(4)=0.62543278953658920649161245819414034d+00
	  x(5)=0.98021315858273505572384465267532505d+00
	  x(6)=0.14002363417962260250249073578743264d+01
	  x(7)=0.18785945055991226659841686341678724d+01
	  x(8)=0.24091879673843461517890318646095693d+01
	  x(9)=0.29867138306149492166241543600335717d+01
	  x(10)=0.36065737319948958372606284683570266d+01
	  x(11)=0.42647654793772025172415851557161659d+01
	  x(12)=0.49577865215147900457282048591878265d+01
	  x(13)=0.56825569402033835331167210824787617d+01
	  x(14)=0.64363605312603828778605929983314127d+01
	  x(15)=0.72167996452014815389475188567303121d+01
	  x(16)=0.80217595113515507421197980875149369d+01
	  x(17)=0.88493788614634816269699513213708997d+01
	  x(18)=0.96980248504438417711526199127547443d+01
	  x(19)=0.10566271182166131481494630861561745d+02
	  x(20)=0.11452878934627758411579634412191808d+02
	  x(21)=0.12356779911330106003219952981453389d+02
	  x(22)=0.13277062520347925556052359752357006d+02
	  x(23)=0.14212960280227379783468677487690002d+02
	  x(24)=0.15163843131286117937861490645445883d+02
	  x(25)=0.16129211834035846351298459921963513d+02
	  x(26)=0.17108695899939579732063066330738366d+02
	  x(27)=0.18102055768589796258538626716472208d+02
	  x(28)=0.19109190390395511371934844646602869d+02
	  x(29)=0.20130152154913822926118882605805993d+02
	  x(30)=0.21165172450830002759403214440681040d+02
	  x(31)=0.22214703800018561707929620752111077d+02
	  x(32)=0.23279488597200625576988386455923319d+02
	  x(33)=0.24360673016746289931688806973397732d+02
	  x(34)=0.25460002587127451789683618699200451d+02
	  x(35)=0.26580225791803091084375409991480410d+02
	  x(36)=0.27728035052626292866762014455161989d+02
	  w(1)=0.69511944436498607213792411130270921d-01
	  w(2)=0.15909081406147243531457036169740604d+00
	  w(3)=0.24305240853533374711936687617708230d+00
	  w(4)=0.31968136778214911730700009684369434d+00
	  w(5)=0.38861583821018325091145584337937180d+00
	  w(6)=0.45027651490975162396068753878353164d+00
	  w(7)=0.50542366833399765546630533208372071d+00
	  w(8)=0.55488112295767544335234333630069159d+00
	  w(9)=0.59940607536473111682795433807768859d+00
	  w(10)=0.63964831820243539528547671579872258d+00
	  w(11)=0.67615269572807168430017554783262312d+00
	  w(12)=0.70937703945268570926430129475193098d+00
	  w(13)=0.73971183935845019608024131230195053d+00
	  w(14)=0.76749632153441160742346482948050834d+00
	  w(15)=0.79302992954234163835991466839914210d+00
	  w(16)=0.81658000692285714894325110435602255d+00
	  w(17)=0.83838691595559167168971725914161652d+00
	  w(18)=0.85866766530031546356127591934637167d+00
	  w(19)=0.87761878886172950409161330753704533d+00
	  w(20)=0.89541891941597706594535566182457842d+00
	  w(21)=0.91223129526075630302273111738031730d+00
	  w(22)=0.92820632453781548587556926577235572d+00
	  w(23)=0.94348428787583971111274649956612848d+00
	  w(24)=0.95819826511204764241114162359735928d+00
	  w(25)=0.97247741465258175086461278624483384d+00
	  w(26)=0.98645081746307394787720568274380639d+00
	  w(27)=0.10002522385876044808128426666371524d+01
	  w(28)=0.10140264169597386079146872361889109d+01
	  w(29)=0.10279380258279977589097597956424579d+01
	  w(30)=0.10421853786456081181199806451331824d+01
	  w(31)=0.10570235062817368021370612041209824d+01
	  w(32)=0.10728043592728884192410987452603877d+01
	  w(33)=0.10900568310850353714869243049179204d+01
	  w(34)=0.11096639729316220002175441550207324d+01
	  w(35)=0.11336107695019650432044500121264718d+01
	  w(36)=0.11734853243038561032562938635237515d+01
	endif
	if(n.eq. 37) then
	  x(1)=0.26411910931522439294205639725987567d-01
	  x(2)=0.13803646212333578469078076977893943d+00
	  x(3)=0.33458866458286440348501855623908341d+00
	  x(4)=0.60990059393603779369641415541991591d+00
	  x(5)=0.95681745451752964193303796491818503d+00
	  x(6)=0.13681782159121467223883428232511505d+01
	  x(7)=0.18373504640983484570426753634819761d+01
	  x(8)=0.23584324939925189745792977191740647d+01
	  x(9)=0.29262632101579311161287932918639854d+01
	  x(10)=0.35363476922733063645409856690093875d+01
	  x(11)=0.41847608285535615735284409311134368d+01
	  x(12)=0.48680578548268362837347922322805971d+01
	  x(13)=0.55832012213620751950315934664104134d+01
	  x(14)=0.63275038677703676626151718664914370d+01
	  x(15)=0.70985855606344072654678711842279881d+01
	  x(16)=0.78943385082265287167047063121572137d+01
	  x(17)=0.87128992260604185560168843949213624d+01
	  x(18)=0.95526246361202105106258386513218284d+01
	  x(19)=0.10412071231990294606362112972419709d+02
	  x(20)=0.11289976725642052457487807259894907d+02
	  x(21)=0.12185243941497299502429996209684759d+02
	  x(22)=0.13096926913784281865105185715947300d+02
	  x(23)=0.14024219245635096697810695332009345d+02
	  x(24)=0.14966444857664761514115525642409921d+02
	  x(25)=0.15923051329229624073491322633344680d+02
	  x(26)=0.16893606147966337971411121543496847d+02
	  x(27)=0.17877796363475876972870537429116666d+02
	  x(28)=0.18875432425143959136448756908066571d+02
	  x(29)=0.19886457443917272769340343074873090d+02
	  x(30)=0.20910963800098624432166616315953434d+02
	  x(31)=0.21949220245145550478582663345150650d+02
	  x(32)=0.23001714444389616431863032630644739d+02
	  x(33)=0.24069220006013843260461726458743215d+02
	  x(34)=0.25152902844913263891157839680090547d+02
	  x(35)=0.26254489692371379305768641643226147d+02
	  x(36)=0.27376803594474612424392034881748259d+02
	  x(37)=0.28528002198033593828085940913297236d+02
	  w(1)=0.67649676167360742184975208601827035d-01
	  w(2)=0.15496839931055050865182920460938476d+00
	  w(3)=0.23708305259617798443905201111192582d+00
	  w(4)=0.31233209049937799006713134986057412d+00
	  w(5)=0.38029950932003797614555651307455264d+00
	  w(6)=0.44131360550008746912453716504387558d+00
	  w(7)=0.49604736684752565034628446483111475d+00
	  w(8)=0.54525789333571705874703638983191922d+00
	  w(9)=0.58965605446404534273341369043919258d+00
	  w(10)=0.62986023397233292797636750037781894d+00
	  w(11)=0.66639312805720818388977022550534457d+00
	  w(12)=0.69969560255345997212828024203190580d+00
	  w(13)=0.73014400539591861605259737189044245d+00
	  w(14)=0.75806514767400290377707960942643695d+00
	  w(15)=0.78374740362428396700522625906160101d+00
	  w(16)=0.80744830649832832758505674064508639d+00
	  w(17)=0.82939962879891959701694759132806212d+00
	  w(18)=0.84981091234194716665939495214843191d+00
	  w(19)=0.86887216649901544140988107756129466d+00
	  w(20)=0.88675619025991547772491685464046896d+00
	  w(21)=0.90362077527298800827537661461974494d+00
	  w(22)=0.91961092564740731791772532233153470d+00
	  w(23)=0.93486117283187752935447178970207460d+00
	  w(24)=0.94949805240417506357886168188997544d+00
	  w(25)=0.96364283281658358326637880963971838d+00
	  w(26)=0.97741463773467263109751002048142254d+00
	  w(27)=0.99093419212349864722000347683206201d+00
	  w(28)=0.10043285584637444696198826932231896d+01
	  w(29)=0.10177374684816955507926650170702487d+01
	  w(30)=0.10313222078463066821996108046732843d+01
	  w(31)=0.10452789938153590476588306046323851d+01
	  w(32)=0.10598598197124693420789753872668371d+01
	  w(33)=0.10754097758743259571900807713973336d+01
	  w(34)=0.10924360626488454073523826082237065d+01
	  w(35)=0.11117141892961428517594413278857246d+01
	  w(36)=0.11353410551996869770619014161638916d+01
	  w(37)=0.11809043377131303032001596875488758d+01
	endif
	if(n.eq. 38) then
	  x(1)=0.25700257544476846210956821892068547d-01
	  x(2)=0.13437730671510350610731165943434462d+00
	  x(3)=0.32595440017712046243403278822370339d+00
	  x(4)=0.59469192164253537047358122435980476d+00
	  x(5)=0.93386055036037418641825524900923483d+00
	  x(6)=0.13366516749940666741736094991210848d+01
	  x(7)=0.17966966989055765946403653288143687d+01
	  x(8)=0.23082824719392154300123820576118305d+01
	  x(9)=0.28663822209047862266118045226903632d+01
	  x(10)=0.34665993632945317770577275950927287d+01
	  x(11)=0.41050836339964167365224056993611157d+01
	  x(12)=0.47784489121199582584154086362104863d+01
	  x(13)=0.54837038163375826371748189558275044d+01
	  x(14)=0.62181967441935146467812955961562693d+01
	  x(15)=0.69795731405245007294979586731642485d+01
	  x(16)=0.77657418386686707378885330399498343d+01
	  x(17)=0.85748477001384681983608970767818391d+01
	  x(18)=0.94052485653211341798396460944786668d+01
	  x(19)=0.10255495278392480429374700179323554d+02
	  x(20)=0.11124314109370851966218651796225458d+02
	  x(21)=0.12010591256336200061127783556003124d+02
	  x(22)=0.12913359319214089637739562022034079d+02
	  x(23)=0.13831785750856202099612346501089633d+02
	  x(24)=0.14765163360026418715165164030622691d+02
	  x(25)=0.15712903001068566410936000465881079d+02
	  x(26)=0.16674528663719286214472958818078041d+02
	  x(27)=0.17649675301574401231619049212895334d+02
	  x(28)=0.18638089938014424262746615568175912d+02
	  x(29)=0.19639636918084001138140592956915498d+02
	  x(30)=0.20654308688728896470365725690498948d+02
	  x(31)=0.21682244324286205738872013171203434d+02
	  x(32)=0.22723759221275248165738958050496876d+02
	  x(33)=0.23779391643480760620832370477728546d+02
	  x(34)=0.24849974804387837679087169817648828d+02
	  x(35)=0.25936753996308112846236326731741428d+02
	  x(36)=0.27041596697766728141232306370511651d+02
	  x(37)=0.28167590252521488736192623036913574d+02
	  x(38)=0.29320962649240779995807315572164953d+02
	  w(1)=0.65834105304151860349470837263652356d-01
	  w(2)=0.15094121610877292427588258760806639d+00
	  w(3)=0.23123369629337622854770017966075102d+00
	  w(4)=0.30510468405302060279637998974067159d+00
	  w(5)=0.37208937577467365853678415987815242d+00
	  w(6)=0.43242816098550262982058711713762023d+00
	  w(7)=0.48670941510737797397467829796369188d+00
	  w(8)=0.53562540884530773777072454322478734d+00
	  w(9)=0.57984278819344259314760847701109014d+00
	  w(10)=0.61995117810859579066118385526351631d+00
	  w(11)=0.65645416844019888191752443162840791d+00
	  w(12)=0.68977873388914845431685307630687021d+00
	  w(13)=0.72028984500715997896236331143882126d+00
	  w(14)=0.74830413909214332779384903915342875d+00
	  w(15)=0.77410057710162016864074985278421082d+00
	  w(16)=0.79792801073672492417898638450424187d+00
	  w(17)=0.82001035032794500345687538356287405d+00
	  w(18)=0.84055014635036973125181702926056460d+00
	  w(19)=0.85973124956521562722855378524400294d+00
	  w(20)=0.87772100427513155551650925190187991d+00
	  w(21)=0.89467224914328558060816476427135058d+00
	  w(22)=0.91072527777349121524963493357063271d+00
	  w(23)=0.92600984369793104544754669404937886d+00
	  w(24)=0.94064726902680118048039048517239280d+00
	  w(25)=0.95475272252572462861053281812928617d+00
	  w(26)=0.96843776378844259600242594387964346d+00
	  w(27)=0.98181331353225009817009549806243740d+00
	  w(28)=0.99499330568698229892987683342653327d+00
	  w(29)=0.10080994461836765285767114619375207d+01
	  w(30)=0.10212677513142154328562583032180555d+01
	  w(31)=0.10346580508699245726234039466362447d+01
	  w(32)=0.10484679850247504706572954091825522d+01
	  w(33)=0.10629558985700717776978763140505180d+01
	  w(34)=0.10784786131313242041329658604809083d+01
	  w(35)=0.10955761354344732971810572053072974d+01
	  w(36)=0.11151239584354482037298339491826482d+01
	  w(37)=0.11401180619063624455122862855205312d+01
	  w(38)=0.11835141220341260925863480224506930d+01
	endif
	if(n.eq. 39) then
	  x(1)=0.25073887894726854669302795741714363d-01
	  x(2)=0.13115344977535206560936842379305745d+00
	  x(3)=0.31833541602906467726796790884691291d+00
	  x(4)=0.58124668846864069315927281422773376d+00
	  x(5)=0.91352613422709438850688457023352385d+00
	  x(6)=0.13086737639678514000252107507549226d+01
	  x(7)=0.17605547962436960407472952283569612d+01
	  x(8)=0.22636252428551268955914110847515985d+01
	  x(9)=0.28129803717777250859910509461769834d+01
	  x(10)=0.34043140824946438449671859416412190d+01
	  x(11)=0.40338457650440728841090276546310633d+01
	  x(12)=0.46982443636267854358834483718965203d+01
	  x(13)=0.53945620989331608541306195547804236d+01
	  x(14)=0.61201809156473414574861635628622025d+01
	  x(15)=0.68727704453347486790448783722240478d+01
	  x(16)=0.76502548970767074720811251609120518d+01
	  x(17)=0.84507863323098462160487542860209942d+01
	  x(18)=0.92727223628167401159316796110942960d+01
	  x(19)=0.10114606967849358198918707785196602d+02
	  x(20)=0.10975153662712441970938925805967301d+02
	  x(21)=0.11853230621739365702183022222016007d+02
	  x(22)=0.12747847587070733510472564375959337d+02
	  x(23)=0.13658144525609888120243340381421149d+02
	  x(24)=0.14583382072903562587384840298909694d+02
	  x(25)=0.15522933859046167626161150110419840d+02
	  x(26)=0.16476280873633431411917626974172890d+02
	  x(27)=0.17443008118557223440348025178536773d+02
	  x(28)=0.18422803939836828845955096767283976d+02
	  x(29)=0.19415462654160794642166365520097315d+02
	  x(30)=0.20420891407608838363785253022797406d+02
	  x(31)=0.21439122657746818134683053358457983d+02
	  x(32)=0.22470334096155962555485530174337327d+02
	  x(33)=0.23514878337990626988585063372738659d+02
	  x(34)=0.24573326062807730352233193116262555d+02
	  x(35)=0.25646530816950477316140677430666983d+02
	  x(36)=0.26735726352941803440899093402549624d+02
	  x(37)=0.27842739408498495379262749338522553d+02
	  x(38)=0.28971263364292116904152862844057381d+02
	  x(39)=0.30124885504124957691374220303259790d+02
	  w(1)=0.64235714592269621547870883659925312d-01
	  w(2)=0.14738884967476767462457587498647626d+00
	  w(3)=0.22605882906388347075576916722638998d+00
	  w(4)=0.29868941957400840792047347349580377d+00
	  w(5)=0.36477790743588461852553450626146514d+00
	  w(6)=0.42449139500404392544297138556430582d+00
	  w(7)=0.47834607841692106111608495666587260d+00
	  w(8)=0.52697816813428965954102523028268479d+00
	  w(9)=0.57101569189262657566530378971947357d+00
	  w(10)=0.61102291998874314060685719596222043d+00
	  w(11)=0.64748637909929174227841031097341329d+00
	  w(12)=0.68082041008123117542538693669484928d+00
	  w(13)=0.71137941191494469261868971443618648d+00
	  w(14)=0.73947037235748680483737871327321045d+00
	  w(15)=0.76536316260410841572081608319422230d+00
	  w(16)=0.78929811977364650044108884685556404d+00
	  w(17)=0.81149133728208522331470931021613069d+00
	  w(18)=0.83213833324749852948798434226773679d+00
	  w(19)=0.85141671030042120893455148689099588d+00
	  w(20)=0.86948825995940692834551555279176682d+00
	  w(21)=0.88650080433177846916947828503907658d+00
	  w(22)=0.90258994713049844893504314313759096d+00
	  w(23)=0.91788083120008634452346996113192290d+00
	  w(24)=0.93248996390617033824810278019867837d+00
	  w(25)=0.94652716586289864508785285579506308d+00
	  w(26)=0.96009771620203732123144391152891330d+00
	  w(27)=0.97330480712751232807988799322629347d+00
	  w(28)=0.98625248964186451594571281020762399d+00
	  w(29)=0.99904938423317091178432747256010771d+00
	  w(30)=0.10118135423928773519719470641575754d+01
	  w(31)=0.10246790248726833638670541404280812d+01
	  w(32)=0.10378045585471802336741120598162524d+01
	  w(33)=0.10513856205994547288185003708349541d+01
	  w(34)=0.10656719105692995519518717628670856d+01
	  w(35)=0.10810033236575720128058719637920149d+01
	  w(36)=0.10978821659188529036299541985499673d+01
	  w(37)=0.11172342139069533217821117432322353d+01
	  w(38)=0.11412213696802919749018201400758699d+01
	  w(39)=0.11817543630745042104734920940245502d+01
	endif
	if(n.eq. 40) then
	  x(1)=0.24504667826819235415536368805078382d-01
	  x(2)=0.12821748571760233081917590425291564d+00
	  x(3)=0.31137268245398080912522686958254781d+00
	  x(4)=0.56890585223203204989772530097980052d+00
	  x(5)=0.89477164873848979986803442443488166d+00
	  x(6)=0.12827408059868423695348838009522296d+01
	  x(7)=0.17268891682406728449450383777730167d+01
	  x(8)=0.22218298182375098015484127245144919d+01
	  x(9)=0.27627751283186414710257849947083741d+01
	  x(10)=0.33455087714491904549163336923811585d+01
	  x(11)=0.39663215429908382780865849781548604d+01
	  x(12)=0.46219407417781592783967425930313766d+01
	  x(13)=0.53094665888658552077572494454216212d+01
	  x(14)=0.60263198727720990177658677566796541d+01
	  x(15)=0.67702004675008753409315431781578809d+01
	  x(16)=0.75390546476126569785947140189819038d+01
	  x(17)=0.83310488819235093416182280634529889d+01
	  x(18)=0.91445481836585695845087684574536979d+01
	  x(19)=0.99780976580742954951119827455841005d+01
	  x(20)=0.10830406394724086283076758263632655d+02
	  x(21)=0.11700333225833329464649068540893495d+02
	  x(22)=0.12586874116096410602949617896229029d+02
	  x(23)=0.13489151093708425577233356307260692d+02
	  x(24)=0.14406402713490455980149818060453981d+02
	  x(25)=0.15337976090804016138235965627245605d+02
	  x(26)=0.16283320582711546364862442715093493d+02
	  x(27)=0.17241983238187017946074774954468012d+02
	  x(28)=0.18213606211667723755454062484204769d+02
	  x(29)=0.19197926466344409135444948333315551d+02
	  x(30)=0.20194778344840742079213669057935476d+02
	  x(31)=0.21204100118586271861431669094599783d+02
	  x(32)=0.22225946654943975033802416874095798d+02
	  x(33)=0.23260511845374328032676203292794526d+02
	  x(34)=0.24308166596091595579309796448796988d+02
	  x(35)=0.25369517780656448024956262088380754d+02
	  x(36)=0.26445492197921929289350373437628150d+02
	  x(37)=0.27537461088154344679423957131803036d+02
	  x(38)=0.28647456688034615979177033295854926d+02
	  x(39)=0.29778334017986210824346926528960466d+02
	  x(40)=0.30938371037795256768276885850355029d+02
	  w(1)=0.62782402890552257979095429618610069d-01
	  w(2)=0.14414527700462842485507053424953483d+00
	  w(3)=0.22130189479626832804726177528209519d+00
	  w(4)=0.29274363832989835909614839692949317d+00
	  w(5)=0.35794171729349866239999755634926260d+00
	  w(6)=0.41700559913000234679714139929274097d+00
	  w(7)=0.47039246816630259084845988581946585d+00
	  w(8)=0.51869148658738262192002821393543854d+00
	  w(9)=0.56249754937039597724179884608020075d+00
	  w(10)=0.60235274236903557643074691441142932d+00
	  w(11)=0.63872841833503812836170254740864038d+00
	  w(12)=0.67202755341193376459330011130077764d+00
	  w(13)=0.70259495805650751254489705388550647d+00
	  w(14)=0.73072879442495675128554921684553847d+00
	  w(15)=0.75669053960591947660674350117915310d+00
	  w(16)=0.78071258971543677773752278881147504d+00
	  w(17)=0.80300368667774868480790928515489213d+00
	  w(18)=0.82375270171335557289893358756671660d+00
	  w(19)=0.84313133222241798403473467260482721d+00
	  w(20)=0.86129615643818069337100951088359579d+00
	  w(21)=0.87839035105925988844433049962390214d+00
	  w(22)=0.89454525993312516973787751339841634d+00
	  w(23)=0.90988192085007990606015937373740599d+00
	  w(24)=0.92451261055897526741631509139551781d+00
	  w(25)=0.93854244741608816582356666913256049d+00
	  w(26)=0.95207109077029727917107493340154178d+00
	  w(27)=0.96519459157104703361795827731839381d+00
	  w(28)=0.97800749098771688760933784578810446d+00
	  w(29)=0.99060534542288103398988141634617932d+00
	  w(30)=0.10030880346103638878219044272555038d+01
	  w(31)=0.10155646343432478406754171373904683d+01
	  w(32)=0.10281610016829541009997228684369475d+01
	  w(33)=0.10410328462714633079855275354930200d+01
	  w(34)=0.10543834318522862236733317331527360d+01
	  w(35)=0.10684925996095646638650578097440302d+01
	  w(36)=0.10837428943236429024210565330577083d+01
	  w(37)=0.11007132595541071484745998532162048d+01
	  w(38)=0.11204089142133897283315491222310811d+01
	  w(39)=0.11446152485325957748329983587609604d+01
	  w(40)=0.11821089382133427303500639027333818d+01
	endif
	if(n.eq. 41) then
	  x(1)=0.23984523421017991950954240110149840d-01
	  x(2)=0.12552961049068050991550649087002967d+00
	  x(3)=0.30497904043054141487445463098993059d+00
	  x(4)=0.55753159882308778172443908260902390d+00
	  x(5)=0.87741720264378519900105857232119888d+00
	  x(6)=0.12586491038184279833700429662712850d+01
	  x(7)=0.16954977461019282714005385059863329d+01
	  x(8)=0.21827260342350083277551675564609468d+01
	  x(9)=0.27156613618673488552701655862620100d+01
	  x(10)=0.32901776514269975848492322256788611d+01
	  x(11)=0.39026386408220425927595442772144452d+01
	  x(12)=0.45498318829865622703323424502741545d+01
	  x(13)=0.52289076040329840466824862232897431d+01
	  x(14)=0.59373274690486210758422203070949763d+01
	  x(15)=0.66728236147476049922033780603669584d+01
	  x(16)=0.74333663342336304680202374584041536d+01
	  x(17)=0.82171383220225351351473364047706127d+01
	  x(18)=0.90225136171926507699936337303370237d+01
	  x(19)=0.98480398528942885150172514840960503d+01
	  x(20)=0.10692422891002696161422136356122792d+02
	  x(21)=0.11554513294398519818173554085660726d+02
	  x(22)=0.12433294349000162171137162658851594d+02
	  x(23)=0.13327871512316947999465810426045209d+02
	  x(24)=0.14237463264860524603250269137788564d+02
	  x(25)=0.15161393403778083310839974728878587d+02
	  x(26)=0.16099084867358556039107497781515121d+02
	  x(27)=0.17050055232336600141707094735465944d+02
	  x(28)=0.18013914092609461192751041380688548d+02
	  x(29)=0.18990362612595298230644402792677283d+02
	  x(30)=0.19979195621968958818115424946881831d+02
	  x(31)=0.20980306596836737043076936970464885d+02
	  x(32)=0.21993695652042131172265726490877569d+02
	  x(33)=0.23019480134884943822726199869066477d+02
	  x(34)=0.24057907429698456525102301384322345d+02
	  x(35)=0.25109372769166562022746802540495992d+02
	  x(36)=0.26174451464588528892818430904299021d+02
	  x(37)=0.27253979420866915717169831623323262d+02
	  x(38)=0.28349199152628795417285800795070827d+02
	  x(39)=0.29461964303315493651780343498103321d+02
	  x(40)=0.30595867666822844199714381829835474d+02
	  x(41)=0.31760614049108848888636202900670469d+02
	  w(1)=0.61453777689078850632320438762690173d-01
	  w(2)=0.14116901928623146189600845445966115d+00
	  w(3)=0.21691178102955907536220081510691671d+00
	  w(4)=0.28721914904195389173224839396425523d+00
	  w(5)=0.35154646142852036261317039134155493d+00
	  w(6)=0.40995869480166080567329345285543241d+00
	  w(7)=0.46286472101062492434664363827323541d+00
	  w(8)=0.51081350768430644482265279293642379d+00
	  w(9)=0.55437048040962799699826746291364543d+00
	  w(10)=0.59405718617497671463212327580549754d+00
	  w(11)=0.63033041409925372189348991014412604d+00
	  w(12)=0.66358196163380622767391514571500011d+00
	  w(13)=0.69414710302202875524812952789943665d+00
	  w(14)=0.72231518314433129646090492315124720d+00
	  w(15)=0.74833924850753152924198730033822358d+00
	  w(16)=0.77244365386107194382248053443618119d+00
	  w(17)=0.79482962192212569529914389931946062d+00
	  w(18)=0.81567916211028024253693047285196371d+00
	  w(19)=0.83515784442209617388641618163092062d+00
	  w(20)=0.85341685831049940436088263595593162d+00
	  w(21)=0.87059467195834050468050691051757894d+00
	  w(22)=0.88681849942647339446466503432020545d+00
	  w(23)=0.90220570265884358907015894146752544d+00
	  w(24)=0.91686520534588789033136890793684870d+00
	  w(25)=0.93089897139517174817768818684271537d+00
	  w(26)=0.94440359709427723622354733379324898d+00
	  w(27)=0.95747207569971692908694649304379709d+00
	  w(28)=0.97019581022582634943773882696405053d+00
	  w(29)=0.98266696542779785605858933195122518d+00
	  w(30)=0.99498119901604997750155234825797379d+00
	  w(31)=0.10072407235150886428698413510574028d+01
	  w(32)=0.10195570153317672357218270917655900d+01
	  w(33)=0.10320537595879675230037264554994181d+01
	  w(34)=0.10448685551989436159914248491986655d+01
	  w(35)=0.10581641602642044563964418557588942d+01
	  w(36)=0.10721519908466690118586939206579700d+01
	  w(37)=0.10871725696261811400233909807866439d+01
	  w(38)=0.11037689531946959231589744376833551d+01
	  w(39)=0.11228513333944662999641650458215736d+01
	  w(40)=0.11475919063733051039832844253396615d+01
	  w(41)=0.11746124972473792613669729689718224d+01
	endif
	if(n.eq. 42) then
	  x(1)=0.23399519154861270209266876918263733d-01
	  x(2)=0.12250727755965652721048542161952355d+00
	  x(3)=0.29779385079556730531180619436781853d+00
	  x(4)=0.54476244056479006250270913369604386d+00
	  x(5)=0.85796593033227286362318864121334627d+00
	  x(6)=0.12317064415078076144993701745988801d+01
	  x(7)=0.16604889563747902148094226504326798d+01
	  x(8)=0.21392575607345967192429725400870666d+01
	  x(9)=0.26634773326195908538238654728047550d+01
	  x(10)=0.32291274032903434232366635114885867d+01
	  x(11)=0.38326531517021260597744003462139517d+01
	  x(12)=0.44709063426711255218037877057213336d+01
	  x(13)=0.51410878286817593973978546273428947d+01
	  x(14)=0.58406986322303806602462827868293971d+01
	  x(15)=0.65675004483780758945954403316136450d+01
	  x(16)=0.73194844194713235552285368612501770d+01
	  x(17)=0.80948463450017218434595633880235255d+01
	  x(18)=0.88919665623227750472779007395729423d+01
	  x(19)=0.97093931113621838591143387020565569d+01
	  x(20)=0.10545827225370498325673906947486103d+02
	  x(21)=0.11400110553885486552871952881105244d+02
	  x(22)=0.12271213789242862546302603732328862d+02
	  x(23)=0.13158226541458786229554789315443486d+02
	  x(24)=0.14060348411404792301482302718795836d+02
	  x(25)=0.14976881274013200240347032377030700d+02
	  x(26)=0.15907222823958095503371623635757715d+02
	  x(27)=0.16850861473230875020590247004292905d+02
	  x(28)=0.17807372741036434860006920644082129d+02
	  x(29)=0.18776417356958841509140256675891578d+02
	  x(30)=0.19757741446668578788603554130531847d+02
	  x(31)=0.20751179385310333458392051397822797d+02
	  x(32)=0.21756660233976980123316025128588080d+02
	  x(33)=0.22774219302597114023001267923973501d+02
	  x(34)=0.23804016061690816741247544996440411d+02
	  x(35)=0.24846361937852712742369476472958922d+02
	  x(36)=0.25901759563898949068061483558267355d+02
	  x(37)=0.26970970182886965460511419223621488d+02
	  x(38)=0.28055109231405054970309720374643803d+02
	  x(39)=0.29155906125746835044765248312614858d+02
	  x(40)=0.30276036870974266435041499789804220d+02
	  x(41)=0.31422744585242831760751869296655059d+02
	  x(42)=0.32611636111093410761441191425547004d+02
	  w(1)=0.59959549528834581166858441747535835d-01
	  w(2)=0.13782354106246585967454620913485996d+00
	  w(3)=0.21198373628310368532723373391490895d+00
	  w(4)=0.28103396142753983566464626164815854d+00
	  w(5)=0.34441587073831536613965909054968506d+00
	  w(6)=0.40214554766643612060406098862586077d+00
	  w(7)=0.45457562783648930437863100451068021d+00
	  w(8)=0.50220599007960209370082793611800298d+00
	  w(9)=0.54556427189496681240399311718647368d+00
	  w(10)=0.58514446288410426610937520308652893d+00
	  w(11)=0.62138329530779745635271638093399815d+00
	  w(12)=0.65465737881544439069614327308954671d+00
	  w(13)=0.68528975194393804137860115588409826d+00
	  w(14)=0.71355932009544631444697415645350702d+00
	  w(15)=0.73970991145305309277802052747574635d+00
	  w(16)=0.76395766265738540568008829723112285d+00
	  w(17)=0.78649652296777516902182014746358618d+00
	  w(18)=0.80750215877814202070084093065815978d+00
	  w(19)=0.82713469038170439606716399794095196d+00
	  w(20)=0.84554066844173625394631699236924760d+00
	  w(21)=0.86285460596226726259772021876415238d+00
	  w(22)=0.87920028191136079254164314988884144d+00
	  w(23)=0.89469195141805224480435754230711609d+00
	  w(24)=0.90943554210252131042580003850162029d+00
	  w(25)=0.92352988433189653338928337689139880d+00
	  w(26)=0.93706801176950760279282803821843117d+00
	  w(27)=0.95013857293707892903711353937978856d+00
	  w(28)=0.96282741662106641200580270378850400d+00
	  w(29)=0.97521945976814672363275349198374897d+00
	  w(30)=0.98740101730765483800666970637394115d+00
	  w(31)=0.99946288622088297337597850855672732d+00
	  w(32)=0.10115044760703817416924721328541636d+01
	  w(33)=0.10236398737916996282137915841303766d+01
	  w(34)=0.10360055297867141188561390663380735d+01
	  w(35)=0.10487706272210348679152502882061526d+01
	  w(36)=0.10621564297165377865894697606563568d+01
	  w(37)=0.10764703972462128511722312396159396d+01
	  w(38)=0.10921305609416507298448095752974041d+01
	  w(39)=0.11099745940549852196710389762301929d+01
	  w(40)=0.11308477326180361721696954191429541d+01
	  w(41)=0.11659271347310256050633370250579901d+01
	  w(42)=0.13123354895155796562278283090563491d+01
	endif
	end
c
c
c
c
ccc	subroutine numthetafour(numtets,nlams)
ccc	integer *4 numtets(nlams),nlams 
	subroutine nthalf(numtets,nlams,nxtotp)
c
c This routine returns the number of Fourier modes needed in the
c phi integral for each of the discrete lambda values given
c by Norman's quadratures. (see weights.f).
c
c Input arguments:
c	nlams - number of nodes in the lambda quadrature.  This must
c	  be an integer in the range [2,39].
c
c Output arguments:
c	numtest(i) - number of Fourier modes needed for phi
c                    integral with lambda_i.
c
c Approximate accuracies of the quadrature:
c
c	NLAMS	maximum error
c
c        2     0.15318d+00
c        3     0.76505d-01
c        4     0.32149d-01
c        5     0.15630d-01
c        6     0.75110d-02
c        7     0.35030d-02
c        8     0.16243d-02
c        9     0.72230d-03
c       10     0.33074d-03
c       11     0.15035d-03
c       12     0.70952d-04
c       13     0.31751d-04
c       14     0.14589d-04
c       15     0.64300d-05
c       16     0.29477d-05
c       17     0.13222d-05
c       18     0.61488d-06
c       19     0.27435d-06
c       20     0.12534d-06
c       21     0.55324d-07
c       22     0.25257d-07
c       23     0.11293d-07
c       24     0.52063d-08
c       25     0.23256d-08
c       26     0.10580d-08
c       27     0.46835d-09
c       28     0.21286d-09
c       29     0.95164d-10
c       30     0.43599d-10
c       31     0.19516d-10
c       32     0.88491d-11
c       33     0.39313d-11
c       34     0.17821d-11
c       35     0.79603d-12
c       36     0.36460d-12
c       37     0.16331d-12
c       38     0.73497d-13
c       39     0.31530d-13
c
	integer *4 numtets(nlams),nlams,nxtotp
      if(nlams.eq. 2) then
         numtets( 1) =  3
         numtets( 2) =  1
      endif
      if(nlams.eq. 3) then
ccc         numtets( 1) =  3
ccc         numtets( 2) =  4
ccc         numtets( 3) =  1
         numtets( 1) =  4
         numtets( 2) =  4
         numtets( 3) =  4
      endif
      if(nlams.eq. 4) then
         numtets( 1) =  3
         numtets( 2) =  7
         numtets( 3) =  5
         numtets( 4) =  1
      endif
      if(nlams.eq. 5) then
ccc         numtets( 1) =  4
ccc         numtets( 2) =  8
ccc         numtets( 3) =  10
ccc         numtets( 4) =  8
ccc         numtets( 5) =  2
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) =  8
         numtets( 4) =  8
         numtets( 5) =  4
      endif
      if(nlams.eq. 6) then
         numtets( 1) =  3
         numtets( 2) =  7
         numtets( 3) = 10
         numtets( 4) = 12
         numtets( 5) =  8
         numtets( 6) =  1
      endif
      if(nlams.eq. 7) then
         numtets( 1) =  3
         numtets( 2) =  7
         numtets( 3) = 11
         numtets( 4) = 15
         numtets( 5) = 16
         numtets( 6) =  9
         numtets( 7) =  1
      endif
cccc
      if(nlams.eq. 8) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 16
         numtets( 4) = 16
         numtets( 5) = 24
         numtets( 6) = 24
         numtets( 7) =  8
         numtets( 8) =  4
      endif
cccc
      if(nlams.eq. 9) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 20
         numtets( 7) = 24
         numtets( 8) =  8
         numtets( 9) =  2
      endif
      if(nlams.eq.10) then
         numtets( 1) =  4
         numtets( 2) =  7
         numtets( 3) = 11
         numtets( 4) = 15
         numtets( 5) = 20
         numtets( 6) = 24
         numtets( 7) = 27
         numtets( 8) = 25
         numtets( 9) =  6
         numtets(10) =  1
      endif
      if(nlams.eq.11) then
         numtets( 1) =  4
         numtets( 2) =  7
         numtets( 3) = 11
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 24
         numtets( 7) = 28
         numtets( 8) = 32
         numtets( 9) = 29
         numtets(10) =  6
         numtets(11) =  1
      endif
      if(nlams.eq.12) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 11
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 24
         numtets( 7) = 28
         numtets( 8) = 33
         numtets( 9) = 35
         numtets(10) = 32
         numtets(11) =  5
         numtets(12) =  1
      endif
      if(nlams.eq.13) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 19
         numtets( 6) = 24
         numtets( 7) = 28
         numtets( 8) = 32
         numtets( 9) = 37
         numtets(10) = 38
         numtets(11) = 37
         numtets(12) =  6
         numtets(13) =  1
      endif
      if(nlams.eq.14) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 24
         numtets( 7) = 29
         numtets( 8) = 33
         numtets( 9) = 38
         numtets(10) = 40
         numtets(11) = 44
         numtets(12) = 35
         numtets(13) =  5
         numtets(14) =  1
      endif
      if(nlams.eq.15) then
         numtets( 1) =  4
         numtets( 2) =  8
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 25
         numtets( 7) = 29
         numtets( 8) = 33
         numtets( 9) = 38
         numtets(10) = 41
         numtets(11) = 45
         numtets(12) = 47
         numtets(13) = 40
         numtets(14) =  5
         numtets(15) =  1
      endif
      if(nlams.eq.16) then
         numtets( 1) =  8
         numtets( 2) =  8
         numtets( 3) = 16
         numtets( 4) = 16
         numtets( 5) = 24
         numtets( 6) = 24
         numtets( 7) = 32
         numtets( 8) = 36
         numtets( 9) = 36
         numtets(10) = 48
         numtets(11) = 48
         numtets(12) = 48
         numtets(13) = 48
         numtets(14) = 46
         numtets(15) =  8
         numtets(16) =  8
      endif
      if(nlams.eq.17) then
         numtets( 1) =  8
         numtets( 2) =  8
         numtets( 3) = 16
         numtets( 4) = 16
         numtets( 5) = 24
         numtets( 6) = 32
         numtets( 7) = 32
         numtets( 8) = 32
         numtets( 9) = 48
         numtets(10) = 48
         numtets(11) = 48
         numtets(12) = 48
         numtets(13) = 48
         numtets(14) = 48
         numtets(15) = 48
         numtets(16) =  8
         numtets(17) =  4
      endif
      if(nlams.eq.18) then
         numtets( 1) =  6
         numtets( 2) =  8
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 20
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 38
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 56
         numtets(14) = 60
         numtets(15) = 60
         numtets(16) = 52
         numtets(17) =  4
         numtets(18) =  2
      endif
      if(nlams.eq.19) then
         numtets( 1) =  5
         numtets( 2) =  9
         numtets( 3) = 12
         numtets( 4) = 16
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 29
         numtets( 8) = 34
         numtets( 9) = 38
         numtets(10) = 43
         numtets(11) = 47
         numtets(12) = 52
         numtets(13) = 56
         numtets(14) = 60
         numtets(15) = 65
         numtets(16) = 65
         numtets(17) = 53
         numtets(18) =  5
         numtets(19) =  1
      endif
      if(nlams.eq.20) then
         numtets( 1) =  5
         numtets( 2) =  9
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 29
         numtets( 8) = 34
         numtets( 9) = 38
         numtets(10) = 43
         numtets(11) = 47
         numtets(12) = 52
         numtets(13) = 56
         numtets(14) = 60
         numtets(15) = 64
         numtets(16) = 68
         numtets(17) = 66
         numtets(18) = 53
         numtets(19) =  4
         numtets(20) =  1
      endif
      if(nlams.eq.21) then
         numtets( 1) =  5
         numtets( 2) =  9
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 38
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 57
         numtets(14) = 61
         numtets(15) = 65
         numtets(16) = 68
         numtets(17) = 71
         numtets(18) = 68
         numtets(19) = 54
         numtets(20) =  5
         numtets(21) =  1
      endif
      if(nlams.eq.22) then
         numtets( 1) =  6
         numtets( 2) =  9
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 57
         numtets(14) = 61
         numtets(15) = 66
         numtets(16) = 68
         numtets(17) = 74
         numtets(18) = 74
         numtets(19) = 75
         numtets(20) = 63
         numtets(21) =  4
         numtets(22) =  1
      endif
      if(nlams.eq.23) then
         numtets( 1) =  6
         numtets( 2) =  9
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 57
         numtets(14) = 61
         numtets(15) = 66
         numtets(16) = 70
         numtets(17) = 75
         numtets(18) = 78
         numtets(19) = 82
         numtets(20) = 78
         numtets(21) = 67
         numtets(22) =  4
         numtets(23) =  1
      endif
      if(nlams.eq.24) then
         numtets( 1) =  6
         numtets( 2) =  9
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 57
         numtets(14) = 61
         numtets(15) = 66
         numtets(16) = 70
         numtets(17) = 75
         numtets(18) = 79
         numtets(19) = 82
         numtets(20) = 83
         numtets(21) = 83
         numtets(22) = 67
         numtets(23) =  5
         numtets(24) =  1
      endif
      if(nlams.eq.25) then
         numtets( 1) =  6
         numtets( 2) = 10
         numtets( 3) = 13
         numtets( 4) = 17
         numtets( 5) = 21
         numtets( 6) = 25
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 52
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 66
         numtets(16) = 71
         numtets(17) = 75
         numtets(18) = 79
         numtets(19) = 83
         numtets(20) = 88
         numtets(21) = 88
         numtets(22) = 89
         numtets(23) = 71
         numtets(24) =  4
         numtets(25) =  1
      endif
      if(nlams.eq.26) then
ccc         numtets( 1) =  6
ccc         numtets( 2) = 10
ccc         numtets( 3) = 13
ccc         numtets( 4) = 17
ccc         numtets( 5) = 21
ccc         numtets( 6) = 26
ccc         numtets( 7) = 30
ccc         numtets( 8) = 34
ccc         numtets( 9) = 39
ccc         numtets(10) = 43
ccc         numtets(11) = 48
ccc         numtets(12) = 52
ccc         numtets(13) = 57
ccc         numtets(14) = 62
ccc         numtets(15) = 66
ccc         numtets(16) = 71
ccc         numtets(17) = 75
ccc         numtets(18) = 80
ccc         numtets(19) = 84
ccc         numtets(20) = 88
ccc         numtets(21) = 91
ccc         numtets(22) = 92
ccc         numtets(23) = 89
ccc         numtets(24) = 69
ccc         numtets(25) =  5
ccc         numtets(26) =  1
         numtets( 1) =  8
         numtets( 2) = 16
         numtets( 3) = 16
         numtets( 4) = 16
         numtets( 5) = 24
         numtets( 6) = 32
         numtets( 7) = 32
         numtets( 8) = 32
         numtets( 9) = 48
         numtets(10) = 48
         numtets(11) = 48
         numtets(12) = 64
         numtets(13) = 64
         numtets(14) = 64
         numtets(15) = 64
         numtets(16) = 72
         numtets(17) = 72
         numtets(18) = 80
         numtets(19) = 80
         numtets(20) = 88
         numtets(21) = 88
         numtets(22) = 88
         numtets(23) = 88
         numtets(24) = 72
         numtets(25) = 32
         numtets(26) =  4
      endif
      if(nlams.eq.27) then
         numtets( 1) =  6
         numtets( 2) = 10
         numtets( 3) = 14
         numtets( 4) = 17
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 66
         numtets(16) = 71
         numtets(17) = 75
         numtets(18) = 80
         numtets(19) = 84
         numtets(20) = 89
         numtets(21) = 92
         numtets(22) = 95
         numtets(23) = 97
         numtets(24) = 95
         numtets(25) = 75
         numtets(26) =  4
         numtets(27) =  1
      endif
      if(nlams.eq.28) then
         numtets( 1) =  6
         numtets( 2) = 10
         numtets( 3) = 14
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 34
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 66
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 80
         numtets(19) = 85
         numtets(20) = 89
         numtets(21) = 93
         numtets(22) = 98
         numtets(23) =102
         numtets(24) =102
         numtets(25) = 99
         numtets(26) = 80
         numtets(27) =  4
         numtets(28) =  1
      endif
      if(nlams.eq.29) then
         numtets( 1) =  6
         numtets( 2) = 10
         numtets( 3) = 14
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 43
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 66
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 80
         numtets(19) = 85
         numtets(20) = 89
         numtets(21) = 94
         numtets(22) = 98
         numtets(23) =102
         numtets(24) =103
         numtets(25) =108
         numtets(26) =101
         numtets(27) = 86
         numtets(28) =  4
         numtets(29) =  1
      endif
      if(nlams.eq.30) then
*         numtets( 1) =  7
*        numtets( 2) = 10
*        numtets( 3) = 14
*        numtets( 4) = 18
*        numtets( 5) = 22
*        numtets( 6) = 26
*        numtets( 7) = 30
*        numtets( 8) = 35
*        numtets( 9) = 39
*        numtets(10) = 43
*        numtets(11) = 48
*        numtets(12) = 53
*        numtets(13) = 57
*        numtets(14) = 62
*        numtets(15) = 66
*        numtets(16) = 71
*        numtets(17) = 76
*        numtets(18) = 80
*        numtets(19) = 85
*        numtets(20) = 89
*        numtets(21) = 94
*        numtets(22) = 97
*        numtets(23) =103
*        numtets(24) =107
*        numtets(25) =110
*        numtets(26) =112
*        numtets(27) =108
*        numtets(28) = 84
*        numtets(29) =  4
*        numtets(30) =  1
         numtets( 1) =  8
         numtets( 2) = 10
         numtets( 3) = 14
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 36
         numtets( 9) = 40
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 54
         numtets(13) = 58
         numtets(14) = 62
         numtets(15) = 66
         numtets(16) = 72
         numtets(17) = 76
         numtets(18) = 80
         numtets(19) = 86
         numtets(20) = 90
         numtets(21) = 94
         numtets(22) = 98
         numtets(23) =104
         numtets(24) =108
         numtets(25) =110
         numtets(26) =112
         numtets(27) =108
         numtets(28) = 84
         numtets(29) =  4
         numtets(30) =  2
      endif
      if(nlams.eq.31) then
         numtets( 1) =  7
         numtets( 2) = 10
         numtets( 3) = 14
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 80
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 94
         numtets(22) = 99
         numtets(23) =103
         numtets(24) =107
         numtets(25) =110
         numtets(26) =115
         numtets(27) =117
         numtets(28) =111
         numtets(29) = 85
         numtets(30) =  5
         numtets(31) =  1
      endif
      if(nlams.eq.32) then
         numtets( 1) =  7
         numtets( 2) = 11
         numtets( 3) = 14
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 30
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 80
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 94
         numtets(22) = 99
         numtets(23) =103
         numtets(24) =107
         numtets(25) =112
         numtets(26) =114
         numtets(27) =119
         numtets(28) =117
         numtets(29) =108
         numtets(30) = 89
         numtets(31) =  4
         numtets(32) =  1
      endif
      if(nlams.eq.33) then
         numtets( 1) =  7
         numtets( 2) = 11
         numtets( 3) = 15
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 94
         numtets(22) = 99
         numtets(23) =103
         numtets(24) =107
         numtets(25) =112
         numtets(26) =116
         numtets(27) =120
         numtets(28) =124
         numtets(29) =124
         numtets(30) =116
         numtets(31) = 93
         numtets(32) =  5
         numtets(33) =  1
      endif
      if(nlams.eq.34) then
         numtets( 1) =  7
         numtets( 2) = 11
         numtets( 3) = 15
         numtets( 4) = 18
         numtets( 5) = 22
         numtets( 6) = 26
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 94
         numtets(22) = 99
         numtets(23) =104
         numtets(24) =108
         numtets(25) =112
         numtets(26) =117
         numtets(27) =121
         numtets(28) =125
         numtets(29) =128
         numtets(30) =131
         numtets(31) =127
         numtets(32) = 95
         numtets(33) =  4
         numtets(34) =  1
      endif
      if(nlams.eq.35) then
ccc         numtets( 1) =  7
ccc         numtets( 2) = 11
ccc         numtets( 3) = 15
ccc         numtets( 4) = 19
ccc         numtets( 5) = 23
ccc         numtets( 6) = 27
ccc         numtets( 7) = 31
ccc         numtets( 8) = 35
ccc         numtets( 9) = 39
ccc         numtets(10) = 44
ccc         numtets(11) = 48
ccc         numtets(12) = 53
ccc         numtets(13) = 57
ccc         numtets(14) = 62
ccc         numtets(15) = 67
ccc         numtets(16) = 71
ccc         numtets(17) = 76
ccc         numtets(18) = 81
ccc         numtets(19) = 85
ccc         numtets(20) = 90
ccc         numtets(21) = 95
ccc         numtets(22) = 99
ccc         numtets(23) =104
ccc         numtets(24) =108
ccc         numtets(25) =113
ccc         numtets(26) =117
ccc         numtets(27) =121
ccc         numtets(28) =125
ccc         numtets(29) =130
ccc         numtets(30) =133
ccc         numtets(31) =133
ccc         numtets(32) =124
ccc         numtets(33) =105
ccc         numtets(34) =  4
cccpp12         numtets(35) =  1
         numtets( 1) =  8
         numtets( 2) = 16
         numtets( 3) = 16
         numtets( 4) = 32
         numtets( 5) = 32
         numtets( 6) = 32
         numtets( 7) = 32
         numtets( 8) = 48
         numtets( 9) = 48
         numtets(10) = 48
         numtets(11) = 48
         numtets(12) = 64
         numtets(13) = 64
         numtets(14) = 64
         numtets(15) = 72
         numtets(16) = 72
         numtets(17) = 80
         numtets(18) = 88
         numtets(19) = 88
         numtets(20) = 96
         numtets(21) = 96
         numtets(22) =104
         numtets(23) =104
         numtets(24) =104
         numtets(25) =124
         numtets(26) =124
         numtets(27) =124
         numtets(28) =124
         numtets(29) =132
         numtets(30) =132
         numtets(31) =132
         numtets(32) =124
         numtets(33) =104
         numtets(34) =  4
         numtets(35) =  4
      endif
      if(nlams.eq.36) then
         numtets( 1) =  7
         numtets( 2) = 11
         numtets( 3) = 15
         numtets( 4) = 19
         numtets( 5) = 23
         numtets( 6) = 27
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 39
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 95
         numtets(22) = 99
         numtets(23) =104
         numtets(24) =108
         numtets(25) =113
         numtets(26) =117
         numtets(27) =122
         numtets(28) =126
         numtets(29) =130
         numtets(30) =133
         numtets(31) =137
         numtets(32) =137
         numtets(33) =128
         numtets(34) =103
         numtets(35) =  4
         numtets(36) =  1
      endif
      if(nlams.eq.37) then
         numtets( 1) =  8
         numtets( 2) = 11
         numtets( 3) = 15
         numtets( 4) = 19
         numtets( 5) = 23
         numtets( 6) = 27
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 40
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 95
         numtets(22) = 99
         numtets(23) =104
         numtets(24) =108
         numtets(25) =113
         numtets(26) =118
         numtets(27) =122
         numtets(28) =126
         numtets(29) =131
         numtets(30) =135
         numtets(31) =139
         numtets(32) =142
         numtets(33) =144
         numtets(34) =139
         numtets(35) =107
         numtets(36) =  4
         numtets(37) =  1
      endif
      if(nlams.eq.38) then
         numtets( 1) =  8
         numtets( 2) = 12
         numtets( 3) = 15
         numtets( 4) = 19
         numtets( 5) = 23
         numtets( 6) = 27
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 40
         numtets(10) = 44
         numtets(11) = 48
         numtets(12) = 53
         numtets(13) = 57
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 95
         numtets(22) = 99
         numtets(23) =104
         numtets(24) =109
         numtets(25) =113
         numtets(26) =118
         numtets(27) =122
         numtets(28) =127
         numtets(29) =131
         numtets(30) =135
         numtets(31) =139
         numtets(32) =143
         numtets(33) =143
         numtets(34) =141
         numtets(35) =139
         numtets(36) =106
         numtets(37) =  4
         numtets(38) =  1
      endif
      if(nlams.eq.39) then
         numtets( 1) =  8
         numtets( 2) = 12
         numtets( 3) = 15
         numtets( 4) = 19
         numtets( 5) = 23
         numtets( 6) = 27
         numtets( 7) = 31
         numtets( 8) = 35
         numtets( 9) = 40
         numtets(10) = 44
         numtets(11) = 49
         numtets(12) = 53
         numtets(13) = 58
         numtets(14) = 62
         numtets(15) = 67
         numtets(16) = 71
         numtets(17) = 76
         numtets(18) = 81
         numtets(19) = 85
         numtets(20) = 90
         numtets(21) = 95
         numtets(22) = 99
         numtets(23) =104
         numtets(24) =109
         numtets(25) =113
         numtets(26) =118
         numtets(27) =122
         numtets(28) =127
         numtets(29) =131
         numtets(30) =136
         numtets(31) =140
         numtets(32) =142
         numtets(33) =147
         numtets(34) =151
         numtets(35) =151
         numtets(36) =139
         numtets(37) =111
         numtets(38) =  5
         numtets(39) =  1
      endif
c
c ... calculate nxtotp:
c
      nxtotp = 0
      do 101 i=1,nlams
         nxtotp = nxtotp + numtets(i)
 101  continue
      nxtotp = nxtotp/2
c
      return
      end
c
c
c
c
ccc	subroutine numthetahalf(numtets,nlams)
ccc	integer *4 numtets(nlams),nlams
	subroutine ntfour(numtets,nlams,nxtot,nthmax)
c
c This routine returns the number of Fourier modes needed in the
c phi integral for each of the discrete lambda values given
c by Norman's quadratures. (see weights.f).
c
c Input arguments:
c	nlams - number of nodes in the lambda quadrature.  This must
c	  be an integer in the range [2,39].
c
c Output arguments:
c	numtest(i) - number of Fourier modes needed for phi
c                    integral with lambda_i.
c
c Approximate accuracies of the quadrature:
c
c	NLAMS	maximum error
c
c        2     0.15318d+00
c        3     0.76505d-01
c        4     0.32149d-01
c        5     0.15630d-01
c        6     0.75110d-02
c        7     0.35030d-02
c        8     0.16243d-02
c        9     0.72230d-03
c       10     0.33074d-03
c       11     0.15035d-03
c       12     0.70952d-04
c       13     0.31751d-04
c       14     0.14589d-04
c       15     0.64300d-05
c       16     0.29477d-05
c       17     0.13222d-05
c       18     0.61488d-06
c       19     0.27435d-06
c       20     0.12534d-06
c       21     0.55324d-07
c       22     0.25257d-07
c       23     0.11293d-07
c       24     0.52063d-08
c       25     0.23256d-08
c       26     0.10580d-08
c       27     0.46835d-09
c       28     0.21286d-09
c       29     0.95164d-10
c       30     0.43599d-10
c       31     0.19516d-10
c       32     0.88491d-11
c       33     0.39313d-11
c       34     0.17821d-11
c       35     0.79603d-12
c       36     0.36460d-12
c       37     0.16331d-12
c       38     0.73497d-13
c       39     0.31530d-13
c
	integer *4 numtets(nlams),nlams,nxtot,nthmax
      if(nlams.eq. 2) then
         numtets( 1) = 1
         numtets( 2) = 1
      endif
      if(nlams.eq. 3) then
         numtets( 1) = 1
         numtets( 2) = 2
         numtets( 3) = 2
      endif
      if(nlams.eq. 4) then
         numtets( 1) = 1
         numtets( 2) = 2
         numtets( 3) = 2
         numtets( 4) = 1
      endif
      if(nlams.eq. 5) then
         numtets( 1) = 2
         numtets( 2) = 2
         numtets( 3) = 3
         numtets( 4) = 3
         numtets( 5) = 1
      endif
      if(nlams.eq. 6) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 3
         numtets( 4) = 3
         numtets( 5) = 2
         numtets( 6) = 1
      endif
      if(nlams.eq. 7) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 3
         numtets( 4) = 4
         numtets( 5) = 4
         numtets( 6) = 3
         numtets( 7) = 1
      endif
      if(nlams.eq. 8) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 4
         numtets( 4) = 4
         numtets( 5) = 5
         numtets( 6) = 5
         numtets( 7) = 5
         numtets( 8) = 3
ccc         numtets( 8) = 1
      endif
      if(nlams.eq. 9) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 4
         numtets( 4) = 5
         numtets( 5) = 5
         numtets( 6) = 4
         numtets( 7) = 5
         numtets( 8) = 4
         numtets( 9) = 1
      endif
      if(nlams.eq.10) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 4
         numtets( 4) = 5
         numtets( 5) = 5
         numtets( 6) = 6
         numtets( 7) = 6
         numtets( 8) = 6
         numtets( 9) = 6
         numtets(10) = 1
      endif
      if(nlams.eq.11) then
         numtets( 1) = 2
         numtets( 2) = 3
         numtets( 3) = 4
         numtets( 4) = 5
         numtets( 5) = 6
         numtets( 6) = 6
         numtets( 7) = 6
         numtets( 8) = 7
         numtets( 9) = 7
         numtets(10) = 5
         numtets(11) = 1
      endif
      if(nlams.eq.12) then
         numtets( 1) = 2
         numtets( 2) = 4
         numtets( 3) = 5
         numtets( 4) = 5
         numtets( 5) = 6
         numtets( 6) = 6
         numtets( 7) = 7
         numtets( 8) = 7
         numtets( 9) = 7
         numtets(10) = 7
         numtets(11) = 5
         numtets(12) = 1
      endif
      if(nlams.eq.13) then
         numtets( 1) = 3
         numtets( 2) = 4
         numtets( 3) = 5
         numtets( 4) = 6
         numtets( 5) = 6
         numtets( 6) = 7
         numtets( 7) = 7
         numtets( 8) = 8
         numtets( 9) = 8
         numtets(10) = 8
         numtets(11) = 7
         numtets(12) = 5
         numtets(13) = 1
      endif
      if(nlams.eq.14) then
         numtets( 1) = 3
         numtets( 2) = 4
         numtets( 3) = 5
         numtets( 4) = 6
         numtets( 5) = 7
         numtets( 6) = 7
         numtets( 7) = 8
         numtets( 8) = 8
         numtets( 9) = 8
         numtets(10) = 9
         numtets(11) = 8
         numtets(12) = 8
         numtets(13) = 7
         numtets(14) = 1
      endif
      if(nlams.eq.15) then
         numtets( 1) = 3
         numtets( 2) = 4
         numtets( 3) = 5
         numtets( 4) = 6
         numtets( 5) = 7
         numtets( 6) = 7
         numtets( 7) = 8
         numtets( 8) = 8
         numtets( 9) = 9
         numtets(10) = 9
         numtets(11) = 9
         numtets(12) = 9
         numtets(13) = 8
         numtets(14) = 7
         numtets(15) = 1
      endif
      if(nlams.eq.16) then
         numtets( 1) = 3
         numtets( 2) = 4
         numtets( 3) = 5
         numtets( 4) = 6
         numtets( 5) = 7
         numtets( 6) = 8
         numtets( 7) = 8
         numtets( 8) = 9
         numtets( 9) = 9
         numtets(10) =10
         numtets(11) =10
         numtets(12) =10
         numtets(13) =10
         numtets(14) = 9
         numtets(15) = 8
         numtets(16) = 1
         numtets( 1) = 4
         numtets( 2) = 4
         numtets( 3) = 8
         numtets( 4) = 8
         numtets( 5) = 8
         numtets( 6) = 8
         numtets( 7) = 8
         numtets( 8) = 12
         numtets( 9) = 12
         numtets(10) =12
         numtets(11) =12
         numtets(12) =12
         numtets(13) =12
         numtets(14) = 12
         numtets(15) = 8
         numtets(16) = 4
      endif
      if(nlams.eq.17) then
         numtets( 1) = 3
         numtets( 2) = 4
         numtets( 3) = 8
         numtets( 4) = 8
         numtets( 5) = 8
         numtets( 6) = 8
         numtets( 7) =11
         numtets( 8) =11
         numtets( 9) =11
         numtets(10) =11
         numtets(11) =11
         numtets(12) =11
         numtets(13) =11
         numtets(14) =11
         numtets(15) =11
         numtets(16) = 8
         numtets(17) = 1
      endif
      if(nlams.eq.18) then
         numtets( 1) = 3
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 7
         numtets( 5) = 7
         numtets( 6) = 8
         numtets( 7) = 9
         numtets( 8) = 9
         numtets( 9) =10
         numtets(10) =10
         numtets(11) =11
         numtets(12) =11
         numtets(13) =11
         numtets(14) =11
         numtets(15) =11
         numtets(16) =11
         numtets(17) = 7
         numtets(18) = 1
      endif
      if(nlams.eq.19) then
         numtets( 1) = 3
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 7
         numtets( 5) = 8
         numtets( 6) = 8
         numtets( 7) = 9
         numtets( 8) =10
         numtets( 9) =10
         numtets(10) =11
         numtets(11) =11
         numtets(12) =12
         numtets(13) =12
         numtets(14) =12
         numtets(15) =12
         numtets(16) =12
         numtets(17) = 9
         numtets(18) = 9
         numtets(19) = 1
      endif
      if(nlams.eq.20) then
         numtets( 1) = 3
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 7
         numtets( 5) = 8
         numtets( 6) = 9
         numtets( 7) = 9
         numtets( 8) =10
         numtets( 9) =11
         numtets(10) =11
         numtets(11) =12
         numtets(12) =12
         numtets(13) =12
         numtets(14) =12
         numtets(15) =13
         numtets(16) =13
         numtets(17) =12
         numtets(18) =12
         numtets(19) = 8
         numtets(20) = 1
      endif
      if(nlams.eq.21) then
         numtets( 1) = 4
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 7
         numtets( 5) = 8
         numtets( 6) = 9
         numtets( 7) =10
         numtets( 8) =10
         numtets( 9) =11
         numtets(10) =12
         numtets(11) =12
         numtets(12) =12
         numtets(13) =13
         numtets(14) =13
         numtets(15) =13
         numtets(16) =13
         numtets(17) =13
         numtets(18) =13
         numtets(19) =12
         numtets(20) =10
         numtets(21) = 1
      endif
      if(nlams.eq.22) then
         numtets( 1) = 4
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 7
         numtets( 5) = 8
         numtets( 6) = 9
         numtets( 7) =10
         numtets( 8) =11
         numtets( 9) =11
         numtets(10) =12
         numtets(11) =12
         numtets(12) =13
         numtets(13) =13
         numtets(14) =13
         numtets(15) =14
         numtets(16) =14
         numtets(17) =14
         numtets(18) =14
         numtets(19) =14
         numtets(20) =12
         numtets(21) =10
         numtets(22) = 1
      endif
      if(nlams.eq.23) then
         numtets( 1) = 4
         numtets( 2) = 5
         numtets( 3) = 6
         numtets( 4) = 8
         numtets( 5) = 9
         numtets( 6) = 9
         numtets( 7) =10
         numtets( 8) =11
         numtets( 9) =12
         numtets(10) =12
         numtets(11) =13
         numtets(12) =13
         numtets(13) =14
         numtets(14) =14
         numtets(15) =14
         numtets(16) =14
         numtets(17) =15
         numtets(18) =15
         numtets(19) =14
         numtets(20) =14
         numtets(21) =14
         numtets(22) = 9
         numtets(23) = 1
      endif
      if(nlams.eq.24) then
         numtets( 1) = 4
         numtets( 2) = 5
         numtets( 3) = 7
         numtets( 4) = 8
         numtets( 5) = 9
         numtets( 6) =10
         numtets( 7) =10
         numtets( 8) =11
         numtets( 9) =12
         numtets(10) =13
         numtets(11) =13
         numtets(12) =14
         numtets(13) =14
         numtets(14) =14
         numtets(15) =15
         numtets(16) =15
         numtets(17) =15
         numtets(18) =15
         numtets(19) =15
         numtets(20) =15
         numtets(21) =15
         numtets(22) =14
         numtets(23) =10
         numtets(24) = 1
      endif
      if(nlams.eq.25) then
         numtets( 1) = 4
         numtets( 2) = 6
         numtets( 3) = 7
         numtets( 4) = 8
         numtets( 5) = 9
         numtets( 6) =10
         numtets( 7) =11
         numtets( 8) =11
         numtets( 9) =12
         numtets(10) =13
         numtets(11) =13
         numtets(12) =14
         numtets(13) =14
         numtets(14) =15
         numtets(15) =15
         numtets(16) =15
         numtets(17) =16
         numtets(18) =16
         numtets(19) =16
         numtets(20) =16
         numtets(21) =16
         numtets(22) =13
         numtets(23) =14
         numtets(24) =11
         numtets(25) = 1
      endif
      if(nlams.eq.26) then
ccc         numtets( 1) = 4
ccc         numtets( 2) = 6
ccc         numtets( 3) = 7
ccc         numtets( 4) = 8
ccc         numtets( 5) = 9
ccc         numtets( 6) =10
ccc         numtets( 7) =11
ccc         numtets( 8) =12
ccc         numtets( 9) =12
ccc         numtets(10) =13
ccc         numtets(11) =14
ccc         numtets(12) =14
ccc         numtets(13) =15
ccc         numtets(14) =15
ccc         numtets(15) =16
ccc         numtets(16) =16
ccc         numtets(17) =16
ccc         numtets(18) =16
ccc         numtets(19) =17
ccc         numtets(20) =17
ccc         numtets(21) =17
ccc         numtets(22) =16
ccc         numtets(23) =15
ccc         numtets(24) =14
ccc         numtets(25) =11
ccc         numtets(26) = 1
C
ccc         numtets( 1) = 2
ccc         numtets( 2) = 4
ccc         numtets( 3) = 5
cccff99         numtets( 4) = 6
         numtets( 1) = 3
         numtets( 2) = 8
         numtets( 3) = 8
         numtets( 4) = 8
         numtets( 5) = 8
         numtets( 6) =10
         numtets( 7) =10
         numtets( 8) =12
         numtets( 9) =12
         numtets(10) =13
         numtets(11) =14
         numtets(12) =14
         numtets(13) =15
         numtets(14) =16
         numtets(15) =16
         numtets(16) =16
         numtets(17) =16
         numtets(18) =16
         numtets(19) =16
         numtets(20) =16
         numtets(21) =16
         numtets(22) =16
         numtets(23) =16
         numtets(24) =16
         numtets(25) =13
         numtets(26) = 1
      endif
      if(nlams.eq.27) then
         numtets( 1) = 4
         numtets( 2) = 6
         numtets( 3) = 7
         numtets( 4) = 8
         numtets( 5) = 9
         numtets( 6) =10
         numtets( 7) =11
         numtets( 8) =12
         numtets( 9) =13
         numtets(10) =13
         numtets(11) =14
         numtets(12) =15
         numtets(13) =15
         numtets(14) =16
         numtets(15) =16
         numtets(16) =16
         numtets(17) =17
         numtets(18) =17
         numtets(19) =17
         numtets(20) =17
         numtets(21) =17
         numtets(22) =17
         numtets(23) =17
         numtets(24) =16
         numtets(25) =15
         numtets(26) =12
         numtets(27) = 1
      endif
      if(nlams.eq.28) then
         numtets( 1) = 4
         numtets( 2) = 6
         numtets( 3) = 7
         numtets( 4) = 8
         numtets( 5) = 9
         numtets( 6) =10
         numtets( 7) =11
         numtets( 8) =12
         numtets( 9) =13
         numtets(10) =14
         numtets(11) =14
         numtets(12) =15
         numtets(13) =15
         numtets(14) =16
         numtets(15) =16
         numtets(16) =17
         numtets(17) =17
         numtets(18) =17
         numtets(19) =18
         numtets(20) =18
         numtets(21) =18
         numtets(22) =18
         numtets(23) =18
         numtets(24) =18
         numtets(25) =17
         numtets(26) =15
         numtets(27) =12
         numtets(28) = 1
      endif
      if(nlams.eq.29) then
         numtets( 1) = 4
         numtets( 2) = 6
         numtets( 3) = 7
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =11
         numtets( 7) =12
         numtets( 8) =12
         numtets( 9) =13
         numtets(10) =14
         numtets(11) =15
         numtets(12) =15
         numtets(13) =16
         numtets(14) =16
         numtets(15) =17
         numtets(16) =17
         numtets(17) =18
         numtets(18) =18
         numtets(19) =18
         numtets(20) =18
         numtets(21) =19
         numtets(22) =19
         numtets(23) =19
         numtets(24) =19
         numtets(25) =18
         numtets(26) =16
         numtets(27) =17
         numtets(28) =11
         numtets(29) = 1
      endif
      if(nlams.eq.30) then
         numtets( 1) = 5
         numtets( 2) = 6
         numtets( 3) = 8
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =11
         numtets( 7) =12
         numtets( 8) =13
         numtets( 9) =13
         numtets(10) =14
         numtets(11) =15
         numtets(12) =16
         numtets(13) =16
         numtets(14) =17
         numtets(15) =17
         numtets(16) =18
         numtets(17) =18
         numtets(18) =18
         numtets(19) =19
         numtets(20) =19
         numtets(21) =19
         numtets(22) =19
         numtets(23) =19
         numtets(24) =19
         numtets(25) =19
         numtets(26) =19
         numtets(27) =19
         numtets(28) =15
         numtets(29) =12
         numtets(30) = 1
      endif
      if(nlams.eq.31) then
         numtets( 1) = 5
         numtets( 2) = 6
         numtets( 3) = 8
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =11
         numtets( 7) =12
         numtets( 8) =13
         numtets( 9) =14
         numtets(10) =14
         numtets(11) =15
         numtets(12) =16
         numtets(13) =16
         numtets(14) =17
         numtets(15) =18
         numtets(16) =18
         numtets(17) =18
         numtets(18) =19
         numtets(19) =19
         numtets(20) =19
         numtets(21) =20
         numtets(22) =20
         numtets(23) =20
         numtets(24) =20
         numtets(25) =20
         numtets(26) =20
         numtets(27) =20
         numtets(28) =18
         numtets(29) =19
         numtets(30) =11
         numtets(31) = 1
      endif
      if(nlams.eq.32) then
         numtets( 1) = 5
         numtets( 2) = 6
         numtets( 3) = 8
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =11
         numtets( 7) =12
         numtets( 8) =13
         numtets( 9) =14
         numtets(10) =15
         numtets(11) =15
         numtets(12) =16
         numtets(13) =17
         numtets(14) =17
         numtets(15) =18
         numtets(16) =18
         numtets(17) =19
         numtets(18) =19
         numtets(19) =20
         numtets(20) =20
         numtets(21) =20
         numtets(22) =20
         numtets(23) =21
         numtets(24) =21
         numtets(25) =21
         numtets(26) =21
         numtets(27) =20
         numtets(28) =20
         numtets(29) =19
         numtets(30) =17
         numtets(31) =13
         numtets(32) = 1
      endif
      if(nlams.eq.33) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 8
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =11
         numtets( 7) =12
         numtets( 8) =13
         numtets( 9) =14
         numtets(10) =15
         numtets(11) =16
         numtets(12) =16
         numtets(13) =17
         numtets(14) =18
         numtets(15) =18
         numtets(16) =19
         numtets(17) =19
         numtets(18) =20
         numtets(19) =20
         numtets(20) =20
         numtets(21) =21
         numtets(22) =21
         numtets(23) =21
         numtets(24) =21
         numtets(25) =21
         numtets(26) =21
         numtets(27) =20
         numtets(28) =21
         numtets(29) =19
         numtets(30) =19
         numtets(31) =18
         numtets(32) =14
         numtets(33) = 1
      endif
      if(nlams.eq.34) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 8
         numtets( 4) = 9
         numtets( 5) =10
         numtets( 6) =12
         numtets( 7) =13
         numtets( 8) =13
         numtets( 9) =14
         numtets(10) =15
         numtets(11) =16
         numtets(12) =17
         numtets(13) =17
         numtets(14) =18
         numtets(15) =19
         numtets(16) =19
         numtets(17) =20
         numtets(18) =20
         numtets(19) =20
         numtets(20) =21
         numtets(21) =21
         numtets(22) =21
         numtets(23) =22
         numtets(24) =22
         numtets(25) =22
         numtets(26) =22
         numtets(27) =22
         numtets(28) =22
         numtets(29) =22
         numtets(30) =21
         numtets(31) =21
         numtets(32) =18
         numtets(33) =13
         numtets(34) = 1
      endif
      if(nlams.eq.35) then
ccc         numtets( 1) = 5
ccc         numtets( 2) = 7
ccc         numtets( 3) = 8
ccc         numtets( 4) = 9
ccc         numtets( 5) =11
ccc         numtets( 6) =12
ccc         numtets( 7) =13
ccc         numtets( 8) =14
ccc         numtets( 9) =15
ccc         numtets(10) =15
ccc         numtets(11) =16
ccc         numtets(12) =17
ccc         numtets(13) =18
ccc         numtets(14) =18
ccc         numtets(15) =19
ccc         numtets(16) =19
ccc         numtets(17) =20
ccc         numtets(18) =20
ccc         numtets(19) =21
ccc         numtets(20) =21
ccc         numtets(21) =22
ccc         numtets(22) =22
ccc         numtets(23) =22
ccc         numtets(24) =22
ccc         numtets(25) =23
ccc         numtets(26) =23
ccc         numtets(27) =23
ccc         numtets(28) =23
ccc         numtets(29) =23
ccc         numtets(30) =22
ccc         numtets(31) =22
ccc         numtets(32) =21
ccc         numtets(33) =19
ccc         numtets(34) =13
cccff12         numtets(35) = 1
         numtets( 1) = 8
         numtets( 2) = 8
         numtets( 3) = 8
         numtets( 4) =16
         numtets( 5) =16
         numtets( 6) =16
         numtets( 7) =16
         numtets( 8) =16
         numtets( 9) =16
         numtets(10) =16
         numtets(11) =16
         numtets(12) =20
         numtets(13) =20
         numtets(14) =20
         numtets(15) =20
         numtets(16) =20
         numtets(17) =20
         numtets(18) =20
         numtets(19) =23
         numtets(20) =23
         numtets(21) =23
         numtets(22) =23
         numtets(23) =23
         numtets(24) =23
         numtets(25) =23
         numtets(26) =23
         numtets(27) =23
         numtets(28) =23
         numtets(29) =23
         numtets(30) =23
         numtets(31) =23
         numtets(32) =23
         numtets(33) =20
         numtets(34) =16
         numtets(35) = 1
      endif
      if(nlams.eq.36) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 8
         numtets( 4) =10
         numtets( 5) =11
         numtets( 6) =12
         numtets( 7) =13
         numtets( 8) =14
         numtets( 9) =15
         numtets(10) =16
         numtets(11) =16
         numtets(12) =17
         numtets(13) =18
         numtets(14) =19
         numtets(15) =19
         numtets(16) =20
         numtets(17) =20
         numtets(18) =21
         numtets(19) =21
         numtets(20) =22
         numtets(21) =22
         numtets(22) =22
         numtets(23) =23
         numtets(24) =23
         numtets(25) =23
         numtets(26) =23
         numtets(27) =23
         numtets(28) =23
         numtets(29) =23
         numtets(30) =23
         numtets(31) =23
         numtets(32) =22
         numtets(33) =21
         numtets(34) =18
         numtets(35) =15
         numtets(36) = 1
      endif
      if(nlams.eq.37) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 8
         numtets( 4) =10
         numtets( 5) =11
         numtets( 6) =12
         numtets( 7) =13
         numtets( 8) =14
         numtets( 9) =15
         numtets(10) =16
         numtets(11) =17
         numtets(12) =17
         numtets(13) =18
         numtets(14) =19
         numtets(15) =19
         numtets(16) =20
         numtets(17) =21
         numtets(18) =21
         numtets(19) =22
         numtets(20) =22
         numtets(21) =22
         numtets(22) =23
         numtets(23) =23
         numtets(24) =23
         numtets(25) =24
         numtets(26) =24
         numtets(27) =24
         numtets(28) =24
         numtets(29) =24
         numtets(30) =24
         numtets(31) =24
         numtets(32) =24
         numtets(33) =22
         numtets(34) =22
         numtets(35) =21
         numtets(36) =14
         numtets(37) = 1
      endif
      if(nlams.eq.38) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 9
         numtets( 4) =10
         numtets( 5) =11
         numtets( 6) =12
         numtets( 7) =13
         numtets( 8) =14
         numtets( 9) =15
         numtets(10) =16
         numtets(11) =17
         numtets(12) =18
         numtets(13) =18
         numtets(14) =19
         numtets(15) =20
         numtets(16) =20
         numtets(17) =21
         numtets(18) =22
         numtets(19) =22
         numtets(20) =22
         numtets(21) =23
         numtets(22) =23
         numtets(23) =24
         numtets(24) =24
         numtets(25) =24
         numtets(26) =24
         numtets(27) =25
         numtets(28) =25
         numtets(29) =25
         numtets(30) =25
         numtets(31) =25
         numtets(32) =25
         numtets(33) =24
         numtets(34) =24
         numtets(35) =22
         numtets(36) =21
         numtets(37) =15
         numtets(38) = 1
      endif
      if(nlams.eq.39) then
         numtets( 1) = 5
         numtets( 2) = 7
         numtets( 3) = 9
         numtets( 4) =10
         numtets( 5) =11
         numtets( 6) =12
         numtets( 7) =13
         numtets( 8) =14
         numtets( 9) =15
         numtets(10) =16
         numtets(11) =17
         numtets(12) =18
         numtets(13) =19
         numtets(14) =19
         numtets(15) =20
         numtets(16) =21
         numtets(17) =21
         numtets(18) =22
         numtets(19) =22
         numtets(20) =23
         numtets(21) =23
         numtets(22) =24
         numtets(23) =24
         numtets(24) =24
         numtets(25) =25
         numtets(26) =25
         numtets(27) =25
         numtets(28) =25
         numtets(29) =25
         numtets(30) =26
         numtets(31) =25
         numtets(32) =25
         numtets(33) =25
         numtets(34) =25
         numtets(35) =25
         numtets(36) =23
         numtets(37) =20
         numtets(38) =15
         numtets(39) = 1
      endif
c
c ... calculate nthmax and nxtot:
c
      nthmax = 0
      nxtot = 0
      do 101 i = 1, nlams
         nxtot = nxtot + numtets(i)
         if (numtets(i).gt.nthmax) nthmax = numtets(i)
 101  continue
c
      return
      end
c
c
c
c
c
c
c
c
      subroutine localevalriv3d(nboxes, iderivonoff,
     1     pot, potx, poty, potz, nterms, scale, dc,
     2     pptmp, n22, sources, local, iz, w)
      implicit none
c
c     the following subroutine is designed to evaluate the local
c     expansions from the 3D Laplace Particle code.
c
c     INPUT PARAMETERS:
c
c     nboxes (integer *4) the number of boxes in the quadtree
c
c     iderivonoff (integer *4) flag that indicates whether or
c           not the derivatives are to be computed
c               (iderivonoff = 0 -> don't compute derivatives)
c               (iderivonoff = 1 -> compute derivatives)
c
c     nterms (integer *4) the order or the local expansions
c
c     scale(0:201) (real *8) an array containing the precomputed
c           lengthscales for each level
c
c     dc ...................
c
c     pptmp ........................
c
c     n22 (integer *4) ............
c
c     sources(3,nsources) (real *8) array that contains
c           all of the source locations
c
c     local(.....) (complex *16) array containing the local
c           expansions at each level
c
c     iz(1) (integer *4) array generated by riverdale that indicates
c           how the boxes are arranged by level
c
c     w(1) (integer *4) precomputed riverdale array that contains
c           all of the needed information on boxes
c
c     OUTPUT PARAMETERS:
c
c     pot(natoms), potx(natoms), poty(natoms), and potz(natoms) (real *8)
c           arrays that contain the potential and all of its first
c           derivatives at the source locations.
c           they are altered here to refect the far-field contributions.
c
c------------------------------------------------------------------------------
c
c
      integer *4  ibox, nboxes, box(15), nkids, ier, npts, istart,
     1    ilevel, i, iat, nterms, n22, iderivonoff, iz(1), w(1)
c
      real *8  centr0(3), tmppot, tmpfld(3), scale(0:201),
     1    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2)),
     2    sources(3,1), pot(1), potx(1), poty(1), potz(1)
c
      complex *16  local((nterms+1)*(nterms+2)/2,*)
        do 2000 ibox = 1, nboxes
c
          call d3mgetbk(ier, ibox, box, centr0, nkids, w)
c
          if(nkids .ge. 1) goto 2000
c
          npts = box(15)
          istart = box(14) - 1
          ilevel = box(1)
c
          do 1000 i = 1, npts
c
            iat = iz(istart+i)
c
            call brtaev3d(iderivonoff, local(1,ibox),
     1          centr0, sources(1,iat), nterms, n22,
     2          tmppot, tmpfld, scale(ilevel), dc, pptmp)
c
            pot(iat) = pot(iat) + tmppot
c
            if(iderivonoff .eq. 1)then
              potx(iat) = potx(iat) + tmpfld(1)
              poty(iat) = poty(iat) + tmpfld(2)
              potz(iat) = potz(iat) + tmpfld(3)
            endif
c
 1000     continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine localevalrivtarg3d(nboxes, iderivonoff, pot, potx,
     1     poty, potz, pottar, pottarx, pottary, pottarz, nterms,
     2     scale, dc, pptmp, n22, sources, targets, local, iw,
     3     izsour, zboxsour, iztarg, zboxtarg, itargflag)
      implicit none
c
c
c
c--------------------------------------------------------------------
c
c
      integer *4  box(15), iat, ibox, iderivonoff, ier, ilevel,
     1    itargflag, iw(1), jj, n22, nboxes, nkids, nterms,
     2    izsour(1), zboxsour(2,1), istartsource, iendsource,
     3    iztarg(1), zboxtarg(2,1), istarttarget, iendtarget
c
      real *8  centr0(3), tmppot, tmpfld(3), scale(0:201),
     1    dc(0:4*nterms,0:4*nterms), pptmp((n22+2)*(n22+2)),
     2    sources(3,1), pot(1), potx(1), poty(1), potz(1),
     3    pottar(1), pottarx(1), pottary(1), pottarz(1), targets(3,1)
c
      complex *16  local((nterms+1)*(nterms+2)/2,*)
        do 3000 ibox = 1, nboxes
c
          call d3mgetbk(ier, ibox, box, centr0, nkids, iw)
c
          if(nkids .ge. 1) goto 3000 
c
          ilevel = box(1)
c
          if(itargflag .eq. 1)then
c
            istartsource = zboxsour(1,ibox)
            iendsource = zboxsour(1,ibox) + zboxsour(2,ibox) - 1
c
            do 1000 jj = istartsource, iendsource
c
              iat = izsour(jj)
c
              call brtaev3d(iderivonoff, local(1,ibox),
     1            centr0, sources(1,iat), nterms, n22,
     2            tmppot, tmpfld, scale(ilevel), dc, pptmp)
c
              pot(iat) = pot(iat) + tmppot
c
              if(iderivonoff .eq. 1)then
                potx(iat) = potx(iat) + tmpfld(1)
                poty(iat) = poty(iat) + tmpfld(2)
                potz(iat) = potz(iat) + tmpfld(3)
              endif
c
 1000       continue
c
          endif
c
          istarttarget = zboxtarg(1,ibox)
          iendtarget = zboxtarg(1,ibox) + zboxtarg(2,ibox) - 1
c
          do 2000 jj = istarttarget, iendtarget
c
            iat = iztarg(jj)
c
            call brtaev3d(iderivonoff, local(1,ibox),
     1          centr0, targets(1,iat), nterms, n22,
     2          tmppot, tmpfld, scale(ilevel), dc, pptmp)
c
            pottar(iat) = pottar(iat) + tmppot
c
            if(iderivonoff .eq. 1)then
              pottarx(iat) = pottarx(iat) + tmpfld(1)
              pottary(iat) = pottary(iat) + tmpfld(2)
              pottarz(iat) = pottarz(iat) + tmpfld(3)
            endif
c
 2000     continue
c
 3000   continue
c
      return
      end
c
c
c
c
c
      subroutine localintriver3d(iflagtype, iderivonoff, nlev,
     1     nboxes, centr0, sources, monocharge, dipstr, dipvec,
     2     pot, potx, poty, potz, eps, close, iz, iw)
      implicit none
c
c
c
c-----------------------------------------------------------------------
c
c
      integer *4  iflagtype, npts, ier, box(15), box1(15), nboxes,
     1   il, ilbox, istart, list(2000), iistrt, mylstt, nlist,
     2   ikids, ipts, mybox, nkids, nlev, iderivonoff, iz(1), iw(1)
c
      real *8  centr0(3), sources(3,1), monocharge(1), dipstr(1),
     1   dipvec(3,1), eps, pot(1), potx(1), poty(1), potz(1)
      external  close
c
        do 2000 mybox = 1, nboxes
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .ge. 1) goto 2000
c
          npts = box(15)
c
          istart = box(14) - 1
c
c-----------------------------------------------------------------------
c step 3: calculate the direct interaction within mybox itself:
c-----------------------------------------------------------------------
c
          call collocriv3d(sources, pot, potx, poty, potz,
     1        npts, npts, iz, istart, istart, iflagtype,
     2        iderivonoff, monocharge, dipstr, dipvec, close, eps)
c
          if(nlev .eq. 0) goto 2000
c
c-----------------------------------------------------------------------
c step 4: handle list 1 interaction:
c-----------------------------------------------------------------------
c
          mylstt = 1
          call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
c
          if(nlist .gt. 2000)then
            ier = 999
            call prinf('nlist exceeds limit *',nlist,1)
            return
          endif
c
          do 1000 il = 1, nlist
            ilbox = list(il)
            call d3mgetbk(ier,ilbox,box1,centr0,ikids,iw)
            ipts = box1(15)
            iistrt = box1(14) - 1
c
            call collocriv3d(sources, pot, potx, poty, potz,
     1          ipts, npts, iz, iistrt, istart, iflagtype,
     2          iderivonoff, monocharge, dipstr, dipvec, close, eps)
c
 1000     continue
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine collocriv3d(sources, pot, potx, poty, potz,
     1     ipts, npts, iz, iistrt, istart, iflagtype, 
     2     iderivonoff, monocharge, dipstr, dipvec, close, eps)
      implicit none
c
c
c
c-----------------------------------------------------------------------
c
c      
      integer *4  iz(1), ipts, npts, iflagtype, iistrt,
     1     istart, iat, jat, j, k, iderivonoff, iflag(2)
c      
      real *8  sources(3,1), eps, monocharge(1), dipstr(1), dipvec(3,1),
     1     pot(1), potx(1), poty(1), potz(1), xinfo1(8), xinfo2(8),
     2     xout(4), rr, rdis, rx, ry, rz, rrr, rtttt, rtmp2,
     3     tout(3), tin(3), rmul2, rtmpf, rtmpb, rmul
      external  close
c
        do 2000 k = 1, npts
          iat = iz(istart+k)
c
          do 1000 j = 1, ipts
c
            jat = iz(iistrt+j)
c
            if(jat .eq. iat) goto 1000
c
            if(jat .gt. iat) goto 1000
c
            rx = sources(1,iat) - sources(1,jat)
            ry = sources(2,iat) - sources(2,jat)
            rz = sources(3,iat) - sources(3,jat)
c
            rr = rx*rx + ry*ry + rz*rz
            rdis = dsqrt(rr)
c
            if(rdis .le. eps)then
c
              iflag(1) = iflagtype
              iflag(2) = iderivonoff
c
              if(iflagtype .eq. 0)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = monocharge(iat)
                xinfo1(5) = 0d0
                xinfo1(6) = 0d0
                xinfo1(7) = 0d0
                xinfo1(8) = 0d0
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = 0d0
                xinfo2(6) = 0d0
                xinfo2(7) = 0d0
                xinfo2(8) = 0d0
              endif
c
              if(iflagtype .eq. 1)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = 0d0
                xinfo1(5) = dipstr(iat)
                xinfo1(6) = dipvec(1,iat)
                xinfo1(7) = dipvec(2,iat)
                xinfo1(8) = dipvec(3,iat)
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = 0d0
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              if(iflagtype .eq. 2)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = monocharge(iat)
                xinfo1(5) = dipstr(iat)
                xinfo1(6) = dipvec(1,iat)
                xinfo1(7) = dipvec(2,iat)
                xinfo1(8) = dipvec(3,iat)
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              call close(iat, jat, eps, xinfo1, xinfo2, iflag, xout)
c
              pot(iat) = pot(iat) + xout(1)
c
              if(iderivonoff .eq. 1)then
                potx(iat) = potx(iat) + xout(2)
                poty(iat) = poty(iat) + xout(3) 
                potz(iat) = potz(iat) + xout(4) 
              endif
c
              call close(jat, iat, eps, xinfo2, xinfo1, iflag, xout)
c
              pot(jat) = pot(jat) + xout(1)
c
              if(iderivonoff .eq. 1)then
                potx(jat) = potx(jat) + xout(2)
                poty(jat) = poty(jat) + xout(3)
                potz(jat) = potz(jat) + xout(4)
              endif
c
              goto 1000
c
            endif
c
c           now compute the interaction for two points
c           that are not within eps of each other
c
            if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
              pot(iat) = pot(iat) + monocharge(jat) / rdis
              pot(jat) = pot(jat) + monocharge(iat) / rdis
c
              if(iderivonoff .eq. 1)then
                rmul2 = 1d0 / (rdis*rr)
c
                rmul = monocharge(jat) * rmul2
c
                potx(iat) = potx(iat) + rmul * rx
                poty(iat) = poty(iat) + rmul * ry
                potz(iat) = potz(iat) + rmul * rz
c
                rmul = monocharge(iat) * rmul2
c
                potx(jat) = potx(jat) - rmul * rx
                poty(jat) = poty(jat) - rmul * ry
                potz(jat) = potz(jat) - rmul * rz
c
              endif
c
            endif
c
            if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
              rrr = rdis * rr
c
              tout(1) = dipvec(1,jat) * dipstr(jat)
              tout(2) = dipvec(2,jat) * dipstr(jat)
              tout(3) = dipvec(3,jat) * dipstr(jat)
c
              tin(1)  = dipvec(1,iat) * dipstr(iat)
              tin(2)  = dipvec(2,iat) * dipstr(iat)
              tin(3)  = dipvec(3,iat) * dipstr(iat)
c
              rtmpf = (tout(1) * rx + tout(2) * ry
     1               + tout(3) * rz) / rrr
c
              rtmpb = (tin(1) * rx + tin(2) * ry
     1               + tin(3) * rz) / rrr
c
              pot(iat) = pot(iat) + rtmpf
              pot(jat) = pot(jat) - rtmpb
c
              if(iderivonoff .eq. 1)then
c
                rtmp2 = 1d0 / rrr
c
                rtttt = 3.0d0 * rtmpf / rr
c
                potx(iat) = potx(iat) - tout(1) * rtmp2 + rx * rtttt
                poty(iat) = poty(iat) - tout(2) * rtmp2 + ry * rtttt
                potz(iat) = potz(iat) - tout(3) * rtmp2 + rz * rtttt
c
                rtttt = 3.0d0 * rtmpb / rr
c
                potx(jat) = potx(jat) - tin(1) * rtmp2 + rx * rtttt
                poty(jat) = poty(jat) - tin(2) * rtmp2 + ry * rtttt
                potz(jat) = potz(jat) - tin(3) * rtmp2 + rz * rtttt
c
              endif
c
            endif
c
 1000     continue
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine directcont3d(iflagtype, iderivonoff, nparts,
     1    zparts, monocharge, dipstr, dipvec, point, ptfrc,
     2    rpot, eps, iz, iat, istart)
      implicit real *8(a-h,o-z)
c
c purpose:
c     direct evaluation of potential and electric field (-gradient)
c     due to a collection of monocharges.
c
c input:
c     nparts =         number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     dipstr(3,nparts) = array of strengths of dipstrs
c     point(3) =       coordinates of evaluation point
c
c output:
c     rpot = potential due to sources at point. 
c     ptfrc(3) = field at point (- gradient of potential).
c
c----------------------------------------------------------------------------
c
c
      integer *4  nparts, iflagtype, iderivonoff, iz(1), iat
c
c executions starts:
c
      real *8  zparts(3,1), monocharge(1), dipstr(1), dipvec(3,1),
     1   point(3), ptfrc(3), rpot
        rpot = 0.0d0
        ptfrc(1) = 0.0d0
        ptfrc(2) = 0.0d0
        ptfrc(3) = 0.0d0
c
        do 1000 jj = 1, nparts
c
          j = iz(istart+jj)
c
          if(j .eq. iat) goto 1000
c
          rx = point(1) - zparts(1,j)
          ry = point(2) - zparts(2,j)
          rz = point(3) - zparts(3,j)
          rr = rx*rx + ry*ry + rz*rz
          rdis = dsqrt(rr)
c
          if(rdis .gt. eps)then
c
            if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
              rpot = rpot + monocharge(j)/rdis
c
              if(iderivonoff .eq. 1)then
                rmul = monocharge(j)/(rdis*rr)
c
                ptfrc(1) = ptfrc(1) + rmul*rx
                ptfrc(2) = ptfrc(2) + rmul*ry
                ptfrc(3) = ptfrc(3) + rmul*rz
              endif
c
            endif
c
            if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
              rtmp = dipstr(j) * (dipvec(1,j) * rx
     1                          + dipvec(2,j) * ry
     2                          + dipvec(3,j) * rz)
              rrr = rdis*rr
              rpot = rpot + rtmp/rrr
c
              if(iderivonoff .eq. 1)then
                rrrrr = rrr*rr
                rtttt = 3.0d0*rtmp/rrrrr
                rtmp2 = dipstr(j) / rrr
c
                ptfrc(1) = ptfrc(1)
     1                   - dipvec(1,j) * rtmp2 + rx * rtttt
                ptfrc(2) = ptfrc(2)
     1                   - dipvec(2,j) * rtmp2 + ry * rtttt
                ptfrc(3) = ptfrc(3)
     1                   - dipvec(3,j) * rtmp2 + rz * rtttt
              endif
c
            endif
c
          endif
c
 1000   continue
c
      return
      end
c
c
c
c
c
      subroutine localintrivtarg3d(iflagtype, iderivonoff, nterms,
     1     nlev, nboxes, maxppb, n22, centr0, sources, monocharge,
     2     dipstr, dipvec, pot, potx, poty, potz, targets, pottar,
     3     pottarx, pottary, pottarz, dc, pptmp, scale, eps, mpole,
     4     mw1, close, iw, izsour, zboxsour, iztarg,
     5     zboxtarg, itargflag)
      implicit none
c
c
      integer *4  iflagtype, nterms, npts, ntgs, ier, box(15), box1(15),
     1   nboxes, il, ilbox, istart, list(2000), iistrt, mylstt, nlist,
     2   ikids, ipts, maxppb, n22, mybox, nkids, nlev, iderivonoff,
     3   iw(1), izsour(1), zboxsour(2,1), iztarg(1), zboxtarg(2,1),
     4   istgs, itargflag
c
      real *8  centr0(3), sources(3,1), monocharge(1), dipstr(1),
     1   dipvec(3,1), scale(0:201), eps, dc(0:4*nterms,0:4*nterms),
     2   pptmp((n22+2)*(n22+2)), pot(1), potx(1), poty(1), potz(1),
     3   targets(3,1), pottar(1), pottarx(1), pottary(1), pottarz(1)
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1   mw1(0:nterms,0:nterms)
      external  close
c
        do 2000 mybox = 1, nboxes
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .ge. 1) goto 2000
c
          npts = zboxsour(2,mybox)
          istart = zboxsour(1,mybox) - 1
c
c-----------------------------------------------------------------------
c step 3: calculate the direct interaction within mybox itself:
c-----------------------------------------------------------------------
c
          if(itargflag .eq. 1)then
            call collocrivtarg3d(sources, pot, potx, poty, potz,
     1          npts, npts, istart, istart, iflagtype, iderivonoff,
     2          monocharge, dipstr, dipvec, close, eps, izsour)
          endif
c
          ntgs = zboxtarg(2,mybox)
          iistrt = zboxtarg(1,mybox) - 1 
c
          call collocrivtotargets3d(targets, sources,
     1        pottar, pottarx, pottary, pottarz, ntgs, npts,
     2        iistrt, istart, iflagtype, iderivonoff, monocharge,
     3        dipstr, dipvec, close, eps, izsour, iztarg)
c
          if(nlev .eq. 0) goto 2000
c
c-----------------------------------------------------------------------
c step 4: handle list 1 interaction:
c-----------------------------------------------------------------------
c
          mylstt = 1
          call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
c
          if(nlist .gt. 2000)then
            ier = 999
            call prinf('nlist exceeds limit *',nlist,1)
            return
          endif
c
          do 1000 il = 1, nlist
            ilbox = list(il)
            call d3mgetbk(ier,ilbox,box1,centr0,ikids,iw)
c
            if(itargflag .eq. 1)then
              ipts = zboxsour(2,ilbox)
              iistrt = zboxsour(1,ilbox) - 1
c
              call collocrivtarg3d(sources, pot, potx, poty, potz,
     1            ipts, npts, iistrt, istart, iflagtype, iderivonoff,
     2            monocharge, dipstr, dipvec, close, eps, izsour)
            endif
c
            ntgs = zboxtarg(2,ilbox)
            iistrt = zboxtarg(1,ilbox) - 1 
c
            call collocrivtotargets3d(targets, sources,
     1          pottar, pottarx, pottary, pottarz, ntgs, npts,
     2          iistrt, istart, iflagtype, iderivonoff, monocharge,
     3          dipstr, dipvec, close, eps, izsour, iztarg)
c
 1000     continue
c
c-----------------------------------------------------------------------
c step 5: treat the list 3 interaction:
c-----------------------------------------------------------------------
c
          ntgs = zboxtarg(2,mybox)
c
          istgs = zboxtarg(1,mybox) - 1
c
          call stobfarparttarg3d(npts, ntgs, istart, istgs,
     1        eps, sources, targets, pot, potx, poty, potz,
     2        pottar, pottarx, pottary, pottarz, nterms, mw1, mpole,
     3        n22, scale, mybox, centr0, maxppb, iflagtype,
     4        iderivonoff, monocharge, dipstr, dipvec, dc,
     5        pptmp, iw, izsour, zboxsour, iztarg, itargflag)
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine collocrivtarg3d(sources, pot, potx, poty, potz,
     1    ipts, npts, iistrt, istart, iflagtype, iderivonoff,
     2    monocharge, dipstr, dipvec, close, eps, izsour)
      implicit none
c
c      
      integer *4  ipts, npts, iflagtype, iistrt, istart, iat,
     1     jat, j, k, iderivonoff, iflag(2), izsour(1)
c      
      real *8  sources(3,1), eps, monocharge(1), dipstr(1), dipvec(3,1),
     1     pot(1), potx(1), poty(1), potz(1), xinfo1(8), xinfo2(8),
     2     xout(4), rr, rdis, rx, ry, rz, rrr, rtttt, rtmp2, tout(3),
     3     tin(3), rmul2, rtmpf, rtmpb, rmul
      external  close
c
        do 2000 k = 1, npts
          iat = izsour(istart+k)
c
          do 1000 j = 1, ipts
c
            jat = izsour(iistrt+j)
c
            if(jat .eq. iat) goto 1000
c
            if(jat .gt. iat) goto 1000
c
            rx = sources(1,iat) - sources(1,jat)
            ry = sources(2,iat) - sources(2,jat)
            rz = sources(3,iat) - sources(3,jat)
c
            rr = rx*rx + ry*ry + rz*rz
            rdis = dsqrt(rr)
c
            if(rdis .le. eps)then
c
              iflag(1) = iflagtype
              iflag(2) = iderivonoff
c
              if(iflagtype .eq. 0)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = monocharge(iat)
                xinfo1(5) = 0d0
                xinfo1(6) = 0d0
                xinfo1(7) = 0d0
                xinfo1(8) = 0d0
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = 0d0
                xinfo2(6) = 0d0
                xinfo2(7) = 0d0
                xinfo2(8) = 0d0
              endif
c
              if(iflagtype .eq. 1)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = 0d0
                xinfo1(5) = dipstr(iat)
                xinfo1(6) = dipvec(1,iat)
                xinfo1(7) = dipvec(2,iat)
                xinfo1(8) = dipvec(3,iat)
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = 0d0
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              if(iflagtype .eq. 2)then
                xinfo1(1) = sources(1,iat)
                xinfo1(2) = sources(2,iat)
                xinfo1(3) = sources(3,iat)
                xinfo1(4) = monocharge(iat)
                xinfo1(5) = dipstr(iat)
                xinfo1(6) = dipvec(1,iat)
                xinfo1(7) = dipvec(2,iat)
                xinfo1(8) = dipvec(3,iat)
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              call close(iat, jat, eps, xinfo1, xinfo2, iflag, xout)
c
              pot(iat) = pot(iat) + xout(1)
c
              if(iderivonoff .eq. 1)then
                potx(iat) = potx(iat) + xout(2)
                poty(iat) = poty(iat) + xout(3) 
                potz(iat) = potz(iat) + xout(4) 
              endif
c
              call close(jat, iat, eps, xinfo2, xinfo1, iflag, xout)
c
              pot(jat) = pot(jat) + xout(1)
c
              if(iderivonoff .eq. 1)then
                potx(jat) = potx(jat) + xout(2)
                poty(jat) = poty(jat) + xout(3)
                potz(jat) = potz(jat) + xout(4)
              endif
c
              goto 1000
c
            endif
c
c           now compute the interaction for two points
c           that are not within eps of each other
c
            if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
              pot(iat) = pot(iat) + monocharge(jat) / rdis
              pot(jat) = pot(jat) + monocharge(iat) / rdis
c
              if(iderivonoff .eq. 1)then
                rmul2 = 1d0 / (rdis*rr)
c
                rmul = monocharge(jat) * rmul2
c
                potx(iat) = potx(iat) + rmul * rx
                poty(iat) = poty(iat) + rmul * ry
                potz(iat) = potz(iat) + rmul * rz
c
                rmul = monocharge(iat) * rmul2
c
                potx(jat) = potx(jat) - rmul * rx
                poty(jat) = poty(jat) - rmul * ry
                potz(jat) = potz(jat) - rmul * rz
c
              endif
c
            endif
c
            if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
              rrr = rdis * rr
c
              tout(1) = dipvec(1,jat) * dipstr(jat)
              tout(2) = dipvec(2,jat) * dipstr(jat)
              tout(3) = dipvec(3,jat) * dipstr(jat)
c
              tin(1)  = dipvec(1,iat) * dipstr(iat)
              tin(2)  = dipvec(2,iat) * dipstr(iat)
              tin(3)  = dipvec(3,iat) * dipstr(iat)
c
              rtmpf = (tout(1) * rx + tout(2) * ry
     1               + tout(3) * rz) / rrr
c
              rtmpb = (tin(1) * rx + tin(2) * ry
     1               + tin(3) * rz) / rrr
c
              pot(iat) = pot(iat) + rtmpf
              pot(jat) = pot(jat) - rtmpb
c
              if(iderivonoff .eq. 1)then
c
                rtmp2 = 1d0 / rrr
c
                rtttt = 3.0d0 * rtmpf / rr
c
                potx(iat) = potx(iat) - tout(1) * rtmp2 + rx * rtttt
                poty(iat) = poty(iat) - tout(2) * rtmp2 + ry * rtttt
                potz(iat) = potz(iat) - tout(3) * rtmp2 + rz * rtttt
c
                rtttt = 3.0d0 * rtmpb / rr
c
                potx(jat) = potx(jat) - tin(1) * rtmp2 + rx * rtttt
                poty(jat) = poty(jat) - tin(2) * rtmp2 + ry * rtttt
                potz(jat) = potz(jat) - tin(3) * rtmp2 + rz * rtttt
c
              endif
c
            endif
c
 1000     continue
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine collocrivtotargets3d(targets, sources,
     1     pottar, pottarx, pottary, pottarz, ipts, npts,
     2     iistrt, istart, iflagtype, iderivonoff, monocharge,
     3     dipstr, dipvec, close, eps, izsour, iztarg)
      implicit none
c
c      
      integer *4  ipts, npts, iflagtype, iistrt, istart, iat, jat,
     1     j, k, iderivonoff, iflag(2), izsour(1), iztarg(1)
c      
      real *8  targets(3,1), sources(3,1), eps, monocharge(1),
     1     dipstr(1), dipvec(3,1), pottar(1), pottarx(1), pottary(1),
     2     pottarz(1), xinfo1(8), xinfo2(8), xout(4), rr, rdis,
     3     rx, ry, rz, rrr, rtttt, rtmp2, tout(3), rmul2, rtmpf, rmul
      external  close
c
        do 2000 k = 1, npts
          jat = izsour(istart+k)
c
          do 1000 j = 1, ipts
c
            iat = iztarg(iistrt+j)
c
            rx = targets(1,iat) - sources(1,jat)
            ry = targets(2,iat) - sources(2,jat)
            rz = targets(3,iat) - sources(3,jat)
c
            rr = rx*rx + ry*ry + rz*rz
            rdis = dsqrt(rr)
c
            if(rdis .le. eps)then
c
              iflag(1) = iflagtype
              iflag(2) = iderivonoff
c
              if(iflagtype .eq. 0)then
                xinfo1(1) = targets(1,iat)
                xinfo1(2) = targets(2,iat)
                xinfo1(3) = targets(3,iat)
                xinfo1(4) = 0d0
                xinfo1(5) = 0d0
                xinfo1(6) = 0d0
                xinfo1(7) = 0d0
                xinfo1(8) = 0d0
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = 0d0
                xinfo2(6) = 0d0
                xinfo2(7) = 0d0
                xinfo2(8) = 0d0
              endif
c
              if(iflagtype .eq. 1)then
                xinfo1(1) = targets(1,iat)
                xinfo1(2) = targets(2,iat)
                xinfo1(3) = targets(3,iat)
                xinfo1(4) = 0d0
                xinfo1(5) = 0d0 
                xinfo1(6) = 0d0 
                xinfo1(7) = 0d0 
                xinfo1(8) = 0d0 
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = 0d0
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              if(iflagtype .eq. 2)then
                xinfo1(1) = targets(1,iat)
                xinfo1(2) = targets(2,iat)
                xinfo1(3) = targets(3,iat)
                xinfo1(4) = 0d0
                xinfo1(5) = 0d0 
                xinfo1(6) = 0d0 
                xinfo1(7) = 0d0 
                xinfo1(8) = 0d0 
c
                xinfo2(1) = sources(1,jat)
                xinfo2(2) = sources(2,jat)
                xinfo2(3) = sources(3,jat)
                xinfo2(4) = monocharge(jat)
                xinfo2(5) = dipstr(jat)
                xinfo2(6) = dipvec(1,jat)
                xinfo2(7) = dipvec(2,jat)
                xinfo2(8) = dipvec(3,jat)
              endif
c
              call close(iat, jat, eps, xinfo1, xinfo2, iflag, xout)
c
              pottar(iat) = pottar(iat) + xout(1)
c
              if(iderivonoff .eq. 1)then
                pottarx(iat) = pottarx(iat) + xout(2)
                pottary(iat) = pottary(iat) + xout(3) 
                pottarz(iat) = pottarz(iat) + xout(4) 
              endif
c
              goto 1000
c
            endif
c
c           now compute the interaction for two points
c           that are not within eps of each other
c
            if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
              pottar(iat) = pottar(iat) + monocharge(jat) / rdis
c
              if(iderivonoff .eq. 1)then
                rmul2 = 1d0 / (rdis*rr)
c
                rmul = monocharge(jat) * rmul2
c
                pottarx(iat) = pottarx(iat) + rmul * rx
                pottary(iat) = pottary(iat) + rmul * ry
                pottarz(iat) = pottarz(iat) + rmul * rz
c
              endif
c
            endif
c
            if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
              rrr = rdis * rr
c
              tout(1) = dipvec(1,jat) * dipstr(jat)
              tout(2) = dipvec(2,jat) * dipstr(jat)
              tout(3) = dipvec(3,jat) * dipstr(jat)
c
              rtmpf = (tout(1) * rx + tout(2) * ry
     1               + tout(3) * rz) / rrr
c
              pottar(iat) = pottar(iat) + rtmpf
c
              if(iderivonoff .eq. 1)then
c
                rtmp2 = 1d0 / rrr
c
                rtttt = 3.0d0 * rtmpf / rr
c
                pottarx(iat) = pottarx(iat) 
     1                       - tout(1) * rtmp2 + rx * rtttt
                pottary(iat) = pottary(iat) 
     1                       - tout(2) * rtmp2 + ry * rtttt
                pottarz(iat) = pottarz(iat) 
     1                       - tout(3) * rtmp2 + rz * rtttt
c
              endif
c
            endif
c
 1000     continue
c
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine stobfarparttarg3d(npts, ntgs, istart, istgs,
     1    eps, sources, targets, pot, potx, poty, potz,
     2    pottar, pottarx, pottary, pottarz, nterms, mw3, mpole,
     3    n22, scale, mybox, centr0, maxppb, iflagtype,
     4    iderivonoff, monocharge, dipstr, dipvec, dc, pptmp,
     5    iw, izsour, zboxsour, iztarg, itargflag)
      implicit none
c
c
      integer *4  npts, ntgs, kk, istart, iat , iilvl, nterms, n22,
     1    nlist, mylstt, list(2000), ier, il, ilbox, box1(15), istgs,
     2    ikids, ipts, maxppb, mybox, iistrt, iflagtype, iderivonoff,
     3    iw(1), izsour(1), zboxsour(2,1), iztarg(1), iskip, itargflag
c
      real *8  eps, tmppot, tmpfld(3), sources(3,1), targets(3,1),
     1    dc(0:4*nterms,0:4*nterms), scale(0:201), centr0(3),
     2    pptmp((n22+2)*(n22+2)), monocharge(1), dipstr(1),
     3    dipvec(3,1), pot(1), potx(1), poty(1), potz(1),
     4    pottar(1), pottarx(1), pottary(1), pottarz(1)
c
      complex *16 mpole((nterms+1)*(nterms+2)/2,*),
     1    mw3(0:nterms,0:nterms)
        mylstt = 3
        call d3mgetl(ier,mybox,mylstt,list,nlist,iw)
        do 4000 il = 1, nlist
c
          ilbox = list(il)
          call d3mgetbk(ier,ilbox,box1,centr0,ikids,iw)
c
          ipts = zboxsour(2,ilbox)
c
          if(ipts .le. maxppb)then
c
            iistrt = zboxsour(1,ilbox) - 1
c
            if(itargflag .eq. 1)then
c
              do 2000 kk = 1, npts
                iat = izsour(istart+kk)
c
                call directcont3d(iflagtype, iderivonoff, ipts,
     1              sources, monocharge, dipstr, dipvec,
     2              sources(1,iat), tmpfld, tmppot, eps,
     3              izsour, iat, iistrt)
c
                pot(iat) = pot(iat) + tmppot
c
                if(iderivonoff .eq. 1)then
                  potx(iat) = potx(iat) + tmpfld(1)
                  poty(iat) = poty(iat) + tmpfld(2)
                  potz(iat) = potz(iat) + tmpfld(3)
                endif
c
 2000         continue
c
            endif
c
            do 2500 kk = 1, ntgs
              iat = iztarg(istgs+kk)
c
              iskip = 0
c
              call directconttarg3d(iflagtype, iderivonoff, ipts,
     1            sources, monocharge, dipstr, dipvec,
     2            targets(1,iat), tmpfld, tmppot, eps,
     3            izsour, iskip, iistrt)
c
              pottar(iat) = pottar(iat) + tmppot
c
              if(iderivonoff .eq. 1)then
                pottarx(iat) = pottarx(iat) + tmpfld(1)
                pottary(iat) = pottary(iat) + tmpfld(2)
                pottarz(iat) = pottarz(iat) + tmpfld(3)
              endif
c
 2500       continue
c
          endif
c
          if(ipts .gt. maxppb)then
c
            iilvl = box1(1)
            call maptmp3d(mpole(1,ilbox),mw3,nterms)
c
            if(itargflag .eq. 1)then
              do 3000 kk = 1, npts
c
                iat = izsour(istart+kk)
                call mpeval3d(iderivonoff, mw3, centr0,
     1              sources(1,iat), nterms, n22, tmppot,
     2              tmpfld, scale(iilvl), dc, pptmp)
c
                pot(iat) = pot(iat) + tmppot
c
                if(iderivonoff .eq. 1)then
                  potx(iat) = potx(iat) + tmpfld(1)
                  poty(iat) = poty(iat) + tmpfld(2)
                  potz(iat) = potz(iat) + tmpfld(3)
                endif
c
 3000         continue
            endif
c
            do 3500 kk = 1, ntgs
c
              iat = iztarg(istgs+kk)
              call mpeval3d(iderivonoff, mw3, centr0,
     1            targets(1,iat), nterms, n22, tmppot,
     2            tmpfld, scale(iilvl), dc, pptmp)
c
              pottar(iat) = pottar(iat) + tmppot
c
              if(iderivonoff .eq. 1)then
                pottarx(iat) = pottarx(iat) + tmpfld(1)
                pottary(iat) = pottary(iat) + tmpfld(2)
                pottarz(iat) = pottarz(iat) + tmpfld(3)
              endif
c
 3500       continue
c
          endif
c
 4000   continue
c
      return
      end
c
c
c
c
c
      subroutine directconttarg3d(iflagtype, iderivonoff, nparts,
     1    zparts, monocharge, dipstr, dipvec, point, ptfrc,
     2    rpot, eps, iz, iat, istart)
      implicit real *8(a-h,o-z)
c
c purpose:
c     direct evaluation of potential and electric field (-gradient)
c     due to a collection of monocharges.
c
c input:
c     nparts =         number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     dipstr(3,nparts) = array of strengths of dipstrs
c     point(3) =       coordinates of evaluation point
c     close =  a user provided subroutine handles near approach
c
c output:
c     rpot = potential due to sources at point. 
c     ptfrc(3) = field at point (- gradient of potential).
c
c----------------------------------------------------------------------------
c
c
      integer *4  nparts, iflagtype, iderivonoff, iz(1), iat
c
      real *8  zparts(3,1), monocharge(1), dipstr(1), dipvec(3,1),
     1   point(3), ptfrc(3), rpot
        rpot = 0.0d0
        ptfrc(1) = 0.0d0
        ptfrc(2) = 0.0d0
        ptfrc(3) = 0.0d0
c
        do 1000 jj = 1, nparts
c
          j = iz(istart+jj)
c
          if(j .eq. iat) goto 1000
c
          rx = point(1) - zparts(1,j)
          ry = point(2) - zparts(2,j)
          rz = point(3) - zparts(3,j)
          rr = rx*rx + ry*ry + rz*rz
          rdis = dsqrt(rr)
c
c         the if statement takes care of two points getting
c         too close, also eliminates the case of point and
c         one of zparts(*,j) coincides:
c
          if(rdis .gt. eps)then
c
            if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
              rpot = rpot + monocharge(j) / rdis
c
              if(iderivonoff .eq. 1)then
                rmul = monocharge(j) / (rdis*rr)
c
                ptfrc(1) = ptfrc(1) + rmul*rx
                ptfrc(2) = ptfrc(2) + rmul*ry
                ptfrc(3) = ptfrc(3) + rmul*rz
              endif
c
            endif
c
            if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
              rtmp = dipstr(j) * (dipvec(1,j) * rx
     1                          + dipvec(2,j) * ry
     2                          + dipvec(3,j) * rz)
              rrr = rdis*rr
              rpot = rpot + rtmp/rrr
c
              if(iderivonoff .eq. 1)then
                rrrrr = rrr * rr
                rtttt = 3.0d0 * rtmp / rrrrr
                rtmp2 = dipstr(j) / rrr
c
                ptfrc(1) = ptfrc(1)
     1                   - dipvec(1,j) * rtmp2 + rx * rtttt
                ptfrc(2) = ptfrc(2)
     1                   - dipvec(2,j) * rtmp2 + ry * rtttt
                ptfrc(3) = ptfrc(3)
     1                   - dipvec(3,j) * rtmp2 + rz * rtttt
              endif
c
            endif
c
          endif
c
 1000   continue
c
      return
      end
c
c
c
c
c
c
        subroutine lol12get(arr,imap)
        implicit real *8 (a-h,o-z)
c
        integer imap(1),iimap(24)
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260(16),
     6  arr1261(16),arr1262(16),arr1263(16),arr1264(16),
     7  arr1265(16),arr1266(16),arr1267(16),arr1268(16),
     8  arr1269(16),arr1270(16),arr1271(16),arr1272(16),
     9  arr1273(16),arr1274(16),arr1275(16),arr1276(16),
     a  arr1277(16),arr1278(16),arr1279(16),arr1280(16)
         real *8
     1  arr1281(16),arr1282(16),arr1283(16),arr1284(16),
     2  arr1285(16),arr1286(16),arr1287(16),arr1288(16),
     3  arr1289(16),arr1290(16),arr1291(16),arr1292(16),
     4  arr1293(16),arr1294(16),arr1295(16),arr1296(16),
     5  arr1297(16),arr1298(16),arr1299(16),arr1300(16),
     6  arr1301(16),arr1302(16),arr1303(16),arr1304(16),
     7  arr1305(16),arr1306(16),arr1307(16),arr1308(16),
     8  arr1309(16),arr1310(16),arr1311(16),arr1312(16),
     9  arr1313(16),arr1314(16),arr1315(16),arr1316(16),
     a  arr1317(16),arr1318(16),arr1319(16),arr1320(16)
         real *8
     1  arr1321(16),arr1322(16),arr1323(16),arr1324(16),
     2  arr1325(16),arr1326(16),arr1327(16),arr1328(16),
     3  arr1329(16),arr1330(16),arr1331(16),arr1332(16),
     4  arr1333(16),arr1334(16),arr1335(16),arr1336(16),
     5  arr1337(16),arr1338(16),arr1339(16),arr1340(16),
     6  arr1341(16),arr1342(16),arr1343(16),arr1344(16),
     7  arr1345(16),arr1346(16),arr1347(16),arr1348(16),
     8  arr1349(16),arr1350(16),arr1351(16),arr1352(16),
     9  arr1353(16),arr1354(16),arr1355(16),arr1356(16),
     a  arr1357(16),arr1358(16),arr1359(16),arr1360(16)
         real *8
     1  arr1361(16),arr1362(16),arr1363(16),arr1364(16),
     2  arr1365(16),arr1366(16),arr1367(16),arr1368(16),
     3  arr1369(16),arr1370(16),arr1371(16),arr1372(16),
     4  arr1373(16),arr1374(16),arr1375(16),arr1376(16),
     5  arr1377(16),arr1378(16),arr1379(16),arr1380(16),
     6  arr1381(16),arr1382(16),arr1383(16),arr1384(16),
     7  arr1385(16),arr1386(16),arr1387(16),arr1388(16),
     8  arr1389(16),arr1390(16),arr1391(16),arr1392(16),
     9  arr1393(16),arr1394(16),arr1395(16),arr1396(16),
     a  arr1397(16),arr1398(16),arr1399(16),arr1400(16)
         real *8
     1  arr1401(16),arr1402(16),arr1403(16),arr1404(16),
     2  arr1405(16),arr1406(16),arr1407(16),arr1408(16),
     3  arr1409(16),arr1410(16),arr1411(16),arr1412(16),
     4  arr1413(16),arr1414(16),arr1415(16),arr1416(16),
     5  arr1417(16),arr1418(16),arr1419(16),arr1420(16),
     6  arr1421(16),arr1422(16),arr1423(16),arr1424(16),
     7  arr1425(16),arr1426(16),arr1427(16),arr1428(16),
     8  arr1429(16),arr1430(16),arr1431(16),arr1432(16),
     9  arr1433(16),arr1434(16),arr1435(16),arr1436(16),
     a  arr1437(16),arr1438(16),arr1439(16),arr1440(16)
         real *8
     1  arr1441(16),arr1442(16),arr1443(16),arr1444(16),
     2  arr1445(16),arr1446(16),arr1447(16),arr1448(16),
     3  arr1449(16),arr1450(16),arr1451(16),arr1452(16),
     4  arr1453(16),arr1454(16),arr1455(16),arr1456(16),
     5  arr1457(16),arr1458(16),arr1459(16),arr1460(16),
     6  arr1461(16),arr1462(16),arr1463(16),arr1464(16),
     7  arr1465(16),arr1466(16),arr1467(16),arr1468(16),
     8  arr1469(16),arr1470(16),arr1471(16),arr1472(16),
     9  arr1473(16),arr1474(16),arr1475(16),arr1476(16),
     a  arr1477(16),arr1478(16),arr1479(16),arr1480(16)
         real *8
     1  arr1481(16),arr1482(16),arr1483(16),arr1484(16),
     2  arr1485(16),arr1486(16),arr1487(16),arr1488(16),
     3  arr1489(16),arr1490(16),arr1491(16),arr1492(16),
     4  arr1493(16),arr1494(16),arr1495(16),arr1496(16),
     5  arr1497(16),arr1498(16),arr1499(16),arr1500(16),
     6  arr1501(16),arr1502(16),arr1503(16),arr1504(16),
     7  arr1505(16),arr1506(16),arr1507(16),arr1508(16),
     8  arr1509(16),arr1510(16),arr1511(16),arr1512(16),
     9  arr1513(16),arr1514(16),arr1515(16),arr1516(16),
     a  arr1517(16),arr1518(16),arr1519(16),arr1520(16)
         real *8
     1  arr1521(16),arr1522(16),arr1523(16),arr1524(16),
     2  arr1525(16),arr1526(16),arr1527(16),arr1528(16),
     3  arr1529(16),arr1530(16),arr1531(16),arr1532(16),
     4  arr1533(16),arr1534(16),arr1535(16),arr1536(16),
     5  arr1537(16),arr1538(16),arr1539(16),arr1540(16),
     6  arr1541(16),arr1542(16),arr1543(16),arr1544(16),
     7  arr1545(16),arr1546(16),arr1547(16),arr1548(16),
     8  arr1549(16),arr1550(16),arr1551(16),arr1552(16),
     9  arr1553(16),arr1554(16),arr1555(16),arr1556(16),
     a  arr1557(16),arr1558(16),arr1559(16),arr1560(16)
         real *8
     1  arr1561(16),arr1562(16),arr1563(16),arr1564(16),
     2  arr1565(16),arr1566(16),arr1567(16),arr1568(16),
     3  arr1569(16),arr1570(16),arr1571(16),arr1572(16),
     4  arr1573(16),arr1574(16),arr1575(16),arr1576(16),
     5  arr1577(16),arr1578(16),arr1579(16),arr1580(16),
     6  arr1581(16),arr1582(16),arr1583(16),arr1584(16),
     7  arr1585(16),arr1586(16),arr1587(16),arr1588(16),
     8  arr1589(16),arr1590(16),arr1591(16),arr1592(16),
     9  arr1593(16),arr1594(16),arr1595(16),arr1596(16),
     a  arr1597(16),arr1598(16),arr1599(16),arr1600(16)
         real *8
     1  arr1601(16),arr1602(16),arr1603(16),arr1604(16),
     2  arr1605(16),arr1606(16),arr1607(16),arr1608(16),
     3  arr1609(16),arr1610(16),arr1611(16),arr1612(16),
     4  arr1613(16),arr1614(16),arr1615(16),arr1616(16),
     5  arr1617(16),arr1618(16),arr1619(16),arr1620(16),
     6  arr1621(16),arr1622(16),arr1623(16),arr1624(16)
         real *8
     1  arr1625(16)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2),
     5  arr2257(2),arr2258(2),arr2259(2),arr2260(2),
     6  arr2261(2),arr2262(2),arr2263(2),arr2264(2),
     7  arr2265(2),arr2266(2),arr2267(2),arr2268(2),
     8  arr2269(2),arr2270(2),arr2271(2),arr2272(2),
     9  arr2273(2),arr2274(2),arr2275(2),arr2276(2),
     a  arr2277(2),arr2278(2),arr2279(2),arr2280(2)
         real *8
     1  arr2281(2),arr2282(2),arr2283(2),arr2284(2),
     2  arr2285(2),arr2286(2),arr2287(2),arr2288(2),
     3  arr2289(2),arr2290(2),arr2291(2),arr2292(2),
     4  arr2293(2),arr2294(2),arr2295(2),arr2296(2),
     5  arr2297(2),arr2298(2),arr2299(2),arr2300(2),
     6  arr2301(2),arr2302(2),arr2303(2),arr2304(2),
     7  arr2305(2),arr2306(2),arr2307(2),arr2308(2),
     8  arr2309(2),arr2310(2),arr2311(2),arr2312(2),
     9  arr2313(2),arr2314(2),arr2315(2),arr2316(2),
     a  arr2317(2),arr2318(2),arr2319(2),arr2320(2)
         real *8
     1  arr2321(2),arr2322(2),arr2323(2),arr2324(2),
     2  arr2325(2),arr2326(2),arr2327(2),arr2328(2),
     3  arr2329(2),arr2330(2),arr2331(2),arr2332(2),
     4  arr2333(2),arr2334(2),arr2335(2),arr2336(2),
     5  arr2337(2),arr2338(2),arr2339(2),arr2340(2),
     6  arr2341(2),arr2342(2),arr2343(2),arr2344(2),
     7  arr2345(2),arr2346(2),arr2347(2),arr2348(2),
     8  arr2349(2),arr2350(2),arr2351(2),arr2352(2),
     9  arr2353(2),arr2354(2),arr2355(2),arr2356(2),
     a  arr2357(2),arr2358(2),arr2359(2),arr2360(2)
         real *8
     1  arr2361(2),arr2362(2),arr2363(2),arr2364(2),
     2  arr2365(2),arr2366(2),arr2367(2),arr2368(2),
     3  arr2369(2),arr2370(2),arr2371(2),arr2372(2),
     4  arr2373(2),arr2374(2),arr2375(2),arr2376(2),
     5  arr2377(2),arr2378(2),arr2379(2),arr2380(2),
     6  arr2381(2),arr2382(2),arr2383(2),arr2384(2),
     7  arr2385(2),arr2386(2),arr2387(2),arr2388(2),
     8  arr2389(2),arr2390(2),arr2391(2),arr2392(2),
     9  arr2393(2),arr2394(2),arr2395(2),arr2396(2),
     a  arr2397(2),arr2398(2),arr2399(2),arr2400(2)
         real *8
     1  arr2401(2),arr2402(2),arr2403(2),arr2404(2),
     2  arr2405(2),arr2406(2),arr2407(2),arr2408(2),
     3  arr2409(2),arr2410(2),arr2411(2),arr2412(2),
     4  arr2413(2),arr2414(2),arr2415(2),arr2416(2),
     5  arr2417(2),arr2418(2),arr2419(2),arr2420(2),
     6  arr2421(2),arr2422(2),arr2423(2),arr2424(2),
     7  arr2425(2),arr2426(2),arr2427(2),arr2428(2),
     8  arr2429(2),arr2430(2),arr2431(2),arr2432(2),
     9  arr2433(2),arr2434(2),arr2435(2),arr2436(2),
     a  arr2437(2),arr2438(2),arr2439(2),arr2440(2)
         real *8
     1  arr2441(2),arr2442(2),arr2443(2),arr2444(2),
     2  arr2445(2),arr2446(2),arr2447(2),arr2448(2),
     3  arr2449(2),arr2450(2),arr2451(2),arr2452(2),
     4  arr2453(2),arr2454(2),arr2455(2),arr2456(2),
     5  arr2457(2),arr2458(2),arr2459(2),arr2460(2),
     6  arr2461(2),arr2462(2),arr2463(2),arr2464(2),
     7  arr2465(2),arr2466(2),arr2467(2),arr2468(2),
     8  arr2469(2),arr2470(2),arr2471(2),arr2472(2),
     9  arr2473(2),arr2474(2),arr2475(2),arr2476(2),
     a  arr2477(2),arr2478(2),arr2479(2),arr2480(2)
         real *8
     1  arr2481(2),arr2482(2),arr2483(2),arr2484(2),
     2  arr2485(2),arr2486(2),arr2487(2),arr2488(2),
     3  arr2489(2),arr2490(2),arr2491(2),arr2492(2),
     4  arr2493(2),arr2494(2),arr2495(2),arr2496(2),
     5  arr2497(2),arr2498(2),arr2499(2),arr2500(2),
     6  arr2501(2),arr2502(2),arr2503(2),arr2504(2),
     7  arr2505(2),arr2506(2),arr2507(2),arr2508(2),
     8  arr2509(2),arr2510(2),arr2511(2),arr2512(2),
     9  arr2513(2),arr2514(2),arr2515(2),arr2516(2),
     a  arr2517(2),arr2518(2),arr2519(2),arr2520(2)
         real *8
     1  arr2521(2),arr2522(2),arr2523(2),arr2524(2),
     2  arr2525(2),arr2526(2),arr2527(2),arr2528(2),
     3  arr2529(2),arr2530(2),arr2531(2),arr2532(2),
     4  arr2533(2),arr2534(2),arr2535(2),arr2536(2),
     5  arr2537(2),arr2538(2),arr2539(2),arr2540(2),
     6  arr2541(2),arr2542(2),arr2543(2),arr2544(2),
     7  arr2545(2),arr2546(2),arr2547(2),arr2548(2),
     8  arr2549(2),arr2550(2),arr2551(2),arr2552(2),
     9  arr2553(2),arr2554(2),arr2555(2),arr2556(2),
     a  arr2557(2),arr2558(2),arr2559(2),arr2560(2)
         real *8
     1  arr2561(2),arr2562(2),arr2563(2),arr2564(2),
     2  arr2565(2),arr2566(2),arr2567(2),arr2568(2),
     3  arr2569(2),arr2570(2),arr2571(2),arr2572(2),
     4  arr2573(2),arr2574(2),arr2575(2),arr2576(2),
     5  arr2577(2),arr2578(2),arr2579(2),arr2580(2),
     6  arr2581(2),arr2582(2),arr2583(2),arr2584(2),
     7  arr2585(2),arr2586(2),arr2587(2),arr2588(2),
     8  arr2589(2),arr2590(2),arr2591(2),arr2592(2),
     9  arr2593(2),arr2594(2),arr2595(2),arr2596(2),
     a  arr2597(2),arr2598(2),arr2599(2),arr2600(2)
         real *8
     1  arr2601(2),arr2602(2),arr2603(2),arr2604(2),
     2  arr2605(2),arr2606(2),arr2607(2),arr2608(2),
     3  arr2609(2),arr2610(2),arr2611(2),arr2612(2),
     4  arr2613(2),arr2614(2),arr2615(2),arr2616(2),
     5  arr2617(2),arr2618(2),arr2619(2),arr2620(2),
     6  arr2621(2),arr2622(2),arr2623(2),arr2624(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2)),
     a  (arr1260(16),arr2260(1)),(arr1261(1),arr2260(2))
         equivalence
     1  (arr1261(16),arr2261(1)),(arr1262(1),arr2261(2)),
     2  (arr1262(16),arr2262(1)),(arr1263(1),arr2262(2)),
     3  (arr1263(16),arr2263(1)),(arr1264(1),arr2263(2)),
     4  (arr1264(16),arr2264(1)),(arr1265(1),arr2264(2)),
     5  (arr1265(16),arr2265(1)),(arr1266(1),arr2265(2)),
     6  (arr1266(16),arr2266(1)),(arr1267(1),arr2266(2)),
     7  (arr1267(16),arr2267(1)),(arr1268(1),arr2267(2)),
     8  (arr1268(16),arr2268(1)),(arr1269(1),arr2268(2)),
     9  (arr1269(16),arr2269(1)),(arr1270(1),arr2269(2)),
     a  (arr1270(16),arr2270(1)),(arr1271(1),arr2270(2))
         equivalence
     1  (arr1271(16),arr2271(1)),(arr1272(1),arr2271(2)),
     2  (arr1272(16),arr2272(1)),(arr1273(1),arr2272(2)),
     3  (arr1273(16),arr2273(1)),(arr1274(1),arr2273(2)),
     4  (arr1274(16),arr2274(1)),(arr1275(1),arr2274(2)),
     5  (arr1275(16),arr2275(1)),(arr1276(1),arr2275(2)),
     6  (arr1276(16),arr2276(1)),(arr1277(1),arr2276(2)),
     7  (arr1277(16),arr2277(1)),(arr1278(1),arr2277(2)),
     8  (arr1278(16),arr2278(1)),(arr1279(1),arr2278(2)),
     9  (arr1279(16),arr2279(1)),(arr1280(1),arr2279(2)),
     a  (arr1280(16),arr2280(1)),(arr1281(1),arr2280(2))
         equivalence
     1  (arr1281(16),arr2281(1)),(arr1282(1),arr2281(2)),
     2  (arr1282(16),arr2282(1)),(arr1283(1),arr2282(2)),
     3  (arr1283(16),arr2283(1)),(arr1284(1),arr2283(2)),
     4  (arr1284(16),arr2284(1)),(arr1285(1),arr2284(2)),
     5  (arr1285(16),arr2285(1)),(arr1286(1),arr2285(2)),
     6  (arr1286(16),arr2286(1)),(arr1287(1),arr2286(2)),
     7  (arr1287(16),arr2287(1)),(arr1288(1),arr2287(2)),
     8  (arr1288(16),arr2288(1)),(arr1289(1),arr2288(2)),
     9  (arr1289(16),arr2289(1)),(arr1290(1),arr2289(2)),
     a  (arr1290(16),arr2290(1)),(arr1291(1),arr2290(2))
         equivalence
     1  (arr1291(16),arr2291(1)),(arr1292(1),arr2291(2)),
     2  (arr1292(16),arr2292(1)),(arr1293(1),arr2292(2)),
     3  (arr1293(16),arr2293(1)),(arr1294(1),arr2293(2)),
     4  (arr1294(16),arr2294(1)),(arr1295(1),arr2294(2)),
     5  (arr1295(16),arr2295(1)),(arr1296(1),arr2295(2)),
     6  (arr1296(16),arr2296(1)),(arr1297(1),arr2296(2)),
     7  (arr1297(16),arr2297(1)),(arr1298(1),arr2297(2)),
     8  (arr1298(16),arr2298(1)),(arr1299(1),arr2298(2)),
     9  (arr1299(16),arr2299(1)),(arr1300(1),arr2299(2)),
     a  (arr1300(16),arr2300(1)),(arr1301(1),arr2300(2))
         equivalence
     1  (arr1301(16),arr2301(1)),(arr1302(1),arr2301(2)),
     2  (arr1302(16),arr2302(1)),(arr1303(1),arr2302(2)),
     3  (arr1303(16),arr2303(1)),(arr1304(1),arr2303(2)),
     4  (arr1304(16),arr2304(1)),(arr1305(1),arr2304(2)),
     5  (arr1305(16),arr2305(1)),(arr1306(1),arr2305(2)),
     6  (arr1306(16),arr2306(1)),(arr1307(1),arr2306(2)),
     7  (arr1307(16),arr2307(1)),(arr1308(1),arr2307(2)),
     8  (arr1308(16),arr2308(1)),(arr1309(1),arr2308(2)),
     9  (arr1309(16),arr2309(1)),(arr1310(1),arr2309(2)),
     a  (arr1310(16),arr2310(1)),(arr1311(1),arr2310(2))
         equivalence
     1  (arr1311(16),arr2311(1)),(arr1312(1),arr2311(2)),
     2  (arr1312(16),arr2312(1)),(arr1313(1),arr2312(2)),
     3  (arr1313(16),arr2313(1)),(arr1314(1),arr2313(2)),
     4  (arr1314(16),arr2314(1)),(arr1315(1),arr2314(2)),
     5  (arr1315(16),arr2315(1)),(arr1316(1),arr2315(2)),
     6  (arr1316(16),arr2316(1)),(arr1317(1),arr2316(2)),
     7  (arr1317(16),arr2317(1)),(arr1318(1),arr2317(2)),
     8  (arr1318(16),arr2318(1)),(arr1319(1),arr2318(2)),
     9  (arr1319(16),arr2319(1)),(arr1320(1),arr2319(2)),
     a  (arr1320(16),arr2320(1)),(arr1321(1),arr2320(2))
         equivalence
     1  (arr1321(16),arr2321(1)),(arr1322(1),arr2321(2)),
     2  (arr1322(16),arr2322(1)),(arr1323(1),arr2322(2)),
     3  (arr1323(16),arr2323(1)),(arr1324(1),arr2323(2)),
     4  (arr1324(16),arr2324(1)),(arr1325(1),arr2324(2)),
     5  (arr1325(16),arr2325(1)),(arr1326(1),arr2325(2)),
     6  (arr1326(16),arr2326(1)),(arr1327(1),arr2326(2)),
     7  (arr1327(16),arr2327(1)),(arr1328(1),arr2327(2)),
     8  (arr1328(16),arr2328(1)),(arr1329(1),arr2328(2)),
     9  (arr1329(16),arr2329(1)),(arr1330(1),arr2329(2)),
     a  (arr1330(16),arr2330(1)),(arr1331(1),arr2330(2))
         equivalence
     1  (arr1331(16),arr2331(1)),(arr1332(1),arr2331(2)),
     2  (arr1332(16),arr2332(1)),(arr1333(1),arr2332(2)),
     3  (arr1333(16),arr2333(1)),(arr1334(1),arr2333(2)),
     4  (arr1334(16),arr2334(1)),(arr1335(1),arr2334(2)),
     5  (arr1335(16),arr2335(1)),(arr1336(1),arr2335(2)),
     6  (arr1336(16),arr2336(1)),(arr1337(1),arr2336(2)),
     7  (arr1337(16),arr2337(1)),(arr1338(1),arr2337(2)),
     8  (arr1338(16),arr2338(1)),(arr1339(1),arr2338(2)),
     9  (arr1339(16),arr2339(1)),(arr1340(1),arr2339(2)),
     a  (arr1340(16),arr2340(1)),(arr1341(1),arr2340(2))
         equivalence
     1  (arr1341(16),arr2341(1)),(arr1342(1),arr2341(2)),
     2  (arr1342(16),arr2342(1)),(arr1343(1),arr2342(2)),
     3  (arr1343(16),arr2343(1)),(arr1344(1),arr2343(2)),
     4  (arr1344(16),arr2344(1)),(arr1345(1),arr2344(2)),
     5  (arr1345(16),arr2345(1)),(arr1346(1),arr2345(2)),
     6  (arr1346(16),arr2346(1)),(arr1347(1),arr2346(2)),
     7  (arr1347(16),arr2347(1)),(arr1348(1),arr2347(2)),
     8  (arr1348(16),arr2348(1)),(arr1349(1),arr2348(2)),
     9  (arr1349(16),arr2349(1)),(arr1350(1),arr2349(2)),
     a  (arr1350(16),arr2350(1)),(arr1351(1),arr2350(2))
         equivalence
     1  (arr1351(16),arr2351(1)),(arr1352(1),arr2351(2)),
     2  (arr1352(16),arr2352(1)),(arr1353(1),arr2352(2)),
     3  (arr1353(16),arr2353(1)),(arr1354(1),arr2353(2)),
     4  (arr1354(16),arr2354(1)),(arr1355(1),arr2354(2)),
     5  (arr1355(16),arr2355(1)),(arr1356(1),arr2355(2)),
     6  (arr1356(16),arr2356(1)),(arr1357(1),arr2356(2)),
     7  (arr1357(16),arr2357(1)),(arr1358(1),arr2357(2)),
     8  (arr1358(16),arr2358(1)),(arr1359(1),arr2358(2)),
     9  (arr1359(16),arr2359(1)),(arr1360(1),arr2359(2)),
     a  (arr1360(16),arr2360(1)),(arr1361(1),arr2360(2))
         equivalence
     1  (arr1361(16),arr2361(1)),(arr1362(1),arr2361(2)),
     2  (arr1362(16),arr2362(1)),(arr1363(1),arr2362(2)),
     3  (arr1363(16),arr2363(1)),(arr1364(1),arr2363(2)),
     4  (arr1364(16),arr2364(1)),(arr1365(1),arr2364(2)),
     5  (arr1365(16),arr2365(1)),(arr1366(1),arr2365(2)),
     6  (arr1366(16),arr2366(1)),(arr1367(1),arr2366(2)),
     7  (arr1367(16),arr2367(1)),(arr1368(1),arr2367(2)),
     8  (arr1368(16),arr2368(1)),(arr1369(1),arr2368(2)),
     9  (arr1369(16),arr2369(1)),(arr1370(1),arr2369(2)),
     a  (arr1370(16),arr2370(1)),(arr1371(1),arr2370(2))
         equivalence
     1  (arr1371(16),arr2371(1)),(arr1372(1),arr2371(2)),
     2  (arr1372(16),arr2372(1)),(arr1373(1),arr2372(2)),
     3  (arr1373(16),arr2373(1)),(arr1374(1),arr2373(2)),
     4  (arr1374(16),arr2374(1)),(arr1375(1),arr2374(2)),
     5  (arr1375(16),arr2375(1)),(arr1376(1),arr2375(2)),
     6  (arr1376(16),arr2376(1)),(arr1377(1),arr2376(2)),
     7  (arr1377(16),arr2377(1)),(arr1378(1),arr2377(2)),
     8  (arr1378(16),arr2378(1)),(arr1379(1),arr2378(2)),
     9  (arr1379(16),arr2379(1)),(arr1380(1),arr2379(2)),
     a  (arr1380(16),arr2380(1)),(arr1381(1),arr2380(2))
         equivalence
     1  (arr1381(16),arr2381(1)),(arr1382(1),arr2381(2)),
     2  (arr1382(16),arr2382(1)),(arr1383(1),arr2382(2)),
     3  (arr1383(16),arr2383(1)),(arr1384(1),arr2383(2)),
     4  (arr1384(16),arr2384(1)),(arr1385(1),arr2384(2)),
     5  (arr1385(16),arr2385(1)),(arr1386(1),arr2385(2)),
     6  (arr1386(16),arr2386(1)),(arr1387(1),arr2386(2)),
     7  (arr1387(16),arr2387(1)),(arr1388(1),arr2387(2)),
     8  (arr1388(16),arr2388(1)),(arr1389(1),arr2388(2)),
     9  (arr1389(16),arr2389(1)),(arr1390(1),arr2389(2)),
     a  (arr1390(16),arr2390(1)),(arr1391(1),arr2390(2))
         equivalence
     1  (arr1391(16),arr2391(1)),(arr1392(1),arr2391(2)),
     2  (arr1392(16),arr2392(1)),(arr1393(1),arr2392(2)),
     3  (arr1393(16),arr2393(1)),(arr1394(1),arr2393(2)),
     4  (arr1394(16),arr2394(1)),(arr1395(1),arr2394(2)),
     5  (arr1395(16),arr2395(1)),(arr1396(1),arr2395(2)),
     6  (arr1396(16),arr2396(1)),(arr1397(1),arr2396(2)),
     7  (arr1397(16),arr2397(1)),(arr1398(1),arr2397(2)),
     8  (arr1398(16),arr2398(1)),(arr1399(1),arr2398(2)),
     9  (arr1399(16),arr2399(1)),(arr1400(1),arr2399(2)),
     a  (arr1400(16),arr2400(1)),(arr1401(1),arr2400(2))
         equivalence
     1  (arr1401(16),arr2401(1)),(arr1402(1),arr2401(2)),
     2  (arr1402(16),arr2402(1)),(arr1403(1),arr2402(2)),
     3  (arr1403(16),arr2403(1)),(arr1404(1),arr2403(2)),
     4  (arr1404(16),arr2404(1)),(arr1405(1),arr2404(2)),
     5  (arr1405(16),arr2405(1)),(arr1406(1),arr2405(2)),
     6  (arr1406(16),arr2406(1)),(arr1407(1),arr2406(2)),
     7  (arr1407(16),arr2407(1)),(arr1408(1),arr2407(2)),
     8  (arr1408(16),arr2408(1)),(arr1409(1),arr2408(2)),
     9  (arr1409(16),arr2409(1)),(arr1410(1),arr2409(2)),
     a  (arr1410(16),arr2410(1)),(arr1411(1),arr2410(2))
         equivalence
     1  (arr1411(16),arr2411(1)),(arr1412(1),arr2411(2)),
     2  (arr1412(16),arr2412(1)),(arr1413(1),arr2412(2)),
     3  (arr1413(16),arr2413(1)),(arr1414(1),arr2413(2)),
     4  (arr1414(16),arr2414(1)),(arr1415(1),arr2414(2)),
     5  (arr1415(16),arr2415(1)),(arr1416(1),arr2415(2)),
     6  (arr1416(16),arr2416(1)),(arr1417(1),arr2416(2)),
     7  (arr1417(16),arr2417(1)),(arr1418(1),arr2417(2)),
     8  (arr1418(16),arr2418(1)),(arr1419(1),arr2418(2)),
     9  (arr1419(16),arr2419(1)),(arr1420(1),arr2419(2)),
     a  (arr1420(16),arr2420(1)),(arr1421(1),arr2420(2))
         equivalence
     1  (arr1421(16),arr2421(1)),(arr1422(1),arr2421(2)),
     2  (arr1422(16),arr2422(1)),(arr1423(1),arr2422(2)),
     3  (arr1423(16),arr2423(1)),(arr1424(1),arr2423(2)),
     4  (arr1424(16),arr2424(1)),(arr1425(1),arr2424(2)),
     5  (arr1425(16),arr2425(1)),(arr1426(1),arr2425(2)),
     6  (arr1426(16),arr2426(1)),(arr1427(1),arr2426(2)),
     7  (arr1427(16),arr2427(1)),(arr1428(1),arr2427(2)),
     8  (arr1428(16),arr2428(1)),(arr1429(1),arr2428(2)),
     9  (arr1429(16),arr2429(1)),(arr1430(1),arr2429(2)),
     a  (arr1430(16),arr2430(1)),(arr1431(1),arr2430(2))
         equivalence
     1  (arr1431(16),arr2431(1)),(arr1432(1),arr2431(2)),
     2  (arr1432(16),arr2432(1)),(arr1433(1),arr2432(2)),
     3  (arr1433(16),arr2433(1)),(arr1434(1),arr2433(2)),
     4  (arr1434(16),arr2434(1)),(arr1435(1),arr2434(2)),
     5  (arr1435(16),arr2435(1)),(arr1436(1),arr2435(2)),
     6  (arr1436(16),arr2436(1)),(arr1437(1),arr2436(2)),
     7  (arr1437(16),arr2437(1)),(arr1438(1),arr2437(2)),
     8  (arr1438(16),arr2438(1)),(arr1439(1),arr2438(2)),
     9  (arr1439(16),arr2439(1)),(arr1440(1),arr2439(2)),
     a  (arr1440(16),arr2440(1)),(arr1441(1),arr2440(2))
         equivalence
     1  (arr1441(16),arr2441(1)),(arr1442(1),arr2441(2)),
     2  (arr1442(16),arr2442(1)),(arr1443(1),arr2442(2)),
     3  (arr1443(16),arr2443(1)),(arr1444(1),arr2443(2)),
     4  (arr1444(16),arr2444(1)),(arr1445(1),arr2444(2)),
     5  (arr1445(16),arr2445(1)),(arr1446(1),arr2445(2)),
     6  (arr1446(16),arr2446(1)),(arr1447(1),arr2446(2)),
     7  (arr1447(16),arr2447(1)),(arr1448(1),arr2447(2)),
     8  (arr1448(16),arr2448(1)),(arr1449(1),arr2448(2)),
     9  (arr1449(16),arr2449(1)),(arr1450(1),arr2449(2)),
     a  (arr1450(16),arr2450(1)),(arr1451(1),arr2450(2))
         equivalence
     1  (arr1451(16),arr2451(1)),(arr1452(1),arr2451(2)),
     2  (arr1452(16),arr2452(1)),(arr1453(1),arr2452(2)),
     3  (arr1453(16),arr2453(1)),(arr1454(1),arr2453(2)),
     4  (arr1454(16),arr2454(1)),(arr1455(1),arr2454(2)),
     5  (arr1455(16),arr2455(1)),(arr1456(1),arr2455(2)),
     6  (arr1456(16),arr2456(1)),(arr1457(1),arr2456(2)),
     7  (arr1457(16),arr2457(1)),(arr1458(1),arr2457(2)),
     8  (arr1458(16),arr2458(1)),(arr1459(1),arr2458(2)),
     9  (arr1459(16),arr2459(1)),(arr1460(1),arr2459(2)),
     a  (arr1460(16),arr2460(1)),(arr1461(1),arr2460(2))
         equivalence
     1  (arr1461(16),arr2461(1)),(arr1462(1),arr2461(2)),
     2  (arr1462(16),arr2462(1)),(arr1463(1),arr2462(2)),
     3  (arr1463(16),arr2463(1)),(arr1464(1),arr2463(2)),
     4  (arr1464(16),arr2464(1)),(arr1465(1),arr2464(2)),
     5  (arr1465(16),arr2465(1)),(arr1466(1),arr2465(2)),
     6  (arr1466(16),arr2466(1)),(arr1467(1),arr2466(2)),
     7  (arr1467(16),arr2467(1)),(arr1468(1),arr2467(2)),
     8  (arr1468(16),arr2468(1)),(arr1469(1),arr2468(2)),
     9  (arr1469(16),arr2469(1)),(arr1470(1),arr2469(2)),
     a  (arr1470(16),arr2470(1)),(arr1471(1),arr2470(2))
         equivalence
     1  (arr1471(16),arr2471(1)),(arr1472(1),arr2471(2)),
     2  (arr1472(16),arr2472(1)),(arr1473(1),arr2472(2)),
     3  (arr1473(16),arr2473(1)),(arr1474(1),arr2473(2)),
     4  (arr1474(16),arr2474(1)),(arr1475(1),arr2474(2)),
     5  (arr1475(16),arr2475(1)),(arr1476(1),arr2475(2)),
     6  (arr1476(16),arr2476(1)),(arr1477(1),arr2476(2)),
     7  (arr1477(16),arr2477(1)),(arr1478(1),arr2477(2)),
     8  (arr1478(16),arr2478(1)),(arr1479(1),arr2478(2)),
     9  (arr1479(16),arr2479(1)),(arr1480(1),arr2479(2)),
     a  (arr1480(16),arr2480(1)),(arr1481(1),arr2480(2))
         equivalence
     1  (arr1481(16),arr2481(1)),(arr1482(1),arr2481(2)),
     2  (arr1482(16),arr2482(1)),(arr1483(1),arr2482(2)),
     3  (arr1483(16),arr2483(1)),(arr1484(1),arr2483(2)),
     4  (arr1484(16),arr2484(1)),(arr1485(1),arr2484(2)),
     5  (arr1485(16),arr2485(1)),(arr1486(1),arr2485(2)),
     6  (arr1486(16),arr2486(1)),(arr1487(1),arr2486(2)),
     7  (arr1487(16),arr2487(1)),(arr1488(1),arr2487(2)),
     8  (arr1488(16),arr2488(1)),(arr1489(1),arr2488(2)),
     9  (arr1489(16),arr2489(1)),(arr1490(1),arr2489(2)),
     a  (arr1490(16),arr2490(1)),(arr1491(1),arr2490(2))
         equivalence
     1  (arr1491(16),arr2491(1)),(arr1492(1),arr2491(2)),
     2  (arr1492(16),arr2492(1)),(arr1493(1),arr2492(2)),
     3  (arr1493(16),arr2493(1)),(arr1494(1),arr2493(2)),
     4  (arr1494(16),arr2494(1)),(arr1495(1),arr2494(2)),
     5  (arr1495(16),arr2495(1)),(arr1496(1),arr2495(2)),
     6  (arr1496(16),arr2496(1)),(arr1497(1),arr2496(2)),
     7  (arr1497(16),arr2497(1)),(arr1498(1),arr2497(2)),
     8  (arr1498(16),arr2498(1)),(arr1499(1),arr2498(2)),
     9  (arr1499(16),arr2499(1)),(arr1500(1),arr2499(2)),
     a  (arr1500(16),arr2500(1)),(arr1501(1),arr2500(2))
         equivalence
     1  (arr1501(16),arr2501(1)),(arr1502(1),arr2501(2)),
     2  (arr1502(16),arr2502(1)),(arr1503(1),arr2502(2)),
     3  (arr1503(16),arr2503(1)),(arr1504(1),arr2503(2)),
     4  (arr1504(16),arr2504(1)),(arr1505(1),arr2504(2)),
     5  (arr1505(16),arr2505(1)),(arr1506(1),arr2505(2)),
     6  (arr1506(16),arr2506(1)),(arr1507(1),arr2506(2)),
     7  (arr1507(16),arr2507(1)),(arr1508(1),arr2507(2)),
     8  (arr1508(16),arr2508(1)),(arr1509(1),arr2508(2)),
     9  (arr1509(16),arr2509(1)),(arr1510(1),arr2509(2)),
     a  (arr1510(16),arr2510(1)),(arr1511(1),arr2510(2))
         equivalence
     1  (arr1511(16),arr2511(1)),(arr1512(1),arr2511(2)),
     2  (arr1512(16),arr2512(1)),(arr1513(1),arr2512(2)),
     3  (arr1513(16),arr2513(1)),(arr1514(1),arr2513(2)),
     4  (arr1514(16),arr2514(1)),(arr1515(1),arr2514(2)),
     5  (arr1515(16),arr2515(1)),(arr1516(1),arr2515(2)),
     6  (arr1516(16),arr2516(1)),(arr1517(1),arr2516(2)),
     7  (arr1517(16),arr2517(1)),(arr1518(1),arr2517(2)),
     8  (arr1518(16),arr2518(1)),(arr1519(1),arr2518(2)),
     9  (arr1519(16),arr2519(1)),(arr1520(1),arr2519(2)),
     a  (arr1520(16),arr2520(1)),(arr1521(1),arr2520(2))
         equivalence
     1  (arr1521(16),arr2521(1)),(arr1522(1),arr2521(2)),
     2  (arr1522(16),arr2522(1)),(arr1523(1),arr2522(2)),
     3  (arr1523(16),arr2523(1)),(arr1524(1),arr2523(2)),
     4  (arr1524(16),arr2524(1)),(arr1525(1),arr2524(2)),
     5  (arr1525(16),arr2525(1)),(arr1526(1),arr2525(2)),
     6  (arr1526(16),arr2526(1)),(arr1527(1),arr2526(2)),
     7  (arr1527(16),arr2527(1)),(arr1528(1),arr2527(2)),
     8  (arr1528(16),arr2528(1)),(arr1529(1),arr2528(2)),
     9  (arr1529(16),arr2529(1)),(arr1530(1),arr2529(2)),
     a  (arr1530(16),arr2530(1)),(arr1531(1),arr2530(2))
         equivalence
     1  (arr1531(16),arr2531(1)),(arr1532(1),arr2531(2)),
     2  (arr1532(16),arr2532(1)),(arr1533(1),arr2532(2)),
     3  (arr1533(16),arr2533(1)),(arr1534(1),arr2533(2)),
     4  (arr1534(16),arr2534(1)),(arr1535(1),arr2534(2)),
     5  (arr1535(16),arr2535(1)),(arr1536(1),arr2535(2)),
     6  (arr1536(16),arr2536(1)),(arr1537(1),arr2536(2)),
     7  (arr1537(16),arr2537(1)),(arr1538(1),arr2537(2)),
     8  (arr1538(16),arr2538(1)),(arr1539(1),arr2538(2)),
     9  (arr1539(16),arr2539(1)),(arr1540(1),arr2539(2)),
     a  (arr1540(16),arr2540(1)),(arr1541(1),arr2540(2))
         equivalence
     1  (arr1541(16),arr2541(1)),(arr1542(1),arr2541(2)),
     2  (arr1542(16),arr2542(1)),(arr1543(1),arr2542(2)),
     3  (arr1543(16),arr2543(1)),(arr1544(1),arr2543(2)),
     4  (arr1544(16),arr2544(1)),(arr1545(1),arr2544(2)),
     5  (arr1545(16),arr2545(1)),(arr1546(1),arr2545(2)),
     6  (arr1546(16),arr2546(1)),(arr1547(1),arr2546(2)),
     7  (arr1547(16),arr2547(1)),(arr1548(1),arr2547(2)),
     8  (arr1548(16),arr2548(1)),(arr1549(1),arr2548(2)),
     9  (arr1549(16),arr2549(1)),(arr1550(1),arr2549(2)),
     a  (arr1550(16),arr2550(1)),(arr1551(1),arr2550(2))
         equivalence
     1  (arr1551(16),arr2551(1)),(arr1552(1),arr2551(2)),
     2  (arr1552(16),arr2552(1)),(arr1553(1),arr2552(2)),
     3  (arr1553(16),arr2553(1)),(arr1554(1),arr2553(2)),
     4  (arr1554(16),arr2554(1)),(arr1555(1),arr2554(2)),
     5  (arr1555(16),arr2555(1)),(arr1556(1),arr2555(2)),
     6  (arr1556(16),arr2556(1)),(arr1557(1),arr2556(2)),
     7  (arr1557(16),arr2557(1)),(arr1558(1),arr2557(2)),
     8  (arr1558(16),arr2558(1)),(arr1559(1),arr2558(2)),
     9  (arr1559(16),arr2559(1)),(arr1560(1),arr2559(2)),
     a  (arr1560(16),arr2560(1)),(arr1561(1),arr2560(2))
         equivalence
     1  (arr1561(16),arr2561(1)),(arr1562(1),arr2561(2)),
     2  (arr1562(16),arr2562(1)),(arr1563(1),arr2562(2)),
     3  (arr1563(16),arr2563(1)),(arr1564(1),arr2563(2)),
     4  (arr1564(16),arr2564(1)),(arr1565(1),arr2564(2)),
     5  (arr1565(16),arr2565(1)),(arr1566(1),arr2565(2)),
     6  (arr1566(16),arr2566(1)),(arr1567(1),arr2566(2)),
     7  (arr1567(16),arr2567(1)),(arr1568(1),arr2567(2)),
     8  (arr1568(16),arr2568(1)),(arr1569(1),arr2568(2)),
     9  (arr1569(16),arr2569(1)),(arr1570(1),arr2569(2)),
     a  (arr1570(16),arr2570(1)),(arr1571(1),arr2570(2))
         equivalence
     1  (arr1571(16),arr2571(1)),(arr1572(1),arr2571(2)),
     2  (arr1572(16),arr2572(1)),(arr1573(1),arr2572(2)),
     3  (arr1573(16),arr2573(1)),(arr1574(1),arr2573(2)),
     4  (arr1574(16),arr2574(1)),(arr1575(1),arr2574(2)),
     5  (arr1575(16),arr2575(1)),(arr1576(1),arr2575(2)),
     6  (arr1576(16),arr2576(1)),(arr1577(1),arr2576(2)),
     7  (arr1577(16),arr2577(1)),(arr1578(1),arr2577(2)),
     8  (arr1578(16),arr2578(1)),(arr1579(1),arr2578(2)),
     9  (arr1579(16),arr2579(1)),(arr1580(1),arr2579(2)),
     a  (arr1580(16),arr2580(1)),(arr1581(1),arr2580(2))
         equivalence
     1  (arr1581(16),arr2581(1)),(arr1582(1),arr2581(2)),
     2  (arr1582(16),arr2582(1)),(arr1583(1),arr2582(2)),
     3  (arr1583(16),arr2583(1)),(arr1584(1),arr2583(2)),
     4  (arr1584(16),arr2584(1)),(arr1585(1),arr2584(2)),
     5  (arr1585(16),arr2585(1)),(arr1586(1),arr2585(2)),
     6  (arr1586(16),arr2586(1)),(arr1587(1),arr2586(2)),
     7  (arr1587(16),arr2587(1)),(arr1588(1),arr2587(2)),
     8  (arr1588(16),arr2588(1)),(arr1589(1),arr2588(2)),
     9  (arr1589(16),arr2589(1)),(arr1590(1),arr2589(2)),
     a  (arr1590(16),arr2590(1)),(arr1591(1),arr2590(2))
         equivalence
     1  (arr1591(16),arr2591(1)),(arr1592(1),arr2591(2)),
     2  (arr1592(16),arr2592(1)),(arr1593(1),arr2592(2)),
     3  (arr1593(16),arr2593(1)),(arr1594(1),arr2593(2)),
     4  (arr1594(16),arr2594(1)),(arr1595(1),arr2594(2)),
     5  (arr1595(16),arr2595(1)),(arr1596(1),arr2595(2)),
     6  (arr1596(16),arr2596(1)),(arr1597(1),arr2596(2)),
     7  (arr1597(16),arr2597(1)),(arr1598(1),arr2597(2)),
     8  (arr1598(16),arr2598(1)),(arr1599(1),arr2598(2)),
     9  (arr1599(16),arr2599(1)),(arr1600(1),arr2599(2)),
     a  (arr1600(16),arr2600(1)),(arr1601(1),arr2600(2))
         equivalence
     1  (arr1601(16),arr2601(1)),(arr1602(1),arr2601(2)),
     2  (arr1602(16),arr2602(1)),(arr1603(1),arr2602(2)),
     3  (arr1603(16),arr2603(1)),(arr1604(1),arr2603(2)),
     4  (arr1604(16),arr2604(1)),(arr1605(1),arr2604(2)),
     5  (arr1605(16),arr2605(1)),(arr1606(1),arr2605(2)),
     6  (arr1606(16),arr2606(1)),(arr1607(1),arr2606(2)),
     7  (arr1607(16),arr2607(1)),(arr1608(1),arr2607(2)),
     8  (arr1608(16),arr2608(1)),(arr1609(1),arr2608(2)),
     9  (arr1609(16),arr2609(1)),(arr1610(1),arr2609(2)),
     a  (arr1610(16),arr2610(1)),(arr1611(1),arr2610(2))
         equivalence
     1  (arr1611(16),arr2611(1)),(arr1612(1),arr2611(2)),
     2  (arr1612(16),arr2612(1)),(arr1613(1),arr2612(2)),
     3  (arr1613(16),arr2613(1)),(arr1614(1),arr2613(2)),
     4  (arr1614(16),arr2614(1)),(arr1615(1),arr2614(2)),
     5  (arr1615(16),arr2615(1)),(arr1616(1),arr2615(2)),
     6  (arr1616(16),arr2616(1)),(arr1617(1),arr2616(2)),
     7  (arr1617(16),arr2617(1)),(arr1618(1),arr2617(2)),
     8  (arr1618(16),arr2618(1)),(arr1619(1),arr2618(2)),
     9  (arr1619(16),arr2619(1)),(arr1620(1),arr2619(2)),
     a  (arr1620(16),arr2620(1)),(arr1621(1),arr2620(2))
         equivalence
     1  (arr1621(16),arr2621(1)),(arr1622(1),arr2621(2)),
     2  (arr1622(16),arr2622(1)),(arr1623(1),arr2622(2)),
     3  (arr1623(16),arr2623(1)),(arr1624(1),arr2623(2)),
     4  (arr1624(16),arr2624(1)),(arr1625(1),arr2624(2))
c
c
c
        data iimap/1,985,1905,2763,3561,4301,4985,5615,6193,6721,7201,
     1           7635,8025,8373,8681,8951,9185,9385,9553,9691,9801,9885,
     2           9945,9983/
         data arr1001/
     1      0.1000000000000000d+01,-.4330127018922193d+00,
     2      0.1875000000000000d+00,-.8118988160479112d-01,
     3      0.3515625000000000d-01,-.1522310280089832d-01,
     4      0.6591796874999978d-02,-.2854331775168339d-02,
     5      0.1235961914062310d-02,-.5351872078431952d-03,
     6      0.2317428588852547d-03,-.1003476014652838d-03,
     7      0.4345178603254920d-04,-.1881517524208157d-04,
     8      0.8147209832259027d-05,-.3527845192465170d-05/
         data arr1002/
     1      0.1527601603379771d-05,-.6614701550942228d-06,
     2      0.2864241560002954d-06,-.1240221240427574d-06,
     3      0.5369971996959152d-07,-.2323952636859758d-07,
     4      0.1004935065424761d-07,-.4303628620790271d-08,
     5      0.1815690510011265d-08,-.6292127779144307d-09,
     6      0.1595853919305334d-09,0.2500238266868428d-09,
     7      -.4675897859496042d-10,0.1581164098481232d-09,
     8      0.1310778133911147d-08,-.1939787438403172d-08/
         data arr1003/
     1      0.5801701964340984d-08,-.6651217647089324d-08,
     2      0.1303290246541533d-07,-.1250106904819787d-07,
     3      0.1977619189123770d-07,-.1365884885210617d-07,
     4      0.1915962437590727d-07,-.9921249025057760d-08,
     5      0.1247623435429684d-07,0.4271090928257129d-19,
     6      0.1000000000000000d+01,-.8660254037844386d+00,
     7      0.5625000000000000d+00,-.3247595264191645d+00,
     8      0.1757812500000000d+00,-.9133861680539003d-01/
         data arr1004/
     1      0.4614257812500007d-01,-.2283465420134766d-01,
     2      0.1112365722656314d-01,-.5351872078441995d-02,
     3      0.2549171447757951d-02,-.1204171217656230d-02,
     4      0.5648732185610520d-03,-.2634124539014343d-03,
     5      0.1222081483680907d-03,-.5644552602979932d-04,
     6      0.2596923212929582d-04,-.1190647906990917d-04,
     7      0.5442084348501221d-05,-.2480520376254267d-05,
     8      0.1127811222315034d-05,-.5116230530485692d-06/
         data arr1005/
     1      0.2316443724397684d-06,-.1047070554499356d-06,
     2      0.4735072624169365d-07,-.2145706842349782d-07,
     3      0.9998310608900375d-08,-.4793799454927373d-08,
     4      0.2897382766746761d-08,-.1600244228845887d-08,
     5      0.1616090353139175d-08,-.6934039767086690d-10,
     6      0.3979159656534848d-09,0.2803679600575556d-08,
     7      -.2303353565832897d-08,0.7019228253203408d-08,
     8      -.4192597089102544d-08,0.8558308978370356d-08/
         data arr1006/
     1      -.4265963630644315d-08,0.6805311910759604d-08,
     2      -.4213447548776900d-18,0.2605802963717460d-17,
     3      0.1000000000000000d+01,-.1299038105676658d+01,
     4      0.1125000000000000d+01,-.8118988160479113d+00,
     5      0.5273437500000002d+00,-.3196851588188659d+00,
     6      0.1845703125000016d+00,-.1027559439060713d+00,
     7      0.5561828613282487d-01,-.2943529643147102d-01,
     8      0.1529502868659703d-01,-.7827112915005568d-02/
         data arr1007/
     1      0.3954112530181164d-02,-.1975593405412482d-02,
     2      0.9776651880370946d-03,-.4797869767487525d-03,
     3      0.2337230935760135d-03,-.1131115732781540d-03,
     4      0.5442085851704675d-04,-.2604555071165412d-04,
     5      0.1240596921573941d-04,-.5883954769335327d-05,
     6      0.2779831672325341d-05,-.1309678733480420d-05,
     7      0.6152455305955931d-06,-.2903292943117269d-06,
     8      0.1346089674741039d-06,-.6348323641863447d-07/
         data arr1008/
     1      0.1713735148407835d-07,0.4206157564460333d-08,
     2      -.4491773518219503d-07,0.5599259427081952d-07,
     3      -.1124747648421011d-06,0.1087900548493117d-06,
     4      -.1712143381978425d-06,0.1186769006475917d-06,
     5      -.1652778747652329d-06,0.8568549440435554d-07,
     6      -.1070354110867002d-06,-.1302312553946815d-17,
     7      0.6992194082377380d-17,-.8299344291778258d-17,
     8      0.1000000000000000d+01,-.1732050807568877d+01/
         data arr1009/
     1      0.1875000000000000d+01,-.1623797632095822d+01,
     2      0.1230468749999998d+01,-.8524937568503021d+00,
     3      0.5537109374999803d+00,-.3425198130201767d+00,
     4      0.2039337158201886d+00,-.1177411857254829d+00,
     5      0.6627845764084574d-01,-.3652652693411610d-01,
     6      0.1977056264488284d-01,-.1053649814824624d-01,
     7      0.5540102701027576d-02,-.2878721787699802d-02,
     8      0.1480246111469688d-02,-.7540768212752337d-03/
         data arr1010/
     1      0.3809453626129186d-03,-.1909992469687844d-03,
     2      0.9510981249249849d-04,-.4706595651568008d-04,
     3      0.2315560723554525d-04,-.1133061184696583d-04,
     4      0.5509120160312496d-05,-.2663043650272800d-05,
     5      0.1263927013460296d-05,-.6001837194253466d-06,
     6      0.2613137073620100d-06,-.1469903766702637d-06,
     7      0.5965754059064180d-07,-.1217456591990669d-06,
     8      0.8893971948079664d-07,-.2259726480352508d-06/
         data arr1011/
     1      0.1345860812218370d-06,-.2669077071763413d-06,
     2      0.1330646137789804d-06,-.2104104794094562d-06,
     3      -.6416791687261118d-17,0.3835609184090864d-16,
     4      -.4399717678274046d-16,0.3964928031435818d-16,
     5      0.1000000000000000d+01,-.2165063509461098d+01,
     6      0.2812500000000003d+01,-.2841645856167702d+01,
     7      0.2460937500000024d+01,-.1918110952913301d+01,
     8      0.1384277343750185d+01,-.9419294858062679d+00/
         data arr1012/
     1      0.6118011474620429d+00,-.3826588536127124d+00,
     2      0.2319746017520063d+00,-.1369744760290144d+00,
     3      0.7908225062678986d-01,-.4478011726238851d-01,
     4      0.2493046239243111d-01,-.1367392909238224d-01,
     5      0.7401231617561932d-02,-.3958905882330620d-02,
     6      0.2095203996404573d-02,-.1098255667631029d-02,
     7      0.5706759290765908d-03,-.2941974307243179d-03,
     8      0.1505667018081696d-03,-.7657617239742140d-04/
         data arr1013/
     1      0.3868137558275022d-04,-.1945933903238966d-04,
     2      0.9579490623345412d-05,-.4645194440384177d-05,
     3      0.1768062774028666d-05,-.4791823319195392d-06,
     4      -.8687654078856750d-06,0.1092436847284418d-05,
     5      -.2119126238121995d-05,0.1474379092553117d-05,
     6      -.2197521869472395d-05,0.1136238734035941d-05,
     7      -.1478748576345156d-05,0.2616052956421937d-16,
     8      -.1396523817390015d-15,0.1661933976416485d-15/
         data arr1014/
     1      -.1285228062513258d-15,-.5949887444398757d-15,
     2      0.1000000000000005d+01,-.2598076211353327d+01,
     3      0.3937500000000045d+01,-.4546633369868397d+01,
     4      0.4429687500000394d+01,-.3836221905827099d+01,
     5      0.3045410156252473d+01,-.2260630765937718d+01,
     6      0.1590682983413523d+01,-.1071444790128765d+01,
     7      0.6959238053144975d+00,-.4383183233483214d+00,
     8      0.2688796524073096d+00,-.1612084223542226d+00/
         data arr1015/
     1      0.9473575819616425d-01,-.5469571704035200d-01,
     2      0.3108517708728050d-01,-.1741918761500039d-01,
     3      0.9637952580142760d-02,-.5271630090743607d-02,
     4      0.2853424782547733d-02,-.1529826248587710d-02,
     5      0.8131910570129876d-03,-.4288353099619236d-03,
     6      0.2248093322170923d-03,-.1169549097450101d-03,
     7      0.6089426709301092d-04,-.3079348238131203d-04,
     8      0.1592333487878202d-04,-.6228678921341807d-05/
         data arr1016/
     1      0.2567601662308201d-05,0.2323846896082050d-05,
     2      -.1630442307538338d-05,0.4798893373306288d-05,
     3      -.2440302999831271d-05,0.4097735833657650d-05,
     4      0.4901073926516168d-16,-.3381443985432976d-15,
     5      0.3714161262864478d-15,-.3918451147635069d-15,
     6      -.1247028985708828d-14,0.1212133218274800d-13,
     7      0.9999999999999768d+00,-.3031088913245426d+01,
     8      0.5249999999999805d+01,-.6819950054801462d+01/
         data arr1017/
     1      0.7382812499998483d+01,-.7033073494008966d+01,
     2      0.6090820312491043d+01,-.4898033326151575d+01,
     3      0.3711593627877625d+01,-.2678611975069994d+01,
     4      0.1855796813708808d+01,-.1241901914861552d+01,
     5      0.8066389548472833d+00,-.5104933315277677d+00,
     6      0.3157858499178745d+00,-.1914349840321731d+00,
     7      0.1139789363759485d+00,-.6677345185503950d-01,
     8      0.3855163305600859d-01,-.2196476944285366d-01/
         data arr1018/
     1      0.1236426716342838d-01,-.6883285885567264d-02,
     2      0.3793732118250815d-02,-.2071409839536832d-02,
     3      0.1123411177062836d-02,-.6054320289217968d-03,
     4      0.3295301045427677d-03,-.1799219296927016d-03,
     5      0.1076457355641521d-03,-.6430394156631394d-04,
     6      0.5072070424897292d-04,-.3074121741047736d-04,
     7      0.3099891988013010d-04,-.1553505411374230d-04,
     8      0.1671095242098658d-04,-.1173433551203329d-15/
         data arr1019/
     1      0.7680446630896311d-15,-.8455417312722075d-15,
     2      0.8611528975403520d-15,0.2891017004355681d-14,
     3      -.2716696648276593d-13,0.5356244624250317d-13,
     4      0.9999999999997527d+00,-.3464101615137301d+01,
     5      0.6749999999997760d+01,-.9742785792571427d+01,
     6      0.1160156249998625d+02,-.1205669741829067d+02,
     7      0.1131152343741525d+02,-.9796066652257357d+01,
     8      0.7953414916561923d+01,-.6122541657140642d+01/
         data arr1020/
     1      0.4506935117495506d+01,-.3193462066362633d+01,
     2      0.2189448585827336d+01,-.1458552375395960d+01,
     3      0.9473575269122990d+00,-.6016528115249838d+00,
     4      0.3745021465131903d+00,-.2289375871411599d+00,
     5      0.1376841738929310d+00,-.8158360838897537d-01,
     6      0.4769001952608493d-01,-.2753333339383157d-01,
     7      0.1571351035323082d-01,-.8875290559614174d-02,
     8      0.4961605584651208d-02,-.2754766239670553d-02/
         data arr1021/
     1      0.1512944718598667d-02,-.8384880526966684d-03,
     2      0.4555747387060531d-03,-.2678227151405132d-03,
     3      0.1398951545634793d-03,-.9774152911779069d-04,
     4      0.4397743211072031d-04,-.3871576728151666d-04,
     5      -.1394061632635702d-14,0.7531172582142457d-14,
     6      -.9068667564639635d-14,0.6935790251896358d-14,
     7      0.3217854611823034d-13,-.2492628702599031d-12,
     8      0.5905915608839476d-12,-.2419979142378256d-11/
         data arr1022/
     1      0.1000000000005082d+01,-.3897114317051223d+01,
     2      0.8437500000038909d+01,-.1339633046492394d+02,
     3      0.1740234375023304d+02,-.1959213330556983d+02,
     4      0.1979516601697160d+02,-.1836762497739632d+02,
     5      0.1590682984067663d+02,-.1301040104338146d+02,
     6      0.1014060405108490d+02,-.7584472504807564d+01,
     7      0.5473621623064126d+01,-.3828700392482905d+01,
     8      0.2605233850817229d+01,-.1729753373006652d+01/
         data arr1023/
     1      0.1123508824411196d+01,-.7154351785169837d+00,
     2      0.4474805814141049d+00,-.2753568101120367d+00,
     3      0.1669247889487559d+00,-.9981842991087634d-01,
     4      0.5890958426981212d-01,-.3434974572495073d-01,
     5      0.1972322193045493d-01,-.1117975642092500d-01,
     6      0.6108339409769775d-02,-.3271951421793916d-02,
     7      0.1505356703089040d-02,-.7057787602191562d-03,
     8      0.9261726075847016d-04,0.3491747922896560d-05/
         data arr1024/
     1      -.1869381425074577d-03,0.1736788887337646d-14,
     2      -.3732159277139839d-14,0.7919314450330346d-14,
     3      0.3363463200650293d-14,-.3286865629212062d-13,
     4      0.4876777177105181d-13,-.5805044490221471d-12,
     5      0.1184259657091204d-11,-.5274014191268664d-11,
     6      0.1000000000007415d+01,-.4330127018961175d+01,
     7      0.1031250000006007d+02,-.1786177395329544d+02,
     8      0.2513671875032544d+02,-.3047665180877218d+02/
         data arr1025/
     1      0.3299194336129891d+02,-.3265355551491651d+02,
     2      0.3004623414000651d+02,-.2602080207857202d+02,
     3      0.2140794186255763d+02,-.1685438328684921d+02,
     4      0.1277178365559709d+02,-.9359045067804235d+01,
     5      0.6657819201103466d+01,-.4612674086339439d+01,
     6      0.3120855108267960d+01,-.2066806416677300d+01,
     7      0.1342433414107980d+01,-.8566509065947363d+00,
     8      0.5378623987563195d+00,-.3327258578517699d+00/
         data arr1026/
     1      0.2029727668533950d+00,-.1222468758003793d+00,
     2      0.7262269889130349d-01,-.4263085097466976d-01,
     3      0.2449810775741896d-01,-.1387931600268878d-01,
     4      0.7394576458067917d-02,-.3904238301579892d-02,
     5      0.1658314155834503d-02,-.7129665154115370d-03,
     6      0.7095522168464018d-13,-.4512963547473165d-12,
     7      0.4985499020416174d-12,-.4997946305402826d-12,
     8      -.1716416008195856d-11,0.1585038533819910d-10/
         data arr1027/
     1      -.3175388204644732d-10,0.1451592310812007d-09,
     2      -.2702288929095630d-09,0.1311467439551169d-08,
     3      0.9999999979158864d+00,-.4763139712746309d+01,
     4      0.1237499998760332d+02,-.2322030608925143d+02,
     5      0.3519140617813361d+02,-.4571497745825715d+02,
     6      0.5278710901959812d+02,-.5551104310945439d+02,
     7      0.5408321973870390d+02,-.4943951845709007d+02,
     8      0.4281587646807906d+02,-.3539418205285886d+02/
         data arr1028/
     1      0.2809789472357561d+02,-.2152571903250687d+02,
     2      0.1597866081469586d+02,-.1153139918131711d+02,
     3      0.8113920727227548d+01,-.5579687151463873d+01,
     4      0.3758423865673553d+01,-.2483399445556514d+01,
     5      0.1614382199413238d+01,-.1032128886178813d+01,
     6      0.6548842438095717d+00,-.4083062908339804d+00,
     7      0.2603193649538048d+00,-.1600744700798643d+00,
     8      0.1100424659643638d+00,-.6317698900464709d-01/
         data arr1029/
     1      0.5029285371683049d-01,-.2370716505840037d-01,
     2      0.2196399546925992d-01,-.1379210533141507d-12,
     3      0.9474789727527786d-12,-.9872246347537694d-12,
     4      0.1142116214778398d-11,0.3366023722284442d-11,
     5      -.3417582762168941d-10,0.6245520950446139d-10,
     6      -.3045362268917726d-09,0.5304080009961258d-09,
     7      -.2791370437535934d-08,0.4099017605056772d-08,
     8      0.9999999829879148d+00,-.5196152398352700d+01/
         data arr1030/
     1      0.1462499989458385d+02,-.2955311676279134d+02,
     2      0.4798828071666906d+02,-.6649451233565228d+02,
     3      0.8158007547310348d+02,-.9083625107426789d+02,
     4      0.9341646195030724d+02,-.8989002932678420d+02,
     5      0.8173936665823225d+02,-.7078835227008959d+02,
     6      0.5875002889519623d+02,-.4696518115352582d+02,
     7      0.3631476169370959d+02,-.2725600856199626d+02,
     8      0.1991488953078676d+02,-.1420272573460603d+02/
         data arr1031/
     1      0.9905014035565136d+01,-.6771726262232294d+01,
     2      0.4539068912668074d+01,-.2996806884569507d+01,
     3      0.1936414983482676d+01,-.1246312818479956d+01,
     4      0.7727140624467661d+00,-.4948702823248450d+00,
     5      0.2794550554795027d+00,-.1847360915845727d+00,
     6      0.8348091035777107d-01,-.6030773863864550d-01,
     7      0.2687119492131906d-12,-.2521212878155108d-11,
     8      0.2276690772375207d-11,-.3718775468600059d-11/
         data arr1032/
     1      -.7279823143158786d-11,0.9814895393327462d-10,
     2      -.1375537371854945d-09,0.8109391308843789d-09,
     3      -.1142036764353693d-08,0.7729282952916856d-08,
     4      -.8967755578318213d-08,0.4585273606630397d-07,
     5      0.9999999474535110d+00,-.5629164836378660d+01,
     6      0.1706249969272212d+02,-.3694139469495126d+02,
     7      0.6398437349563961d+02,-.9420055295604228d+02,
     8      0.1223701099768422d+03,-.1438240389277880d+03/
         data arr1033/
     1      0.1556940921046436d+03,-.1573074488605568d+03,
     2      0.1498554707466571d+03,-.1356773223525674d+03,
     3      0.1174999703852568d+03,-.9784293850066985d+02,
     4      0.7868178845648857d+02,-.6132253735211671d+02,
     5      0.4646755451507090d+02,-.3431290370432291d+02,
     6      0.2476044696139391d+02,-.1746689542437001d+02,
     7      0.1209644479880512d+02,-.8175499576430882d+01,
     8      0.5465961071185665d+01,-.3510949344131582d+01/
         data arr1034/
     1      0.2279139214724460d+01,-.1317976228537945d+01,
     2      0.8374859093688649d+00,-.3796786991263148d+00,
     3      0.2399153305997985d+00,-.8958717179119581d-12,
     4      0.1059370511000077d-10,-.8991350596506678d-11,
     5      0.1702996244462379d-10,0.2723469862993246d-10,
     6      -.4283903317199107d-09,0.5226802364394195d-09,
     7      -.3412419521850788d-08,0.4244372510957661d-08,
     8      -.3314064426782108d-07,0.3382492153764138d-07/
         data arr1035/
     1      -.1939529878085038d-06,0.1954634124205762d-06,
     2      0.9999987727651000d+00,-.6062176675921204d+01,
     3      0.1968749394019120d+02,-.4546632812238938d+02,
     4      0.8367184463757526d+02,-.1304315180157484d+03,
     5      0.1788485044523646d+03,-.2212676880448075d+03,
     6      0.2515053561980401d+03,-.2662123726036370d+03,
     7      0.2651272022317834d+03,-.2504804739830538d+03,
     8      0.2259556338180180d+03,-.1956837150747661d+03/
         data arr1036/
     1      0.1633989512472428d+03,-.1320740481783797d+03,
     2      0.1036109544619346d+03,-.7917261054029779d+02,
     3      0.5893447615384492d+02,-.4297676664764163d+02,
     4      0.3046297668602483d+02,-.2135165548373675d+02,
     5      0.1428871132478023d+02,-.9679374338800031d+01,
     6      0.5773465264161470d+01,-.3799568485670321d+01,
     7      0.1758041317155946d+01,-.1128251828267670d+01,
     8      -.1019955937580151d-11,-.1879035210693228d-10/
         data arr1037/
     1      0.7640249846766002d-11,-.4739645857413102d-10,
     2      -.6262375180292546d-11,0.9467562685261921d-09,
     3      -.2164031023952041d-09,0.6083320849080825d-08,
     4      -.7094967875201968d-09,0.6657963627502756d-07,
     5      -.1141173990160779d-07,0.3591346528993497d-06,
     6      -.3586267448724496d-07,0.2372876133938186d-05,
     7      0.9999996989328241d+00,-.6495179390513765d+01,
     8      0.2249999915515454d+02,-.5520906277089293d+02/
         data arr1038/
     1      0.1075781201881377d+03,-.1770140098562784d+03,
     2      0.2554980379797899d+03,-.3319007445869155d+03,
     3      0.3952235081535867d+03,-.4373463623016852d+03,
     4      0.4545070674100827d+03,-.4472775046829841d+03,
     5      0.4196407984437260d+03,-.3773535565086004d+03,
     6      0.3267953729495854d+03,-.2734110979306531d+03,
     7      0.2219070081828410d+03,-.1747314997706198d+03,
     8      0.1342351075849596d+03,-.9979859822235546d+02/
         data arr1039/
     1      0.7290477390615379d+02,-.5061215969905161d+02,
     2      0.3505482172039134d+02,-.2143963788571862d+02,
     3      0.1394511316939877d+02,-.6516754829137877d+01,
     4      0.3851634583572666d+01,-.6729395638398849d-11,
     5      0.1411833130579016d-09,-.1084346238409169d-09,
     6      0.2570693601859011d-09,0.2917170978412768d-09,
     7      -.6060025913201091d-08,0.5803543351684871d-08,
     8      -.4561289128030660d-07,0.4467106762319319d-07/
         data arr1040/
     1      -.4561955868505107d-06,0.3689088300865859d-06,
     2      -.2613041735342707d-05,0.2060472658835210d-05,
     3      -.1670434030567965d-04,0.1232226804098659d-04,
     4      0.9999186428762078d+00,-.6928145013423554d+01,
     5      0.2549959111196052d+02,-.6625066250348804d+02,
     6      0.1362639175156030d+03,-.2360178481660782d+03,
     7      0.3576901774875347d+03,-.4867845885459376d+03,
     8      0.6059842474374804d+03,-.6997436833454102d+03/
         data arr1041/
     1      0.7574246901627103d+03,-.7752480145991848d+03,
     2      0.7550965248418379d+03,-.7043081727683959d+03,
     3      0.6310878279391173d+03,-.5466382587868108d+03,
     4      0.4569662085277389d+03,-.3724724405199013d+03,
     5      0.2917551536138137d+03,-.2258339108859331d+03,
     6      0.1640355618456656d+03,-.1211466354418653d+03,
     7      0.7651298275228230d+02,-.5402950019518587d+02,
     8      0.2590661769617575d+02,-.1733840750571883d+02/
         data arr1042/
     1      -.1626733499476157d-10,-.2551208265198567d-09,
     2      0.1139716789136350d-09,-.6449429756483852d-09,
     3      -.8996045358226896d-10,0.1295074093711870d-07,
     4      -.3166301064663089d-08,0.8287873519294270d-07,
     5      -.9258689085430775d-08,0.9076160604611471d-06,
     6      -.1621672995765733d-06,0.4883304590481718d-05,
     7      -.4619051860853711d-06,0.3225199921988338d-04,
     8      -.4071810637678666d-05,0.1509619815310660d-03/
         data arr1043/
     1      0.9999901321683423d+00,-.7360448259315982d+01,
     2      0.2868744246156043d+02,-.7866990105750849d+02,
     3      0.1703319741784402d+03,-.3097620927977138d+03,
     4      0.4918335945538164d+03,-.6997157120766220d+03,
     5      0.9090157095404138d+03,-.1093215893001622d+04,
     6      0.1230915234126305d+04,-.1307697086340602d+04,
     7      0.1321313857869324d+04,-.1274117485749604d+04,
     8      0.1181510603704563d+04,-.1050961248961642d+04/
         data arr1044/
     1      0.9071318162228504d+03,-.7473437016432757d+03,
     2      0.6048286509380961d+03,-.4559841272875860d+03,
     3      0.3457945987168721d+03,-.2237906668068300d+03,
     4      0.1582338841146890d+03,-.7675692326763199d+02,
     5      0.4919392884545222d+02,-.9318049580938243d-10,
     6      0.1654376049081666d-08,-.1364228209939029d-08,
     7      0.2878859914742674d-08,0.3766805546819702d-08,
     8      -.6977751061099344d-07,0.7428206801704079d-07/
         data arr1045/
     1      -.5350089894458307d-06,0.5768118874284299d-06,
     2      -.5293209462526500d-05,0.4729478537486732d-05,
     3      -.3051823154109661d-04,0.2655525061541317d-04,
     4      -.1942679378811082d-03,0.1582153393163897d-03,
     5      -.9495282440673428d-03,0.7499858267211702d-03,
     6      0.9952381175300866d+00,-.7790617877667471d+01,
     7      0.3204256552078613d+02,-.9254180427896102d+02,
     8      0.2103275078681859d+03,-.4008263833106860d+03/
         data arr1046/
     1      0.6651278648232362d+03,-.9876927634790288d+03,
     2      0.1335768676022044d+04,-.1671530041444289d+04,
     3      0.1951970720702761d+04,-.2152687210961588d+04,
     4      0.2245638863866910d+04,-.2245912430263846d+04,
     5      0.2135466093893293d+04,-.1974300801811843d+04,
     6      0.1720005908166247d+04,-.1489566395731578d+04,
     7      0.1176036986555632d+04,-.9613293091949083d+03,
     8      0.6399857363705854d+03,-.4967127514067548d+03/
         data arr1047/
     1      0.2462240823142151d+03,-.1803035963020888d+03,
     2      0.8006960515733318d-09,-.7640870143827490d-08,
     3      0.7415251876278082d-08,-.1090916891381302d-07,
     4      -.2320594077818286d-07,0.2960210222298745d-06,
     5      -.4407443521775453d-06,0.2465696232405267d-05,
     6      -.3610427080743025d-05,0.2335334233348885d-04,
     7      -.2855072880879579d-04,0.1388299694894395d-03,
     8      -.1658179992184443d-03,0.8699430005188920d-03/
         data arr1048/
     1      -.9719084915291703d-03,0.4332468342892219d-02,
     2      -.4723439105529327d-02,0.2160500933194230d-01,
     3      0.9773778635795699d+00,-.8135346227519127d+01,
     4      0.3553096005754868d+02,-.1076014006937215d+03,
     5      0.2567896330587996d+03,-.5108611694011395d+03,
     6      0.8858920182024527d+03,-.1367329018956533d+04,
     7      0.1926642616772323d+04,-.2494801712469688d+04,
     8      0.3030823024035602d+04,-.3437738426322051d+04/
         data arr1049/
     1      0.3737057218466001d+04,-.3808511106613066d+04,
     2      0.3801923932622272d+04,-.3502867519208217d+04,
     3      0.3276723645287902d+04,-.2703861838683358d+04,
     4      0.2406537380786540d+04,-.1637810307244539d+04,
     5      0.1404947224205924d+04,-.7078301618437139d+03,
     6      0.5873783333161414d+03,-.2062848540595446d-08,
     7      0.1868063688631019d-07,-.1850259659403018d-07,
     8      0.2594811981889213d-07,0.5852300156965499d-07/
         data arr1050/
     1      -.7160186425935567d-06,0.1108096553591408d-05,
     2      -.6027473006002885d-05,0.9114631135947846d-05,
     3      -.5677291351488363d-04,0.7187322327495633d-04,
     4      -.3387918255656640d-03,0.4185011043419295d-03,
     5      -.2118652677584583d-02,0.2449772722168373d-02,
     6      -.1057520468054250d-01,0.1192766633331765d-01,
     7      -.5269485646283652d-01,0.5709909419135857d-01,
     8      0.7754523317624738d+00,-.8422499979278509d+01/
         data arr1051/
     1      0.3844374653786470d+02,-.1240757939594725d+03,
     2      0.3079277628041474d+03,-.6436432911373223d+03,
     3      0.1155662656008989d+04,-.1866117642847370d+04,
     4      0.2708431746105094d+04,-.3663348512565146d+04,
     5      0.4542777571325450d+04,-.5395186412142003d+04,
     6      0.5898444317909926d+04,-.6343771324980995d+04,
     7      0.6157365778127026d+04,-.6137773759131859d+04,
     8      0.5251195954826048d+04,-.4934008974094836d+04/
         data arr1052/
     1      0.3417114830494123d+04,-.3072351948162294d+04,
     2      0.1563501569381499d+04,-.1351308984298682d+04,
     3      0.7283847891479067d-08,-.5582915516760915d-07,
     4      0.5852313900396886d-07,-.7044879697063800d-07,
     5      -.1921060569292451d-06,0.2061174743728081d-05,
     6      -.3599767468048483d-05,0.1799580790470813d-04,
     7      -.3005246557177476d-04,0.1663949901942054d-03,
     8      -.2346539743778837d-03,0.1006160680345639d-02/
         data arr1053/
     1      -.1379092073268129d-02,0.6250482186322450d-02,
     2      -.8037498481752378d-02,0.3144983514749953d-01,
     3      -.3939914488532362d-01,0.1563512213944832d+00,
     4      -.1883594240033079d+00,0.6707440602979292d+00,
     5      0.2107769429630220d+00,-.6310789437947054d+01,
     6      0.4013422762453621d+02,-.1336122533080721d+03,
     7      0.3622290288415969d+03,-.7737154751587708d+03,
     8      0.1481036475749644d+04,-.2433725767680056d+04/
         data arr1054/
     1      0.3749631971395294d+04,-.5107257211963235d+04,
     2      0.6771180636696555d+04,-.7971105899271282d+04,
     3      0.9472504119505923d+04,-.9705432167739013d+04,
     4      0.1065062668699320d+05,-.9471996216119400d+04,
     5      0.9793150071658775d+04,-.6868145677773506d+04,
     6      0.6806192636026304d+04,-.3497083710137606d+04,
     7      0.3336047407350796d+04,-.1432640884388185d-07,
     8      0.1048192265914120d-06,-.1118433216363432d-06/
         data arr1055/
     1      0.1280605489997731d-06,0.3709066913777794d-06,
     2      -.3823630138084007d-05,0.6930596040369314d-05,
     3      -.3377795496187703d-04,0.5808940989270916d-04,
     4      -.3104804171086728d-03,0.4523737482979916d-03,
     5      -.1885331433948869d-02,0.2665235777717903d-02,
     6      -.1168717495801868d-01,0.1551498863851702d-01,
     7      -.5895348527860640d-01,0.7618871048412741d-01,
     8      -.2928639280515236d+00,0.3641089014413969d+00/
         data arr1056/
     1      -.1259003902254004d+01,0.1528091847413013d+01,
     2      -.4223017837898243d+01,-.3371280939457811d+01,
     3      0.2829551211646151d+02,-.1422594718899378d+03,
     4      0.3780183946266712d+03,-.9267542169180711d+03,
     5      0.1747792200585721d+04,-.3162934881404350d+04,
     6      0.4740572992795539d+04,-.7099069494335413d+04,
     7      0.8959889886206782d+04,-.1173729106770270d+05,
     8      0.1258582299484150d+05,-.1497612036624447d+05/
         data arr1057/
     1      0.1371120207294377d+05,-.1516738264602748d+05,
     2      0.1072989302318000d+05,-.1126868808502205d+05,
     3      0.5824669297253578d+04,-.5833667139236608d+04,
     4      0.2877623192059029d-07,-.1964418281560965d-06,
     5      0.2149765678939962d-06,-.2278876164585490d-06,
     6      -.7243206027269102d-06,0.7030930597593662d-05,
     7      -.1347597449369515d-04,0.6327039428298549d-04,
     8      -.1136495781290294d-03,0.5762575531393681d-03/
         data arr1058/
     1      -.8814570026931916d-03,0.3522411574393600d-02,
     2      -.5213296701457817d-02,0.2176404412416904d-01,
     3      -.3029344969095357d-01,0.1102221887403057d+00,
     4      -.1491759589415890d+00,0.5469452216879764d+00,
     5      -.7125418206617862d+00,0.2359095726751748d+01,
     6      -.2998052565158692d+01,0.9788356313874394d+01,
     7      -.1108031638518255d+02,0.2604160594925714d+02,
     8      0.8355325061090291d+01,-.6152291783841312d+02/
         data arr1059/
     1      0.3804126431499151d+03,-.8503189233897467d+03,
     2      0.2069114606768116d+04,-.3414850055559536d+04,
     3      0.6170662737087720d+04,-.8340451092029563d+04,
     4      0.1258445806146201d+05,-.1405486839539645d+05,
     5      0.1879275705473080d+05,-.1765556736301868d+05,
     6      0.2154869696636646d+05,-.1526379980577174d+05,
     7      0.1747843014212964d+05,-.9068380764404639d+04,
     8      0.9777788985660348d+04,-.4603759569106423d-07/
         data arr1060/
     1      0.2938994468075455d-06,-.3293276142371297d-06,
     2      0.3227271855172569d-06,0.1127368979860898d-05,
     3      -.1031298358569515d-04,0.2088559711441020d-04,
     4      -.9459945316622277d-04,0.1772365743420938d-03,
     5      -.8535866781629605d-03,0.1369088792211406d-02,
     6      -.5253318623914348d-02,0.8128826660013362d-02,
     7      -.3235182995666314d-01,0.4715198884115110d-01,
     8      -.1645211459454751d+00,0.2328492495973501d+00/
         data arr1061/
     1      -.8155195985044813d+00,0.1111675835344122d+01,
     2      -.3529713949286431d+01,0.4689600001108721d+01,
     3      -.1464933176331631d+02,0.1890443087880016d+02,
     4      -.5307956451140966d+02,0.5778469750195754d+02,
     5      -.1328088082235462d+03,0.2104380967127856d+02,
     6      0.3000547789791907d+02,-.7959635397722541d+03,
     7      0.1442285510411344d+04,-.3869741817394329d+04,
     8      0.5529615915873007d+04,-.1034589815421688d+05/
         data arr1062/
     1      0.1182876095915729d+05,-.1844568055851429d+05,
     2      0.1758026408265339d+05,-.2415322287158009d+05,
     3      0.1694117321423443d+05,-.2142538157340058d+05,
     4      0.1110878218527821d+05,-.1298673886685498d+05,
     5      0.1000000000000000d+01,-.7500000000000000d+00,
     6      0.4592793267718459d+00,-.2567449488305466d+00,
     7      0.1361595707651045d+00,-.6976102089721083d-01,
     8      0.3488051044860521d-01,-.1712599065101020d-01/
         data arr1063/
     1      0.8291084572331670d-02,-.3969054561122949d-02,
     2      0.1882687885584396d-02,-.8862460196801467d-03,
     3      0.4145036206939154d-03,-.1927981745914807d-03,
     4      0.8924821231178111d-04,-.4114139266513687d-04,
     5      0.1889538960164126d-04,-.8649853123815411d-05,
     6      0.3948093141911566d-05,-.1797293375505025d-05,
     7      0.8162089425148588d-06,-.3698444777511128d-06,
     8      0.1671672891486454d-06,-.7535321384647718d-07/
         data arr1064/
     1      0.3360817097943031d-07,-.1475323426146278d-07,
     2      0.5624883519491223d-08,-.1717625918961402d-08,
     3      -.1315546002036920d-08,0.1148460729057720d-08,
     4      -.2732340781087005d-08,-.1634918562990236d-08,
     5      0.6316257324693074d-09,-.1084500648234421d-07,
     6      0.9428331987880269d-08,-.2423342399421081d-07,
     7      0.1508229031216286d-07,-.2847050494800848d-07,
     8      0.1439741594742654d-07,-.2196673848887993d-07/
         data arr1065/
     1      -.7482723165090343d-18,0.1000000000000000d+01,
     2      -.1224744871391589d+01,0.1026979795322186d+01,
     3      -.7261843774138905d+00,0.4650734726480723d+00,
     4      -.2790440835888425d+00,0.1598425794094308d+00,
     5      -.8843823543821586d-01,0.4762865473350110d-01,
     6      -.2510250514122707d-01,0.1299827495551117d-01,
     7      -.6632057931904668d-02,0.3341835027731229d-02,
     8      -.1665966634922167d-02,0.8228278621428173d-03/
         data arr1066/
     1      -.4031016749166659d-03,0.1960633871519438d-03,
     2      -.9475438845056133d-04,0.4553167434963634d-04,
     3      -.2176629825454803d-04,0.1035675350414271d-04,
     4      -.4906622530441910d-05,0.2315333473969067d-05,
     5      -.1087411770999600d-05,0.5087099590644792d-06,
     6      -.2347441817797020d-06,0.1100611840350872d-06,
     7      -.4973974203904703d-07,0.3606744220428769d-07,
     8      -.2902913256286609d-07,0.5991860735406120d-07/
         data arr1067/
     1      -.6499322438082915d-07,0.1251036400152166d-06,
     2      -.1193954495068815d-06,0.1899511851293377d-06,
     3      -.1309053782137573d-06,0.1850073993157125d-06,
     4      -.9592053159090368d-07,0.1216319290400885d-06,
     5      -.2334042999036129d-18,-.4886622235295677d-18,
     6      0.1000000000000000d+01,-.1677050983124842d+01,
     7      0.1778781183844713d+01,-.1518923601189342d+01,
     8      0.1139192700892007d+01,-.7830655174468218d+00/
         data arr1068/
     1      0.5054666180101414d+00,-.3111090699528207d+00,
     2      0.1844649865851830d+00,-.1061304705920109d+00,
     3      0.5956557888794727d-01,-.3274316249473435d-01,
     4      0.1768332881496387d-01,-.9405705932965529d-02,
     5      0.4936967189327326d-02,-.2561361512842728d-02,
     6      0.1315233270728075d-02,-.6691769231072363d-03,
     7      0.3376723315489433d-03,-.1691282615271005d-03,
     8      0.8414039523043966d-04,-.4160268775368677d-04/
         data arr1069/
     1      0.2045514458713034d-04,-.1000571910613905d-04,
     2      0.4872267785658197d-05,-.2362356729273999d-05,
     3      0.1143066461432948d-05,-.5495327819133055d-06,
     4      0.2654465649502802d-06,-.1200050412913837d-06,
     5      0.5477483520872201d-07,-.5773395994622031d-08,
     6      -.7506832722324536d-08,0.3874911185455662d-07,
     7      -.2665632729710759d-07,0.4902103766947775d-07,
     8      -.2539171919766187d-07,0.3664823598246374d-07/
         data arr1070/
     1      0.1749460858039646d-16,0.3337443172230824d-16,
     2      -.2208787033773895d-15,0.1000000000000000d+01,
     3      -.2121320343559645d+01,0.2717133139910526d+01,
     4      -.2717133139910543d+01,0.2334650303796228d+01,
     5      -.1808412349164336d+01,0.1298567253818623d+01,
     6      -.8799493322102906d+00,0.5695558721483809d+00,
     7      -.3551804893734897d+00,0.2147667489437153d+00,
     8      -.1265316009892256d+00,0.7291023256826390d-01/
         data arr1071/
     1      -.4121373865094314d-01,0.2290951405566238d-01,
     2      -.1254805829243270d-01,0.6783341337667753d-02,
     3      -.3624282619633393d-02,0.1916127315971972d-02,
     4      -.1003443107683436d-02,0.5209610322566381d-03,
     5      -.2683694850551230d-03,0.1372563164735944d-03,
     6      -.6979032168297239d-04,0.3521511847675334d-04,
     7      -.1770973200904211d-04,0.8537199338682702d-05,
     8      -.3962308018202299d-05,0.8846329366650111d-06/
         data arr1072/
     1      0.3998778346846591d-06,-.2380151458416340d-05,
     2      0.2529417142976910d-05,-.4317426015293124d-05,
     3      0.3004499372466113d-05,-.4301590847553948d-05,
     4      0.2233972336966465d-05,-.2841380445254700d-05,
     5      -.1613740477195446d-16,-.4040315148841384d-16,
     6      0.2504637441752765d-15,-.5180252350294675d-15,
     7      0.1000000000000003d+01,-.2561737691489907d+01,
     8      0.3842606537234877d+01,-.4402258830702764d+01/
         data arr1073/
     1      0.4262468784251757d+01,-.3672902844007264d+01,
     2      0.2903684652894339d+01,-.2147929703785967d+01,
     3      0.1506903195464628d+01,-.1012420163639077d+01,
     4      0.6561232558730421d+00,-.4124425586996233d+00,
     5      0.2525684544296937d+00,-.1511950775494278d+00,
     6      0.8872816635397462d-01,-.5116315748457506d-01,
     7      0.2904453164868644d-01,-.1625884728471261d-01,
     8      0.8987427722995058d-02,-.4911537932467303d-02/
         data arr1074/
     1      0.2656361367710594d-02,-.1423092729144297d-02,
     2      0.7558650294410391d-03,-.3982890565473214d-03,
     3      0.2085173784253633d-03,-.1083559535974339d-03,
     4      0.5619345112426952d-04,-.2851506114445268d-04,
     5      0.1462428169306474d-04,-.6253943685939956d-05,
     6      0.2750236998948243d-05,0.8521507866656906d-06,
     7      -.7566039534673434d-06,0.2821614632146329d-05,
     8      -.1461120783514987d-05,0.2488416968749799d-05/
         data arr1075/
     1      -.1560083776987967d-15,-.2688290917324957d-15,
     2      0.1830835969790522d-14,-.3080452961499561d-14,
     3      0.2289180671507927d-13,0.9999999999999537d+00,
     4      -.2999999999999807d+01,0.5155397656824996d+01,
     5      -.6655589755985485d+01,0.7168772306795807d+01,
     6      -.6800894554976940d+01,0.5869261312895418d+01,
     7      -.4705878202731319d+01,0.3556875281445241d+01,
     8      -.2561242932606069d+01,0.1771011981018401d+01/
         data arr1076/
     1      -.1183111548370465d+01,0.7672666897718393d+00,
     2      -.4849030027448738d+00,0.2995807578419807d+00,
     3      -.1814051353756460d+00,0.1078955966187025d+00,
     4      -.6314977978154595d-01,0.3642781368743142d-01,
     5      -.2073800097861008d-01,0.1166499494659751d-01,
     6      -.6489309783607236d-02,0.3574390292237375d-02,
     7      -.1950379983047168d-02,0.1058265074066344d-02,
     8      -.5709730331372825d-03,0.3143465553063474d-03/
         data arr1077/
     1      -.1742655802607964d-03,0.1114052528719951d-03,
     2      -.7026356855228112d-04,0.6343749376181842d-04,
     3      -.3976361823867433d-04,0.4458179975549113d-04,
     4      -.2263011239472097d-04,0.2595670696592533d-04,
     5      0.1995152373095259d-15,0.3328523703186537d-15,
     6      -.2311375305505945d-14,0.3847704298019538d-14,
     7      -.2885849637222273d-13,0.5751005200548260d-13,
     8      0.9999999999997565d+00,-.3436931771216476d+01/
         data arr1078/
     1      0.6655589755985072d+01,-.9558363075727969d+01,
     2      0.1133482425829885d+02,-.1173852262580187d+02,
     3      0.1098038247310341d+02,-.9485000750642703d+01,
     4      0.7683728798345096d+01,-.5903373270943688d+01,
     5      0.4338075680986339d+01,-.3069066764698892d+01,
     6      0.2101246365374185d+01,-.1398043566047395d+01,
     7      0.9070257791705742d+00,-.5754433248351193d+00,
     8      0.3578491987839559d+00,-.2185674715378414d+00/
         data arr1079/
     1      0.1313423522560451d+00,-.7776824176990034d-01,
     2      0.4542858261942650d-01,-.2621100744816248d-01,
     3      0.1495002893033364d-01,-.8439378932027279d-02,
     4      0.4715549518890423d-02,-.2616799679848121d-02,
     5      0.1436561192158687d-02,-.7955798331978313d-03,
     6      0.4320731517750566d-03,-.2535887704420607d-03,
     7      0.1324125556123255d-03,-.9223326124225162d-04,
     8      0.4152347840714686d-04,-.3650959947474325d-04/
         data arr1080/
     1      0.1137942424275574d-14,0.2909072438880853d-14,
     2      -.1766588043146037d-13,0.3636950163919926d-13,
     3      -.2265537378316435d-12,0.5207223978572879d-12,
     4      -.1955681190313522d-11,0.1000000000003737d+01,
     5      -.3872983346223146d+01,0.8343223298011378d+01,
     6      -.1319179432460139d+02,0.1707703761279419d+02,
     7      -.1916892717884397d+02,0.1931810395965856d+02,
     8      -.1788508893750728d+02,0.1545865993177896d+02/
         data arr1081/
     1      -.1262194299127730d+02,0.9822637389217119d+01,
     2      -.7336472875213728d+01,0.5288020842588916d+01,
     3      -.3694679788860901d+01,0.2511441161124597d+01,
     4      -.1665902380508382d+01,0.1081096438703058d+01,
     5      -.6878758452433929d+00,0.4299241330013223d+00,
     6      -.2643701062961305d+00,0.1601612543165469d+00,
     7      -.9571381702659675d-01,0.5645642407979206d-01,
     8      -.3289969984660215d-01,0.1888902833784859d-01/
         data arr1082/
     1      -.1070281152398077d-01,0.5865613643368527d-02,
     2      -.3147425403410339d-02,0.1483146897940212d-02,
     3      -.7010939029712324d-03,0.1380250901733133d-03,
     4      -.2088049361910875d-04,-.1413201959951034d-03,
     5      0.2510596251217392d-14,-.1376288361082096d-14,
     6      -.4227925428750695d-14,-.3086035632176231d-13,
     7      -.1968176169366661d-13,-.3359634871854109d-12,
     8      0.7706168737998144d-13,-.2799554644869423d-11/
         data arr1083/
     1      0.9999999999989621d+00,-.4308421984923298d+01,
     2      0.1021831994508218d+02,-.1763708860712591d+02,
     3      0.2474697857532865d+02,-.2992747796560214d+02,
     4      0.3232537074144700d+02,-.3193127064446698d+02,
     5      0.2933074496616947d+02,-.2536194063952965d+02,
     6      0.2083696047672064d+02,-.1638433309294008d+02,
     7      0.1240150793727770d+02,-.9078317316061882d+01,
     8      0.6452008264560832d+01,-.4466201548747111d+01/
         data arr1084/
     1      0.3019334509682941d+01,-.1998092499187986d+01,
     2      0.1296907611261203d+01,-.8270672529718104d+00,
     3      0.5189694168717173d+00,-.3208544596105188d+00,
     4      0.1956154319716415d+00,-.1177599084431498d+00,
     5      0.6991309355281631d-01,-.4104578743577521d-01,
     6      0.2357705299583056d-01,-.1340662000730909d-01,
     7      0.7139872766581832d-02,-.3833897002214056d-02,
     8      0.1633454140013787d-02,-.7572326152868035d-03/
         data arr1085/
     1      -.1125239402470195d-12,-.1871653291966899d-12,
     2      0.1305527807657225d-11,-.2189400637932679d-11,
     3      0.1630335331057808d-10,-.3251561304125884d-10,
     4      0.1376176523406515d-09,-.2290738833034624d-09,
     5      0.1127919584442337d-08,0.9999999982176529d+00,
     6      -.4743416483346789d+01,0.1228089216003053d+02,
     7      -.2297544541041154d+02,0.3473136802471007d+02,
     8      -.4501699791654925d+02,0.5187952665291123d+02/
         data arr1086/
     1      -.5446215712272296d+02,0.5297936464711565d+02,
     2      -.4836331846991825d+02,0.4183147275797391d+02,
     3      -.3454118731169609d+02,0.2739239904199955d+02,
     4      -.2096540259558394d+02,0.1554922491913066d+02,
     5      -.1121252471664330d+02,0.7883725848598536d+01,
     6      -.5417717134642278d+01,0.3647014696198510d+01,
     7      -.2408432655274017d+01,0.1564755670941963d+01,
     8      -.9999520698285554d+00,0.6339786157817519d+00/
         data arr1087/
     1      -.3951058348949998d+00,0.2513508889560082d+00,
     2      -.1544312546224980d+00,0.1054609069866996d+00,
     3      -.6053619552416250d-01,0.4759002175182767d-01,
     4      -.2244457471858779d-01,0.2050523277096795d-01,
     5      0.2762137547998405d-12,0.3707261540523562d-12,
     6      -.2836643304094561d-11,0.4231285016729191d-11,
     7      -.3493374146058448d-10,0.6373083564533162d-10,
     8      -.2914117368551021d-09,0.4459953728744522d-09/
         data arr1088/
     1      -.2413462220343606d-08,0.3485348419562421d-08,
     2      0.9999999853562385d+00,-.5178078774160316d+01,
     3      0.1453094748732109d+02,-.2928806105579962d+02,
     4      0.4745208204973126d+02,-.6562298705669166d+02,
     5      0.8037141527128049d+02,-.8935224562811705d+02,
     6      0.9176294391735778d+02,-.8818848881875140d+02,
     7      0.8010114224388352d+02,-.6929791153889034d+02,
     8      0.5745868010099743d+02,-.4589298927092473d+02/
         data arr1089/
     1      0.3545735454492483d+02,-.2659282779109429d+02,
     2      0.1941711383936345d+02,-.1383898557381275d+02,
     3      0.9645866187607975d+01,-.6591040631478276d+01,
     4      0.4416092755328615d+01,-.2914269818232146d+01,
     5      0.1882756122966550d+01,-.1211007154091536d+01,
     6      0.7509557068183834d+00,-.4799989144072831d+00,
     7      0.2713310309178458d+00,-.1783262922118762d+00,
     8      0.8070026309600473d-01,-.5755632799947894d-01/
         data arr1090/
     1      -.9113574849260373d-12,-.6696201099635915d-12,
     2      0.6869188768189433d-11,-.6037102027804467d-11,
     3      0.8085848984730803d-10,-.1046350779916325d-09,
     4      0.6468899857506983d-09,-.6850197383313106d-09,
     5      0.5552067070236398d-08,-.5578571227296964d-08,
     6      0.3261296131601583d-07,0.9999999687276866d+00,
     7      -.5612485875565071d+01,0.1696849083318111d+02,
     8      -.3665612909942059d+02,0.6336615307597682d+02/
         data arr1091/
     1      -.9312884141358062d+02,0.1207910773871002d+03,
     2      -.1417714073337851d+03,0.1532800954382789d+03,
     3      -.1546927725265664d+03,0.1472123550194701d+03,
     4      -.1331583229208328d+03,0.1152183617776307d+03,
     5      -.9586652136185545d+02,0.7703552688331897d+02,
     6      -.5999894523695472d+02,0.4543560710577307d+02,
     7      -.3353190145279088d+02,0.2418213487006286d+02,
     8      -.1705032057659001d+02,0.1179708665906913d+02/
         data arr1092/
     1      -.7968238766212512d+01,0.5314015941030868d+01,
     2      -.3408772693933649d+01,0.2195388061865713d+01,
     3      -.1267974191453406d+01,0.7893460534353062d+00,
     4      -.3568225781528322d+00,0.2150437365757017d+00,
     5      0.4747844186160238d-11,0.3332509477857197d-11,
     6      -.3461189715650355d-10,0.2730505801472694d-10,
     7      -.4050442530157269d-09,0.5026153768140057d-09,
     8      -.3220254544497857d-08,0.3200333430959275d-08/
         data arr1093/
     1      -.2777123587230525d-07,0.2650300783822508d-07,
     2      -.1623043592474889d-06,0.1465943386821780d-06,
     3      0.9999989795395702d+00,-.6046692429345345d+01,
     4      0.1959352067121729d+02,-.4516084112809863d+02,
     5      0.8296574518133779d+02,-.1291310775434820d+03,
     6      0.1768199306158950d+03,-.2184843606102576d+03,
     7      0.2480599906756119d+03,-.2622941658498260d+03,
     8      0.2609781199907538d+03,-.2463465698118854d+03/
         data arr1094/
     1      0.2220492257951696d+03,-.1921587008015516d+03,
     2      0.1603470828066671d+03,-.1295253243955861d+03,
     3      0.1015547534923434d+03,-.7755868217268896d+02,
     4      0.5770846440932906d+02,-.4205896801113943d+02,
     5      0.2980458720129403d+02,-.2086973311010968d+02,
     6      0.1396412749716532d+02,-.9434570454354183d+01,
     7      0.5629965111770558d+01,-.3680392586897442d+01,
     8      0.1703945956230438d+01,-.1076642592899833d+01/
         data arr1095/
     1      -.1502445019300922d-10,-.2694967547995673d-11,
     2      0.7316524140024573d-10,0.3032302647934240d-10,
     3      0.7793976711805049d-09,-.6325621393858608d-10,
     4      0.5592527851394165d-08,0.1362092413225075d-08,
     5      0.5263204638076955d-07,0.2146341168059150d-08,
     6      0.2838079568000340d-06,0.4978914344423675d-07,
     7      0.1868047785997623d-05,0.1000000178154808d+01,
     8      -.6480731979559386d+01,0.2240605542298444d+02/
         data arr1096/
     1      -.5488335434574553d+02,0.1067782830461632d+03,
     2      -.1754544320994984d+03,0.2529302010553789d+03,
     3      -.3281924300037768d+03,0.3904037200795123d+03,
     4      -.4316048185610434d+03,0.4481506942276960d+03,
     5      -.4406707877969331d+03,0.4131362144704562d+03,
     6      -.3712528219519781d+03,0.3213041950241945d+03,
     7      -.2686610083072304d+03,0.2179165393433992d+03,
     8      -.1714982573560634d+03,0.1316464091064159d+03/
         data arr1097/
     1      -.9781871440452316d+02,0.7135026874120718d+02,
     2      -.4949516758122216d+02,0.3416167404108312d+02,
     3      -.2088463533640330d+02,0.1347948814439609d+02,
     4      -.6296473728196080d+01,0.3655844080357327d+01,
     5      0.7906232076049686d-10,0.4977939553054196d-10,
     6      -.5406496841673762d-09,0.3321387531206575d-09,
     7      -.6251844827843997d-08,0.7007714223909073d-08,
     8      -.4907940475298594d-07,0.4204397675414972d-07/
         data arr1098/
     1      -.4275109008905325d-06,0.3611899321735714d-06,
     2      -.2473230541567191d-05,0.1941018300619274d-05,
     3      -.1562484048689040d-04,0.1184182758468535d-04,
     4      0.9999233394861401d+00,-.6914602689869037d+01,
     5      0.2540569025129635d+02,-.6590471109361201d+02,
     6      0.1353645460649599d+03,-.2341667233489421d+03,
     7      0.3544823625045643d+03,-.4819201387068490d+03,
     8      0.5993619022985504d+03,-.6914949872124874d+03/
         data arr1099/
     1      0.7478984977124131d+03,-.7649293601978457d+03,
     2      0.7445383127891245d+03,-.6940133576083054d+03,
     3      0.6215013388081638d+03,-.5380306262695688d+03,
     4      0.4495557411305441d+03,-.3662558796176967d+03,
     5      0.2867917259639943d+03,-.2219153767423247d+03,
     6      0.1611832764379099d+03,-.1190415503054841d+03,
     7      0.7520653858116539d+02,-.5314160635132783d+02,
     8      0.2551266314566975d+02,-.1711844014963227d+02/
         data arr1100/
     1      -.2313493789664339d-09,-.9602238766391989d-10,
     2      0.1343880934508122d-08,-.2006581271315199d-09,
     3      0.1500424272770827d-07,-.1062808259030266d-07,
     4      0.1134767959645866d-06,-.4783452788783620d-07,
     5      0.1019833886347400d-05,-.4975677588849328d-06,
     6      0.5728771929248817d-05,-.2320444057805048d-05,
     7      0.3677909522280531d-04,-.1527757641083383d-04,
     8      0.1766564003187881d-03,0.9999349382645972d+00/
         data arr1101/
     1      -.7347572351804686d+01,0.2859326930020167d+02,
     2      -.7830309047612417d+02,0.1693259062651470d+03,
     3      -.3075825446151507d+03,0.4878677315877349d+03,
     4      -.6934133663994263d+03,0.9000425385613328d+03,
     5      -.1081541554529280d+04,0.1216860718381834d+04,
     6      -.1291842043103324d+04,0.1304479357657582d+04,
     7      -.1257105677016028d+04,0.1165268935950501d+04,
     8      -.1036074635745456d+04,0.8944591017791955d+03/
         data arr1102/
     1      -.7368566446349020d+03,0.5973339556180231d+03,
     2      -.4506413469746412d+03,0.3434512708381287d+03,
     3      -.2223873468225433d+03,0.1589881501937578d+03,
     4      -.7728819628518557d+02,0.5078195819989736d+02,
     5      0.8871322616502808d-09,0.6520983684119293d-09,
     6      -.6414970369307996d-08,0.4773489414975226d-08,
     7      -.7496802019654364d-07,0.9453686570907677d-07,
     8      -.5945072261960536d-06,0.5822378008213358d-06/
         data arr1103/
     1      -.5131879746592567d-05,0.4917116282846613d-05,
     2      -.2991921068739388d-04,0.2674474549265745d-04,
     3      -.1880828295111862d-03,0.1620001394077353d-03,
     4      -.9274842019993541d-03,0.7670079539357053d-03,
     5      0.9953322110828347d+00,-.7778454651370616d+01,
     6      0.3194890981847653d+02,-.9215474128753155d+02,
     7      0.2092117155863857d+03,-.3982844590764837d+03,
     8      0.6602876325552765d+03,-.9796438530176335d+03/
         data arr1104/
     1      0.1323823545266143d+04,-.1655325949607767d+04,
     2      0.1931710362949693d+04,-.2128922997994889d+04,
     3      0.2219499537431173d+04,-.2218488960428598d+04,
     4      0.2108337328363360d+04,-.1948469277814603d+04,
     5      0.1696934236743606d+04,-.1469685211509627d+04,
     6      0.1160386068828262d+04,-.9496496565664140d+03,
     7      0.6322876765379459d+03,-.4922051426540618d+03,
     8      0.2442910723908975d+03,-.1801743419638425d+03/
         data arr1105/
     1      -.3135162848533750d-08,-.3346657173885324d-08,
     2      0.2740940937377520d-07,-.3200611840945762d-07,
     3      0.3304076087771441d-06,-.5344424055322099d-06,
     4      0.2699909358811740d-05,-.3555278793237635d-05,
     5      0.2272674977005023d-04,-.2862793236468364d-04,
     6      0.1356462277968444d-03,-.1615020970710757d-03,
     7      0.8417792873065294d-03,-.9601064991733921d-03,
     8      0.4219877094741795d-02,-.4655427804627489d-02/
         data arr1106/
     1      0.2112924119666139d-01,0.9774665565269034d+00,
     2      -.8125357445517061d+01,0.3543711960686112d+02,
     3      -.1071982918273511d+03,0.2555531516136262d+03,
     4      -.5079267173445661d+03,0.8800188305317129d+03,
     5      -.1357176156293683d+04,0.1910894875907333d+04,
     6      -.2472743904170650d+04,0.3002268606748282d+04,
     7      -.3403601238072864d+04,0.3698879554549969d+04,
     8      -.3768809786513977d+04,0.3763533223081977d+04/
         data arr1107/
     1      -.3468102774899337d+04,0.3248741974447892d+04,
     2      -.2682892354902123d+04,0.2395469638596934d+04,
     3      -.1631213626729699d+04,0.1406628746708244d+04,
     4      -.7099525538474450d+03,0.5942918203450846d+03,
     5      0.7263198168205840d-08,0.8091337834612916d-08,
     6      -.6493288558950322d-07,0.7864389502879449d-07,
     7      -.7852657138511839d-06,0.1300383124554296d-05,
     8      -.6435756566901462d-05,0.8690566386283090d-05/
         data arr1108/
     1      -.5403641428422896d-04,0.6977940439117527d-04,
     2      -.3232600467998921d-03,0.3944955097437422d-03,
     3      -.2003391640506583d-02,0.2342532560984266d-02,
     4      -.1005868853445213d-01,0.1137385364293666d-01,
     5      -.5033546307122337d-01,0.5502807401295442d-01,
     6      0.7841711480836833d+00,-.8419594998699560d+01,
     7      0.3838068029200367d+02,-.1236730459973021d+03,
     8      0.3066643870013060d+03,-.6403363481581222d+03/
         data arr1109/
     1      0.1148896043358776d+04,-.1853611802430662d+04,
     2      0.2688682791547801d+04,-.3634054381191716d+04,
     3      0.4504374447489112d+04,-.5346584987884323d+04,
     4      0.5843899456249297d+04,-.6283460279150365d+04,
     5      0.6098989881989395d+04,-.6080824280434669d+04,
     6      0.5205053331668533d+04,-.4895930654633369d+04,
     7      0.3392575659772587d+04,-.3056451037192392d+04,
     8      0.1557933297247248d+04,-.1352110312048420d+04/
         data arr1110/
     1      -.1863673091931441d-07,-.2467902854635652d-07,
     2      0.1845817829880423d-06,-.2593167002949025d-06,
     3      0.2263181479982127d-05,-.4093939707967466d-05,
     4      0.1878519480045737d-04,-.2797687764361060d-04,
     5      0.1560660181716412d-03,-.2216313258618688d-03,
     6      0.9429469289136505d-03,-.1266141259722821d-02,
     7      0.5812599498168332d-02,-.7479070639447225d-02,
     8      0.2938635315180917d-01,-.3655914294525081d-01/
         data arr1111/
     1      0.1467517224132053d+00,-.1765696324475122d+00,
     2      0.6330203449384352d+00,0.2582412397654317d+00,
     3      -.6441562507903003d+01,0.4020807533088403d+02,
     4      -.1336331213958224d+03,0.3613058449028899d+03,
     5      -.7713101092257893d+03,0.1474375446381343d+04,
     6      -.2422126358500155d+04,0.3728254080035928d+04,
     7      -.5078056044907589d+04,0.6727630480911332d+04,
     8      -.7922263203392515d+04,0.9409607742199475d+04/
         data arr1112/
     1      -.9647085634145791d+04,0.1058181244063538d+05,
     2      -.9420885334949370d+04,0.9737353905569976d+04,
     3      -.6837772703700744d+04,0.6773252622153459d+04,
     4      -.3487465361933706d+04,0.3328050077444416d+04,
     5      0.3280923599218496d-07,0.4587196911989092d-07,
     6      -.3358852343191544d-06,0.4913469915787410d-06,
     7      -.4135341014045978d-05,0.7670866616787949d-05,
     8      -.3445249672723283d-04,0.5270730295525678d-04/
         data arr1113/
     1      -.2853392737817844d-03,0.4161735487748207d-03,
     2      -.1729012859501539d-02,0.2383566087521261d-02,
     3      -.1064123480782491d-01,0.1406154039581410d-01,
     4      -.5390540573953632d-01,0.6884687987092346d-01,
     5      -.2690277558421760d+00,0.3323627389534140d+00,
     6      -.1162436758281079d+01,0.1398164020184561d+01,
     7      -.3850457875350937d+01,-.3841297647610337d+01,
     8      0.2948633143766635d+02,-.1434468923101126d+03/
         data arr1114/
     1      0.3805538677055885d+03,-.9275214583913415d+03,
     2      0.1749695465116943d+04,-.3157362273136779d+04,
     3      0.4735423276074740d+04,-.7074649216455162d+04,
     4      0.8936485489850893d+04,-.1167756861532766d+05,
     5      0.1253564171523752d+05,-.1487018671730795d+05,
     6      0.1363292866935775d+05,-.1502522468156160d+05,
     7      0.1065140472595202d+05,-.1113577915650499d+05,
     8      0.5769885978081364d+04,-.5754197601628910d+04/
         data arr1115/
     1      -.5334633991087532d-07,-.8145876440656608d-07,
     2      0.5778693764925709d-06,-.9005828747159306d-06,
     3      0.7162299153789488d-05,-.1380607312145750d-04,
     4      0.6003035708677885d-04,-.9571826104639226d-04,
     5      0.4947057734221711d-03,-.7517366950244572d-03,
     6      0.3011779504590490d-02,-.4323510416933820d-02,
     7      0.1848952571571826d-01,-.2545287449626242d-01,
     8      0.9396770593906821d-01,-.1249555392123613d+00/
         data arr1116/
     1      0.4685234943620190d+00,-.6028195097819536d+00,
     2      0.2030112659325023d+01,-.2541767425185809d+01,
     3      0.8471702005991570d+01,-.9318879161100834d+01,
     4      0.2133318714979949d+02,0.1444640910984833d+02,
     5      -.7651144508983200d+02,0.3965190309851307d+03,
     6      -.8835459404668949d+03,0.2087644886971680d+04,
     7      -.3449878366167895d+04,0.6126712290062339d+04,
     8      -.8286676244933273d+04,0.1232279174137559d+05/
         data arr1117/
     1      -.1378252581419859d+05,0.1816559527057646d+05,
     2      -.1709209553016831d+05,0.2056569226013240d+05,
     3      -.1462442815249632d+05,0.1650224917382923d+05,
     4      -.8587570140684087d+04,0.9135729647678624d+04,
     5      0.7699188255698155d-07,0.1329442276420546d-06,
     6      -.9065051472504182d-06,0.1533483338782785d-05,
     7      -.1133844221199479d-04,0.2295098325824958d-04,
     8      -.9580897973921652d-04,0.1610395450605221d-03/
         data arr1118/
     1      -.7842982912673024d-03,0.1255787754593854d-02,
     2      -.4805365436927641d-02,0.7263056238754051d-02,
     3      -.2940260658613503d-01,0.4264167596441487d-01,
     4      -.1500955968720905d+00,0.2100984280232300d+00,
     5      -.7474884719537998d+00,0.1012713437315688d+01,
     6      -.3251381706196077d+01,0.4283434153886441d+01,
     7      -.1357133805300116d+02,0.1739518429542991d+02,
     8      -.4932318904234299d+02,0.5255983504671427d+02/
         data arr1119/
     1      -.1206578816309370d+03,0.5122187425567417d+01,
     2      0.6324745642706164d+02,-.8345491193336263d+03,
     3      0.1513688558052878d+04,-.3933899623899079d+04,
     4      0.5636439748262436d+04,-.1040258685455043d+05,
     5      0.1193196778606794d+05,-.1842535887916566d+05,
     6      0.1761306581265712d+05,-.2400744436286032d+05,
     7      0.1690159234293352d+05,-.2121468144992542d+05,
     8      0.1103560037535667d+05,-.1282499904270893d+05/
         data arr1120/
     1      0.1000000000000000d+01,-.9682458365518542d+00,
     2      0.7261843774138907d+00,-.4803258171543562d+00,
     3      0.2941382905783861d+00,-.1708789051338015d+00,
     4      0.9552421194998024d-01,-.5185151165880824d-01,
     5      0.2749841663154359d-01,-.1431062973528964d-01,
     6      0.7332015916407210d-02,-.3707433092023254d-02,
     7      0.1853716546244079d-02,-.9179029117793685d-03,
     8      0.4506813840973428d-03,-.2196349439867936d-03/
         data arr1121/
     1      0.1063303159309639d-03,-.5117326645349657d-04,
     2      0.2449736168316072d-04,-.1167108162249108d-04,
     3      0.5536185399787323d-05,-.2616006398310317d-05,
     4      0.1231819352464053d-05,-.5792639330703546d-06,
     5      0.2716836646511457d-06,-.1290975890568959d-06,
     6      0.5798164542855140d-07,-.2564125711066899d-07,
     7      -.6422769260154583d-08,0.2337336483881977d-07,
     8      -.7020082067746227d-07,0.8482767779425923d-07/
         data arr1122/
     1      -.1553938587480227d-06,0.1527800286503938d-06,
     2      -.2297834856398269d-06,0.1627325603838599d-06,
     3      -.2186544910772892d-06,0.1158739346382965d-06,
     4      -.1402581406443544d-06,-.1301376246013274d-17,
     5      0.1000000000000000d+01,-.1500000000000000d+01,
     6      0.1488235112473832d+01,-.1215138880951474d+01,
     7      0.8824148717351570d+00,-.5919418912669695d+00,
     8      0.3748640767764070d+00,-.2272019406101319d+00/
         data arr1123/
     1      0.1330195935320661d+00,-.7572473476832929d-01,
     2      0.4211922475654461d-01,-.2297412259409611d-01,
     3      0.1232407864268376d-01,-.6516464219256811d-02,
     4      0.3402569809567908d-02,-.1757079484366016d-02,
     5      0.8984753189237860d-03,-.4554129942662503d-03,
     6      0.2290202921220027d-03,-.1143512558510824d-03,
     7      0.5672658269625802d-04,-.2797407357423252d-04,
     8      0.1371864283208653d-04,-.6693091698662526d-05/
         data arr1124/
     1      0.3245332920417932d-05,-.1565294071376244d-05,
     2      0.7415139878311511d-06,-.3542482853268194d-06,
     3      0.1573506777108332d-06,-.9836044404787613d-07,
     4      0.5012214636787072d-07,-.1012893456794158d-06,
     5      0.8338221567823424d-07,-.1821975838006346d-06,
     6      0.1153869970478205d-06,-.2078284022485672d-06,
     7      0.1072487867666559d-06,-.1597327889376868d-06,
     8      -.5593191456183231d-17,-.4657011029763724d-17/
         data arr1125/
     1      0.1000000000000000d+01,-.1984313483298443d+01,
     2      0.2430277761902948d+01,-.2353106324627091d+01,
     3      0.1973139637556577d+01,-.1499456307105694d+01,
     4      0.1060275722847406d+01,-.7094378321715056d+00,
     5      0.4543484086108639d+00,-.2807948317140416d+00,
     6      0.1684768990297184d+00,-.9859262916390381d-01,
     7      0.5647602327025337d-01,-.3175731835368916d-01,
     8      0.1757079504858486d-01,-.9583737385365441d-02/
         data arr1126/
     1      0.5161348253132106d-02,-.2748246578580174d-02,
     2      0.1448453739291113d-02,-.7563671654731271d-03,
     3      0.3916550833149156d-03,-.2012556201669270d-03,
     4      0.1026907753410396d-03,-.5207189117580379d-04,
     5      0.2623137628113803d-04,-.1314779874490095d-04,
     6      0.6469134563916540d-05,-.3125691257999158d-05,
     7      0.1251470087565549d-05,-.3794154196439635d-06,
     8      -.4050488719548480d-06,0.5809078644123726d-06/
         data arr1127/
     1      -.1118397522716096d-05,0.8008945697061817d-06,
     2      -.1160859791871487d-05,0.6146716320399091d-06,
     3      -.7784353082382716d-06,0.2681594784984687d-16,
     4      0.3434260936597907d-16,-.3157424997875103d-15,
     5      0.1000000000000002d+01,-.2449489742783182d+01,
     6      0.3557562367689443d+01,-.3977475644174365d+01,
     7      0.3778274752770523d+01,-.3205972438644118d+01,
     8      0.2502661432782464d+01,-.1831760606114523d+01/
         data arr1128/
     1      0.1273565647111064d+01,-.8490437647477892d+00,
     2      0.5465461631575249d+00,-.3415348859633330d+00,
     3      0.2080543936076478d+00,-.1239678773502773d+00,
     4      0.7244624460432966d-01,-.4161719989633963d-01,
     5      0.2354476107509642d-01,-.1313913383418148d-01,
     6      0.7242278910251974d-02,-.3947496212451638d-02,
     7      0.2129840318909548d-02,-.1138490487091122d-02,
     8      0.6034843255498659d-03,-.3174007505993479d-03/
         data arr1129/
     1      0.1659315194724927d-03,-.8605385094561799d-04,
     2      0.4457912152824413d-04,-.2234466890437961d-04,
     3      0.1132141081353227d-04,-.4150159473167207d-05,
     4      0.1404052775732163d-05,0.2195732477092081d-05,
     5      -.1628057004208057d-05,0.3919375096222880d-05,
     6      -.2063253744737553d-05,0.3229968102379897d-05,
     7      0.1203166439327929d-15,0.6816653643052076d-16,
     8      -.1113558370636797d-14,0.8952841293621910d-14/
         data arr1130/
     1      0.9999999999999848d+00,-.2904737509655500d+01,
     2      0.4871392896287346d+01,-.6169896834884406d+01,
     3      0.6544163836751917d+01,-.6130243509252832d+01,
     4      0.5234691951885146d+01,-.4159447985760337d+01,
     5      0.3119585989300360d+01,-.2231265367377117d+01,
     6      0.1533741366122796d+01,-.1019254204371142d+01,
     7      0.6579257592909071d+00,-.4140647683260057d+00,
     8      0.2548522476848237d+00,-.1537936938862493d+00/
         data arr1131/
     1      0.9118843259066302d-01,-.5321949324244047d-01,
     2      0.3061937724638515d-01,-.1738942828899465d-01,
     3      0.9759729410096869d-02,-.5418350248104547d-02,
     4      0.2978796698989455d-02,-.1622679218035796d-02,
     5      0.8787276864510059d-03,-.4733364085505050d-03,
     6      0.2591258255798574d-03,-.1429774761110623d-03,
     7      0.8910171800569225d-04,-.5547723446174947d-04,
     8      0.4765800765229374d-04,-.2986201224889546d-04/
         data arr1132/
     1      0.3210937778590012d-04,-.1649601488415709d-04,
     2      0.1834135070069396d-04,-.2616013384338189d-15,
     3      -.2121874374146821d-15,0.2689793507578199d-14,
     4      -.2050545580092592d-13,0.3677424854193715d-13,
     5      0.9999999999998516d+00,-.3354101966249387d+01,
     6      0.6372242050485833d+01,-.9011711130520836d+01,
     7      0.1055214711978952d+02,-.1081273320115869d+02,
     8      0.1002367195092314d+02,-.8591718815033612d+01/
         data arr1133/
     1      0.6913322887170138d+01,-.5280137572107184d+01,
     2      0.3859831125585520d+01,-.2718011211167345d+01,
     3      0.1853125107606440d+01,-.1228314602508181d+01,
     4      0.7941872635038726d+00,-.5022881033655003d+00,
     5      0.3114677220083536d+00,-.1897416014609856d+00,
     6      0.1137457055548817d+00,-.6719929198074660d-01,
     7      0.3917348055084727d-01,-.2255849080600913d-01,
     8      0.1284324511460288d-01,-.7238109200096460d-02/
         data arr1134/
     1      0.4037751357553979d-02,-.2239099002958393d-02,
     2      0.1228277695102159d-02,-.6842578220999406d-03,
     3      0.3737354027165122d-03,-.2274474006636251d-03,
     4      0.1204945336189683d-03,-.9164700847713880d-04,
     5      0.4251291004187781d-04,-.4120502544867375d-04,
     6      -.8480308335180662d-15,-.1123818028612636d-14,
     7      0.9517098671459624d-14,-.6109044191106029d-13,
     8      0.1300450860877628d-12,-.4823517865493744d-12/
         data arr1135/
     1      0.1000000000001063d+01,-.3799671038397538d+01,
     2      0.8060319472585976d+01,-.1258416974320478d+02,
     3      0.1611867097365404d+02,-.1793088949346679d+02,
     4      0.1793088949361566d+02,-.1648923725649233d+02,
     5      0.1416809585337579d+02,-.1150779304941120d+02,
     6      0.8913898171152119d+01,-.6629941994802365d+01,
     7      0.4760764663148508d+01,-.3314932787999406d+01,
     8      0.2246301071593728d+01,-.1485788829543976d+01/
         data arr1136/
     1      0.9616917915075343d+00,-.6104276305278074d+00,
     2      0.3806690941937972d+00,-.2335964366108385d+00,
     3      0.1412456926159888d+00,-.8425486633650873d-01,
     4      0.4961848758300702d-01,-.2886945244403883d-01,
     5      0.1657057905812149d-01,-.9384706437921043d-02,
     6      0.5181830762611985d-02,-.2797164920717893d-02,
     7      0.1389583238313120d-02,-.6723261009154081d-03,
     8      0.2209833299386813d-03,-.6814927408597658d-04/
         data arr1137/
     1      -.5141403231069534d-04,-.8195451370272328d-15,
     2      0.4129013423299937d-14,-.3414269423093230d-14,
     3      -.8473740191479059d-13,-.4544610338160438d-13,
     4      -.2024351296379823d-12,-.5326522132660027d-12,
     5      0.9999999999952430d+00,-.4242640687122888d+01,
     6      0.9935730974598368d+01,-.1696849102015037d+02,
     7      0.2359531826827544d+02,-.2831438192229371d+02,
     8      0.3037754048138333d+02,-.2983015257645793d+02/
         data arr1138/
     1      0.2725765897328753d+02,-.2345965762142886d+02,
     2      0.1919359882714699d+02,-.1503529515300508d+02,
     3      0.1134154089322928d+02,-.8276562001384516d+01,
     4      0.5865461687337427d+01,-.4049576881993294d+01,
     5      0.2731089465420122d+01,-.1803319500563146d+01,
     6      0.1168068856022984d+01,-.7434717270091424d+00,
     7      0.4656746336072276d+00,-.2874176989098101d+00,
     8      0.1749466203801910d+00,-.1051587052268437d+00/
         data arr1139/
     1      0.6233689521878097d-01,-.3655791926966594d-01,
     2      0.2097339233015062d-01,-.1194045726713045d-01,
     3      0.6353886314307526d-02,-.3446692978678588d-02,
     4      0.1474478062978419d-02,-.7175017103450335d-03,
     5      0.8929093260303196d-13,0.4789935329908485d-13,
     6      -.8554435366886370d-12,0.7060685849037299d-11,
     7      -.1170153892269753d-10,0.4903125282102422d-10,
     8      -.9374745329185681d-10,0.5343886361474130d-09/
         data arr1140/
     1      0.9999999991744366d+00,-.4683748495499323d+01,
     2      0.1199853506178160d+02,-.2224587937995685d+02,
     3      0.3336881907183279d+02,-.4296032962303354d+02,
     4      0.4921724056649152d+02,-.5139753404726649d+02,
     5      0.4976544812977600d+02,-.4523974353471351d+02,
     6      0.3898237993436987d+02,-.3207871000250919d+02,
     7      0.2536044147376298d+02,-.1935499107973387d+02,
     8      0.1431735996684520d+02,-.1029942858498556d+02/
         data arr1141/
     1      0.7225630583481764d+01,-.4955343503654464d+01,
     2      0.3329387262380884d+01,-.2194920207830714d+01,
     3      0.1423515718659681d+01,-.9083734489070244d+00,
     4      0.5744332478543044d+00,-.3574043162255602d+00,
     5      0.2256758286665703d+00,-.1381892029789447d+00,
     6      0.9227793978200643d-01,-.5288790993484656d-01,
     7      0.3987454369187358d-01,-.1887749463589255d-01,
     8      0.1639620717357417d-01,-.2069441872406048d-12/
         data arr1142/
     1      -.3660815137540684d-13,0.1863954270581460d-11,
     2      -.1740986417261056d-10,0.2550450105270571d-10,
     3      -.1142435483525996d-09,0.2026397281385622d-09,
     4      -.1289482422345924d-08,0.1796110902520498d-08,
     5      0.9999999921896797d+00,-.5123475372041593d+01,
     6      0.1424876633998880d+02,-.2849753271860334d+02,
     7      0.4586105497487683d+02,-.6304852679343474d+02,
     8      0.7681512699005093d+02,-.8500105916234084d+02/
         data arr1143/
     1      0.8692987808039182d+02,-.8322902028202278d+02,
     2      0.7533833396168559d+02,-.6497473669759873d+02,
     3      0.5372085478700408d+02,-.4279547573751512d+02,
     4      0.3298468611594582d+02,-.2468335438951017d+02,
     5      0.1798592271567771d+02,-.1279448497427244d+02,
     6      0.8902367795994488d+01,-.6073014866792844d+01,
     7      0.4063412735076885d+01,-.2677568611108531d+01,
     8      0.1728410650558987d+01,-.1109709857447972d+01/
         data arr1144/
     1      0.6882285034766399d+00,-.4380433959461214d+00,
     2      0.2481880478246563d+00,-.1613819634669015d+00,
     3      0.7352781367608680d-01,-.5122333568969571d-01,
     4      0.3536986381087542d-12,-.6638541278416025d-12,
     5      -.1440476931908111d-11,0.3323806416350354d-10,
     6      -.1990250193137285d-10,0.1579519513824278d-09,
     7      -.1306553951960948d-09,0.2204326791281622d-08,
     8      -.1339574257952455d-08,0.1193650583170832d-07/
         data arr1145/
     1      0.9999999926796286d+00,-.5562148777125986d+01,
     2      0.1668644654643482d+02,-.3580464530239561d+02,
     3      0.6152906200579243d+02,-.8995666502320112d+02,
     4      0.1161335569881669d+03,-.1357357992426900d+03,
     5      0.1462017811342979d+03,-.1470453832247825d+03,
     6      0.1394995193343389d+03,-.1258229404114029d+03,
     7      0.1085869084464799d+03,-.9013177679088614d+02,
     8      0.7226621711663128d+02,-.5616907188978358d+02/
         data arr1146/
     1      0.4245349109141303d+02,-.3127604993753750d+02,
     2      0.2251516225075498d+02,-.1584986918434035d+02,
     3      0.1094237244903598d+02,-.7378217675273008d+01,
     4      0.4898138319085495d+01,-.3133617105519224d+01,
     5      0.1993120282512431d+01,-.1148564041742439d+01,
     6      0.6929699506845750d+00,-.3124981108401454d+00,
     7      0.1744580902570007d+00,-.2762519095620801d-11,
     8      0.3149505859231694d-11,0.1442835277574663d-10/
         data arr1147/
     1      -.2300632308031230d-09,0.1987134098903026d-09,
     2      -.1211110855752325d-08,0.1412358305730998d-08,
     3      -.1575414582653735d-07,0.1360264067198149d-07,
     4      -.8835009185982234d-07,0.7771703004298575d-07,
     5      0.9999993614521348d+00,-.5999999489028312d+01,
     6      0.1931158659294626d+02,-.4424840847741340d+02,
     7      0.8086501312533291d+02,-.1252755534727063d+03,
     8      0.1708243117663682d+03,-.2102809572241783d+03/
         data arr1148/
     1      0.2379308922284417d+03,-.2508012946923762d+03,
     2      0.2488332360673739d+03,-.2342690440228024d+03,
     3      0.2106555081168805d+03,-.1818932647033666d+03,
     4      0.1514702200052098d+03,-.1221204277822613d+03,
     5      0.9558275718491124d+02,-.7287591914137485d+02,
     6      0.5414833660719267d+02,-.3940396577181430d+02,
     7      0.2789743050376378d+02,-.1950122605155886d+02,
     8      0.1304770251374508d+02,-.8790224179530243d+01/
         data arr1149/
     1      0.5254499566962904d+01,-.3414817847281280d+01,
     2      0.1590186190109343d+01,-.9907223625490500d+00,
     3      0.7572315620943312d-11,-.1875422060330616d-10,
     4      -.1039749866800785d-10,0.6234828637442706d-09,
     5      -.1494122077207457d-09,0.2442333179159424d-08,
     6      -.2662598331247009d-09,0.3907664949533302d-07,
     7      -.8353802191003277d-08,0.1976201429814645d-06,
     8      -.2252862229036809d-07,0.1519879176838046d-05/
         data arr1150/
     1      0.9999997561249031d+00,-.6437189405922908d+01,
     2      0.2212420480505128d+02,-.5390998044436310d+02,
     3      0.1043963007810345d+03,-.1708242216232750d+03,
     4      0.2453278367473241d+03,-.3172408998017026d+03,
     5      0.3762022398927939d+03,-.4147215078315338d+03,
     6      0.4294946713618989d+03,-.4213099062802900d+03,
     7      0.3941048756752445d+03,-.3534217279622474d+03,
     8      0.3052851319657085d+03,-.2548179594289857d+03/
         data arr1151/
     1      0.2063526373606851d+03,-.1621715087900799d+03,
     2      0.1243400330316792d+03,-.9231837553633257d+02,
     3      0.6732333873729860d+02,-.4672755271276485d+02,
     4      0.3231388647426791d+02,-.1979554821807783d+02,
     5      0.1285701325064827d+02,-.6047553588035409d+01,
     6      0.3567345140082324d+01,-.5015309781152491d-10,
     7      0.5889251985579367d-10,0.2319609287743864d-09,
     8      -.3886155676203466d-08,0.3202709635805431d-08/
         data arr1152/
     1      -.1997953127768355d-07,0.2192259534560232d-07,
     2      -.2639371251146507d-06,0.2170627361006809d-06,
     3      -.1467128337085834d-05,0.1212865475114080d-05,
     4      -.1065072411061782d-04,0.8068006560173080d-05,
     5      0.9999470471009895d+00,-.6873824477716626d+01,
     6      0.2512401386477326d+02,-.6487046316414947d+02,
     7      0.1326841598599348d+03,-.2286650201236921d+03,
     8      0.3449726653866992d+03,-.4675320316776105d+03/
         data arr1153/
     1      0.5798161969828343d+03,-.6671953376860194d+03,
     2      0.7198886816124853d+03,-.7346393099812611d+03,
     3      0.7136036660520160d+03,-.6638929906194376d+03,
     4      0.5935170459415192d+03,-.5129287569761905d+03,
     5      0.4280157782514383d+03,-.3481611819937053d+03,
     6      0.2724164566208084d+03,-.2104652120031708d+03,
     7      0.1529200866160535d+03,-.1127313033391349d+03,
     8      0.7136741594032024d+02,-.5030630922590936d+02/
         data arr1154/
     1      0.2431377013283382d+02,-.1624112808132242d+02,
     2      0.1578387335831227d-09,-.2144677208801344d-09,
     3      -.6213062920487978d-09,0.1192090393459730d-07,
     4      -.8606932432891618d-08,0.5849808365264655d-07,
     5      -.5553990867968400d-07,0.7974953763881793d-06,
     6      -.5751117337083988d-06,0.4360057861846729d-05,
     7      -.3104655307011776d-05,0.3195561196642954d-04,
     8      -.2105979358978232d-04,0.1574547621147069d-03/
         data arr1155/
     1      0.9999002979053736d+00,-.7309240890923112d+01,
     2      0.2831136110489103d+02,-.7720789451680502d+02,
     3      0.1663278243009056d+03,-.3011056234755684d+03,
     4      0.4761060171122052d+03,-.6747720862120060d+03,
     5      0.8735488973331090d+03,-.1047175318665887d+04,
     6      0.1175552483047666d+04,-.1245416685388382d+04,
     7      0.1255194416422901d+04,-.1207527538412844d+04,
     8      0.1117657702625757d+04,-.9925705088852643d+03/
         data arr1156/
     1      0.8564025350226779d+03,-.7053222038784844d+03,
     2      0.5725970918184912d+03,-.4326749334314645d+03,
     3      0.3316374874131083d+03,-.2152859233760252d+03,
     4      0.1559557235006219d+03,-.7644308740208214d+02,
     5      0.5164515013186045d+02,-.6593510526893562d-09,
     6      0.5150740807141054d-09,0.3595537625147057d-08,
     7      -.4895101512869576d-07,0.4952160189983238d-07,
     8      -.2702152246958253d-06,0.3556517280940239d-06/
         data arr1157/
     1      -.3403532829195475d-05,0.3394523499314078d-05,
     2      -.1939155880701080d-04,0.1949658828906975d-04,
     3      -.1386798696388652d-03,0.1275865981488721d-03,
     4      -.6982039170075974d-03,0.6283982189116684d-03,
     5      0.9962454997176200d+00,-.7742749063985331d+01,
     6      0.3167070153062746d+02,-.9100025517055562d+02,
     7      0.2058920818080884d+03,-.3907299056910941d+03,
     8      0.6459436561610207d+03,-.9558221170140436d+03/
         data arr1158/
     1      0.1288583705695051d+04,-.1607592488400946d+04,
     2      0.1872286340461576d+04,-.2059304926791358d+04,
     3      0.2143420122881086d+04,-.2138664999787496d+04,
     4      0.2030147297054878d+04,-.1873469777946079d+04,
     5      0.1630932134678737d+04,-.1411340994365117d+04,
     6      0.1115541520056461d+04,-.9133099127236567d+03,
     7      0.6095694911944877d+03,-.4757493485220613d+03,
     8      0.2379759513220123d+03,-.1765596727862703d+03/
         data arr1159/
     1      0.2701821755469623d-08,-.5326556510980908d-09,
     2      -.1920643786102033d-07,0.2008768324050707d-06,
     3      -.2635805773215942d-06,0.1238769831658982d-05,
     4      -.2010489856901292d-05,0.1452612725510603d-04,
     5      -.1834867505608657d-04,0.8603941570163111d-04,
     6      -.1091150945682601d-03,0.6016261410962928d-03,
     7      -.7002461117379568d-03,0.3090668140353186d-02,
     8      -.3524905290216706d-02,0.1647769770195399d-01/
         data arr1160/
     1      0.9820882815833870d+00,-.8109181395164066d+01,
     2      0.3517262080581481d+02,-.1060445248135196d+03,
     3      0.2519292378227383d+03,-.4993766913731969d+03,
     4      0.8627866810604493d+03,-.1327657789883533d+04,
     5      0.1864905900304736d+04,-.2409021792864719d+04,
     6      0.2918925797473879d+04,-.3305086477485283d+04,
     7      0.3585668838988109d+04,-.3651960681300375d+04,
     8      0.3642036667649215d+04,-.3358414876175576d+04/
         data arr1161/
     1      0.3143699908721331d+04,-.2602952175793884d+04,
     2      0.2323948576522110d+04,-.1588924512355738d+04,
     3      0.1371295265460803d+04,-.6988813818232577d+03,
     4      0.5855304740013062d+03,-.6405397161875652d-08,
     5      0.8134122646123012d-09,0.4659088643486909d-07,
     6      -.4737700782858062d-06,0.6392331035046506d-06,
     7      -.2957946312821248d-05,0.4897026204126285d-05,
     8      -.3441522891601555d-04,0.4454836585605943d-04/
         data arr1162/
     1      -.2047177341284543d-03,0.2655763068272364d-03,
     2      -.1427892163373555d-02,0.1701910310211450d-02,
     3      -.7351257498049075d-02,0.8580086969424031d-02,
     4      -.3915393569561538d-01,0.4357410375407672d-01,
     5      0.8278137645581640d+00,-.8429591337681849d+01,
     6      0.3825206420745349d+02,-.1225417552855248d+03,
     7      0.3031126303426285d+03,-.6307237836147634d+03,
     8      0.1129455544914375d+04,-.1817262006672237d+04/
         data arr1163/
     1      0.2632139087814577d+04,-.3549214661624640d+04,
     2      0.4395187714991620d+04,-.5206064049699897d+04,
     3      0.5689740152678966d+04,-.6106202938521311d+04,
     4      0.5932389467966636d+04,-.5905549835244418d+04,
     5      0.5069316733394003d+04,-.4762380240860056d+04,
     6      0.3313918945198159d+04,-.2983749416962941d+04,
     7      0.1536013643780564d+04,-.1332015972714056d+04,
     8      0.1710563613572268d-07,0.2263913756577799d-08/
         data arr1164/
     1      -.1372594994031768d-06,0.1269125685330998d-05,
     2      -.1881152999836073d-05,0.8288863512502776d-05,
     3      -.1466525157394640d-04,0.9376440091825492d-04,
     4      -.1317087041159843d-03,0.5665805500234224d-03,
     5      -.7931240317275385d-03,0.3916650762986990d-02,
     6      -.5054433395751121d-02,0.2032775969634796d-01,
     7      -.2564123396372598d-01,0.1079048913592363d+00,
     8      -.1299426209688016d+00,0.4773214565566383d+00/
         data arr1165/
     1      0.4387648350516857d+00,-.6981372185108641d+01,
     2      0.4058268234677251d+02,-.1342348653357929d+03,
     3      0.3590375858537198d+03,-.7657614105893601d+03,
     4      0.1455748327050309d+04,-.2390988258490654d+04,
     5      0.3663877594132281d+04,-.4991579909646125d+04,
     6      0.6582386312243391d+04,-.7757737111766086d+04,
     7      0.9162598729861450d+04,-.9410832868166580d+04,
     8      0.1025133711991727d+05,-.9160218421255367d+04/
         data arr1166/
     1      0.9386071802966324d+04,-.6631183849506362d+04,
     2      0.6503037006532675d+04,-.3386270971418143d+04,
     3      0.3191510061897334d+04,-.3234403158232563d-07,
     4      -.8132046292051596d-08,0.2704969807379212d-06,
     5      -.2401045351627378d-05,0.3705599714697657d-05,
     6      -.1599788801925047d-04,0.2908515772709479d-04,
     7      -.1787537546919125d-03,0.2599183530310234d-03,
     8      -.1087647032158412d-02,0.1571290255277823d-02/
         data arr1167/
     1      -.7489110635356048d-02,0.9991980891150928d-02,
     2      -.3900711274450895d-01,0.5081162672942826d-01,
     3      -.2067523781466671d+00,0.2572863028894218d+00,
     4      -.9169138157222126d+00,0.1113395265085382d+01,
     5      -.2976095379715238d+01,-.4816397365534384d+01,
     6      0.3211189326512740d+02,-.1452963872653205d+03,
     7      0.3844557143845197d+03,-.9240916918547908d+03,
     8      0.1744418238802957d+04,-.3125785329618705d+04/
         data arr1168/
     1      0.4694858126383626d+04,-.6978951288382121d+04,
     2      0.8837291800981274d+04,-.1149655258841050d+05,
     3      0.1238387461258138d+05,-.1462755638064497d+05,
     4      0.1348381045230099d+05,-.1479106016158202d+05,
     5      0.1055551303896723d+05,-.1098131745265058d+05,
     6      0.5759901253596153d+04,-.5706160066578890d+04,
     7      0.5335512081283850d-07,0.2041945283919020d-07,
     8      -.4666439425322451d-06,0.3969265539000215d-05/
         data arr1169/
     1      -.6389809005491619d-05,0.2702015530453726d-04,
     2      -.5050560097629748d-04,0.2979759997619015d-03,
     3      -.4490393019763582d-03,0.1826591274124016d-02,
     4      -.2725513813300854d-02,0.1252445953774221d-01,
     5      -.1729347812429764d-01,0.6548196160372334d-01,
     6      -.8815962252053410d-01,0.3465335096983283d+00,
     7      -.4460223534583305d+00,0.1541027684438864d+01,
     8      -.1933981821666944d+01,0.6680171307799168d+01/
         data arr1170/
     1      -.7112107745707623d+01,0.1526236508893414d+02,
     2      0.2148439491791817d+02,-.9387474296023723d+02,
     3      0.4128667059150539d+03,-.9191870662377488d+03,
     4      0.2104238768404390d+04,-.3490143899863509d+04,
     5      0.6095176185280257d+04,-.8280280838290445d+04,
     6      0.1215291235242271d+05,-.1366556858112949d+05,
     7      0.1779515306089025d+05,-.1686296116988347d+05,
     8      0.2003900507458666d+05,-.1437934380723508d+05/
         data arr1171/
     1      0.1602008220571010d+05,-.8451508866756804d+04,
     2      0.8860437168902687d+04,-.8102896172675297d-07,
     3      -.4755118421677076d-07,0.7607999171654033d-06,
     4      -.6092095461550367d-05,0.1041048032541014d-04,
     5      -.4280529982328228d-04,0.8314860095873053d-04,
     6      -.4631091851642039d-03,0.7336905887791562d-03,
     7      -.2870193967173058d-02,0.4480074719798854d-02,
     8      -.1956037129466032d-01,0.2833406305137180d-01/
         data arr1172/
     1      -.1028465531624201d+00,0.1449819454939307d+00,
     2      -.5430597235122832d+00,0.7326247766635893d+00,
     3      -.2424901745383957d+01,0.3186294423866301d+01,
     4      -.1050757766665617d+02,0.1336484194258625d+02,
     5      -.3877162380875648d+02,0.3901584288574831d+02,
     6      -.8759097691523296d+02,-.3545407904452213d+02,
     7      0.1523144271034830d+03,-.9291010397690648d+03,
     8      0.1699341992094496d+04,-.4083631104946230d+04/
         data arr1173/
     1      0.5912580624740907d+04,-.1051289434269046d+05,
     2      0.1219500952916884d+05,-.1832778788685125d+05,
     3      0.1772306499641000d+05,-.2358860320621944d+05,
     4      0.1683627611771273d+05,-.2066314485823109d+05,
     5      0.1092620409127303d+05,-.1240779923289196d+05,
     6      0.1000000000000000d+01,-.1145643923738960d+01,
     7      0.9921567416492215d+00,-.7441175562369162d+00,
     8      0.5094624637332227d+00,-.3272081918376500d+00/
         data arr1174/
     1      0.2003732774152414d+00,-.1182396386952224d+00,
     2      0.6773026180815341d-01,-.3786236738424700d-01,
     3      0.2073807269704272d-01,-.1116341697325042d-01,
     4      0.5920295883019168d-02,-.3099196927418717d-02,
     5      0.1603986800379920d-02,-.8217986937539635d-03,
     6      0.4172702797463727d-03,-.2101636458296884d-03,
     7      0.1050819166198410d-03,-.5219424981369272d-04,
     8      0.2576920824462509d-04,-.1265280986519491d-04/
         data arr1175/
     1      0.6182298376476633d-05,-.3007250510988441d-05,
     2      0.1459705395847672d-05,-.7061205059330615d-06,
     3      0.3464544975906285d-06,-.1637395526036961d-06,
     4      0.8147691138235764d-07,-.1326005903152416d-07,
     5      -.6858511202503589d-08,0.7499479949885920d-07,
     6      -.7658818771946795d-07,0.1600098528567393d-06,
     7      -.1084145595109001d-06,0.1797131563391324d-06,
     8      -.9619699035010680d-07,0.1345224573931741d-06/
         data arr1176/
     1      -.4564794223410109d-16,0.1000000000000000d+01,
     2      -.1732050807568878d+01,0.1948557158514988d+01,
     3      -.1778781183844716d+01,0.1428053625814919d+01,
     4      -.1049400812573423d+01,0.7224561259534743d+00,
     5      -.4729585547810957d+00,0.2974408534775839d+00,
     6      -.1810167388607565d+00,0.1071865211882137d+00,
     7      -.6201189490437854d-01,0.3516761117471809d-01,
     8      -.1960104246431058d-01,0.1075987060753717d-01/
         data arr1177/
     1      -.5827573692850700d-02,0.3118579622299981d-02,
     2      -.1651013768976997d-02,0.8656176700978830d-03,
     3      -.4498612938225947d-03,0.2319248903561299d-03,
     4      -.1187048381136461d-03,0.6034674767041195d-04,
     5      -.3050723687345401d-04,0.1529145124079050d-04,
     6      -.7611307519120432d-05,0.3554041734707295d-05,
     7      -.1495565856190184d-05,0.1403545895108719d-07,
     8      0.6360924976261771d-06,-.1712949763917631d-05/
         data arr1178/
     1      0.1817144804793931d-05,-.2807062884556859d-05,
     2      0.2023717091610006d-05,-.2719987993729755d-05,
     3      0.1471041173751840d-05,-.1776462688284964d-05,
     4      0.4039865155642945d-16,0.2148380433823389d-16,
     5      0.1000000000000000d+01,-.2250000000000001d+01,
     6      0.3080939385966562d+01,-.3297948581125854d+01,
     7      0.3029359208135324d+01,-.2502661432781449d+01,
     8      0.1911439242428126d+01,-.1373820454584896d+01/
         data arr1179/
     1      0.9405905661742475d+00,-.6188416686022698d+00,
     2      0.3938284263229745d+00,-.2436483572568323d+00,
     3      0.1471166724908821d+00,-.8697099812529601d-01,
     4      0.5046826657383117d-01,-.2880820161888691d-01,
     5      0.1620461445365296d-01,-.8995747900745847d-02,
     6      0.4934775895948772d-02,-.2677976074316707d-02,
     7      0.1439037934391490d-02,-.7663456694709111d-03,
     8      0.4047766150845381d-03,-.2121757512042516d-03/
         data arr1180/
     1      0.1105057472401841d-03,-.5712167717467655d-04,
     2      0.2941256719514446d-04,-.1478441579106597d-04,
     3      0.7423924999904941d-05,-.3035236562870000d-05,
     4      0.1158167896498082d-05,0.6970656578158114d-06,
     5      -.6327888134402748d-06,0.1667649927309782d-05,
     6      -.9144666336519478d-06,0.1414040509279648d-05,
     7      0.6395148376671479d-15,0.3588474594411986d-15,
     8      0.3443679809873392d-14,0.9999999999999885d+00/
         data arr1181/
     1      -.2738612787525797d+01,0.4397264774834406d+01,
     2      -.5385527481128922d+01,0.5561469850624449d+01,
     3      -.5097171313137893d+01,0.4274108080924418d+01,
     4      -.3344322013032703d+01,0.2475366674359353d+01,
     5      -.1750348561252710d+01,0.1191169746310423d+01,
     6      -.7846222521864912d+00,0.5024990986735914d+00,
     7      -.3140247644175064d+00,0.1920546698431705d+00,
     8      -.1152327881936587d+00,0.6796783775647783d-01/
         data arr1182/
     1      -.3947810179986361d-01,0.2261388121895794d-01,
     2      -.1279105656144904d-01,0.7152142260843801d-02,
     3      -.3956890198983292d-02,0.2168626799817769d-02,
     4      -.1178132478294145d-02,0.6378317196743271d-03,
     5      -.3446256920633338d-03,0.1930550517350127d-03,
     6      -.1105956542504312d-03,0.7734615933091517d-04,
     7      -.5334589648030065d-04,0.5384072687024221d-04,
     8      -.3573678879720487d-04,0.4176286808035012d-04/
         data arr1183/
     1      -.2217021836249568d-04,0.2542275268842635d-04,
     2      -.8820747813159956d-15,-.4682737027098533d-15,
     3      -.4978416176843911d-14,0.1689780503281568d-13,
     4      0.9999999999999508d+00,-.3211308144666191d+01,
     5      0.5899549770956407d+01,-.8123046640191695d+01,
     6      0.9306119025580630d+01,-.9364101636553055d+01,
     7      0.8548216161822939d+01,-.7231008883482860d+01,
     8      0.5752232343217037d+01,-.4349536932899307d+01/
         data arr1184/
     1      0.3151538917378980d+01,-.2201840734851450d+01,
     2      0.1490653220001555d+01,-.9817983169440224d+00,
     3      0.6311560412320494d+00,-.3970936172762693d+00,
     4      0.2450615056583006d+00,-.1486339939615098d+00,
     5      0.8874323337451372d-01,-.5223280526469447d-01,
     6      0.3034371243545844d-01,-.1741774087176842d-01,
     7      0.9886926199510798d-02,-.5556753252816003d-02,
     8      0.3092214108482347d-02,-.1711655699836749d-02/
         data arr1185/
     1      0.9379650404491101d-03,-.5238438885456885d-03,
     2      0.2876123105415441d-03,-.1784195172474997d-03,
     3      0.9586086855829431d-04,-.7579292982886785d-04,
     4      0.3610385922228919d-04,-.3611043128282982d-04,
     5      -.2410301998372088d-14,-.1554088697719632d-14,
     6      -.1494356794958890d-13,0.5543434168256345d-13,
     7      -.1537195638217340d-12,0.1000000000000299d+01,
     8      -.3674234614176855d+01,0.7588539879322136d+01/
         data arr1186/
     1      -.1159168613706942d+02,0.1457988647419240d+02,
     2      -.1597146541564077d+02,0.1576213178714511d+02,
     3      -.1432994177956105d+02,0.1218999567728540d+02,
     4      -.9813878885686389d+01,0.7542175035018716d+01,
     5      -.5570265434108592d+01,0.3974510610181983d+01,
     6      -.2751584326305657d+01,0.1854822029270696d+01,
     7      -.1220993560495345d+01,0.7868386225283539d+00,
     8      -.4974258757528944d+00,0.3090435404235444d+00/
         data arr1187/
     1      -.1889879102183504d+00,0.1139045539157328d+00,
     2      -.6773966108808512d-01,0.3977598975114098d-01,
     3      -.2307480657892479d-01,0.1320002737912936d-01,
     4      -.7445035905852209d-02,0.4082235942272192d-02,
     5      -.2181743395981024d-02,0.1057356412546805d-02,
     6      -.4977258064367899d-03,0.1386910042416525d-03,
     7      -.3275305486045757d-04,-.6063940439069548d-04,
     8      -.7544290368875264d-14,-.2628966706516126d-14/
         data arr1188/
     1      -.2034671347238859d-13,0.1502633796426711d-13,
     2      -.9576732224797574d-13,-.9430981368419746d-13,
     3      0.9999999999972162d+00,-.4130677910464338d+01,
     4      0.9464572098080004d+01,-.1587256994196552d+02,
     5      0.2173441150685109d+02,-.2573945342437497d+02,
     6      0.2730081309001501d+02,-.2654157277669890d+02,
     7      0.2403899565514579d+02,-.2052720041524941d+02,
     8      0.1667637643540487d+02,-.1298069721991275d+02/
         data arr1189/
     1      0.9735522838875044d+01,-.7067460214095127d+01,
     2      0.4984683875357640d+01,-.3426403907065092d+01,
     3      0.2301491474310977d+01,-.1513994209090428d+01,
     4      0.9772755275491661d+00,-.6200338089688555d+00,
     5      0.3871962036275779d+00,-.2383091348690306d+00,
     6      0.1446740894242271d+00,-.8674471728828827d-01,
     7      0.5130240064156683d-01,-.3001950139434309d-01,
     8      0.1719122860941486d-01,-.9772714659479873d-02/
         data arr1190/
     1      0.5196385643302467d-02,-.2822843349776254d-02,
     2      0.1212673207657189d-02,-.5991645808950111d-03,
     3      0.2794797016084712d-12,0.1429790917538111d-12,
     4      0.1423140060918509d-11,-.4491226476772644d-11,
     5      0.1333024990747383d-10,-.2290152904053192d-10,
     6      0.1982682657789462d-09,0.9999999996734480d+00,
     7      -.4582575693681970d+01,0.1152781960975133d+02,
     8      -.2104682279046104d+02,0.3115645176207190d+02/
         data arr1191/
     1      -.3965568893644509d+02,0.4497833361683768d+02,
     2      -.4655699817735546d+02,0.4472505627554108d+02,
     3      -.4037200721054448d+02,0.3456760964988051d+02,
     4      -.2828258446217782d+02,0.2224258346459488d+02,
     5      -.1689443477986182d+02,0.1244249248349240d+02,
     6      -.8914636329633053d+01,0.6230828668102710d+01,
     7      -.4258421806347225d+01,0.2851975676306714d+01,
     8      -.1874686439723785d+01,0.1212375906441788d+01/
         data arr1192/
     1      -.7717446760012167d+00,0.4865400550811986d+00,
     2      -.3020888752132083d+00,0.1896642143169871d+00,
     3      -.1159070144946647d+00,0.7628653183794082d-01,
     4      -.4376366314549711d-01,0.3209538182906855d-01,
     5      -.1531984203851052d-01,0.1284998909712818d-01,
     6      -.8044245976902304d-12,-.3711006077388752d-12,
     7      -.3702036611281477d-11,0.1052520150606487d-10,
     8      -.3263794903173795d-10,0.5081903664206660d-10/
         data arr1193/
     1      -.5148882765659207d-09,0.7511777704924138d-09,
     2      0.9999999967975188d+00,-.5031152944950002d+01,
     3      0.1377837977712645d+02,-.2719558066256308d+02,
     4      0.4326790379793974d+02,-.5889046233560960d+02,
     5      0.7111698909880827d+02,-.7807845914476075d+02,
     6      0.7928904730940868d+02,-.7543270831375444d+02,
     7      0.6788942411626105d+02,-.5824475850620463d+02,
     8      0.4792669138592777d+02,-.3801246583309982d+02/
         data arr1194/
     1      0.2918005501470483d+02,-.2175489572877477d+02,
     2      0.1579748463930439d+02,-.1120173900560049d+02,
     3      0.7771247581714676d+01,-.5286723091326233d+01,
     4      0.3528789933185784d+01,-.2319609936538672d+01,
     5      0.1494877356783474d+01,-.9573290304087554d+00,
     6      0.5935681415267109d+00,-.3761478880984961d+00,
     7      0.2136865912160349d+00,-.1375824027761770d+00,
     8      0.6323742687784418d-01,-.4315470664077377d-01/
         data arr1195/
     1      0.1562806929889229d-11,0.5091282016373971d-12,
     2      0.3435424023097822d-11,0.1238158114526273d-11,
     3      0.8447598274084621d-11,0.4988084837169225d-10,
     4      0.4659998106382899d-09,0.3074373294422586d-09,
     5      0.1763955882840674d-08,0.1000000002900094d+01,
     6      -.5477225554906670d+01,0.1621631124970483d+02,
     7      -.3439999083039426d+02,0.5852581228357285d+02,
     8      -.8481195879545581d+02,0.1086329970316017d+03/
         data arr1196/
     1      -.1260769457226767d+03,0.1349381411743463d+03,
     2      -.1349381277380468d+03,0.1273450870991069d+03,
     3      -.1143119524984601d+03,0.9822066920394519d+02,
     4      -.8119875317241698d+02,0.6486123645470930d+02,
     5      -.5023998585128932d+02,0.3784989221312225d+02,
     6      -.2780176073285680d+02,0.1995563896453612d+02,
     7      -.1401064660857409d+02,0.9641081167888330d+01,
     8      -.6482979110629687d+01,0.4279078070347982d+01/
         data arr1197/
     1      -.2727115313152657d+01,0.1709234735025098d+01,
     2      -.9815531215830818d+00,0.5701575213265568d+00,
     3      -.2557991752707385d+00,0.1284760633344007d+00,
     4      -.1352220510062177d-10,-.6027904649172435d-11,
     5      -.4633203292022571d-10,0.9001622959357295d-10,
     6      -.3147123147463242d-09,0.2074893684140187d-09,
     7      -.6383908138048440d-08,0.5285489597859303d-08,
     8      -.3483545585706584d-07,0.2545727857849291d-07/
         data arr1198/
     1      0.9999996922397933d+00,-.5921359425914238d+01,
     2      0.1884164944265081d+02,-.4274120900350662d+02,
     3      0.7742236279314286d+02,-.1190014794006326d+03,
     4      0.1611287316578863d+03,-.1970897411132753d+03,
     5      0.2217257953291724d+03,-.2324991222042916d+03,
     6      0.2295738856445636d+03,-.2151902053005029d+03,
     7      0.1927201012722214d+03,-.1657865350299650d+03,
     8      0.1375830589954567d+03,-.1105680908248262d+03/
         data arr1199/
     1      0.8628747639545356d+02,-.6560383769853824d+02,
     2      0.4862670061054750d+02,-.3529273051226522d+02,
     3      0.2494148948365215d+02,-.1738101088659250d+02,
     4      0.1161903666410189d+02,-.7785656449479955d+01,
     5      0.4660574659579680d+01,-.2995348458637320d+01,
     6      0.1403351700198764d+01,-.8530870511312111d+00,
     7      0.4784992936024653d-10,0.2116679419268110d-10,
     8      0.1366615510920599d-09,-.1707162658293211d-09/
         data arr1200/
     1      0.7117167135780626d-09,0.3813912204035952d-09,
     2      0.1868838800096334d-07,-.6136491073894638d-08,
     3      0.9061765733915312d-07,-.6007810823754094d-08,
     4      0.8659371434811871d-06,0.9999998238547765d+00,
     5      -.6363956891684211d+01,0.2165442322418222d+02,
     6      -.5230037622937999d+02,0.1004849293957527d+03,
     7      -.1632685826431526d+03,0.2329918127838275d+03,
     8      -.2995604028610398d+03,0.3533804706983940d+03/
         data arr1201/
     1      -.3877040608338304d+03,0.3997555095529392d+03,
     2      -.3905571861081032d+03,0.3639747312971501d+03,
     3      -.3252785690967962d+03,0.2800697922920392d+03,
     4      -.2330819073070992d+03,0.1882173753856266d+03,
     5      -.1475546064141861d+03,0.1128465475874533d+03,
     6      -.8363152616895011d+02,0.6084444805739529d+02,
     7      -.4220323432007623d+02,0.2911520433794775d+02,
     8      -.1786101716975244d+02,0.1156859333507729d+02/
         data arr1202/
     1      -.5478410854635631d+01,0.3219294020702757d+01,
     2      -.2593719638255026d-09,-.1266148799505653d-09,
     3      -.9333996796827668d-09,0.2045022796409760d-08,
     4      -.6674059482156259d-08,0.5529951903509515d-08,
     5      -.1286832427805126d-06,0.1240996473809268d-06,
     6      -.7195813189822818d-06,0.6219244628803158d-06,
     7      -.6252380820164030d-05,0.5124164483987086d-05,
     8      0.9999679483205370d+00,-.6805303835673477d+01/
         data arr1203/
     1      0.2465445496439623d+02,-.6315859320718180d+02,
     2      0.1282751520419486d+03,-.2196661878029407d+03,
     3      0.3294962691522576d+03,-.4442244068500275d+03,
     4      0.5482842215689549d+03,-.6281454895394795d+03,
     5      0.6750292482807038d+03,-.6862872064529900d+03,
     6      0.6643554664469970d+03,-.6160792113427260d+03,
     7      0.5491763821279734d+03,-.4732653879999482d+03,
     8      0.3940019725534164d+03,-.3196982884942089d+03/
         data arr1204/
     1      0.2497756695001587d+03,-.1925729807860639d+03,
     2      0.1399468916567613d+03,-.1030275788867728d+03,
     3      0.6538714691715356d+02,-.4608379606594808d+02,
     4      0.2247415387818984d+02,-.1505188275700565d+02,
     5      0.9119912750420020d-09,0.4576812274364922d-09,
     6      0.3336951994251905d-08,-.7576087320046987d-08,
     7      0.2425354479079696d-07,-.2138722950589739d-07,
     8      0.4601550578328560d-06,-.4642007998572888d-06/
         data arr1205/
     1      0.2593631292920224d-05,-.2352321224595735d-05,
     2      0.2241587224309653d-04,-.1924392106999986d-04,
     3      0.1153374516676120d-03,0.9999058048635475d+00,
     4      -.7245002961831985d+01,0.2784179371994554d+02,
     5      -.7539433922126862d+02,0.1613909345557544d+03,
     6      -.2904937043897110d+03,0.4569243046556040d+03,
     7      -.6444995031705428d+03,0.8306936139700369d+03,
     8      -.9917930404340289d+03,0.1109210804940483d+04/
         data arr1206/
     1      -.1171110515737476d+04,0.1176535127911594d+04,
     2      -.1128642063101630d+04,0.1041983333062323d+04,
     3      -.9235329111916122d+03,0.7957492178633277d+03,
     4      -.6549873920743192d+03,0.5323151727218058d+03,
     5      -.4030899105182565d+03,0.3108391759019592d+03,
     6      -.2025621684404014d+03,0.1488432284984695d+03,
     7      -.7380688082160413d+02,0.5137389779780015d+02,
     8      -.3193909431095709d-08,-.1658728776587272d-08/
         data arr1207/
     1      -.1251408829479244d-07,0.3137854987095999d-07,
     2      -.9703051661880035d-07,0.1074278845798187d-06,
     3      -.1729112789996745d-05,0.2017051068194336d-05,
     4      -.1006370226900669d-04,0.1076938047296269d-04,
     5      -.8519354564542703d-04,0.8533164080270945d-04,
     6      -.4451942119301574d-03,0.4277900319136441d-03,
     7      0.9973758768054172d+00,-.7682808250228839d+01,
     8      0.3120570485450544d+02,-.8908707141147061d+02/
         data arr1208/
     1      0.2004150536446694d+03,-.3783312013335174d+03,
     2      0.6224908119637435d+03,-.9170426856056022d+03,
     3      0.1231402007092727d+04,-.1530436372971752d+04,
     4      0.1776495147487723d+04,-.1947502538755471d+04,
     5      0.2021523580552153d+04,-.2011214697060716d+04,
     6      0.1905443466635941d+04,-.1754174636012561d+04,
     7      0.1525845612287508d+04,-.1318319827713816d+04,
     8      0.1043472534384768d+04,-.8543575859266031d+03/
         data arr1209/
     1      0.5721871416491693d+03,-.4477432014093372d+03,
     2      0.2263503259812662d+03,-.1692347946700514d+03,
     3      0.1189581734943673d-07,0.6370657060418052d-08,
     4      0.5259665633311669d-07,-.1504117927351198d-06,
     5      0.4492731039201295d-06,-.6407950073741070d-06,
     6      0.7293889908056457d-05,-.1030050693378940d-04,
     7      0.4461591712748154d-04,-.5849447867231865d-04,
     8      0.3660184436039809d-03,-.4467985721315669d-03/
         data arr1210/
     1      0.1959172082369338d-02,-.2303571473254920d-02,
     2      0.1140838607585764d-01,0.9872213144821126d+00,
     3      -.8072022700530089d+01,0.3472352183823870d+02,
     4      -.1041011975301186d+03,0.2459215963970910d+03,
     5      -.4852330813674407d+03,0.8345008058138565d+03,
     6      -.1279266947074743d+04,0.1789936277250331d+04,
     7      -.2305159951432738d+04,0.2783825051688966d+04,
     8      -.3145187428510294d+04,0.3402967408843879d+04/
         data arr1211/
     1      -.3462624013571383d+04,0.3446798255267594d+04,
     2      -.3180719037666421d+04,0.2975454946270999d+04,
     3      -.2472541079454424d+04,0.2210018627135636d+04,
     4      -.1519230252674038d+04,0.1315106730268506d+04,
     5      -.6790052960722112d+03,0.5722059786624302d+03,
     6      -.2746805297273547d-07,-.1485562542136671d-07,
     7      -.1230038987468395d-06,0.3567253626528624d-06,
     8      -.1060048230678870d-05,0.1539887070090479d-05/
         data arr1212/
     1      -.1706245622870475d-04,0.2452996485592209d-04,
     2      -.1048564394768582d-03,0.1398229655009827d-03,
     3      -.8576784577707900d-03,0.1065634440471466d-02,
     4      -.4600987265743676d-02,0.5503254201398928d-02,
     5      -.2676044317328507d-01,0.3050316650508036d-01,
     6      0.8778179821980951d+00,-.8427044145599680d+01,
     7      0.3796875047927257d+02,-.1206074172613797d+03,
     8      0.2970459616052352d+03,-.6147607027434131d+03/
         data arr1213/
     1      0.1097095218539957d+04,-.1757509866926412d+04,
     2      0.2538892003624180d+04,-.3410727730876852d+04,
     3      0.4216192008973000d+04,-.4977816199741187d+04,
     4      0.5437429934028746d+04,-.5819400162369897d+04,
     5      0.5659606076715512d+04,-.5621959250212585d+04,
     6      0.4844139986308488d+04,-.4545290148519221d+04,
     7      0.3180755043788839d+04,-.2863097719128885d+04,
     8      0.1493322841768584d+04,-.1297084881541687d+04/
         data arr1214/
     1      0.6824074299542874d-07,0.3740318367159929d-07,
     2      0.3220986394101568d-06,-.9784534576294298d-06,
     3      0.2875952454589186d-05,-.4490023137510835d-05,
     4      0.4474426568381755d-04,-.6862011316813434d-04,
     5      0.2801796043181241d-03,-.3980637380946349d-03,
     6      0.2265171435071329d-02,-.3002871213784973d-02,
     7      0.1226109334069313d-01,-.1563051098853260d-01,
     8      0.7099356795133752d-01,-.8631738135968007d-01/
         data arr1215/
     1      0.3260291729974166d+00,0.6153604532608280d+00,
     2      -.7504069126155311d+01,0.4076423823719047d+02,
     3      -.1339946039591305d+03,0.3539095482380059d+03,
     4      -.7530295939259249d+03,0.1421472595823258d+04,
     5      -.2331640730482266d+04,0.3553141167346575d+04,
     6      -.4838832447521113d+04,0.6347815619181966d+04,
     7      -.7487742559943466d+04,0.8795942753960805d+04,
     8      -.9056049473456338d+04,0.9805352370121839d+04/
         data arr1216/
     1      -.8806638696233747d+04,0.8962689594330915d+04,
     2      -.6379581577337653d+04,0.6208569998106421d+04,
     3      -.3279969490033096d+04,0.3067480211143621d+04,
     4      -.1265769382034077d-06,-.6994193184423066d-07,
     5      -.6141732715061192d-06,0.1908710253904277d-05,
     6      -.5579901677817931d-05,0.8999515071364605d-05,
     7      -.8537871780954868d-04,0.1350683661615076d-03,
     8      -.5396138203408716d-03,0.7896600774044721d-03/
         data arr1217/
     1      -.4337601945618918d-02,0.5930040826555606d-02,
     2      -.2358315140852659d-01,0.3097484037768915d-01,
     3      -.1362473683276627d+00,0.1707756253078861d+00,
     4      -.6274835598280839d+00,0.7627188132947302d+00,
     5      -.1876912927709689d+01,-.6060840567976265d+01,
     6      0.3544137445144640d+02,-.1473851499109997d+03,
     7      0.3884952057796586d+03,-.9161401101869448d+03,
     8      0.1730259748952854d+04,-.3068742120497935d+04/
         data arr1218/
     1      0.4616905010853014d+04,-.6807991672528558d+04,
     2      0.8646130635907240d+04,-.1116177158673217d+05,
     3      0.1207566676274105d+05,-.1414646827813457d+05,
     4      0.1313074998555275d+05,-.1427349803697905d+05,
     5      0.1027868486250780d+05,-.1058551478994744d+05,
     6      0.5639731853452070d+04,-.5529472148431370d+04,
     7      0.1878292869534832d-06,0.1045245014624167d-06,
     8      0.9330952897564072d-06,-.2954033931755262d-05/
         data arr1219/
     1      0.8598657246291976d-05,-.1422449752886944d-04,
     2      0.1297897989720334d-03,-.2105270330614517d-03,
     3      0.8265953659029814d-03,-.1238297869807746d-02,
     4      0.6613169743664103d-02,-.9266521351253511d-02,
     5      0.3608613261831687d-01,-.4853347958452475d-01,
     6      0.2081016237959879d+00,-.2672437399277058d+00,
     7      0.9606394426482292d+00,-.1195649556853969d+01,
     8      0.4401615254434422d+01,-.4290937258638912d+01/
         data arr1220/
     1      0.7222024158752331d+01,0.3082304138457936d+02,
     2      -.1175597446588180d+03,0.4328300031363959d+03,
     3      -.9619329849193445d+03,0.2103630696935808d+04,
     4      -.3500505495677645d+04,0.5941222788726569d+04,
     5      -.8098269740318922d+04,0.1160116625797936d+05,
     6      -.1311182147526659d+05,0.1667354946863022d+05,
     7      -.1591688055398960d+05,0.1846864861386480d+05,
     8      -.1340660094484159d+05,0.1457444842430457d+05/
         data arr1221/
     1      -.7817341191261085d+04,0.8003062180576950d+04,
     2      -.2985115217563497d-06,-.1663054142713981d-06,
     3      -.1571627451353533d-05,0.5172172543238273d-05,
     4      -.1497228490672367d-04,0.2623679251470795d-04,
     5      -.2189541674280765d-03,0.3753068150881310d-03,
     6      -.1419832643740018d-02,0.2240994811679415d-02,
     7      -.1123541727221385d-01,0.1662609386738810d-01,
     8      -.6183949128655775d-01,0.8766891335178718d-01/
         data arr1222/
     1      -.3551387922891790d+00,0.4812672849333694d+00,
     2      -.1648585514045917d+01,0.2162698300981190d+01,
     3      -.7543950716481088d+01,0.9562291425146256d+01,
     4      -.2844667150020629d+02,0.2600289643936653d+02,
     5      -.5503348796197907d+02,-.7358693919223496d+02,
     6      0.2374139208505686d+03,-.1011870325190726d+04,
     7      0.1864877656558741d+04,-.4190657043764462d+04,
     8      0.6130276287113675d+04,-.1053538427105017d+05/
         data arr1223/
     1      0.1235827091605549d+05,-.1811272097195281d+05,
     2      0.1773586573802383d+05,-.2310987764163004d+05,
     3      0.1672977613845783d+05,-.2012922953641406d+05,
     4      0.1084909319767935d+05,-.1210253907450199d+05,
     5      0.1000000000000000d+01,-.1299038105676658d+01,
     6      0.1257788237343632d+01,-.1042902912247828d+01,
     7      0.7821771841858706d+00,-.5461254978365357d+00,
     8      0.3612280629767019d+00,-.2289700757640648d+00/
         data arr1224/
     1      0.1402149629970756d+00,-.8344459357106414d-01,
     2      0.4847692818463774d-01,-.2758774393019672d-01,
     3      0.1542201769273185d-01,-.8487500327244478d-02,
     4      0.4607101307458128d-02,-.2470282848134137d-02,
     5      0.1310065295410322d-02,-.6879217696836750d-03,
     6      0.3580057485433556d-03,-.1847969162845960d-03,
     7      0.9467991688777607d-04,-.4817646961546954d-04,
     8      0.2436044997467447d-04,-.1224569046056487d-04/
         data arr1225/
     1      0.6132438293400500d-05,-.3065702222869891d-05,
     2      0.1569378161732986d-05,-.8416111617483588d-06,
     3      0.5586875377969673d-06,-.4188067607158490d-06,
     4      0.4678536734565836d-06,-.4322708586278737d-06,
     5      0.5489469583373019d-06,-.4034054996993962d-06,
     6      0.4861816339883583d-06,-.2708048062746531d-06,
     7      0.2986701805935942d-06,-.5513259619673216d-16,
     8      0.1000000000000000d+01,-.1936491673103709d+01/
         data arr1226/
     1      0.2408481108499712d+01,-.2408481108499714d+01,
     2      0.2102038021248318d+01,-.1668440955187630d+01,
     3      0.1233828725535220d+01,-.8635002307286756d+00,
     4      0.5781211027305398d+00,-.3731755671625162d+00,
     5      0.2336076069865477d+00,-.1424624970853556d+00,
     6      0.8493785048268451d-01,-.4965167551667216d-01,
     7      0.2852436989333902d-01,-.1613582053417958d-01,
     8      0.9002564120755485d-02,-.4960677091917574d-02/
         data arr1227/
     1      0.2702890387425386d-02,-.1457708675838846d-02,
     2      0.7788593765325416d-03,-.4125984605481729d-03,
     3      0.2168912833792261d-03,-.1131821764502744d-03,
     4      0.5873535601565153d-04,-.3018816126966498d-04,
     5      0.1545406974374957d-04,-.7442120690606929d-05,
     6      0.3506034901246246d-05,-.6390795150312080d-06,
     7      -.3687639376409480d-06,0.2094965842431893d-05,
     8      -.1561157979498563d-05,0.2748615396106050d-05/
         data arr1228/
     1      -.1537721982193096d-05,0.2137537981409934d-05,
     2      -.3005766173844276d-15,0.2023144128556360d-14,
     3      0.9999999999999981d+00,-.2487468592766552d+01,
     4      0.3731202889149817d+01,-.4341951066340888d+01,
     5      0.4307896022381059d+01,-.3822878484855091d+01,
     6      0.3121367212185645d+01,-.2388323629817261d+01,
     7      0.1734363308175810d+01,-.1206344495124899d+01,
     8      0.8092404885801944d+00,-.5263406080119999d+00/
         data arr1229/
     1      0.3333201938924363d+00,-.2062188946888240d+00,
     2      0.1249875237443789d+00,-.7438244912182854d-01,
     3      0.4354858097113178d-01,-.2512372512227223d-01,
     4      0.1430229272552419d-01,-.8043726434111572d-02,
     5      0.4474027967516514d-02,-.2463266422388998d-02,
     6      0.1343952136811416d-02,-.7272003517818394d-03,
     7      0.3921164451623375d-03,-.2112603835257663d-03,
     8      0.1176463090355750d-03,-.6730752965063669d-04/
         data arr1230/
     1      0.4625436082849073d-04,-.3200326287617386d-04,
     2      0.3135465930241737d-04,-.2111234594167447d-04,
     3      0.2396627036710328d-04,-.1306448887066987d-04,
     4      0.1456771385533929d-04,0.8268547510878787d-15,
     5      -.5271561457489166d-14,0.5372352237148956d-14,
     6      0.1000000000000003d+01,-.2999999999999974d+01,
     7      0.5236590016412967d+01,-.6927357450716043d+01,
     8      0.7684274880839801d+01,-.7529021000535516d+01/
         data arr1231/
     1      0.6720995576521856d+01,-.5577922272369899d+01,
     2      0.4364718609020836d+01,-.3253269170709931d+01,
     3      0.2327565745378077d+01,-.1607997118061569d+01,
     4      0.1077740497522861d+01,-.7034562563014449d+00,
     5      0.4485430657639561d+00,-.2801150410253693d+00,
     6      0.1717021024004597d+00,-.1034954152300337d+00,
     7      0.6144070753746688d-01,-.3597269318755038d-01,
     8      0.2079573883140861d-01,-.1188303629750349d-01/
         data arr1232/
     1      0.6716657803089395d-02,-.3760708108841207d-02,
     2      0.2085664562012762d-02,-.1153321044286362d-02,
     3      0.6322816763630575d-03,-.3588071371677946d-03,
     4      0.2011705223752994d-03,-.1347829209532961d-03,
     5      0.7551035048873390d-04,-.6778148670116802d-04,
     6      0.3419708751719420d-04,-.3710302212398444d-04,
     7      0.1893569117691128d-14,-.1097638862290357d-13,
     8      0.1184489165490212d-13,0.6581927483734282d-14/
         data arr1233/
     1      0.1000000000000051d+01,-.3491060010943042d+01,
     2      0.6927357450718082d+01,-.1024569984112653d+02,
     3      0.1254836833424030d+02,-.1344199115313219d+02,
     4      0.1301515196901686d+02,-.1163924962462723d+02,
     5      0.9759807513097464d+01,-.7758552488841702d+01,
     6      0.5895989439533787d+01,-.4310962013135767d+01,
     7      0.3048310478716396d+01,-.2093201099509042d+01,
     8      0.1400575385912360d+01,-.9157451081230544d+00/
         data arr1234/
     1      0.5864747900574584d+00,-.3686465471871694d+00,
     2      0.2278295752914836d+00,-.1386440258602016d+00,
     3      0.8318265734386732d-01,-.4925856441477205d-01,
     4      0.2880687855657714d-01,-.1664432471723078d-01,
     5      0.9480869843672428d-02,-.5320243401046222d-02,
     6      0.2896032096521524d-02,-.1530783522098600d-02,
     7      0.7249817837760467d-03,-.3305496201709981d-03,
     8      0.7605788192040094d-04,-.8971800186579559d-05/
         data arr1235/
     1      -.5503686570525960d-04,0.2683626357533174d-15,
     2      -.2280777842411998d-13,-.2893136754467977d-14,
     3      0.9984967239659310d-13,-.6477548497360842d-13,
     4      0.9999999999990820d+00,-.3968626966597447d+01,
     5      0.8804517661405271d+01,-.1437771713451611d+02,
     6      0.1925201960283137d+02,-.2236882539086261d+02,
     7      0.2333811138019224d+02,-.2236525864858100d+02,
     8      0.2000165341263450d+02,-.1688882293368774d+02/
         data arr1236/
     1      0.1358343365561352d+02,-.1047811424547839d+02,
     2      0.7794656533380488d+01,-.5616647866242247d+01,
     3      0.3934671420977319d+01,-.2687892462305221d+01,
     4      0.1795151498352536d+01,-.1174694660353312d+01,
     5      0.7545656416455527d+00,-.4765677406024703d+00,
     6      0.2963525773145920d+00,-.1816754591438810d+00,
     7      0.1098867561578367d+00,-.6564474643277197d-01,
     8      0.3869309216194112d-01,-.2254058229486326d-01/
         data arr1237/
     1      0.1286075123945530d-01,-.7243597054617930d-02,
     2      0.3836710963320097d-02,-.2032979375260517d-02,
     3      0.8693926974023299d-03,-.3973970887145056d-03,
     4      -.1315355820765283d-12,0.1009039678384427d-11,
     5      -.7999738209771964d-12,-.1431815234327350d-11,
     6      -.3236790959002770d-11,0.6691455228863607d-10,
     7      0.9999999999067274d+00,-.4437059837023948d+01,
     8      0.1086853255911333d+02,-.1940421184591859d+02/
         data arr1238/
     1      0.2818207099737285d+02,-.3528390785649037d+02,
     2      0.3944860823434448d+02,-.4031954329566242d+02,
     3      0.3830025019450545d+02,-.3422703502831821d+02,
     4      0.2904260204027104d+02,-.2356882305599914d+02,
     5      0.1839840537595461d+02,-.1388020431797709d+02,
     6      0.1015926442189850d+02,-.7237327445829703d+01,
     7      0.5031882194063659d+01,-.3422306311968584d+01,
     8      0.2281631239622058d+01,-.1493538911851357d+01/
         data arr1239/
     1      0.9619689969675286d+00,-.6101141328188397d+00,
     2      0.3828870743005684d+00,-.2368609382637548d+00,
     3      0.1473782687603591d+00,-.8960883565710465d-01,
     4      0.5759362043785173d-01,-.3295063314693696d-01,
     5      0.2306615029870623d-01,-.1107862912747721d-01,
     6      0.8721773837722074d-02,0.3739411760043157d-12,
     7      -.3355720285708723d-11,0.2183614779859249d-11,
     8      0.6260284649146615d-11,0.7794406744673398d-11/
         data arr1240/
     1      -.2093449870006607d-09,0.2502649743969942d-09,
     2      0.9999999991471608d+00,-.4898979484192929d+01,
     3      0.1311964175258028d+02,-.2540607701596170d+02,
     4      0.3976045976342477d+02,-.5334425451434348d+02,
     5      0.6360896914198586d+02,-.6905518793748510d+02,
     6      0.6942509772319677d+02,-.6545460954407248d+02,
     7      0.5842991905908653d+02,-.4975837013371135d+02,
     8      0.4066716755590254d+02,-.3205494992993388d+02/
         data arr1241/
     1      0.2446664233732793d+02,-.1814491529952126d+02,
     2      0.1311200837107821d+02,-.9255487492397487d+01,
     3      0.6394289006985671d+01,-.4332928725531058d+01,
     4      0.2882062015158721d+01,-.1887827648169458d+01,
     5      0.1213420027292331d+01,-.7741591317193487d+00,
     6      0.4794532171073045d+00,-.3018956192128955d+00,
     7      0.1718905624633577d+00,-.1091732037851188d+00,
     8      0.5071621644844248d-01,-.3362228587266662d-01/
         data arr1242/
     1      0.1271122900675814d-12,0.4792260834724753d-11,
     2      0.2207055763340594d-11,-.2660036889422332d-10,
     3      0.2585565163147378d-10,0.1433103661045588d-09,
     4      0.3290893434475619d-09,-.5229567772693895d-09,
     5      0.1000000002604385d+01,-.5356071318556789d+01,
     6      0.1555798129142809d+02,-.3246427950712312d+02,
     7      0.5444425197072392d+02,-.7790475916230100d+02,
     8      0.9867081978265414d+02,-.1133707129391879d+03/
         data arr1243/
     1      0.1202478030929484d+03,-.1192695911387815d+03,
     2      0.1117257693853766d+03,-.9961390178053059d+02,
     3      0.8506161795589565d+02,-.6991962077737482d+02,
     4      0.5555761367186722d+02,-.4282411782164684d+02,
     5      0.3211646794950749d+02,-.2349101904377499d+02,
     6      0.1679329940540751d+02,-.1174608437787375d+02,
     7      0.8049923232745175d+01,-.5393300331420754d+01,
     8      0.3539817037766042d+01,-.2246405235335197d+01/
         data arr1244/
     1      0.1391461844371776d+01,-.7960708523467723d+00,
     2      0.4492768135607254d+00,-.2007677231288536d+00,
     3      0.9216948199907489d-01,0.4545379686806636d-11,
     4      -.5955076489980127d-10,0.1992755633925738d-10,
     5      0.1783139002838849d-09,-.1182858344835692d-10,
     6      -.3121615874777288d-08,0.1927668806893396d-08,
     7      -.8490680724184211d-08,0.6885129023108874d-08,
     8      0.9999998561643054d+00,-.5809474932053308d+01/
         data arr1245/
     1      0.1818363295716852d+02,-.4065984043841858d+02,
     2      0.7272565037946074d+02,-.1105334236145308d+03,
     3      0.1481673468363063d+03,-.1796059611389613d+03,
     4      0.2004128916573554d+03,-.2085964084612407d+03,
     5      0.2045810470043214d+03,-.1905758104122382d+03,
     6      0.1697040028179123d+03,-.1452188719933873d+03,
     7      0.1199287286669134d+03,-.9594369208657642d+02,
     8      0.7456276282468258d+02,-.5646535196674250d+02/
         data arr1246/
     1      0.4170629571409480d+02,-.3016164361501152d+02,
     2      0.2125772658499159d+02,-.1476031430180795d+02,
     3      0.9854510252936714d+01,-.6571411269748073d+01,
     4      0.3940002722511030d+01,-.2511654222579391d+01,
     5      0.1187485593232844d+01,-.7091567859441987d+00,
     6      -.1847460365953142d-10,0.2510043786991089d-09,
     7      -.7540103146214454d-10,-.7875800979602277d-09,
     8      0.1397285338451407d-09,0.1283871908600509d-07/
         data arr1247/
     1      -.6881796741699057d-08,0.3221199968690610d-07,
     2      -.1955300105284622d-07,0.5802078788320695d-06,
     3      0.9999997058629437d+00,-.6259989446095458d+01,
     4      0.2099665031888008d+02,-.5007380333169773d+02,
     5      0.9513201783865747d+02,-.1530265170305762d+03,
     6      0.2164122582261560d+03,-.2759804476046218d+03,
     7      0.3231560796257644d+03,-.3521497690079741d+03,
     8      0.3608471497063601d+03,-.3505357353739089d+03/
         data arr1248/
     1      0.3249573896603928d+03,-.2889970824959372d+03,
     2      0.2477065587463011d+03,-.2052934534747972d+03,
     3      0.1651450830805384d+03,-.1290378781617445d+03,
     4      0.9840671682226322d+02,-.7278673378417519d+02,
     5      0.5291221261309120d+02,-.3673309589768372d+02,
     6      0.2543346457011490d+02,-.1566534014556930d+02,
     7      0.1027104900621047d+02,-.4934101062351052d+01,
     8      0.2988918752854593d+01,0.1160028196329801d-09/
         data arr1249/
     1      -.1260663112032736d-08,0.5632608764720155d-09,
     2      0.3349791044669527d-08,0.5568887190199153d-09,
     3      -.6982066121127170d-07,0.5825265910392090d-07,
     4      -.2214858259069637d-06,0.2548391962176186d-06,
     5      -.3346215050349782d-05,0.2794578036493238d-05,
     6      0.9999840813218751d+00,-.6708190349874286d+01,
     7      0.2399695666167772d+02,-.6078722677290662d+02,
     8      0.1222253670109415d+03,-.2074238009108786d+03/
         data arr1250/
     1      0.3086026217100353d+03,-.4129778946072006d+03,
     2      0.5062786309099910d+03,-.5764278988560367d+03,
     3      0.6159304218685150d+03,-.6229030833305879d+03,
     4      0.6000822017518504d+03,-.5539467608612213d+03,
     5      0.4917667921426875d+03,-.4221075109086283d+03,
     6      0.3502481385862895d+03,-.2832001586204044d+03,
     7      0.2207731270072857d+03,-.1696957639461471d+03,
     8      0.1233249074462565d+03,-.9056404490726934d+02/
         data arr1251/
     1      0.5766027565515207d+02,-.4057251643372087d+02,
     2      0.2003694741922147d+02,-.1340727871418700d+02,
     3      -.4866632590780276d-09,0.4865020659048427d-08,
     4      -.2478137799128083d-08,-.1194218060530206d-07,
     5      -.4171788129936127d-08,0.2781224406222382d-06,
     6      -.2636446076426146d-06,0.9517661768680411d-06,
     7      -.1238143570696282d-05,0.1361547010401944d-04,
     8      -.1293690406686398d-04,0.6634946933844279d-04/
         data arr1252/
     1      0.9999352779241722d+00,-.7154077823246125d+01,
     2      0.2718450049217673d+02,-.7287932058395174d+02,
     3      0.1546030208089689d+03,-.2760142022674257d+03,
     4      0.4309348741462865d+03,-.6037429509569036d+03,
     5      0.7733350372068766d+03,-.9180688601453453d+03,
     6      0.1021339949129943d+04,-.1073151210891288d+04,
     7      0.1073255463293449d+04,-.1025459841037495d+04,
     8      0.9431972776064409d+03,-.8335728610755619d+03/
         data arr1253/
     1      0.7164115672562321d+03,-.5890089440498545d+03,
     2      0.4785417115271329d+03,-.3631850209559644d+03,
     3      0.2811280251180127d+03,-.1841284168153056d+03,
     4      0.1366989442191206d+03,-.6887596282735943d+02,
     5      0.4893156630627890d+02,0.1759091423925105d-08,
     6      -.1648871281632873d-07,0.9252647221195718d-08,
     7      0.3771837906572942d-07,0.1978336940169794d-07,
     8      -.9669067281006408d-06,0.1002337775472481d-05/
         data arr1254/
     1      -.3497281148709327d-05,0.4908601790760170d-05,
     2      -.4811059368866596d-04,0.4987044798966946d-04,
     3      -.2386334889186702d-03,0.2537791068574648d-03,
     4      0.9983408408897856d+00,-.7597737532488121d+01,
     5      0.3055262391178213d+02,-.8643008133654597d+02,
     6      0.1928635916903758d+03,-.3613668658546672d+03,
     7      0.5905931695701047d+03,-.8646261641231121d+03,
     8      0.1154493399374744d+04,-.1427218692491285d+04/
         data arr1255/
     1      0.1648868890237169d+04,-.1799250935108987d+04,
     2      0.1860398613395040d+04,-.1843468168466819d+04,
     3      0.1741624924831990d+04,-.1597921305131923d+04,
     4      0.1388175686285190d+04,-.1196481579109630d+04,
     5      0.9487353856186986d+03,-.7761941919786420d+03,
     6      0.5223061503471575d+03,-.4094966441326975d+03,
     7      0.2102162810025775d+03,-.1580313459129947d+03,
     8      -.7418771105831466d-08,0.6134513933234482d-07/
         data arr1256/
     1      -.4185640569866141d-07,-.1147312820712246d-06,
     2      -.1290553490827199d-06,0.3823118372939862d-05,
     3      -.4704456413273609d-05,0.1553827237499126d-04,
     4      -.2490105785924560d-04,0.1973077372990506d-03,
     5      -.2404613129275028d-03,0.1016284262709781d-02,
     6      -.1262933885989938d-02,0.6913392945118958d-02,
     7      0.9921529347390374d+00,-.8010683416497583d+01,
     8      0.3408700766761347d+02,-.1013750987833339d+03/
         data arr1257/
     1      0.2376137618378267d+03,-.4657795516661007d+03,
     2      0.7959009910236088d+03,-.1213525021577233d+04,
     3      0.1688685098154485d+04,-.2165320370659384d+04,
     4      0.2602522563666282d+04,-.2930747613223434d+04,
     5      0.3157599020593082d+04,-.3207192881623973d+04,
     6      0.3180265504753369d+04,-.2935284729492301d+04,
     7      0.2736143903918678d+04,-.2282287339066961d+04,
     8      0.2032825916779976d+04,-.1407294226067263d+04/
         data arr1258/
     1      0.1214108723094731d+04,-.6381955444375612d+03,
     2      0.5353449967158885d+03,0.1775628882913018d-07,
     3      -.1439178965689048d-06,0.1009553284974950d-06,
     4      0.2602096410137707d-06,0.3212618252210394d-06,
     5      -.9048078827429856d-05,0.1138959398659293d-04,
     6      -.3733577857275627d-04,0.6073879084269918d-04,
     7      -.4692783598422706d-03,0.5837076778401748d-03,
     8      -.2428991060835104d-02,0.3074963323736532d-02/
         data arr1259/
     1      -.1647660478662923d-01,0.1907393100082516d-01,
     2      0.9231426243183702d+00,-.8397792972176630d+01,
     3      0.3748902652406715d+02,-.1178429828008870d+03,
     4      0.2884357725243269d+03,-.5926230745570215d+03,
     5      0.1052299857493736d+04,-.1675774615323925d+04,
     6      0.2411411373638158d+04,-.3222852594014409d+04,
     7      0.3973088100858745d+04,-.4669407679035377d+04,
     8      0.5095007847786558d+04,-.5430060485214405d+04/
         data arr1260/
     1      0.5285953969664709d+04,-.5230710456370066d+04,
     2      0.4528140522666923d+04,-.4233142367189504d+04,
     3      0.2984900106079400d+04,-.2677967870660474d+04,
     4      0.1422998481438246d+04,-.1230832686338871d+04,
     5      -.4461841732442137d-07,0.3447907658034476d-06,
     6      -.2594665343075986d-06,-.5629173930556095d-06,
     7      -.9003243016404661d-06,0.2221038679894790d-04,
     8      -.2959353340698678d-04,0.9541677712180608d-04/
         data arr1261/
     1      -.1611920012131912d-03,0.1167539107211472d-02,
     2      -.1528231163055220d-02,0.6122704523840750d-02,
     3      -.8119792208380725d-02,0.4122305600552787d-01,
     4      -.5013248344773418d-01,0.1935468343072845d+00,
     5      0.7689346922843277d+00,-.7962153327685910d+01,
     6      0.4071437287971187d+02,-.1328494323905940d+03,
     7      0.3459054889557077d+03,-.7333038758015246d+03,
     8      0.1372002898228352d+04,-.2244909245641552d+04/
         data arr1262/
     1      0.3394968467589289d+04,-.4616462929845424d+04,
     2      0.6009385995866327d+04,-.7087040766327243d+04,
     3      0.8251753842587640d+04,-.8509804092462332d+04,
     4      0.9118038410305057d+04,-.8232602293662145d+04,
     5      0.8273359294272787d+04,-.5943844332630281d+04,
     6      0.5702522389873115d+04,-.3072560508217961d+04,
     7      0.2824498822239812d+04,0.9000821925507385d-07,
     8      -.6707728304929351d-06,0.5322489440789659d-06/
         data arr1263/
     1      0.9999554431179988d-06,0.1958402476029895d-05,
     2      -.4404879798559474d-04,0.6118583825044895d-04,
     3      -.1950246682603812d-03,0.3382599943667437d-03,
     4      -.2339501462473167d-02,0.3176820966843235d-02,
     5      -.1238919803804274d-01,0.1698049780500164d-01,
     6      -.8295221124391780d-01,0.1044988708813670d+00,
     7      -.3913674744720048d+00,0.4832807389343073d+00,
     8      -.9465790311966295d+00,-.7077005618557416d+01/
         data arr1264/
     1      0.3816483172721068d+02,-.1479691512625526d+03,
     2      0.3884336549055655d+03,-.8986335956724696d+03,
     3      0.1696450808433992d+04,-.2974732468888540d+04,
     4      0.4479537883631943d+04,-.6546192280423892d+04,
     5      0.8336806943022733d+04,-.1067067100282045d+05,
     6      0.1159897790063543d+05,-.1347025747120809d+05,
     7      0.1261082440964824d+05,-.1357526216506048d+05,
     8      0.9886103875307688d+04,-.1007538469098340d+05/
         data arr1265/
     1      0.5486601370614061d+04,-.5309908473987252d+04,
     2      -.1328796151821005d-06,0.9693995292524591d-06,
     3      -.7923074942182955d-06,-.1367017432153034d-05,
     4      -.2995860374352079d-05,0.6434792584488223d-04,
     5      -.9142620917297939d-04,0.2895532211236529d-03,
     6      -.5090128570883029d-03,0.3436839862923774d-02,
     7      -.4759124208053873d-02,0.1829595732788962d-01,
     8      -.2551000368650305d-01,0.1221348817911902d+00/
         data arr1266/
     1      -.1567463222961653d+00,0.5777177876373907d+00,
     2      -.7260577719581408d+00,0.2870226242603233d+01,
     3      -.2439092016544531d+01,0.1672173601245381d+01,
     4      0.3673075101231961d+02,-.1326267934177668d+03,
     5      0.4411562129060983d+03,-.9802230497358360d+03,
     6      0.2075882169846150d+04,-.3464670096292443d+04,
     7      0.5762342567612600d+04,-.7888545096928128d+04,
     8      0.1110693428157348d+05,-.1263091298924442d+05/
         data arr1267/
     1      0.1579734401630931d+05,-.1522904670045690d+05,
     2      0.1736545771987306d+05,-.1277211770344725d+05,
     3      0.1363732487391184d+05,-.7484342707466924d+04,
     4      0.7507556666631916d+04,0.2237464068296002d-06,
     5      -.1548901298280576d-05,0.1370285643399123d-05,
     6      0.1808116743978760d-05,0.5630387381830765d-05,
     7      -.1061352326597443d-03,0.1600615931958297d-03,
     8      -.4998224161463261d-03,0.9110028125554497d-03/
         data arr1268/
     1      -.5761118194598041d-02,0.8400444786134530d-02,
     2      -.3112685598517551d-01,0.4543025553041047d-01,
     3      -.2060788232005175d+00,0.2778233195119054d+00,
     4      -.9820018296709640d+00,0.1293391978533346d+01,
     5      -.4864350426497408d+01,0.6115880761586642d+01,
     6      -.1856054402295617d+02,0.1372851065358169d+02,
     7      -.2265211503688848d+02,-.1103329798457448d+03,
     8      0.3226278156263268d+03,-.1084706697750009d+04/
         data arr1269/
     1      0.2018979091572721d+04,-.4246686403002002d+04,
     2      0.6284660138963017d+04,-.1038763076402310d+05,
     3      0.1234440467820131d+05,-.1753789071972455d+05,
     4      0.1743833868939272d+05,-.2207542679119918d+05,
     5      0.1627923488943448d+05,-.1904785906810136d+05,
     6      0.1054097481666408d+05,-.1141981099593222d+05,
     7      0.1000000000000000d+01,-.1436140661634507d+01,
     8      0.1523257200869243d+01,-.1373045485863451d+01/
         data arr1270/
     1      0.1112293970125058d+01,-.8342204775937936d+00,
     2      0.5898829567112524d+00,-.3980539383041643d+00,
     3      0.2585436169858966d+00,-.1626634585449835d+00,
     4      0.9961061830794783d-01,-.5959633829044952d-01,
     5      0.3494145054355597d-01,-.2012490356715564d-01,
     6      0.1140974785873797d-01,-.6378242958183081d-02,
     7      0.3520694795459884d-02,-.1921261321969221d-02,
     8      0.1037599750466788d-02,-.5550763864396415d-03/
         data arr1271/
     1      0.2943739041443915d-03,-.1548716834240030d-03,
     2      0.8087984353648468d-04,-.4195138936352848d-04,
     3      0.2162394212444189d-04,-.1108289335445907d-04,
     4      0.5654152711818504d-05,-.2874408098816705d-05,
     5      0.1462991396418707d-05,-.7454602008438831d-06,
     6      0.3864425238498250d-06,-.1966656190634165d-06,
     7      0.1056754449391359d-06,-.4670519657073838d-07,
     8      0.2137048503864887d-07,0.2517282784555802d-08/
         data arr1272/
     1      -.3125615614289438d-15,0.9999999999999968d+00,
     2      -.2121320343559646d+01,0.2868198476395952d+01,
     3      -.3098008432848352d+01,0.2904382905795252d+01,
     4      -.2464450617420038d+01,0.1940184302669393d+01,
     5      -.1440213337825875d+01,0.1019378648625930d+01,
     6      -.6935993177084287d+00,0.4564731983794152d+00,
     7      -.2919612385003386d+00,0.1821713937568567d+00,
     8      -.1112262000952893d+00,0.6661857363285610d-01/
         data arr1273/
     1      -.3922394959473139d-01,0.2274250227010504d-01,
     2      -.1300482841262267d-01,0.7343578534232929d-02,
     3      -.4099431522819940d-02,0.2264573625340196d-02,
     4      -.1238943880121581d-02,0.6723168922627268d-03,
     5      -.3623367484829828d-03,0.1959888235360848d-03,
     6      -.1073003457896523d-03,0.6391597871469744d-04,
     7      -.4076181725329675d-04,0.3485965661505845d-04,
     8      -.2853755184427280d-04,0.3274536848536721d-04/
         data arr1274/
     1      -.2356956548546078d-04,0.2795588094458543d-04,
     2      -.1587869818723645d-04,0.1770396382340668d-04,
     3      0.4366434559818653d-15,0.4982965450341135d-14,
     4      0.1000000000000005d+01,-.2704163456598007d+01,
     5      0.4381245542080349d+01,-.5476556927600341d+01,
     6      0.5808765811590420d+01,-.5487669908677339d+01,
     7      0.4752461548491083d+01,-.3844317626896942d+01,
     8      0.2942692685933376d+01,-.2151835293473652d+01/
         data arr1275/
     1      0.1513950325688891d+01,-.1030517024014958d+01,
     2      0.6816229405949808d+00,-.4396601613309116d+00,
     3      0.2773552363603556d+00,-.1715347340020801d+00,
     4      0.1042192339948894d+00,-.6231250522283538d-01,
     5      0.3671787618755033d-01,-.2135075678764361d-01,
     6      0.1226474745486185d-01,-.6967187388471454d-02,
     7      0.3916732641259419d-02,-.2182166502367019d-02,
     8      0.1205092948185263d-02,-.6644864087058017d-03/
         data arr1276/
     1      0.3641401554434768d-03,-.2080313627036784d-03,
     2      0.1184322177623022d-03,-.8201249002812500d-04,
     3      0.4734598047051833d-04,-.4410796752194773d-04,
     4      0.2319022815901291d-04,-.2537174576352072d-04,
     5      0.2310846347003727d-14,0.2557810914075202d-13,
     6      0.2548362663841087d-13,0.9999999999999157d+00,
     7      -.3240370349204544d+01,0.6075694404758592d+01,
     8      -.8592329428044015d+01,0.1014670525054694d+02/
         data arr1277/
     1      -.1054476541405786d+02,0.9951404129388183d+01,
     2      -.8705665122008006d+01,0.7161740757720473d+01,
     3      -.5598590287600768d+01,0.4191938637295585d+01,
     4      -.3024771045620858d+01,0.2113623028409757d+01,
     5      -.1435924122236613d+01,0.9515036241063745d+00,
     6      -.6166449617768430d+00,0.3917344336600008d+00,
     7      -.2444105197401225d+00,0.1500161078361517d+00,
     8      -.9071292584205359d-01,0.5410278912824198d-01/
         data arr1278/
     1      -.3185868651651444d-01,0.1852333237762248d-01,
     2      -.1063416682659791d-01,0.5994785168063556d-02,
     3      -.3314177202231168d-02,0.1731886943378532d-02,
     4      -.8596984737693305d-03,0.3140845243712408d-03,
     5      -.9948734811354606d-04,-.8382936054693124d-04,
     6      0.7099015921273284d-04,-.1193682319676180d-03,
     7      0.1573615131778419d-14,-.1416491374409001d-13,
     8      0.2160961184292732d-13,0.2844587187707136d-13/
         data arr1279/
     1      0.9999999999999989d+00,-.3750000000000859d+01,
     2      0.7954951288350509d+01,-.1252536488989843d+02,
     3      0.1627092627948619d+02,-.1842641992783206d+02,
     4      0.1880638608731326d+02,-.1768128944716113d+02,
     5      0.1554986225220027d+02,-.1293660348649849d+02,
     6      0.1026811069238724d+02,-.7827338703144702d+01,
     7      0.5760765312682315d+01,-.4110965321935039d+01,
     8      0.2854510787594619d+01,-.1934269119981422d+01/
         data arr1280/
     1      0.1282251549886263d+01,-.8333274646167350d+00,
     2      0.5319002376385851d+00,-.3339624029713629d+00,
     3      0.2065395719506944d+00,-.1259661374601742d+00,
     4      0.7582554756668914d-01,-.4507684832759260d-01,
     5      0.2644869306075832d-01,-.1530639922972541d-01,
     6      0.8680199405435474d-02,-.4807802127845843d-02,
     7      0.2524725382407068d-02,-.1268305777900580d-02,
     8      0.5303860182361231d-03,-.1933447660704961d-03/
         data arr1281/
     1      -.8929755226689578d-13,-.7223554188318140d-12,
     2      -.1011057288163538d-11,0.2465825947656909d-11,
     3      0.2051444376088701d-10,0.9999999999663073d+00,
     4      -.4242640687072371d+01,0.1002029191182701d+02,
     5      -.1735565469691954d+02,0.2456855990207937d+02,
     6      -.3009021773377344d+02,0.3300507362621359d+02,
     7      -.3317303942263729d+02,0.3104784830369077d+02,
     8      -.2738162827718069d+02,0.2296019322388781d+02/
         data arr1282/
     1      -.1843444769597180d+02,0.1425134483410587d+02,
     2      -.1065683483970800d+02,0.7737070064090695d+01,
     3      -.5470919018785366d+01,0.3777736113815811d+01,
     4      -.2553089181521645d+01,0.1692129050920300d+01,
     5      -.1101642348726894d+01,0.7059003333080543d+00,
     6      -.4456171458096846d+00,0.2782681573127794d+00,
     7      -.1714512209553223d+00,0.1059616190612846d+00,
     8      -.6420830169217267d-01,0.4069143755806612d-01/
         data arr1283/
     1      -.2328423352493284d-01,0.1585339889490343d-01,
     2      -.7692723707546592d-02,0.5813143629266646d-02,
     3      0.3480047209017312d-12,0.2250370903487726d-11,
     4      0.4014960296759800d-11,-.8066303133223080d-11,
     5      -.7251712347582889d-10,0.1011332677224122d-09,
     6      0.9999999998720607d+00,-.4723610906690725d+01,
     7      0.1227230112494131d+02,-.2316346041112719d+02,
     8      0.3546166166660664d+02,-.4667622273820527d+02/
         data arr1284/
     1      0.5473272255359499d+02,-.5854438414641025d+02,
     2      0.5808520485253557d+02,-.5411769428927676d+02,
     3      0.4779545004597210d+02,-.4030889026056683d+02,
     4      0.3265391995151846d+02,-.2553103073981754d+02,
     5      0.1934261875928269d+02,-.1424671578950560d+02,
     6      0.1022996766211682d+02,-.7178710550808315d+01,
     7      0.4932592954752383d+01,-.3325415530494241d+01,
     8      0.2201715147494359d+01,-.1435651934584104d+01/
         data arr1285/
     1      0.9194211830572407d+00,-.5839396892270908d+00,
     2      0.3609263360980197d+00,-.2258173752833131d+00,
     3      0.1287832571866977d+00,-.8080839828417862d-01,
     4      0.3794625847570047d-01,-.2455586005802378d-01,
     5      -.5709372368589870d-12,0.3299340690527070d-11,
     6      -.7689966716967024d-11,-.4603005076455505d-11,
     7      0.2140433344552536d-10,0.2203322530616505d-09,
     8      -.5208682231354578d-09,0.1000000001163559d+01/
         data arr1286/
     1      -.5196152424203511d+01,0.1471128394778983d+02,
     2      -.3002928260784216d+02,0.4940735356349047d+02,
     3      -.6952230894190632d+02,0.8675792752002036d+02,
     4      -.9837424327783685d+02,0.1031116401875361d+03,
     5      -.1011841508828561d+03,0.9386842184427700d+02,
     6      -.8295503911601957d+02,0.7026485955227557d+02,
     7      -.5732855137846326d+02,0.4524113416621516d+02,
     8      -.3465139318991695d+02,0.2583415214038695d+02/
         data arr1287/
     1      -.1879242668927579d+02,0.1336430840148822d+02,
     2      -.9301973276349164d+01,0.6342376358422180d+01,
     3      -.4229164488535956d+01,0.2757382375983808d+01,
     4      -.1740124747017571d+01,0.1063715073340877d+01,
     5      -.6051658349899051d+00,0.3303983563895447d+00,
     6      -.1462947254445729d+00,0.5943376958813656d-01,
     7      0.7505115567287871d-11,0.2821685904691125d-10,
     8      0.9082850422802479d-10,-.1296026664804659d-09/
         data arr1288/
     1      -.1246982159929895d-08,0.9837325719425317d-09,
     2      -.3312733070903619d-09,-.3418787287314524d-09,
     3      0.9999999398357117d+00,-.5662375792287156d+01,
     4      0.1733741416568793d+02,-.3803379834742257d+02,
     5      0.6689787068461139d+02,-.1001794239701841d+03,
     6      0.1325249134031420d+03,-.1587507473362080d+03,
     7      0.1752560298633862d+03,-.1806498137513477d+03,
     8      0.1756115078665419d+03,-.1622695461044919d+03/
         data arr1289/
     1      0.1434265446501811d+03,-.1218929627611192d+03,
     2      0.1000288562102768d+03,-.7955302653008356d+02,
     3      0.6148923678480825d+02,-.4632584492442963d+02,
     4      0.3405862672416228d+02,-.2451627571161602d+02,
     5      0.1721397100436962d+02,-.1189593634901817d+02,
     6      0.7923249956352355d+01,-.5250621574769483d+01,
     7      0.3149944500482119d+01,-.1987251656646487d+01,
     8      0.9472852215595508d+00,-.5539177718868622d+00/
         data arr1290/
     1      -.3695688030702429d-10,-.1633160171990611d-09,
     2      -.4445131774557371d-09,0.7083548732730015d-09,
     3      0.6444370517080767d-08,-.6110322179691657d-08,
     4      0.3851011733999625d-08,-.2780342815058526d-08,
     5      0.3211662668375088d-06,0.9999997653331997d+00,
     6      -.6123723119787313d+01,0.2015079784649192d+02,
     7      -.4725779999441888d+02,0.8846058568369382d+02,
     8      -.1404267873437310d+03,0.1962524420168408d+03/
         data arr1291/
     1      -.2476075464035217d+03,0.2871316911997785d+03,
     2      -.3101367152257316d+03,0.3152320233015518d+03,
     3      -.3039537286686537d+03,0.2798459717372581d+03,
     4      -.2473055073871052d+03,0.2107277020226752d+03,
     5      -.1737046609488802d+03,0.1390350235567122d+03,
     6      -.1081595377131162d+03,0.8215950569549019d+02,
     7      -.6059370987989368d+02,0.4395827012077920d+02,
     8      -.3052208262235225d+02,0.2117332144825452d+02/
         data arr1292/
     1      -.1309153995155515d+02,0.8662617849702798d+01,
     2      -.4225679333246384d+01,0.2623124354675451d+01,
     3      0.1723517326655379d-09,0.9318265136962181d-09,
     4      0.2048417209803766d-08,-.3754292416056088d-08,
     5      -.3235088662045039d-07,0.3773185081982922d-07,
     6      -.3505241692959199d-07,0.4864995295930472d-07,
     7      -.1687815687701392d-05,0.1593569159622869d-05,
     8      0.9999929608375562d+00,-.6581216694839190d+01/
         data arr1293/
     1      0.2315144110773211d+02,-.5778216317033382d+02,
     2      0.1146577482102151d+03,-.1922871314846710d+03,
     3      0.2830377098560379d+03,-.3751062174581445d+03,
     4      0.4558012894931294d+03,-.5147679100330581d+03,
     5      0.5459714798526020d+03,-.5483706101072656d+03,
     6      0.5249531344327975d+03,-.4817390116466913d+03,
     7      0.4253713558914367d+03,-.3632514171646268d+03,
     8      0.3000917987526484d+03,-.2415897127407144d+03/
         data arr1294/
     1      0.1877699244069411d+03,-.1438505493892684d+03,
     2      0.1045208888033966d+03,-.7665114809100433d+02,
     3      0.4896679530723979d+02,-.3452198813077898d+02,
     4      0.1729854825698413d+02,-.1167356280914234d+02,
     5      -.6972154478033730d-09,-.4325951632808006d-08,
     6      -.8202171316349565d-08,0.1663357146134232d-07,
     7      0.1385009336545150d-06,-.1831110689337899d-06,
     8      0.1987988868690572d-06,-.3166579255095891d-06/
         data arr1295/
     1      0.7460313373073500d-05,-.8103500365519842d-05,
     2      0.3270677320850070d-04,0.9999643039352227d+00,
     3      -.7035335981025102d+01,0.2633929624135183d+02,
     4      -.6968666566141936d+02,0.1460865979171760d+03,
     5      -.2580352019627375d+03,0.3989696066815934d+03,
     6      -.5540409514664094d+03,0.7039395444828073d+03,
     7      -.8295069788983938d+03,0.9164935343005158d+03,
     8      -.9569645220846660d+03,0.9514703318195460d+03/
         data arr1296/
     1      -.9043849186830751d+03,0.8278417307397163d+03,
     2      -.7288738720940145d+03,0.6243824597480785d+03,
     3      -.5125416395097958d+03,0.4162026667046433d+03,
     4      -.3167101838170947d+03,0.2462604847773029d+03,
     5      -.1622665068889530d+03,0.1218985218642181d+03,
     6      -.6257728129512745d+02,0.4551204115936278d+02,
     7      0.2237144670505987d-08,0.1449416642587948d-07,
     8      0.2625136115981992d-07,-.5515753201527514d-07/
         data arr1297/
     1      -.4519442750893402d-06,0.6192355909674116d-06,
     2      -.6928429007220787d-06,0.1126301563705003d-05,
     3      -.2455505828521980d-04,0.2765767368835501d-04,
     4      -.1090427999792502d-03,0.1232420981358859d-03,
     5      0.9990489868634275d+00,-.7486519360816482d+01,
     6      0.2971069544868129d+02,-.8305174390799820d+02,
     7      0.1833583410330836d+03,-.3402249928797579d+03,
     8      0.5511668138501697d+03,-.8003680544896050d+03/
         data arr1298/
     1      0.1060849628605405d+04,-.1302418894652472d+04,
     2      0.1495407022116032d+04,-.1622096869070886d+04,
     3      0.1668679596918746d+04,-.1644966938368542d+04,
     4      0.1548204988145120d+04,-.1414285143157087d+04,
     5      0.1226246667209803d+04,-.1053473236573670d+04,
     6      0.8366618979055698d+03,-.6835393609487521d+03,
     7      0.4622876479230695d+03,-.3628742012876394d+03,
     8      0.1894535229012152d+03,-.1432605986225430d+03/
         data arr1299/
     1      -.7971021467192557d-08,-.6041145552279253d-07,
     2      -.9202474756062558d-07,0.2179824043699012d-06,
     3      0.1736768030121838d-05,-.2699974545066593d-05,
     4      0.3422497780588709d-05,-.6055282866348279d-05,
     5      0.9802624987438287d-04,-.1258559097180322d-03,
     6      0.4592136571348190d-03,-.5898284065020225d-03,
     7      0.3870443867217097d-02,0.9954985103508879d+00,
     8      -.7919102151321049d+01,0.3325728652365545d+02/
         data arr1300/
     1      -.9786657937926089d+02,0.2271023193908547d+03,
     2      -.4413386493791514d+03,0.7479173280944112d+03,
     3      -.1132229037275063d+04,0.1564521472946105d+04,
     4      -.1994422426194127d+04,0.2382626276164019d+04,
     5      -.2671010422204482d+04,0.2862558225459030d+04,
     6      -.2899454827406251d+04,0.2861863728893817d+04,
     7      -.2640183359169045d+04,0.2451256175153143d+04,
     8      -.2052212441512720d+04,0.1821911509868562d+04/
         data arr1301/
     1      -.1270457190147545d+04,0.1093074684810624d+04,
     2      -.5857932320086872d+03,0.4905969935664896d+03,
     3      0.1875540791254584d-07,0.1458746507296019d-06,
     4      0.2160023635439169d-06,-.5228791644143614d-06,
     5      -.4136294497045268d-05,0.6554332391568335d-05,
     6      -.8422876833695460d-05,0.1501878367550966d-04,
     7      -.2347662536976879d-03,0.3069879884968134d-03,
     8      -.1107994340520132d-02,0.1446451597517808d-02/
         data arr1302/
     1      -.9294596446411768d-02,0.1100299825745613d-01,
     2      0.9562701136578642d+00,-.8334630295324873d+01,
     3      0.3678526076922184d+02,-.1142373852266207d+03,
     4      0.2772870186863189d+03,-.5646374148009092d+03,
     5      0.9958304990630795d+03,-.1574093629184964d+04,
     6      0.2252946232457855d+04,-.2991796034305979d+04,
     7      0.3673695530355279d+04,-.4293010174492077d+04,
     8      0.4674741327811788d+04,-.4956506131131875d+04/
         data arr1303/
     1      0.4826496779918484d+04,-.4753260812665746d+04,
     2      0.4133525267650669d+04,-.3847187370765089d+04,
     3      0.2734228888354049d+04,-.2442766383758301d+04,
     4      0.1324137770230612d+04,-.1141398950827170d+04,
     5      -.4266936721310112d-07,-.3499213373646224d-06,
     6      -.4884704533679621d-06,0.1234902576371002d-05,
     7      0.9665441617282760d-05,-.1591587868112570d-04,
     8      0.2107877874547993d-04,-.3823891976944524d-04/
         data arr1304/
     1      0.5553153301328373d-03,-.7535903186117953d-03,
     2      0.2662867038683695d-02,-.3593474718689816d-02,
     3      0.2211498444953021d-01,-.2713733836730541d-01,
     4      0.1047645606333101d+00,0.8744791300420419d+00,
     5      -.8251649784168447d+01,0.4030762676829050d+02,
     6      -.1303751072240033d+03,0.3346988167644816d+03,
     7      -.7055857005638158d+03,0.1307281208852505d+04,
     8      -.2130042493372705d+04,0.3193986384053196d+04/
         data arr1305/
     1      -.4330333101612992d+04,0.5589210352358781d+04,
     2      -.6582219316364657d+04,0.7592732772645334d+04,
     3      -.7835902254406675d+04,0.8305414252645583d+04,
     4      -.7534449190480714d+04,0.7477011184233169d+04,
     5      -.5420474705861661d+04,0.5126412502031808d+04,
     6      -.2818987400408704d+04,0.2552302665047917d+04,
     7      0.8387948777106830d-07,0.7271835445371829d-06,
     8      0.9533737502034984d-06,-.2522970706236229d-05/
         data arr1306/
     1      -.1957156724618507d-04,0.3350813790854124d-04,
     2      -.4574845357314878d-04,0.8441485967590636d-04,
     3      -.1139244855630270d-02,0.1604538904951091d-02,
     4      -.5554163477008096d-02,0.7744727425473881d-02,
     5      -.4565178659475332d-01,0.5805992034196923d-01,
     6      -.2178145374070090d+00,0.2699952894832036d+00,
     7      -.2016220021127023d+00,-.7864402390348025d+01,
     8      0.4015985517913769d+02,-.1471282952046781d+03/
         data arr1307/
     1      0.3842625453079530d+03,-.8722268669773550d+03,
     2      0.1643574211324874d+04,-.2846594726236847d+04,
     3      0.4285308951880390d+04,-.6195955070525164d+04,
     4      0.7903362102157912d+04,-.1000866364348275d+05,
     5      0.1092064211060158d+05,-.1253589540334406d+05,
     6      0.1182903602408746d+05,-.1256931892492193d+05,
     7      0.9258207734664521d+04,-.9299943912406740d+04,
     8      0.5179639242570109d+04,-.4937170102568182d+04/
         data arr1308/
     1      -.1106360525265956d-06,-.9744569766395511d-06,
     2      -.1255738538748808d-05,0.3371479285359418d-05,
     3      0.2600843923456797d-04,-.4499607368276245d-04,
     4      0.6175701612054188d-04,-.1141898040037361d-03,
     5      0.1518531419799166d-02,-.2158441922663568d-02,
     6      0.7431344996140923d-02,-.1043779519417961d-01,
     7      0.6093501226822034d-01,-.7815896468259179d-01,
     8      0.2911986432601105d+00,-.3637539427386585d+00/
         data arr1309/
     1      0.1605039329428709d+01,-.9022981093006611d+00,
     2      -.3127670129151631d+01,0.4165608036787387d+02,
     3      -.1453040760474211d+03,0.4432137516164869d+03,
     4      -.9822482971296259d+03,0.2008409040344292d+04,
     5      -.3351326290986543d+04,0.5427619249076058d+04,
     6      -.7432298535572964d+04,0.1020675439753855d+05,
     7      -.1163960669432504d+05,0.1418661094166109d+05,
     8      -.1376761142846154d+05,0.1528018652976907d+05/
         data arr1310/
     1      -.1138005684479770d+05,0.1180952562876123d+05,
     2      -.6626863643990402d+04,0.6460129872244458d+04,
     3      0.1885822564135037d-06,0.1829726465875257d-05,
     4      0.2106556420202330d-05,-.6124221769808588d-05,
     5      -.4693029852338159d-04,0.8655117361882756d-04,
     6      -.1250959649362114d-03,0.2380047904113612d-03,
     7      -.2806128417164955d-02,0.4236398295191140d-02,
     8      -.1413337913112939d-01,0.2092067300679441d-01/
         data arr1311/
     1      -.1138537228260648d+00,0.1547080458949466d+00,
     2      -.5508865555709386d+00,0.7267174621293714d+00,
     3      -.3017315839244376d+01,0.3783579262208175d+01,
     4      -.1149238760145998d+02,0.5055855444363941d+01,
     5      0.1104316035164185d+01,-.1352332027086392d+03,
     6      0.3814152750954523d+03,-.1121398081182486d+04,
     7      0.2101916490979863d+04,-.4211094692149637d+04,
     8      0.6288030606970050d+04,-.1007751905222115d+05/
         data arr1312/
     1      0.1210197627228037d+05,-.1676085969923564d+05,
     2      0.1689839133302790d+05,-.2090035253977605d+05,
     3      0.1566820832947244d+05,-.1792333242828326d+05,
     4      0.1018400507529376d+05,-.1079968105640650d+05,
     5      0.9999999999999999d+00,-.1561249499599603d+01,
     6      0.1788636002656775d+01,-.1731839362679151d+01,
     7      0.1499816883353991d+01,-.1197507749783314d+01,
     8      0.8981308123374571d+00,-.6407196044841242d+00/
         data arr1313/
     1      0.4386707255141080d+00,-.2901534117868250d+00,
     2      0.1863544028918502d+00,-.1166830759793621d+00,
     3      0.7145349941733866d-01,-.4290643842183932d-01,
     4      0.2531895379627773d-01,-.1470898213838191d-01,
     5      0.8425627335276667d-02,-.4765156004647045d-02,
     6      0.2663800785604372d-02,-.1473339978211855d-02,
     7      0.8069886758020418d-03,-.4380577468238318d-03,
     8      0.2359580694200630d-03,-.1262905222354777d-03/
         data arr1314/
     1      0.6770831855913988d-04,-.3668652972898762d-04,
     2      0.2124688795790918d-04,-.1316518725826981d-04,
     3      0.1052847941971116d-04,-.8443735833766456d-05,
     4      0.9221449577066837d-05,-.6702340886401850d-05,
     5      0.7723129328889838d-05,-.4528921818390934d-05,
     6      0.4929916739666566d-05,0.5840272094375137d-15,
     7      0.1000000000000016d+01,-.2291287847477932d+01,
     8      0.3327794877993430d+01,-.3842606537234720d+01/
         data arr1315/
     1      0.3835094102801766d+01,-.3451584692521402d+01,
     2      0.2872722926436837d+01,-.2247793068956478d+01,
     3      0.1672622285388033d+01,-.1193623459542443d+01,
     4      0.8221068036726906d+00,-.5492024134220829d+00,
     5      0.3572674964787564d+00,-.2270395309648509d+00,
     6      0.1413193330652296d+00,-.8634753482967520d-01,
     7      0.5188644382651547d-01,-.3071158751318651d-01,
     8      0.1793023741566333d-01,-.1033762278307767d-01/
         data arr1316/
     1      0.5891725698132955d-02,-.3322618747378207d-02,
     2      0.1855291413876853d-02,-.1027867577123487d-02,
     3      0.5652995598325905d-03,-.3128945850399696d-03,
     4      0.1734357674761921d-03,-.1050799430088184d-03,
     5      0.6465428894562292d-04,-.5337877442961855d-04,
     6      0.3381844169528469d-04,-.3682533752946557d-04,
     7      0.2094250107455506d-04,-.2407272903687870d-04,
     8      0.2397968030252048d-14,0.6942258007063751d-13/
         data arr1317/
     1      0.9999999999999475d+00,-.2904737509656016d+01,
     2      0.5031152949375056d+01,-.6695089151758172d+01,
     3      0.7531975295728828d+01,-.7522554434904235d+01,
     4      0.6867121256771627d+01,-.5839937700574822d+01,
     5      0.4688459875605424d+01,-.3587968246410869d+01,
     6      0.2636607425574406d+01,-.1871091831588309d+01,
     7      0.1288146285212226d+01,-.8634754408244071d+00,
     8      0.5652773803157036d+00,-.3623218530500996d+00/
         data arr1318/
     1      0.2278621280720867d+00,-.1408582301697354d+00,
     2      0.8572329924507226d-01,-.5142876712298378d-01,
     3      0.3044843914727452d-01,-.1780547139091043d-01,
     4      0.1028072274406873d-01,-.5857338597698187d-02,
     5      0.3266706220331227d-02,-.1777053141589356d-02,
     6      0.8934156728700140d-03,-.4120778881309788d-03,
     7      0.1028064282156181d-03,0.4578051201429707d-07,
     8      -.1057051341490215d-03,0.7632075800094110d-04/
         data arr1319/
     1      -.1031423011256617d-03,-.3914709749102322d-14,
     2      -.5425781388872422d-13,0.7743188872385429d-13,
     3      0.1000000000000410d+01,-.3464101615138622d+01,
     4      0.6914658342969684d+01,-.1037198751445526d+02,
     5      0.1294876802102267d+02,-.1418466467405357d+02,
     6      0.1407341068445267d+02,-.1291258810131817d+02,
     7      0.1111691301080152d+02,-.9076921464865026d+01,
     8      0.7085669551078657d+01,-.5321567040789069d+01/
         data arr1320/
     1      0.3864438871861469d+01,-.2724474438260845d+01,
     2      0.1871021683047366d+01,-.1255119629871482d+01,
     3      0.8243728026456302d+00,-.5312093337468589d+00,
     4      0.3364042811267708d+00,-.2096801933123591d+00,
     5      0.1288004642779403d+00,-.7805201107360057d-01,
     6      0.4669988707142366d-01,-.2758303640300719d-01,
     7      0.1607942477898746d-01,-.9201654468060594d-02,
     8      0.5153719750020592d-02,-.2749509609087164d-02/
         data arr1321/
     1      0.1408074025082891d-02,-.6081561350772848d-03,
     2      0.2278225241969776d-03,-.3890368253637531d-05,
     3      -.4698166545790545d-13,-.1809064892702086d-11,
     4      0.1068588499520039d-11,0.1145761715056363d-10,
     5      0.9999999999896036d+00,-.3992179855691373d+01,
     6      0.8982404675254842d+01,-.1495194940478196d+02,
     7      0.2047379991927935d+02,-.2437586233995601d+02,
     8      0.2609280175456709d+02,-.2567341085909574d+02/
         data arr1322/
     1      0.2358253370671935d+02,-.2045456602959584d+02,
     2      0.1689824478635883d+02,-.1338680837495007d+02,
     3      0.1022434362965090d+02,-.7561641692605588d+01,
     4      0.5434824558620362d+01,-.3807604771944837d+01,
     5      0.2606892018801579d+01,-.1747997895635080d+01,
     6      0.1150108305219795d+01,-.7437269415916788d+00,
     7      0.4735393727184385d+00,-.2972046657993951d+00,
     8      0.1845007271190272d+00,-.1131221847097709d+00/
         data arr1323/
     1      0.6941981060112161d-01,-.4190660935617458d-01,
     2      0.2620267434185221d-01,-.1499797065213280d-01,
     3      0.9939613282720082d-02,-.4881701677574301d-02,
     4      0.3523261693321129d-02,0.1660529658435118d-12,
     5      0.7725448727566408d-11,-.3913959258587147d-11,
     6      -.4806901428989351d-10,0.3678447061572910d-10,
     7      0.1000000000109941d+01,-.4500000000018615d+01,
     8      0.1123592869826230d+02,-.2051390534327542d+02/
         data arr1324/
     1      0.3052951422434789d+02,-.3921587107173771d+02,
     2      0.4501647780792285d+02,-.4725745742293464d+02,
     3      0.4611292589984535d+02,-.4232836538355030d+02,
     4      0.3688583568720213d+02,-.3073311508280291d+02,
     5      0.2462347439510771d+02,-.1905914731819499d+02,
     6      0.1430648267137419d+02,-.1044797358036336d+02,
     7      0.7443453978023890d+01,-.5185344045286763d+01,
     8      0.3538937639281599d+01,-.2370818582850625d+01/
         data arr1325/
     1      0.1560657037736939d+01,-.1011987000404478d+01,
     2      0.6450836493267857d+00,-.4075551778651142d+00,
     3      0.2512246827785180d+00,-.1561842390444874d+00,
     4      0.8919337241282182d-01,-.5538914460679725d-01,
     5      0.2635354088406542d-01,-.1669511494917684d-01,
     6      0.3501298566659229d-12,-.9091187751302425d-11,
     7      -.5179630412641703d-11,0.4188112376364356d-10,
     8      0.7805442286108390d-10,-.2900056443184965d-09/
         data arr1326/
     1      0.1000000000211883d+01,-.4993746088747921d+01,
     2      0.1367593690145404d+02,-.2713734599114033d+02,
     3      0.4357319011309269d+02,-.6002197052925231d+02,
     4      0.7351160074863133d+02,-.8197853575230600d+02,
     5      0.8465673244091258d+02,-.8196852919469350d+02,
     6      0.7512540269340586d+02,-.6566262618271108d+02,
     7      0.5505980176968732d+02,-.4450915825621988d+02,
     8      0.3482658468378840d+02,-.2646537309113863d+02/
         data arr1327/
     1      0.1958749785697539d+02,-.1415204223323620d+02,
     2      0.1000057810297219d+02,-.6919664961411486d+01,
     3      0.4691595024962976d+01,-.3112328039780403d+01,
     4      0.2018806290704874d+01,-.1268614881584765d+01,
     5      0.7714907630510954d+00,-.4378059592489077d+00,
     6      0.2374975380321973d+00,-.1053710466578194d+00,
     7      0.4204276876180882d-01,0.2138666237976500d-11,
     8      0.1725868729412674d-09,-.6143627519223019d-10/
         data arr1328/
     1      -.1026251190712086d-08,0.4667398674713624d-09,
     2      0.2977385882740955d-08,-.1181317487939291d-08,
     3      0.9999999686855420d+00,-.5477225559473840d+01,
     4      0.1630279880105436d+02,-.3490220711017375d+02,
     5      0.6009713789422670d+02,-.8832439474978324d+02,
     6      0.1149136779638942d+03,-.1356204002545263d+03,
     7      0.1477280982550100d+03,-.1504389483617804d+03,
     8      0.1446385700942575d+03,-.1323089221354848d+03/
         data arr1329/
     1      0.1158682488659700d+03,-.9763658297339300d+02,
     2      0.7949556607796514d+02,-.6276278500768204d+02,
     3      0.4818498412672684d+02,-.3607285584742267d+02,
     4      0.2636797928984123d+02,-.1887404202787620d+02,
     5      0.1319026726151740d+02,-.9068246764294547d+01,
     6      0.6022883153713654d+01,-.3969890727181352d+01,
     7      0.2383157392248458d+01,-.1493661301284320d+01,
     8      0.7199352700246214d+00,-.4161407124236498d+00/
         data arr1330/
     1      -.1858450167095290d-10,-.1043842898706525d-08,
     2      0.4736453461692398d-09,0.6357297391565808d-08,
     3      -.4078062298886642d-08,-.1636401894787303d-07,
     4      0.5247581460510819d-08,0.2083838260583478d-06,
     5      0.9999998361128145d+00,-.5952940063416017d+01,
     6      0.1911672569018930d+02,-.4388873748288908d+02,
     7      0.8062876690443147d+02,-.1258816026789382d+03,
     8      0.1733254674191061d+03,-.2157705363368424d+03/
         data arr1331/
     1      0.2471962845254925d+03,-.2640720968263188d+03,
     2      0.2657176323850420d+03,-.2538519951615635d+03,
     3      0.2317349775478039d+03,-.2031863942631720d+03,
     4      0.1718794991345113d+03,-.1407400558837762d+03,
     5      0.1119637201540077d+03,-.8663879099459835d+02,
     6      0.6551547828208115d+02,-.4816649865795630d+02,
     7      0.3489331588787109d+02,-.2426162773375458d+02,
     8      0.1691481235408308d+02,-.1052412089109331d+02/
         data arr1332/
     1      0.7078423277233287d+01,-.3530891049697534d+01,
     2      0.2273055871383886d+01,0.9066641760620173d-10,
     3      0.4639808770102577d-08,-.2254265816703329d-08,
     4      -.2846449220500370d-07,0.1991274182681398d-07,
     5      0.7047628743121569d-07,-.2092190254645132d-07,
     6      -.9523531883208177d-06,0.8259708008163412d-06,
     7      0.9999980702441330d+00,-.6422613764940946d+01,
     8      0.2211781417755758d+02,-.5417741279202455d+02/
         data arr1333/
     1      0.1057304962932498d+03,-.1746955492054969d+03,
     2      0.2537215924814530d+03,-.3321999994900356d+03,
     3      0.3992369658726576d+03,-.4463615912916248d+03,
     4      0.4690636724309498d+03,-.4671251923497472d+03,
     5      0.4436848356258756d+03,-.4041952262314055d+03,
     6      0.3545273306383035d+03,-.3008444442067755d+03,
     7      0.2471765216007609d+03,-.1979138368662524d+03,
     8      0.1532270504497429d+03,-.1168827888031689d+03/
         data arr1334/
     1      0.8487296785775839d+02,-.6208419831062999d+02,
     2      0.3980437030288193d+02,-.2807385772334203d+02,
     3      0.1431775964459943d+02,-.9706684349876217d+01,
     4      -.4479488527303554d-09,-.2002720267066370d-07,
     5      0.1074353656614483d-07,0.1243945040477789d-06,
     6      -.9856326189202416d-07,-.2874574308924452d-06,
     7      0.7025905078786903d-07,0.4304193748114876d-05,
     8      -.4270813255683632d-05,0.9900980171013820d-05/
         data arr1335/
     1      0.9999855755764344d+00,-.6887329486394647d+01,
     2      0.2530608934928512d+02,-.6584829355943735d+02,
     3      0.1359997069919459d+03,-.2370228117191923d+03,
     4      0.3620609091996636d+03,-.4972757433632564d+03,
     5      0.6254733688034753d+03,-.7302770962297838d+03,
     6      0.8000051942248436d+03,-.8288523049857658d+03,
     7      0.8181083079666273d+03,-.7725753009388889d+03,
     8      0.7028238380571846d+03,-.6157147285844964d+03/
         data arr1336/
     1      0.5248316369293442d+03,-.4296003698251256d+03,
     2      0.3477408616678072d+03,-.2649937982890901d+03,
     3      0.2059574176832441d+03,-.1364908851197911d+03,
     4      0.1028932239864449d+03,-.5393778710037470d+02,
     5      0.3953990700306876d+02,0.1501098132217297d-08,
     6      0.6500508303675122d-07,-.3578143721032279d-07,
     7      -.4048839188768664d-06,0.3302950889972787d-06,
     8      0.9208081681806274d-06,-.2176403892360764d-06/
         data arr1337/
     1      -.1411183202954231d-04,0.1440914556479599d-04,
     2      -.3328167722686396d-04,0.4936605962778797d-04,
     3      0.9994750963935493d+00,-.7347927530182312d+01,
     4      0.2867980946151617d+02,-.7898167355063967d+02,
     5      0.1720561417727291d+03,-.3153967964256586d+03,
     6      0.5053581786741409d+03,-.7264660292720692d+03,
     7      0.9540953133034582d+03,-.1161374188592174d+04,
     8      0.1323215641927918d+04,-.1424801572066858d+04/
         data arr1338/
     1      0.1456361988203152d+04,-.1426567199703265d+04,
     2      0.1336154811991874d+04,-.1213993212309528d+04,
     3      0.1049713991691136d+04,-.8980473790717157d+03,
     4      0.7142848656146826d+03,-.5821272611240445d+03,
     5      0.3959361267270607d+03,-.3108307234350776d+03,
     6      0.1656910581878253d+03,-.1256378501144394d+03,
     7      -.6059661275957030d-08,-.2332984493105922d-06,
     8      0.1402309736872294d-06,0.1471804731551072d-05/
         data arr1339/
     1      -.1335587277236528d-05,-.3100045804717841d-05,
     2      0.5222483284961734d-06,0.5301165623482695d-04,
     3      -.6022673356927955d-04,0.1386618343924426d-03,
     4      -.2203594306470854d-03,0.2022874980341445d-02,
     5      0.9976895631467736d+00,-.7797591862448549d+01,
     6      0.3223480221140948d+02,-.9360594546002243d+02,
     7      0.2145481712111202d+03,-.4124376782035885d+03,
     8      0.6918261747702728d+03,-.1037946098732943d+04/
         data arr1340/
     1      0.1421853038706551d+04,-.1799167883834630d+04,
     2      0.2133156712267776d+04,-.2377134736609726d+04,
     3      0.2530117734153344d+04,-.2551880105276298d+04,
     4      0.2501838754979456d+04,-.2303472457805107d+04,
     5      0.2123488380730771d+04,-.1782140981157427d+04,
     6      0.1569271061146947d+04,-.1102216021566970d+04,
     7      0.9396557178672239d+03,-.5148816786026107d+03,
     8      0.4261406043207518d+03,0.1525920356496067d-07/
         data arr1341/
     1      0.5709571611884990d-06,-.3509212664361898d-06,
     2      -.3613508196593642d-05,0.3364308157461974d-05,
     3      0.7460759152955389d-05,-.1129432105546291d-05,
     4      -.1311932215446094d-03,0.1527296357497451d-03,
     5      -.3511808746214386d-03,0.5658666811481921d-03,
     6      -.5036195654981079d-02,0.5882338279032011d-02,
     7      0.9782947440150442d+00,-.8235028125460416d+01,
     8      0.3585182381181957d+02,-.1098103581049318d+03/
         data arr1342/
     1      0.2637357185468944d+03,-.5312987132591535d+03,
     2      0.9289576629261489d+03,-.1455248337770630d+04,
     3      0.2068414176225806d+04,-.2725412798121780d+04,
     4      0.3328906179260398d+04,-.3863142791894995d+04,
     5      0.4193402757388042d+04,-.4417218475490821d+04,
     6      0.4299053942273261d+04,-.4207025929477306d+04,
     7      0.3674644393198457d+04,-.3397060723107025d+04,
     8      0.2435159452304957d+04,-.2160395773605605d+04/
         data arr1343/
     1      0.1199397136631621d+04,-.1024559489976166d+04,
     2      -.3485683080237500d-07,-.1262869668631762d-05,
     3      0.7962302460854253d-06,0.8021842800386076d-05,
     4      -.7687020235168033d-05,-.1618140719216801d-04,
     5      0.2132056833292296d-05,0.2938829091899999d-03,
     6      -.3514242145039606d-03,0.8068336919305978d-03,
     7      -.1318909404232689d-02,0.1135673059855635d-01,
     8      -.1359053264611872d-01,0.4933500600967731d-01/
         data arr1344/
     1      0.9388761527587737d+00,-.8388972610608857d+01,
     2      0.3956767462476842d+02,-.1266499037738943d+03,
     3      0.3204597936344252d+03,-.6704421377926816d+03,
     4      0.1228713120535209d+04,-.1989866967337112d+04,
     5      0.2954552670265590d+04,-.3986533964569800d+04,
     6      0.5094286678092823d+04,-.5979942935497593d+04,
     7      0.6820916213982015d+04,-.7032518758840805d+04,
     8      0.7357093833595293d+04,-.6698647176424778d+04/
         data arr1345/
     1      0.6544324132395397d+04,-.4787433172500488d+04,
     2      0.4448469816542809d+04,-.2504717451529532d+04,
     3      0.2220318911512280d+04,0.7680649937096064d-07,
     4      0.2638111803291589d-05,-.1732749856923481d-05,
     5      -.1687008043061487d-04,0.1695004040723273d-04,
     6      0.3257066664725535d-04,-.2857905945846812d-05,
     7      -.6281556414915486d-03,0.7850044548276757d-03,
     8      -.1801153793908990d-02,0.3015088136597132d-02/
         data arr1346/
     1      -.2456117519247284d-01,0.3058579882604633d-01,
     2      -.1081703823573340d+00,0.1387695345757780d+00,
     3      0.2927370999778288d+00,-.8338692578481371d+01,
     4      0.4114725023448273d+02,-.1444190786729909d+03,
     5      0.3747543277779543d+03,-.8358199881884479d+03,
     6      0.1569157162423580d+04,-.2683596087199003d+04,
     7      0.4031974913834743d+04,-.5765673262064867d+04,
     8      0.7357286323314925d+04,-.9213757038586404d+04/
         data arr1347/
     1      0.1008304656590158d+05,-.1143766406516348d+05,
     2      0.1088042647099673d+05,-.1140382267941899d+05,
     3      0.8502129938324584d+04,-.8413033654686711d+04,
     4      0.4813379180982525d+04,-.4504038328124738d+04,
     5      -.1009597880535825d-06,-.3437148779173588d-05,
     6      0.2276025771193625d-05,0.2199760931296078d-04,
     7      -.2227489765205140d-04,-.4224074387918403d-04,
     8      0.3667673481082032d-05,0.8206548612285794d-03/
         data arr1348/
     1      -.1032075818879303d-02,0.2364827336324827d-02,
     2      -.3967182045553594d-02,0.3213061971468930d-01,
     3      -.4022150176771497d-01,0.1417234574821487d+00,
     4      -.1825367637095314d+00,0.9257439237498575d+00,
     5      -.8690367109317341d-01,-.5800570850083234d+01,
     6      0.4379673593667412d+02,-.1501310383654956d+03,
     7      0.4356057976737825d+03,-.9626001395272363d+03,
     8      0.1922194914629876d+04,-.3204462442812402d+04/
         data arr1349/
     1      0.5097537807522042d+04,-.6986941426019607d+04,
     2      0.9435016345820550d+04,-.1079683015257463d+05,
     3      0.1293704628566498d+05,-.1266198859210414d+05,
     4      0.1379364801829622d+05,-.1040693465037893d+05,
     5      0.1058854154705948d+05,-.6105449295986970d+04,
     6      0.5816400451004506d+04,0.1893686327067312d-06,
     7      0.5977918846061940d-05,-.4188927846934625d-05,
     8      -.3866889154390250d-04,0.4183854904972204d-04/
         data arr1350/
     1      0.6897274289201087d-04,0.1888530187980104d-07,
     2      -.1479247365899722d-02,0.1976447247263903d-02,
     3      -.4535258752419635d-02,0.7852362766123888d-02,
     4      -.5894024861286989d-01,0.7786949738674344d-01,
     5      -.2651690221395498d+00,0.3578439979708271d+00,
     6      -.1711949414794696d+01,0.2115673614829533d+01,
     7      -.6124025361465262d+01,-.1401884541955501d+01,
     8      0.1985370868608548d+02,-.1532119316513497d+03/
         data arr1351/
     1      0.4247189042166482d+03,-.1131659122473771d+04,
     2      0.2134050356988350d+04,-.4088447003176206d+04,
     3      0.6149405897143209d+04,-.9538023486708899d+04,
     4      0.1156321203069995d+05,-.1555277090319438d+05,
     5      0.1589651823505614d+05,-.1909349331917801d+05,
     6      0.1457590655632400d+05,-.1618906328637247d+05,
     7      0.9485748375680438d+04,-.9741127241413714d+04,
     8      0.1000000000000003d+01,-.1677050983124852d+01/
         data arr1352/
     1      0.2053959590644344d+01,-.2117173085744233d+01,
     2      0.1944747658960328d+01,-.1641555957966494d+01,
     3      0.1297763933447220d+01,-.9733229500844798d+00,
     4      0.6989143327590741d+00,-.4838015395504791d+00,
     5      0.3245439389752113d+00,-.2118594305318583d+00,
     6      0.1350344211677688d+00,-.8426657225372644d-01,
     7      0.5160252488197421d-01,-.3106883313312612d-01,
     8      0.1842154723681644d-01,-.1077166776063835d-01/
         data arr1353/
     1      0.6219000824950506d-02,-.3548948076774485d-02,
     2      0.2003610583217833d-02,-.1120101930756674d-02,
     3      0.6204541212179936d-03,-.3413242233355902d-03,
     4      0.1867270927191588d-03,-.1032671164919808d-03,
     5      0.5763401956080739d-04,-.3591826461096740d-04,
     6      0.2316600214901735d-04,-.2034462032256452d-04,
     7      0.1350943849439446d-04,-.1511161237956891d-04,
     8      0.9020850169302044d-05,-.1029490632653700d-04/
         data arr1354/
     1      0.3632227284526438d-13,0.9999999999998836d+00,
     2      -.2449489742783534d+01,0.3787314351886437d+01,
     3      -.4638493828818448d+01,0.4894174281174737d+01,
     4      -.4643021398313858d+01,0.4062643723532641d+01,
     5      -.3334015911481554d+01,0.2596351512175447d+01,
     6      -.1935206158715252d+01,0.1389614126920109d+01,
     7      -.9662276672980402d+00,0.6532093885907747d+00,
     8      -.4307772400945775d+00,0.2778881284308275d+00/
         data arr1355/
     1      -.1757519360874069d+00,0.1091908362629975d+00,
     2      -.6674983767135683d-01,0.4020755212398982d-01,
     3      -.2389392338599964d-01,0.1401977736145973d-01,
     4      -.8125985536068267d-02,0.4642378332020922d-02,
     5      -.2605355083240708d-02,0.1406110662767474d-02,
     6      -.7185102950450589d-03,0.2906136856456927d-03,
     7      -.6742640371577631d-04,-.9950748783463648d-04,
     8      0.1145424245952283d-03,-.1783957862314234d-03/
         data arr1356/
     1      0.1158616048353896d-03,-.1316522484708104d-03,
     2      -.3888189040753278d-13,0.1666607497126183d-12,
     3      0.1000000000000385d+01,-.3092329219214201d+01,
     4      0.5680971527827291d+01,-.7992153134087721d+01,
     5      0.9477527742232503d+01,-.9951404129357718d+01,
     6      0.9527744073685349d+01,-.8479648530274238d+01,
     7      0.7110401452729298d+01,-.5673075915486920d+01,
     8      0.4339068721306776d+01,-.3200059385796907d+01/
         data arr1357/
     1      0.2286232872025596d+01,-.1588262865702330d+01,
     2      0.1076256109612653d+01,-.7132312449344394d+00,
     3      0.4632576479552293d+00,-.2954666151893566d+00,
     4      0.1853499240747586d+00,-.1145191288679171d+00,
     5      0.6977449702659500d-01,-.4195760460157656d-01,
     6      0.2491870916725843d-01,-.1459955329555325d-01,
     7      0.8436821980757544d-02,-.4753029656468293d-02,
     8      0.2608419888273781d-02,-.1309665625296148d-02/
         data arr1358/
     1      0.6363785846785033d-03,-.1913919279666927d-03,
     2      0.3983738800301028d-04,0.8974024233321080d-04,
     3      -.5390523995447701d-12,0.1428843387996690d-11,
     4      0.5266022984269209d-11,0.9999999999919820d+00,
     5      -.3674234614196709d+01,0.7753527423075300d+01,
     6      -.1225940327852123d+02,0.1609046680307322d+02,
     7      -.1848653891263596d+02,0.1919509065911543d+02,
     8      -.1839494037126980d+02,0.1651107614531071d+02/
         data arr1359/
     1      -.1403171655875366d+02,0.1138321653474898d+02,
     2      -.8871886408366774d+01,0.6676978632765678d+01,
     3      -.4872567127220014d+01,0.3459678263936866d+01,
     4      -.2396932843650740d+01,0.1624319154427755d+01,
     5      -.1078898286922707d+01,0.7036900003232389d+00,
     6      -.4513969090350627d+00,0.2853058263739652d+00,
     7      -.1779203374166941d+00,0.1098861194069011d+00,
     8      -.6717416075517412d-01,0.4125077168249917d-01/
         data arr1360/
     1      -.2505654050109840d-01,0.1589096686820362d-01,
     2      -.9255392754842185d-02,0.6321664224297346d-02,
     3      -.3224249151812483d-02,0.2406002035255034d-02,
     4      0.2130868740846686d-11,-.4776759575176510d-11,
     5      -.2076775606096481d-10,0.2660655935074364d-10,
     6      0.1000000000089221d+01,-.4220485754117999d+01,
     7      0.1000976086056448d+02,-.1751708150649420d+02,
     8      0.2515699302562405d+02,-.3134545178728726d+02/
         data arr1361/
     1      0.3504528046702308d+02,-.3594996591277133d+02,
     2      0.3437054576207950d+02,-.3098119126133273d+02,
     3      0.2656083791682984d+02,-.2180692094428483d+02,
     4      0.1723988246965261d+02,-.1318247251103634d+02,
     5      0.9785435068911841d+01,-.7073318297890731d+01,
     6      0.4991776963701534d+01,-.3447085197684810d+01,
     7      0.2333579016097347d+01,-.1551542916693594d+01,
     8      0.1014291108798291d+01,-.6534415112707012d+00/
         data arr1362/
     1      0.4142349327349676d+00,-.2603293406977401d+00,
     2      0.1600419457183689d+00,-.9916766341280839d-01,
     3      0.5676897706438598d-01,-.3523607903913346d-01,
     4      0.1706185944527479d-01,-.1083307768953719d-01,
     5      -.1621532179010814d-11,-.9433319332198319d-11,
     6      0.1483933205816959d-10,0.5712154789463446d-10,
     7      -.1093135418345810d-09,0.9999999998883622d+00,
     8      -.4743416490121817d+01,0.1245146828903789d+02/
         data arr1363/
     1      -.2384274654291142d+02,0.3713488638596849d+02,
     2      -.4982167818291444d+02,0.5962578163069643d+02,
     3      -.6514993379781400d+02,0.6606602658234671d+02,
     4      -.6293313265635403d+02,0.5683614731552916d+02,
     5      -.4901773304713213d+02,0.4060485668572061d+02,
     6      -.3245983381999322d+02,0.2513918066366281d+02,
     7      -.1892367567429310d+02,0.1388338858873013d+02,
     8      -.9949349970163984d+01,0.6977237750762362d+01/
         data arr1364/
     1      -.4793308981407423d+01,0.3227525702309664d+01,
     2      -.2127220965544166d+01,0.1370261337815387d+01,
     3      -.8556551795305965d+00,0.5156596849148431d+00,
     4      -.2910028400453544d+00,0.1552271431611606d+00,
     5      -.6847588846724578d-01,0.2560768552868202d-01,
     6      0.5048202599502205d-10,-.7637955554489352d-10,
     7      -.4884373214817409d-09,0.4086178795490910d-09,
     8      0.2245935386213633d-08,-.1553276933254947d-08/
         data arr1365/
     1      0.9999999844259420d+00,-.5249999990500255d+01,
     2      0.1507947695959373d+02,-.3131488577178778d+02,
     3      0.5251665948002841d+02,-.7542131053232112d+02,
     4      0.9614368269584225d+02,-.1114235294528477d+03,
     5      0.1194072092187320d+03,-.1198211076369134d+03,
     6      0.1136722453475663d+03,-.1027230240308045d+03,
     7      0.8896050609083513d+02,-.7419741483375794d+02,
     8      0.5984245527789688d+02,-.4683384891725685d+02/
         data arr1366/
     1      0.3566522833140167d+02,-.2649805660081230d+02,
     2      0.1923470786989812d+02,-.1367626363498405d+02,
     3      0.9502766159329448d+01,-.6493568225720549d+01,
     4      0.4296451889593967d+01,-.2815357156966786d+01,
     5      0.1689658843535441d+01,-.1052380423165369d+01,
     6      0.5127856774561652d+00,-.2940548781626064d+00,
     7      -.3749515746071157d-09,0.8052116436428946d-09,
     8      0.3645980321945954d-08,-.4446085823885377d-08/
         data arr1367/
     1      -.1591766349809235d-07,0.1470781221594524d-07,
     2      0.1233281250576422d-06,0.9999998800645601d+00,
     3      -.5744562656416069d+01,0.1789422036437009d+02,
     4      -.4001268915298893d+02,0.7182981597379363d+02,
     5      -.1098784829700555d+03,0.1485646937911137d+03,
     6      -.1819537410898174d+03,0.2054075184202980d+03,
     7      -.2165181918179425d+03,0.2152288508601524d+03,
     8      -.2033365629736776d+03,0.1837260574510147d+03/
         data arr1368/
     1      -.1595771495105492d+03,0.1338157314752845d+03,
     2      -.1086981541082789d+03,0.8584059140945121d+02,
     3      -.6599993847651951d+02,0.4963391996589157d+02,
     4      -.3634703187168947d+02,0.2627508704590742d+02,
     5      -.1829225780401366d+02,0.1281447157134209d+02,
     6      -.8026961539469244d+01,0.5486822529373908d+01,
     7      -.2805537463664110d+01,0.1871027657775572d+01,
     8      0.1598804135692508d-08,-.3518233221681493d-08/
         data arr1369/
     1      -.1555127824693832d-07,0.1945249694812251d-07,
     2      0.6763898196446081d-07,-.6394882910704285d-07,
     3      -.5281487452548712d-06,0.5277659753687158d-06,
     4      0.1000000017276785d+01,-.6229967553635278d+01,
     5      0.2089592971083167d+02,-.5001584973499728d+02,
     6      0.9563689886799871d+02,-.1551707180415481d+03,
     7      0.2217181883195278d+03,-.2860545555087880d+03,
     8      0.3392175509809237d+03,-.3746642480261367d+03/
         data arr1370/
     1      0.3893536396485603d+03,-.3837850345522139d+03,
     2      0.3611016656374192d+03,-.3260903873854613d+03,
     3      0.2837318053785929d+03,-.2389602685810529d+03,
     4      0.1950364938807186d+03,-.1551812567467684d+03,
     5      0.1195760309728739d+03,-.9079143335396422d+02,
     6      0.6587096520526986d+02,-.4810891923492892d+02,
     7      0.3096252746338097d+02,-.2191015443259104d+02,
     8      0.1139744672334665d+02,-.7820285171073396d+01/
         data arr1371/
     1      -.7220579789695048d-08,0.1741928388749383d-07,
     2      0.7034848690705175d-07,-.9691986558958074d-07,
     3      -.3005991722022346d-06,0.3092953023715536d-06,
     4      0.2434035507035582d-05,-.2699990979813449d-05,
     5      0.4479218849932626d-06,0.9999975510537739d+00,
     6      -.6708119286512243d+01,0.2408472189965116d+02,
     7      -.6140417992662033d+02,0.1245354559029628d+03,
     8      -.2135318427961684d+03,0.3214092947564750d+03/
         data arr1372/
     1      -.4355873966191529d+03,0.5412444814686629d+03,
     2      -.6249368293191910d+03,0.6776160816396571d+03,
     3      -.6954913245110738d+03,0.6805074677799775d+03,
     4      -.6376074413064253d+03,0.5757858643229145d+03,
     5      -.5013718967465826d+03,0.4248981242058162d+03,
     6      -.3465713470033715d+03,0.2795414313846157d+03,
     7      -.2133165487349520d+03,0.1657959590463525d+03,
     8      -.1105444641246837d+03,0.8371134209385050d+02/
         data arr1373/
     1      -.4488974438058883d+02,0.3326376713446070d+02,
     2      0.2321208966694309d-07,-.5665204297924247d-07,
     3      -.2261666194299766d-06,0.3152898615398094d-06,
     4      0.9649079468543200d-06,-.1004929537412087d-05,
     5      -.7837549332679714d-05,0.8792635625403170d-05,
     6      -.1585169547744343d-05,0.8063951471136944d-05,
     7      0.9997268205831302d+00,-.7180412518534248d+01,
     8      0.2745999915063446d+02,-.7425774828498861d+02/
         data arr1374/
     1      0.1591509524457391d+03,-.2874713013056121d+03,
     2      0.4545133709055955d+03,-.6454514618251577d+03,
     3      0.8383387361525172d+03,-.1010025658518394d+04,
     4      0.1140095248146407d+04,-.1216862749591877d+04,
     5      0.1234177629657015d+04,-.1199751297025796d+04,
     6      0.1116912086157629d+04,-.1008136376775583d+04,
     7      0.8683865444019494d+03,-.7388168805635980d+03,
     8      0.5879485279884524d+03,-.4771733538094473d+03/
         data arr1375/
     1      0.3262201766792013d+03,-.2554475235759300d+03,
     2      0.1390519570132878d+03,-.1054625851791568d+03,
     3      -.8312895465672819d-07,0.2188141316530069d-06,
     4      0.8112218850764936d-06,-.1223814984978467d-05,
     5      -.3403590959558169d-05,0.3808757633383670d-05,
     6      0.2859137664673917d-04,-.3482395980501512d-04,
     7      0.1130320178558162d-04,-.3857146229137575d-04,
     8      0.1020882030999790d-02,0.9988215518644382d+00/
         data arr1376/
     1      -.7644972939764331d+01,0.3101994166273940d+02,
     2      -.8862838710682849d+02,0.2001415816734183d+03,
     3      -.3796834923138994d+03,0.6291118791818272d+03,
     4      -.9335717520315941d+03,0.1265670156274945d+04,
     5      -.1587024441840861d+04,0.1864789573826209d+04,
     6      -.2062615391872629d+04,0.2177613083376636d+04,
     7      -.2183951496844151d+04,0.2124519142109232d+04,
     8      -.1949581732192297d+04,0.1782809134528861d+04/
         data arr1377/
     1      -.1498067414980686d+04,0.1307582561173670d+04,
     2      -.9241864731293345d+03,0.7801936763820098d+03,
     3      -.4370244050020280d+03,0.3579763549908752d+03,
     4      0.2105170641625366d-06,-.5673565800468110d-06,
     5      -.2055335338471412d-05,0.3177546178289956d-05,
     6      0.8577415997959323d-05,-.9823142733174693d-05,
     7      -.7282407652757201d-04,0.9091693466426547d-04,
     8      -.3314183268250022d-04,0.1053704229928768d-03/
         data arr1378/
     1      -.2619418366852508d-02,0.3095482001977432d-02,
     2      0.9907569378984097d+00,-.8100910741908368d+01,
     3      0.3469528111407182d+02,-.1045987487823570d+03,
     4      0.2479708164674626d+03,-.4932694886396251d+03,
     5      0.8533102080697434d+03,-.1322630379209892d+04,
     6      0.1863650419644247d+04,-.2433217263344589d+04,
     7      0.2951777072522163d+04,-.3397546662563498d+04,
     8      0.3671088624705951d+04,-.3837402041802300d+04/
         data arr1379/
     1      0.3727749946776109d+04,-.3619914017319825d+04,
     2      0.3171915634816320d+04,-.2908442120202211d+04,
     3      0.2101192026499312d+04,-.1847486786366683d+04,
     4      0.1050278909942701d+04,-.8887313843251162d+03,
     5      -.4444578182910227d-06,0.1213117367194723d-05,
     6      0.4340098794853776d-05,-.6797280014705584d-05,
     7      -.1806814107890142d-04,0.2096668943943155d-04,
     8      0.1541419062046477d-03,-.1948370236791479d-03/
         data arr1380/
     1      0.7427828861963406d-04,-.2290786373204852d-03,
     2      0.5562422530762102d-02,-.6646795093883903d-02,
     3      0.1973854520526546d-01,0.9750629028447865d+00,
     4      -.8403501133965559d+01,0.3852395378205512d+02,
     5      -.1217486251599764d+03,0.3034740613889583d+03,
     6      -.6286662865990127d+03,0.1138314199616474d+04,
     7      -.1828373890862474d+04,0.2684937017929881d+04,
     8      -.3597939770427223d+04,0.4545781366209286d+04/
         data arr1381/
     1      -.5306677723871863d+04,0.5976219750038471d+04,
     2      -.6141019900670488d+04,0.6327972943707353d+04,
     3      -.5767892545875633d+04,0.5534639050691804d+04,
     4      -.4077987553069700d+04,0.3711361672823172d+04,
     5      -.2136292184325595d+04,0.1851326524750713d+04,
     6      0.9853848362407147d-06,-.2815378122686460d-05,
     7      -.9632632896271853d-05,0.1582037999273356d-04,
     8      0.3963583605879517d-04,-.4811199857045428d-04/
         data arr1382/
     1      -.3460034975087617d-03,0.4586682430200510d-03,
     2      -.2104573265484614d-03,0.5875118680023375d-03,
     3      -.1267875838195278d-01,0.1584183339720916d-01,
     4      -.4616607744280965d-01,0.6051054209909437d-01,
     5      0.6098749428061860d+00,-.8577316828041645d+01,
     6      0.4127375688076440d+02,-.1401427158690705d+03,
     7      0.3606010303678886d+03,-.7907335164206630d+03,
     8      0.1475689782483830d+04,-.2490955086192273d+04/
         data arr1383/
     1      0.3727279819129151d+04,-.5265790975371834d+04,
     2      0.6706865987621353d+04,-.8294864857519979d+04,
     3      0.9084714013674730d+04,-.1016341048346991d+05,
     4      0.9725975342415900d+04,-.1003480005846781d+05,
     5      0.7561733953328013d+04,-.7351584001288913d+04,
     6      0.4316262613847988d+04,-.3962873989384486d+04,
     7      -.1172253218159933d-05,0.3335495450252471d-05,
     8      0.1145614617498595d-04,-.1872885226702834d-04/
         data arr1384/
     1      -.4723587950454608d-04,0.5717155339208322d-04,
     2      0.4106754327835237d-03,-.5413639720581657d-03,
     3      0.2406881832767161d-03,-.6784908454938366d-03,
     4      0.1500782757466416d-01,-.1863730021518618d-01,
     5      0.5440242472185877d-01,-.7085643249174550d-01,
     6      0.4610772848651337d+00,0.4669333450232844d+00,
     7      -.7640939922016622d+01,0.4483642430600286d+02,
     8      -.1515821122545322d+03,0.4209653363801359d+03/
         data arr1385/
     1      -.9234658323265035d+03,0.1796571667818072d+04,
     2      -.2977123070856562d+04,0.4625453765478411d+04,
     3      -.6306086492052230d+04,0.8312683959580481d+04,
     4      -.9490179559701142d+04,0.1107675230373536d+05,
     5      -.1086769706709315d+05,0.1150468813055953d+05,
     6      -.8766805056386399d+04,0.8646564353330422d+04,
     7      -.5104876111701024d+04,0.4708543591303523d+04,
     8      0.2321310427498554d-05,-.7076461716961209d-05/
         data arr1386/
     1      -.2273088554806832d-04,0.3992777254751253d-04,
     2      0.9183866373911492d-04,-.1189628155444338d-03,
     3      -.8306691224413338d-03,0.1176214396462185d-02,
     4      -.6625954451631785d-03,0.1677585889928343d-02,
     5      -.3113257670519753d-01,0.4131450761339850d-01,
     6      -.1175257858998899d+00,0.1615744825724186d+00,
     7      -.9696264899426650d+00,0.1193707243260882d+01,
     8      -.2950849573951243d+01,-.5148153086185854d+01/
         data arr1387/
     1      0.3100914259125400d+02,-.1611902042797255d+03,
     2      0.4429513959825147d+03,-.1111053050001639d+04,
     3      0.2099896737016115d+04,-.3895859151142845d+04,
     4      0.5885088645103225d+04,-.8907186463623872d+04,
     5      0.1086916395561561d+05,-.1429650416292106d+05,
     6      0.1478533462200708d+05,-.1737514115059293d+05,
     7      0.1346681743668233d+05,-.1463031443217318d+05,
     8      0.8833315905099441d+04,-.8873727433465013d+04/
         data arr1388/
     1      0.9999999999999605d+00,-.1785357107135982d+01,
     2      0.2319246914410203d+01,-.2527340731256589d+01,
     3      0.2447087140587158d+01,-.2171574413994415d+01,
     4      0.1800574383890756d+01,-.1413274755023520d+01,
     5      0.1059956066270892d+01,-.7649574004282308d+00,
     6      0.5341024382429745d+00,-.3623353748967262d+00,
     7      0.2396623236821398d+00,-.1549985869686812d+00,
     8      0.9824828975309016d-01,-.6115908318608390d-01/
         data arr1389/
     1      0.3745214264595508d-01,-.2259490652289663d-01,
     2      0.1344636871630677d-01,-.7901569004511287d-02,
     3      0.4587251883129306d-02,-.2630580183057752d-02,
     4      0.1483425244864792d-02,-.8159517545563670d-03,
     5      0.4210819918195001d-03,-.1942677755086808d-03,
     6      0.4698335738663563d-04,0.2810826755959062d-04,
     7      -.9004968794940052d-04,0.8382405932683605d-04,
     8      -.1082064587161661d-03,0.7094120061166221d-04/
         data arr1390/
     1      -.7547113983767682d-04,0.1099721730173584d-12,
     2      0.1000000000000631d+01,-.2598076211354066d+01,
     3      0.4246781869836855d+01,-.5482571818951804d+01,
     4      0.6081624805799617d+01,-.6051140278971920d+01,
     5      0.5541145379637369d+01,-.4749553182556194d+01,
     6      0.3856156606156711d+01,-.2991572027804728d+01,
     7      0.2232432439337473d+01,-.1610853015762996d+01,
     8      0.1128615433276198d+01,-.7704206585743284d+00/
         data arr1391/
     1      0.5138389645048346d+00,-.3356382501808226d+00,
     2      0.2151464067724632d+00,-.1355694563326794d+00,
     3      0.8410121425326980d-01,-.5142822229835788d-01,
     4      0.3103440712621043d-01,-.1848934625775685d-01,
     5      0.1087846607572600d-01,-.6297760421098855d-02,
     6      0.3584105326349197d-02,-.1947754437917977d-02,
     7      0.1008974874828964d-02,-.4104456447842633d-03,
     8      0.1525842731017337d-03,0.6805330353836072d-04/
         data arr1392/
     1      -.8195418694849987d-04,0.1499167656274064d-03,
     2      0.5890208007306272d-12,0.4688800989313189d-11,
     3      0.9999999999959874d+00,-.3269174207677729d+01,
     4      0.6330728631068077d+01,-.9363273916495643d+01,
     5      0.1164542489641042d+02,-.1279672710650413d+02,
     6      0.1279672710637647d+02,-.1187388295336615d+02,
     7      0.1036310948764760d+02,-.8592636455354413d+01,
     8      0.6820193745902934d+01,-.5212851236867828d+01/
         data arr1393/
     1      0.3854955446386247d+01,-.2768873316629393d+01,
     2      0.1937807615176696d+01,-.1324955253630400d+01,
     3      0.8870733465020728d+00,-.5826800581816032d+00,
     4      0.3761591542362578d+00,-.2390340048684743d+00,
     5      0.1498076740017824d+00,-.9275709346395510d-01,
     6      0.5699988423514133d-01,-.3478627820779271d-01,
     7      0.2146347367034897d-01,-.1320952999984964d-01,
     8      0.8598217396093832d-02,-.5149686743917455d-02/
         data arr1394/
     1      0.3681550421963519d-02,-.1975622343877521d-02,
     2      0.1533473865549854d-02,-.2000967652137400d-11,
     3      -.1828334453292650d-10,0.1363004366685165d-10,
     4      0.1000000000087004d+01,-.3872983346268193d+01,
     5      0.8592329427594064d+01,-.1424876639360073d+02,
     6      0.1957180360248139d+02,-.2348616432221791d+02,
     7      0.2542451866372024d+02,-.2535957725894079d+02,
     8      0.2365543197675423d+02,-.2086213004413148d+02/
         data arr1395/
     1      0.1754001465791766d+02,-.1415019896374009d+02,
     2      0.1101053394459277d+02,-.8298519674317353d+01,
     3      0.6079309032269524d+01,-.4341494631902522d+01,
     4      0.3029903723796475d+01,-.2070855435351563d+01,
     5      0.1388605099104962d+01,-.9151234806399344d+00,
     6      0.5934270988490779d+00,-.3795036247114247d+00,
     7      0.2391007631477811d+00,-.1495520539733387d+00,
     8      0.9180492321165978d-01,-.5698353806070582d-01/
         data arr1396/
     1      0.3281244799144414d-01,-.2065913348067345d-01,
     2      0.1029750968918227d-01,-.6744507013062783d-02,
     3      -.2577337867321787d-11,0.2005663497408711d-10,
     4      0.1768041980693211d-10,-.1022339019255946d-09,
     5      0.9999999999330909d+00,-.4437059836916574d+01,
     6      0.1103704699015982d+02,-.2021367184314376d+02,
     7      0.3032050776229439d+02,-.3938749496211090d+02,
     8      0.4583470289257141d+02,-.4886245026834481d+02/
         data arr1397/
     1      0.4847920950424947d+02,-.4528812401563968d+02,
     2      0.4018922399124368d+02,-.3411489622675713d+02,
     3      0.2785469703216955d+02,-.2197540232678419d+02,
     4      0.1681447771882165d+02,-.1251681727784053d+02,
     5      0.9088798500863705d+01,-.6451418353783033d+01,
     6      0.4484258941506923d+01,-.3055400369941187d+01,
     7      0.2041792396151136d+01,-.1336457575260697d+01,
     8      0.8558431240854170d+00,-.5319081589835301d+00/
         data arr1398/
     1      0.3198843158891344d+00,-.1802723844859546d+00,
     2      0.9697147871429713d-01,-.4329087167503554d-01,
     3      0.1718117365169458d-01,-.3164667256113574d-10,
     4      -.4503479728565386d-09,0.2148804315639549d-09,
     5      0.2171000686997126d-08,-.1013038619298676d-08,
     6      0.9999999893061495d+00,-.4974937180165423d+01,
     7      0.1366693663648561d+02,-.2733387322867242d+02,
     8      0.4438467835943835d+02,-.6197983050384975d+02/
         data arr1399/
     1      0.7708644089159739d+02,-.8740780809907491d+02,
     2      0.9186107536898280d+02,-.9057624490970326d+02,
     3      0.8457487295128429d+02,-.7533283788541306d+02,
     4      0.6438494455583168d+02,-.5305392690423394d+02,
     5      0.4231519926244256d+02,-.3277693275202400d+02,
     6      0.2472353935891948d+02,-.1820601741386479d+02,
     7      0.1310793215274980d+02,-.9247931542453636d+01,
     8      0.6382310811609433d+01,-.4331720900359933d+01/
         data arr1400/
     1      0.2853324645955725d+01,-.1858713582074817d+01,
     2      0.1114963077871077d+01,-.6911561201403689d+00,
     3      0.3412741081581733d+00,-.1949783940739758d+00,
     4      0.4080528300844967d-09,0.3903617459907428d-08,
     5      -.2777501072140567d-08,-.1862322112828030d-07,
     6      0.1250790714042814d-07,0.9509310239325155d-07,
     7      0.9999999253624980d+00,-.5494315460059169d+01,
     8      0.1648294582960988d+02,-.3568662195072891d+02/
         data arr1401/
     1      0.6229207145370165d+02,-.9296974270670772d+02,
     2      0.1229874089241104d+03,-.1477181113698696d+03,
     3      0.1638585386382179d+03,-.1700017124335011d+03,
     4      0.1665670028862362d+03,-.1553014175093034d+03,
     5      0.1386351963946638d+03,-.1190801940572822d+03,
     6      0.9883548400514806d+02,-.7953066530451082d+02,
     7      0.6226478098729922d+02,-.4751041890149978d+02,
     8      0.3548940341494158d+02,-.2586074531816074d+02/
         data arr1402/
     1      0.1862940884962932d+02,-.1297742936005533d+02,
     2      0.9113135540402143d+01,-.5746668751633485d+01,
     3      0.3972545395153558d+01,-.2087155449758820d+01,
     4      0.1423319753600090d+01,-.1721815337524358d-08,
     5      -.1641442942808700d-07,0.1172024546811056d-07,
     6      0.7830288876490620d-07,-.5276840235234425d-07,
     7      -.3999388743742599d-06,0.3150552454680097d-06,
     8      0.1000000907697966d+01,-.6000000411148916d+01/
         data arr1403/
     1      0.1948556156136402d+02,-.4535019090948469d+02,
     2      0.8460538464106687d+02,-.1343068862706431d+03,
     3      0.1881991973477888d+03,-.2385861297682738d+03,
     4      0.2784719014805355d+03,-.3031619128299996d+03,
     5      0.3109206693087942d+03,-.3027851303241295d+03,
     6      0.2817367790103392d+03,-.2518109416001765d+03,
     7      0.2170383306738038d+03,-.1811798773523165d+03,
     8      0.1467212782510206d+03,-.1158675677520750d+03/
         data arr1404/
     1      0.8876632846549437d+02,-.6700975806739725d+02,
     2      0.4854075422860702d+02,-.3534409459492442d+02,
     3      0.2282922303726442d+02,-.1617547538942292d+02,
     4      0.8605516811433410d+01,-.5946089807341023d+01,
     5      0.8346970107305848d-08,0.7408048537678171d-07,
     6      -.5683550998806310d-07,-.3525765193739865d-06,
     7      0.2542942248118834d-06,0.1814992128285236d-05,
     8      -.1542128862860052d-05,-.3971726867190033d-05/
         data arr1405/
     1      0.1000001821283522d+01,-.6495144214175195d+01,
     2      0.2267505532009654d+02,-.5640352892985219d+02,
     3      0.1119223159268473d+03,-.1881981734279790d+03,
     4      0.2783495088412374d+03,-.3712927421800846d+03,
     5      0.4547398743079910d+03,-.5181847472420470d+03,
     6      0.5551001420628798d+03,-.5634580679247264d+03,
     7      0.5456509515071645d+03,-.5064731193866082d+03,
     8      0.4532832669357111d+03,-.3916582433794799d+03/
         data arr1406/
     1      0.3292890939157233d+03,-.2670559653573025d+03,
     2      0.2138645174943187d+03,-.1629429208684563d+03,
     3      0.1258123966876673d+03,-.8419291041508706d+02,
     4      0.6339108650275177d+02,-.3475284110582915d+02,
     5      0.2560204296177764d+02,-.2861690291632701d-07,
     6      -.2498166729778464d-06,0.1948629025186113d-06,
     7      0.1188420362092942d-05,-.8710654301528404d-06,
     8      -.6127302757742334d-05,0.5294304491883579d-05/
         data arr1407/
     1      0.1330959631916973d-04,-.6159042792942223d-05,
     2      0.9998430966756049d+00,-.6981966469496152d+01,
     3      0.2605146500406936d+02,-.6892596875363022d+02,
     4      0.1448716020234018d+03,-.2571250603766408d+03,
     5      0.4001397039816410d+03,-.5600839707955476d+03,
     6      0.7179576752443664d+03,-.8545674875986228d+03,
     7      0.9540330766621740d+03,-.1007799649787376d+04,
     8      0.1012733043459197d+04,-.9757480782403910d+03/
         data arr1408/
     1      0.9017321480567161d+03,-.8076545087225403d+03,
     2      0.6922728484007358d+03,-.5851529645893411d+03,
     3      0.4656204628979166d+03,-.3759029885370806d+03,
     4      0.2582678510711962d+03,-.2015106132400027d+03,
     5      0.1123514800895131d+03,-.8496606541168984d+02,
     6      0.1055862367669287d-06,0.8699818219565374d-06,
     7      -.7191441787610666d-06,-.4130211525624235d-05,
     8      0.3199407622179443d-05,0.2144194251860002d-04/
         data arr1409/
     1      -.1967534296750375d-04,-.4505752241501256d-04,
     2      0.2108253846976197d-04,0.5575503155687590d-03,
     3      0.9994207337387096d+00,-.7461480159286723d+01,
     4      0.2961405672552340d+02,-.8298237155805001d+02,
     5      0.1841175375631542d+03,-.3438135202813125d+03,
     6      0.5614757587183894d+03,-.8224065630936374d+03,
     7      0.1101432927600130d+04,-.1366112859424736d+04,
     8      0.1588288280800874d+04,-.1740770118907046d+04/
         data arr1410/
     1      0.1820088346735092d+04,-.1811793287212313d+04,
     2      0.1745454549944107d+04,-.1593104961310886d+04,
     3      0.1441405933832776d+04,-.1210028336936921d+04,
     4      0.1042840452397234d+04,-.7406652625563887d+03,
     5      0.6161230389381165d+03,-.3532109888857005d+03,
     6      0.2840124572909663d+03,-.2899374563412589d-06,
     7      -.2320817112790292d-05,0.1974994602452422d-05,
     8      0.1100612518857284d-04,-.8765995895185120d-05/
         data arr1411/
     1      -.5734594804902841d-04,0.5421910330236631d-04,
     2      0.1183773407338731d-03,-.5567698486574189d-04,
     3      -.1503047759312642d-02,0.1607828844054058d-02,
     4      0.9974110307163577d+00,-.7933153608911754d+01,
     5      0.3332332911096982d+02,-.9865313341325042d+02,
     6      0.2302509540950275d+03,-.4513204008602707d+03,
     7      0.7707977726849275d+03,-.1180070460353988d+04,
     8      0.1645368555178493d+04,-.2125464596644874d+04/
         data arr1412/
     1      0.2556681503291380d+04,-.2914987395009794d+04,
     2      0.3130422411426498d+04,-.3242814668117345d+04,
     3      0.3139600960562147d+04,-.3020980697967096d+04,
     4      0.2652662933465858d+04,-.2407331482371129d+04,
     5      0.1751929073432132d+04,-.1522889478293188d+04,
     6      0.8887240473685305d+03,-.7409891737683564d+03,
     7      0.5961688578610916d-06,0.4755269232043426d-05,
     8      -.4060854212342968d-05,-.2255076444137523d-04/
         data arr1413/
     1      0.1802890334844059d-04,0.1175035933348538d-03,
     2      -.1114366706681572d-03,-.2424989945511087d-03,
     3      0.1150118097613171d-03,0.3080067696902683d-02,
     4      -.3301776834990525d-02,0.5307556430828158d-02,
     5      0.9915991386013434d+00,-.8318967916580507d+01,
     6      0.3720949335288634d+02,-.1158050047329703d+03,
     7      0.2840445151804933d+03,-.5812266999806312d+03,
     8      0.1038496145814050d+04,-.1650941938519749d+04/
         data arr1414/
     1      0.2395268703251335d+04,-.3181905822393035d+04,
     2      0.3972426365262410d+04,-.4604436368254410d+04,
     3      0.5118603964224412d+04,-.5234415440846502d+04,
     4      0.5314725077549486d+04,-.4844805983183944d+04,
     5      0.4567678087238697d+04,-.3387130121260829d+04,
     6      0.3021499065959205d+04,-.1782235238103861d+04,
     7      0.1507466773852468d+04,-.1452387032559278d-05,
     8      -.1103770619941863d-04,0.9894999005130606d-05/
         data arr1415/
     1      0.5224250611420032d-04,-.4375555905097957d-04,
     2      -.2739890769308177d-03,0.2731020324697346d-03,
     3      0.5473598178645446d-03,-.2613591632314506d-03,
     4      -.7283037729300826d-02,0.8189573521925403d-02,
     5      -.1333985359833171d-01,0.2151827400335112d-01,
     6      0.7878999839539042d+00,-.8635334386592084d+01,
     7      0.4068516869196372d+02,-.1344305427378309d+03,
     8      0.3421870227524552d+03,-.7380419327013744d+03/
         data arr1416/
     1      0.1365917840348640d+04,-.2274414566895092d+04,
     2      0.3382042652214180d+04,-.4717836451106807d+04,
     3      0.5985938091386959d+04,-.7305718514032076d+04,
     4      0.7993481607316823d+04,-.8813296306221959d+04,
     5      0.8474162447981575d+04,-.8593837933695207d+04,
     6      0.6541904022646244d+04,-.6238452673164613d+04,
     7      0.3768130507190806d+04,-.3378067185733495d+04,
     8      0.1732756850785595d-05,0.1324041490956492d-04/
         data arr1417/
     1      -.1180399466489752d-04,-.6269265948726123d-04,
     2      0.5226081864141578d-04,0.3283613610918385d-03,
     3      -.3252091411664115d-03,-.6603839327399167d-03,
     4      0.3187233101160205d-03,0.8703454667933941d-02,
     5      -.9716098251994766d-02,0.1574993721702746d-01,
     6      -.2528160981478428d-01,0.2528304261673566d+00,
     7      0.7174417736476909d+00,-.8452076917938171d+01,
     8      0.4449685284166319d+02,-.1486161688184866d+03/
         data arr1418/
     1      0.4014557763691011d+03,-.8738421597397940d+03,
     2      0.1669254521025894d+04,-.2750117476919692d+04,
     3      0.4206247633415558d+04,-.5714476673681837d+04,
     4      0.7416516698771359d+04,-.8461668850903843d+04,
     5      0.9716559043860539d+04,-.9582025884699725d+04,
     6      0.9956823209540132d+04,-.7666976456481120d+04,
     7      0.7409396078392270d+04,-.4500370138417828d+04,
     8      0.4049189536127452d+04,-.3595736411930264d-05/
         data arr1419/
     1      -.2575946819672730d-04,0.2450310981121615d-04,
     2      0.1216130446015523d-03,-.1078355490418423d-03,
     3      -.6432274560032659d-03,0.6809076813905643d-03,
     4      0.1230067262901264d-02,-.5914736530772980d-03,
     5      -.1740499157743199d-01,0.2070529972069724d-01,
     6      -.3424492876044867d-01,0.5637727416814472d-01,
     7      -.5145336877564080d+00,0.6094699785598674d+00,
     8      -.8492998492676154d+00,-.7517269005043148d+01/
         data arr1420/
     1      0.3843557981633370d+02,-.1640348442668854d+03,
     2      0.4471609040498199d+03,-.1067308393812066d+04,
     3      0.2015809007884813d+04,-.3623296128589487d+04,
     4      0.5475649766639911d+04,-.8061077933227417d+04,
     5      0.9870551430742722d+04,-.1263360743347016d+05,
     6      0.1318242073754749d+05,-.1504548548393429d+05,
     7      0.1183623062375667d+05,-.1247149905554032d+05,
     8      0.7770918384856976d+04,-.7540794984900500d+04/
         data arr1421/
     1      0.1000000000000408d+01,-.1887458608818366d+01,
     2      0.2584509141014787d+01,-.2960927193250619d+01,
     3      0.3006835778926312d+01,-.2792474791070642d+01,
     4      0.2418354108447914d+01,-.1978980492696440d+01,
     5      0.1544841152254968d+01,-.1158630864353584d+01,
     6      0.8395078181106049d+00,-.5902391841150818d+00,
     7      0.4041091512240130d+00,-.2702144065873807d+00,
     8      0.1768968688791168d+00,-.1136140878091724d+00/
         data arr1422/
     1      0.7171552019930586d-01,-.4455777147652352d-01,
     2      0.2728590446984045d-01,-.1648637608025411d-01,
     3      0.9837486561419130d-02,-.5795157298155377d-02,
     4      0.3367261900892632d-02,-.1911856870421443d-02,
     5      0.1055380359518426d-02,-.5257475247520615d-03,
     6      0.2262194666629014d-03,-.1625731994771979d-04,
     7      -.4247920724158044d-04,0.1289968843981596d-03,
     8      -.9988236213168525d-04,0.1274747067574553d-03/
         data arr1423/
     1      0.3451388177675709d-11,0.9999999999952501d+00,
     2      -.2738612787543932d+01,0.4706212649276711d+01,
     3      -.6372242050397612d+01,0.7397446433975785d+01,
     4      -.7687651842356397d+01,0.7339426350856491d+01,
     5      -.6547814693482128d+01,0.5524718646995038d+01,
     6      -.4447821075833400d+01,0.3439879946664311d+01,
     7      -.2569227004409254d+01,0.1861120042063375d+01,
     8      -.1312111200088760d+01,0.9029129022545081d+00/
         data arr1424/
     1      -.6079315122411670d+00,0.4013275719427576d+00,
     2      -.2602334809583194d+00,0.1660312488251568d+00,
     3      -.1044023285963373d+00,0.6487784948631681d-01,
     4      -.3996886967214372d-01,0.2462660428909052d-01,
     5      -.1523296916486266d-01,0.9783992589432821d-02,
     6      -.6404997365299380d-02,0.4649735200669811d-02,
     7      -.3024466289912138d-02,0.2492592506449294d-02,
     8      -.1474644408120500d-02,0.1278167263094864d-02/
         data arr1425/
     1      -.9955061342926893d-11,0.1235419290877992d-10,
     2      0.1000000000052291d+01,-.3436931771275530d+01,
     3      0.6980441425611241d+01,-.1080466207941146d+02,
     4      0.1403566776134085d+02,-.1607987748617368d+02,
     5      0.1673646711267923d+02,-.1613873614389111d+02,
     6      0.1461703161071780d+02,-.1256066561464070d+02,
     7      0.1031963969472326d+02,-.8155019545704041d+01,
     8      0.6228498792609442d+01,-.4615760346083876d+01/
         data arr1426/
     1      0.3329775187426476d+01,-.2344675790631760d+01,
     2      0.1615289042980739d+01,-.1090903908945936d+01,
     3      0.7234827779971347d+00,-.4719798995748864d+00,
     4      0.3032721569321413d+00,-.1924244711271248d+00,
     5      0.1205001696275863d+00,-.7519764951855948d-01,
     6      0.4629806606532914d-01,-.2913879970548790d-01,
     7      0.1703488356408042d-01,-.1120088880992718d-01,
     8      0.5867783282745611d-02,-.4153081396703683d-02/
         data arr1427/
     1      0.2139748869211514d-11,0.2054465315305472d-10,
     2      -.1289111173391011d-10,0.9999999999040072d+00,
     3      -.4062019202272408d+01,0.9431082255448955d+01,
     4      -.1633511363639797d+02,0.2339277959977216d+02,
     5      -.2921757235761329d+02,0.3286976891374650d+02,
     6      -.3402344321275668d+02,0.3289154343766482d+02,
     7      -.3002573389195962d+02,0.2610037789220556d+02,
     8      -.2174671990086492d+02,0.1745885412357535d+02/
         data arr1428/
     1      -.1356351058778330d+02,0.1023294680279101d+02,
     2      -.7519439474818082d+01,0.5395093904070891d+01,
     3      -.3787192562624097d+01,0.2605007818538694d+01,
     4      -.1757351475482737d+01,0.1162762311073062d+01,
     5      -.7535447320189436d+00,0.4769631943656340d+00,
     6      -.2927574178642191d+00,0.1726766307281727d+00,
     7      -.9575416954176138d-01,0.4930340519168576d-01,
     8      -.2127955939782851d-01,0.6971882368162580d-02/
         data arr1429/
     1      -.2235507052170750d-09,0.1673376839736540d-09,
     2      0.1182593390350200d-08,-.8034147142211656d-09,
     3      0.9999999942463889d+00,-.4643543901618618d+01,
     4      0.1206428097732418d+02,-.2303561696559753d+02,
     5      0.3596434532263398d+02,-.4855186627776478d+02,
     6      0.5863194903331483d+02,-.6477870596922995d+02,
     7      0.6652641943316859d+02,-.6425468623136557d+02,
     8      0.5889038937179128d+02,-.5157687098184882d+02/
         data arr1430/
     1      0.4340834928691506d+02,-.3526866918308049d+02,
     2      0.2776808502958751d+02,-.2125338903865987d+02,
     3      0.1585525137780272d+02,-.1155605698763939d+02,
     4      0.8241475226837338d+01,-.5762435591858366d+01,
     5      0.3944966562151477d+01,-.2655938773844756d+01,
     6      0.1739176843622808d+01,-.1124440128817185d+01,
     7      0.6730494552787817d+00,-.4141980267255863d+00,
     8      0.2068859000939902d+00,-.1174088614224694d+00/
         data arr1431/
     1      0.2412762271965041d-08,-.2748499136267371d-08,
     2      -.1269472514062392d-07,0.1307619950893998d-07,
     3      0.6252958897988920d-07,0.9999999388110580d+00,
     4      -.5196152636003472d+01,0.1488235130014224d+02,
     5      -.3098008295271091d+02,0.5227889099612498d+02,
     6      -.7575931291676040d+02,0.9765191167647256d+02,
     7      -.1146131548617943d+03,0.1245367867700134d+03,
     8      -.1268220063334303d+03,0.1221793768549918d+03/
         data arr1432/
     1      -.1121769070286240d+03,0.9873834498210366d+02,
     2      -.8372196979316307d+02,0.6866662241393980d+02,
     3      -.5465584105099789d+02,0.4236673827205064d+02,
     4      -.3204764483529956d+02,0.2376047810363590d+02,
     5      -.1722106721158256d+02,0.1236597922284318d+02,
     6      -.8627791833501950d+01,0.6087166581110572d+01,
     7      -.3871047904717262d+01,0.2717577746058149d+01,
     8      -.1473618395810070d+01,0.1033958001590922d+01/
         data arr1433/
     1      -.9880777317278120d-08,0.1103261196726989d-07,
     2      0.5200385291568926d-07,-.5250492964233427d-07,
     3      -.2559786792882914d-06,0.2454100696086554d-06,
     4      0.1000000875840343d+01,-.5728220325504867d+01,
     5      0.1788635441228002d+02,-.4024430483264498d+02,
     6      0.7289943456411137d+02,-.1127587139008739d+03,
     7      0.1544010898498914d+03,-.1917368466087689d+03,
     8      0.2196619697388587d+03,-.2351340951916119d+03/
         data arr1434/
     1      0.2374710367212357d+03,-.2280226539827970d+03,
     2      0.2094463848503328d+03,-.1849769154588101d+03,
     3      0.1576943824868235d+03,-.1303028604484968d+03,
     4      0.1045622968051411d+03,-.8186745811582262d+02,
     5      0.6229066097139291d+02,-.4671406939826757d+02,
     6      0.3376333727280046d+02,-.2450209195577638d+02,
     7      0.1587811137958032d+02,-.1126449652066835d+02,
     8      0.6135675444258745d+01,-.4275119998386346d+01/
         data arr1435/
     1      0.4470965803511269d-07,-.5228765989786327d-07,
     2      -.2351472198033672d-06,0.2486599222053465d-06,
     3      0.1159287717837895d-05,-.1165375275237830d-05,
     4      -.3938665173436532d-05,0.1000003319621537d+01,
     5      -.6244972385609911d+01,0.2107684320363951d+02,
     6      -.5090548107813006d+02,0.9842386629716041d+02,
     7      -.1617262840269586d+03,0.2343058257420280d+03,
     8      -.3067775797783068d+03,0.3694343198665410d+03/
         data arr1436/
     1      -.4145558346340422d+03,0.4378754318677746d+03,
     2      -.4387696578799583d+03,0.4198499763391799d+03,
     3      -.3854696820528258d+03,0.3414400257423555d+03,
     4      -.2923475231700474d+03,0.2435647954341929d+03,
     5      -.1961586363856467d+03,0.1558014645667851d+03,
     6      -.1183720116580284d+03,0.9071553804494775d+02,
     7      -.6086143613995533d+02,0.4550765696655543d+02,
     8      -.2549415526010909d+02,0.1867292324287349d+02/
         data arr1437/
     1      -.1560639468706263d-06,0.1848530879529708d-06,
     2      0.8206664425224030d-06,-.8789897574981019d-06,
     3      -.4047353238858168d-05,0.4121225450643723d-05,
     4      0.1372872764108940d-04,-.1171914653259111d-04,
     5      0.9999104328293054d+00,-.6749911324474943d+01,
     6      0.2445422473902346d+02,-.6304169870816428d+02,
     7      0.1294829054491982d+03,-.2251121262838113d+03,
     8      0.3438622799843869d+03,-.4732505076604815d+03/
         data arr1438/
     1      0.5974062239173662d+03,-.7011241361895053d+03,
     2      0.7727311271714217d+03,-.8065637126575574d+03,
     3      0.8017928273799265d+03,-.7645450026451932d+03,
     4      0.7003199375168939d+03,-.6215065719859021d+03,
     5      0.5292301329392187d+03,-.4435349968636007d+03,
     6      0.3521664603577674d+03,-.2819586337149443d+03,
     7      0.1943294076299343d+03,-.1503452020469469d+03,
     8      0.8569016837439515d+02,-.6426496040554608d+02/
         data arr1439/
     1      0.5370842146828464d-06,-.6640175740340860d-06,
     2      -.2822302315531593d-05,0.3155438501741090d-05,
     3      0.1394054272081950d-04,-.1482942325149888d-04,
     4      -.4695736322296027d-04,0.4176034730431847d-04,
     5      0.3107032934704964d-03,0.9996784901347667d+00,
     6      -.7245756972140863d+01,0.2801839734716529d+02,
     7      -.7672399661120574d+02,0.1667431991472681d+03,
     8      -.3056401764787138d+03,0.4907626071258956d+03/
         data arr1440/
     1      -.7079269418165513d+03,0.9347722682629615d+03,
     2      -.1144641613299633d+04,0.1314603584651311d+04,
     3      -.1425184084676631d+04,0.1473525457757699d+04,
     4      -.1453190123119004d+04,0.1384382196017250d+04,
     5      -.1254102470873363d+04,0.1120667974751490d+04,
     6      -.9374203995788807d+03,0.7961187057239900d+03,
     7      -.5668256406148551d+03,0.4633903405700830d+03,
     8      -.2712604369396832d+03,0.2138738565758276d+03/
         data arr1441/
     1      -.1526777689641091d-05,0.1950748987487408d-05,
     2      0.8018434311342357d-05,-.9265298877132695d-05,
     3      -.3965720283988228d-04,0.4362579999549243d-04,
     4      0.1328085111007967d-03,-.1218905329178498d-03,
     5      -.8890451393989176d-03,0.9515504282124839d-03,
     6      0.1000142036134234d+01,-.7733354243929278d+01,
     7      0.3174707126522228d+02,-.9203111902020115d+02,
     8      0.2108662103005492d+03,-.4063381911413025d+03/
         data arr1442/
     1      0.6835624045399151d+03,-.1031704474093890d+04,
     2      0.1420643296335051d+04,-.1812903911008258d+04,
     3      0.2158497451042701d+04,-.2434405454003717d+04,
     4      0.2593720316058881d+04,-.2659376807343619d+04,
     5      0.2561381366079248d+04,-.2438704832560740d+04,
     6      0.2141479223819446d+04,-.1920803809595020d+04,
     7      0.1405597179176246d+04,-.1205637674075134d+04,
     8      0.7212294365578331d+03,-.5923574855816149d+03/
         data arr1443/
     1      0.2926421735684127d-05,-.3692194670677230d-05,
     2      -.1537334195566586d-04,0.1754230802236251d-04,
     3      0.7598222343317502d-04,-.8249696815834541d-04,
     4      -.2552152460826517d-03,0.2316773592922711d-03,
     5      0.1698276708863166d-02,-.1792363840843035d-02,
     6      -.3244033134952223d-03,0.9991223633067977d+00,
     7      -.8172148490145331d+01,0.3566306532683491d+02,
     8      -.1089803338814595d+03,0.2625870929627213d+03/
         data arr1444/
     1      -.5294316281073156d+03,0.9317465673850399d+03,
     2      -.1462446009384210d+04,0.2092422359451286d+04,
     3      -.2748159372096832d+04,0.3382244102057394d+04,
     4      -.3879096283958008d+04,0.4243731190212812d+04,
     5      -.4301234591076866d+04,0.4284464929704832d+04,
     6      -.3885659195500390d+04,0.3579552879275163d+04,
     7      -.2660605364330198d+04,0.2309392762082391d+04,
     8      -.1389258154907355d+04,0.1139451813118811d+04/
         data arr1445/
     1      -.7485352397447859d-05,0.1000109804132612d-04,
     2      0.3928145303572750d-04,-.4747367208404017d-04,
     3      -.1946076213298542d-03,0.2240090525086835d-03,
     4      0.6466644898155917d-03,-.6202915219629644d-03,
     5      -.4396541275392657d-02,0.4919176221846248d-02,
     6      0.3499944479041039d-03,0.2886656053245272d-02,
     7      0.8850576688810480d+00,-.8565562157314958d+01,
     8      0.3952915497653149d+02,-.1275500620300783d+03/
         data arr1446/
     1      0.3203075447733703d+03,-.6792292183743075d+03,
     2      0.1243359077209038d+04,-.2040928796612954d+04,
     3      0.3008618768297175d+04,-.4140792849195678d+04,
     4      0.5220652067480065d+04,-.6284572585172584d+04,
     5      0.6852391253107539d+04,-.7442019730630392d+04,
     6      0.7171433687288468d+04,-.7148920354292232d+04,
     7      0.5484579648713010d+04,-.5129785736591904d+04,
     8      0.3182272845839750d+04,-.2792283438654140d+04/
         data arr1447/
     1      0.8169203776531437d-05,-.1071017135873459d-04,
     2      -.4288794995918001d-04,0.5086390865019869d-04,
     3      0.2122574964309728d-03,-.2395809461059979d-03,
     4      -.7085635292624205d-03,0.6683578633764842d-03,
     5      0.4773330661110769d-02,-.5231625371693322d-02,
     6      -.6061887601908567d-03,-.2803297518538984d-02,
     7      0.1239374866418007d+00,0.8657366029521414d+00,
     8      -.8840845049118973d+01,0.4351752988778751d+02/
         data arr1448/
     1      -.1433219030378238d+03,0.3765899266067297d+03,
     2      -.8087921060234607d+03,0.1511409349587495d+04,
     3      -.2460311272825660d+04,0.3681349397198843d+04,
     4      -.4944801753437778d+04,0.6269963134108693d+04,
     5      -.7093982698194381d+04,0.7937097688388299d+04,
     6      -.7799540293401504d+04,0.7871351386485065d+04,
     7      -.6092260839491576d+04,0.5698494919832795d+04,
     8      -.3538141909111840d+04,0.3072968182238919d+04/
         data arr1449/
     1      -.1858155832982090d-04,0.2633159902486425d-04,
     2      0.9739894785303761d-04,-.1248776652421962d-03,
     3      -.4837978459588828d-03,0.5912308760357242d-03,
     4      0.1588439198906772d-02,-.1614038700887480d-02,
     5      -.1105834580768687d-01,0.1312051066856842d-01,
     6      -.4476792043141399d-03,0.8941178571495645d-02,
     7      -.2940878783614546d+00,0.3432651721427637d+00,
     8      0.1871932323296334d+00,-.8605460912701880d+01/
         data arr1450/
     1      0.4155777052733278d+02,-.1612659742902649d+03,
     2      0.4360815982995144d+03,-.1007801308338934d+04,
     3      0.1895882989784477d+04,-.3332160378700877d+04,
     4      0.5029774142781480d+04,-.7262564257563575d+04,
     5      0.8906980857443004d+04,-.1118879078939744d+05,
     6      0.1177133716289042d+05,-.1317773595054143d+05,
     7      0.1049281565147161d+05,-.1083491609619825d+05,
     8      0.6967562993727459d+04,-.6618458990896989d+04/
         data arr1451/
     1      0.9999999999968513d+00,-.1984313483312927d+01,
     2      0.2849753278809254d+01,-.3416734151956687d+01,
     3      0.3623993832547030d+01,-.3508916940390796d+01,
     4      0.3162894987478173d+01,-.2689789357027487d+01,
     5      0.2178978419280653d+01,-.1693679808823967d+01,
     6      0.1270259856284098d+01,-.9233741250237470d+00,
     7      0.6529240954826535d+00,-.4504520957180360d+00,
     8      0.3039658449729512d+00,-.2010548660248263d+00/
         data arr1452/
     1      0.1305931697409333d+00,-.8343890000674600d-01,
     2      0.5253384649313164d-01,-.3266574265286523d-01,
     3      0.2015494560490906d-01,-.1242753057166099d-01,
     4      0.7798429500510986d-02,-.5032562331453839d-02,
     5      0.3534623126935941d-02,-.2599751248022255d-02,
     6      0.2185800101480059d-02,-.1568057113144782d-02,
     7      0.1445110491501305d-02,-.9306618343716266d-03,
     8      0.8436223986999229d-03,0.9131641905838920d-11/
         data arr1453/
     1      0.1000000000042496d+01,-.2872281323311787d+01,
     2      0.5165616492528267d+01,-.7305284901845954d+01,
     3      0.8841639614831921d+01,-.9563695496972955d+01,
     4      0.9488684957887789d+01,-.8784815254160664d+01,
     5      0.7681809552773430d+01,-.6401507958857160d+01,
     6      0.5118705083809482d+01,-.3948513876619412d+01,
     7      0.2951084864126314d+01,-.2144580933121688d+01,
     8      0.1519827340892695d+01,-.1052967794580670d+01/
         data arr1454/
     1      0.7146978625140690d+00,-.4761231870493876d+00,
     2      0.3118171486989409d+00,-.2011155604056225d+00,
     3      0.1279520350311615d+00,-.8058809411251133d-01,
     4      0.5027074122608021d-01,-.3154882130104847d-01,
     5      0.1975020938836273d-01,-.1297721486710049d-01,
     6      0.7881118813147610d-02,-.5707241568081723d-02,
     7      0.3266005329200452d-02,-.2614506321481539d-02,
     8      0.1456211607444269d-10,0.2029463563406581d-10/
         data arr1455/
     1      0.9999999999320734d+00,-.3596873642584530d+01,
     2      0.7630121231329181d+01,-.1231305519018059d+02,
     3      0.1664825694156920d+02,-.1982121643703273d+02,
     4      0.2140936067987618d+02,-.2139570238823936d+02,
     5      0.2005847098513508d+02,-.1782104399582408d+02,
     6      0.1512165736924931d+02,-.1232923113241310d+02,
     7      0.9706414223009382d+01,-.7407902584894396d+01,
     8      0.5498896075988772d+01,-.3981011432855457d+01/
         data arr1456/
     1      0.2817344799470215d+01,-.1952592942062090d+01,
     2      0.1326992442612003d+01,-.8848458972206243d+00,
     3      0.5785941251338145d+00,-.3703468348008657d+00,
     4      0.2309196809599427d+00,-.1392464791313809d+00,
     5      0.7990525467616181d-01,-.4311612223956766d-01,
     6      0.2071202653223979d-01,-.8273757364570150d-02,
     7      0.1653464479167638d-02,0.7594604604363384d-10,
     8      0.7037818624866021d-09,-.3584965564438627d-09/
         data arr1457/
     1      0.9999999966183720d+00,-.4242640685501038d+01,
     2      0.1026979796671373d+02,-.1851414156070302d+02,
     3      0.2755339547863466d+02,-.3571328234092368d+02,
     4      0.4163891538205883d+02,-.4461312353068410d+02,
     5      0.4459133329801613d+02,-.4204111273108926d+02,
     6      0.3770539436221578d+02,-.3238283863458458d+02,
     7      0.2677402093040225d+02,-.2140336391177648d+02,
     8      0.1660265394277807d+02,-.1253453566429643d+02/
         data arr1458/
     1      0.9233305558534890d+01,-.6650872911279417d+01,
     2      0.4691686368311710d+01,-.3246365992894614d+01,
     3      0.2201280937926189d+01,-.1467245935493840d+01,
     4      0.9528874378219290d+00,-.6089988347730013d+00,
     5      0.3625445497229961d+00,-.2195214490802185d+00,
     6      0.1102627968905993d+00,-.6073280952681571d-01,
     7      -.1720285582223667d-08,-.9555642023011974d-08,
     8      0.8071946097216154d-08,0.4606191691722200d-07/
         data arr1459/
     1      0.9999999631597869d+00,-.4841229363506437d+01,
     2      0.1309147517504185d+02,-.2597758959650681d+02,
     3      0.4208850620382286d+02,-.5888632035491970d+02,
     4      0.7360789921919836d+02,-.8408220954335950d+02,
     5      0.8918265363895190d+02,-.8887245090388236d+02,
     6      0.8395978607143465d+02,-.7572826495380194d+02,
     7      0.6558342671946967d+02,-.5478900277746383d+02,
     8      0.4432633620524830d+02,-.3484209200937560d+02/
         data arr1460/
     1      0.2669758790900006d+02,-.1998739658798667d+02,
     2      0.1467969579808261d+02,-.1055992088349115d+02,
     3      0.7532663163950024d+01,-.5245730327040973d+01,
     4      0.3691201746325579d+01,-.2357989669794973d+01,
     5      0.1658555761054216d+01,-.9246650025403555d+00,
     6      0.6515770494459644d+00,0.7433829913973312d-08,
     7      0.4177596583553107d-07,-.3488291619293903d-07,
     8      -.2013639833481320d-06,0.1591984248540576d-06/
         data arr1461/
     1      0.1000000790420907d+01,-.5408327492442976d+01,
     2      0.1609772033783877d+02,-.3477505539043082d+02,
     3      0.6081753586613196d+02,-.9122629651102203d+02,
     4      0.1215755762461380d+03,-.1473718774171325d+03,
     5      0.1652166907564142d+03,-.1734264925251560d+03,
     6      0.1720648283318598d+03,-.1625594289211472d+03,
     7      0.1471134280761783d+03,-.1281592814653293d+03,
     8      0.1078912847066880d+03,-.8811614177781707d+02/
         data arr1462/
     1      0.6997157823779518d+02,-.5424874368165150d+02,
     2      0.4094610518546248d+02,-.3047430279203456d+02,
     3      0.2196002115966686d+02,-.1586864559493036d+02,
     4      0.1031264311271900d+02,-.7320265759906500d+01,
     5      0.4093990596142391d+01,-.2868960616454258d+01,
     6      -.3300824831131662d-07,-.1828427925444926d-06,
     7      0.1548783942176129d-06,0.8813970027822991d-06,
     8      -.7069287538274744d-06,-.3458156513432062d-05/
         data arr1463/
     1      0.1000002570474986d+01,-.5952924302042581d+01,
     2      0.1928971829877363d+02,-.4498069249598679d+02,
     3      0.8433875465634252d+02,-.1348757494442377d+03,
     4      0.1907432818096172d+03,-.2443884042565114d+03,
     5      0.2885988850355988d+03,-.3181445026969919d+03,
     6      0.3306287899263934d+03,-.3264142927715396d+03,
     7      0.3080670326082216d+03,-.2792764961169261d+03,
     8      0.2444083337330244d+03,-.2069750818695546d+03/
         data arr1464/
     1      0.1705049459354727d+03,-.1360151685933431d+03,
     2      0.1067889160517726d+03,-.8060474423735125d+02,
     3      0.6096538965419156d+02,-.4085205311105830d+02,
     4      0.3009063151698511d+02,-.1718202691531176d+02,
     5      0.1235956818745396d+02,0.1277543511498092d-06,
     6      0.6941607455539177d-06,-.5993733008193441d-06,
     7      -.3346629059543453d-05,0.2736285862525301d-05,
     8      0.1312185486093252d-04,-.9940407484585923d-05/
         data arr1465/
     1      0.9999386159692227d+00,-.6480688669509692d+01,
     2      0.2266824483254236d+02,-.5667037114330678d+02,
     3      0.1132840159202668d+03,-.1922503191729781d+03,
     4      0.2873728866916076d+03,-.3878391346367759d+03,
     5      0.4809725729897469d+03,-.5553866387961092d+03,
     6      0.6031080974921651d+03,-.6209342944448541d+03,
     7      0.6096081649227565d+03,-.5744592422623112d+03,
     8      0.5207920620598688d+03,-.4573692651183888d+03/
         data arr1466/
     1      0.3863635597245941d+03,-.3206966752890550d+03,
     2      0.2537624839282228d+03,-.2012341480461339d+03,
     3      0.1389772643677103d+03,-.1064813592982463d+03,
     4      0.6213362040850188d+02,-.4605046185775896d+02,
     5      -.4465203163458954d-06,-.2358696445380404d-05,
     6      0.2094498797038961d-05,0.1137386643705472d-04,
     7      -.9565031558686269d-05,-.4454805299654529d-04,
     8      0.3469143570244848d-04,0.2090175597081671d-03/
         data arr1467/
     1      0.9998177345363029d+00,-.6995947684576101d+01,
     2      0.2623348160780286d+02,-.6991693803187684d+02,
     3      0.1483212315729465d+03,-.2660523242580720d+03,
     4      0.4189095329915835d+03,-.5936679761211657d+03,
     5      0.7712336612549607d+03,-.9304930901276449d+03,
     6      0.1053825073758760d+04,-.1128101300810737d+04,
     7      0.1151734170793556d+04,-.1123420528211634d+04,
     8      0.1056971914674704d+04,-.9486717731979207d+03/
         data arr1468/
     1      0.8362974162309637d+03,-.6957070472481343d+03,
     2      0.5812774062140769d+03,-.4141311277793639d+03,
     3      0.3320832849798801d+03,-.1985392156620685d+03,
     4      0.1527522041685971d+03,0.1402961668031931d-05,
     5      0.7140971430920554d-05,-.6578918290190607d-05,
     6      -.3444509621062593d-04,0.3006042870558487d-04,
     7      0.1346933678468269d-03,-.1087371638503370d-03,
     8      -.6348146037738866d-03,0.5748283249411542d-03/
         data arr1469/
     1      0.1001231713564959d+01,-.7500695302545947d+01,
     2      0.2997236761927835d+02,-.8479871553260337d+02,
     3      0.1901474910187978d+03,-.3592781552249373d+03,
     4      0.5938566052560055d+03,-.8817927080872424d+03,
     5      0.1196656386205151d+04,-.1505941239592511d+04,
     6      0.1771461345892773d+04,-.1973371277348064d+04,
     7      0.2082065395812209d+04,-.2109735751610295d+04,
     8      0.2017393748623523d+04,-.1897400686984699d+04/
         data arr1470/
     1      0.1662659154332502d+04,-.1470222424885989d+04,
     2      0.1079957255458015d+04,-.9112633230113913d+03,
     3      0.5590600771075269d+03,-.4495098646300350d+03,
     4      -.2612043338626169d-05,-.1356079363674176d-04,
     5      0.1225159280645338d-04,0.6539807060629626d-04,
     6      -.5595503854709530d-04,-.2560058995145195d-03,
     7      0.2028463950329234d-03,0.1202957636135623d-02,
     8      -.1066909992159141d-02,-.2364161670096096d-02/
         data arr1471/
     1      0.1001326800733126d+01,-.7971631322566077d+01,
     2      0.3390120274576342d+02,-.1013936518543945d+03,
     3      0.2394620629224120d+03,-.4744691184762706d+03,
     4      0.8211313373936945d+03,-.1270010534975266d+04,
     5      0.1790367241688432d+04,-.2321875562977663d+04,
     6      0.2817885766527077d+04,-.3196465835644057d+04,
     7      0.3446908079786168d+04,-.3462695621408513d+04,
     8      0.3394853904133991d+04,-.3065219496863043d+04/
         data arr1472/
     1      0.2770881753043029d+04,-.2063951812871981d+04,
     2      0.1752648841841452d+04,-.1078218980200671d+04,
     3      0.8603219212371087d+03,0.7317152648268301d-05,
     4      0.3590917782882302d-04,-.3430486031249079d-04,
     5      -.1732588214734373d-03,0.1568021415904117d-03,
     6      0.6765165125021191d-03,-.5661718523499008d-03,
     7      -.3201316085736242d-02,0.3005515480187863d-02,
     8      0.6103844123389073d-02,-.3551571113600861d-02/
         data arr1473/
     1      0.9340604333063636d+00,-.8418777945096256d+01,
     2      0.3797432724423786d+02,-.1197069866078444d+03,
     3      0.2957441314724862d+03,-.6159417043377221d+03,
     4      0.1112288621052540d+04,-.1797442557612638d+04,
     5      0.2620334970639498d+04,-.3553343026260248d+04,
     6      0.4439636202052413d+04,-.5261874643575389d+04,
     7      0.5701076187450124d+04,-.6085194654438759d+04,
     8      0.5858280541302666d+04,-.5719349518057656d+04/
         data arr1474/
     1      0.4412745002845782d+04,-.4029648162803755d+04,
     2      0.2566323790445702d+04,-.2185350905616019d+04,
     3      -.8137971519111684d-05,-.4068266891537658d-04,
     4      0.3816249757085159d-04,0.1962475073427122d-03,
     5      -.1743501540476671d-03,-.7671419837685096d-03,
     6      0.6310079394665807d-03,0.3618781678846998d-02,
     7      -.3331493462647315d-02,-.6994347169567872d-02,
     8      0.4058176112083413d-02,0.7410962910021833d-01/
         data arr1475/
     1      0.9267685194694033d+00,-.8885854733224489d+01,
     2      0.4199996224421723d+02,-.1361451699028137d+03,
     3      0.3501972175722698d+03,-.7422580453694926d+03,
     4      0.1363732290929860d+04,-.2196561257179437d+04,
     5      0.3236999657801065d+04,-.4312726504160799d+04,
     6      0.5386056087817597d+04,-.6062184225855831d+04,
     7      0.6674172333826814d+04,-.6560618442932247d+04,
     8      0.6496148593237887d+04,-.5059553627464358d+04/
         data arr1476/
     1      0.4630687815068940d+04,-.2952707179393748d+04,
     2      0.2493574885950894d+04,0.1938523496022697d-04,
     3      0.9006403538488350d-04,-.9084424426126979d-04,
     4      -.4347696464930839d-03,0.4155473268306741d-03,
     5      0.1693155208809033d-02,-.1494824516422688d-02,
     6      -.8070541069120668d-02,0.8003982571909415d-02,
     7      0.1490180948741816d-01,-.8999568053183179d-02,
     8      -.1684158588676986d+00,0.1789210571052041d+00/
         data arr1477/
     1      0.7875628287293655d+00,-.9116340269716490d+01,
     2      0.4289557042537120d+02,-.1557231515636164d+03,
     3      0.4158380643511582d+03,-.9317211561190302d+03,
     4      0.1738118441604227d+04,-.2978046322646047d+04,
     5      0.4462450210608393d+04,-.6284735090019324d+04,
     6      0.7679056140717316d+04,-.9397906906131403d+04,
     7      0.9908072474502202d+04,-.1077256640470625d+05,
     8      0.8659957619280903d+04,-.8664547607054824d+04/
         data arr1478/
     1      0.5738007684452335d+04,-.5252556841955779d+04,
     2      0.1000000000035218d+01,-.2076655965765445d+01,
     3      0.3114983948444575d+01,-.3893729935573877d+01,
     4      0.4298561459432660d+01,-.4325344032985844d+01,
     5      0.4045988859587893d+01,-.3565950395078847d+01,
     6      0.2990140317763591d+01,-.2402989080216909d+01,
     7      0.1861347285324884d+01,-.1396010446789929d+01,
     8      0.1017508763334037d+01,-.7229381185753416d+00/
         data arr1479/
     1      0.5019821652417924d+00,-.3413855670341263d+00,
     2      0.2278171304785238d+00,-.1494345124406969d+00,
     3      0.9649931163378150d-01,-.6149579961737882d-01,
     4      0.3878635245794693d-01,-.2439946713937538d-01,
     5      0.1536569533698262d-01,-.1003383636664745d-01,
     6      0.6732564615499716d-02,-.5031284448557650d-02,
     7      0.3364943320410064d-02,-.2916167290581166d-02,
     8      0.1904968235629116d-02,-.1744311303583026d-02/
         data arr1480/
     1      0.1016065482530333d-09,0.9999999998833003d+00,
     2      -.3000000000431736d+01,0.5625000000548857d+01,
     3      -.8279775810412113d+01,0.1041420462224177d+02,
     4      -.1168991570568553d+02,0.1202011946957551d+02,
     5      -.1151905892633281d+02,0.1041429200095657d+02,
     6      -.8963195597800305d+01,0.7394636424719459d+01,
     7      -.5879695677068851d+01,0.4525638142930068d+01,
     8      -.3384163443566816d+01,0.2465821262142109d+01/
         data arr1481/
     1      -.1755020511741509d+01,0.1222557684152748d+01,
     2      -.8347246990489183d+00,0.5588489716113064d+00,
     3      -.3666199764426267d+00,0.2348305609103770d+00,
     4      -.1461928972496210d+00,0.8685090535496719d-01,
     5      -.4851830270187312d-01,0.2348756874380665d-01,
     6      -.1014373907127738d-01,0.1025810189068018d-02,
     7      0.1752843019365787d-02,-.3982592146777634d-02,
     8      0.2721052896651444d-09,-.7614508535566534d-10/
         data arr1482/
     1      0.9999999988409694d+00,-.3749999999644448d+01,
     2      0.8279775817005755d+01,-.1388560616734041d+02,
     3      0.1948319281029143d+02,-.2404023891483885d+02,
     4      0.2687780427553031d+02,-.2777144541709478d+02,
     5      0.2688958607090099d+02,-.2464878745048187d+02,
     6      0.2155888461037520d+02,-.1810255745300062d+02,
     7      0.1466474125671244d+02,-.1150741799008665d+02,
     8      0.8776057467842872d+01,-.6523092589459924d+01/
         data arr1483/
     1      0.4736400592903362d+01,-.3366165584447632d+01,
     2      0.2344804314554472d+01,-.1602540939426731d+01,
     3      0.1073719365280034d+01,-.7058747359852706d+00,
     4      0.4521109596905412d+00,-.2827469697607943d+00,
     5      0.1657928281316214d+00,-.9623761530325935d-01,
     6      0.4732373942834595d-01,-.2348712228712966d-01,
     7      -.6898726933678729d-08,0.5705500051776860d-08,
     8      0.2934037072722137d-07,0.9999999731853596d+00/
         data arr1484/
     1      -.4415880554099518d+01,0.1110848503889242d+02,
     2      -.2078207184043909d+02,0.3205365143933987d+02,
     3      -.4300448824318820d+02,0.5184003255686452d+02,
     4      -.5736444211054879d+02,0.5915708206129694d+02,
     5      -.5749036172830953d+02,0.5310085236117484d+02,
     6      -.4692720671915866d+02,0.3989320980439500d+02,
     7      -.3276718431823165d+02,0.2610196355941655d+02,
     8      -.2022928050599880d+02,0.1530405830253089d+02/
         data arr1485/
     1      -.1133169914537963d+02,0.8246213617125412d+01,
     2      -.5894250562265887d+01,0.4191102056522052d+01,
     3      -.2927758258403574d+01,0.2073441544205527d+01,
     4      -.1339297477609386d+01,0.9576588375126435d+00,
     5      -.5549060409887831d+00,0.3999245308658856d+00,
     6      0.2962654046707799d-07,-.2384314295312791d-07,
     7      -.1260109785595734d-06,0.1120540664886191d-06,
     8      0.1000000519557642d+01,-.5031153393254137d+01/
         data arr1486/
     1      0.1411863575124051d+02,-.2903488922148483d+02,
     2      0.4869299918455833d+02,-.7043673723273560d+02,
     3      0.9093339272808533d+02,-.1071715098786477d+03,
     4      0.1171710394075151d+03,-.1202497065727009d+03,
     5      0.1168953749319974d+03,-.1084058366986841d+03,
     6      0.9645502924700574d+02,-.8272836000397512d+02,
     7      0.6865586691138517d+02,-.5533445329989370d+02,
     8      0.4341707181518447d+02,-.3328654720469975d+02/
         data arr1487/
     1      0.2488911094246136d+02,-.1835804675775709d+02,
     2      0.1317062105360839d+02,-.9460367652466846d+01,
     3      0.6157116019621535d+01,-.4359704616189152d+01,
     4      0.2500907733117524d+01,-.1755390874160194d+01,
     5      -.1224121959105053d-06,0.9640566434567360d-07,
     6      0.5206844008055746d-06,-.4530338473588532d-06,
     7      -.2147554203048828d-05,0.1000001795583789d+01,
     8      -.5612477009677398d+01,0.1731305640304933d+02/
         data arr1488/
     1      -.3871321504795414d+02,0.7000060704587055d+02,
     2      -.1084442881995317d+03,0.1491109764689764d+03,
     3      -.1863128756490850d+03,0.2151091704992002d+03,
     4      -.2323411572329654d+03,0.2370125063081262d+03,
     5      -.2300471870082115d+03,0.2137317604997137d+03,
     6      -.1909600973445349d+03,0.1648144256413235d+03,
     7      -.1377658609610677d+03,0.1119779409036095d+03,
     8      -.8824056278751655d+02,0.6825410483643338d+02/
         data arr1489/
     1      -.5095197106771600d+02,0.3782321064203499d+02,
     2      -.2518497138739967d+02,0.1811225600590396d+02,
     3      -.1046450751516207d+02,0.7313497421580127d+01,
     4      0.5238028495898428d-06,-.4253059849992970d-06,
     5      -.2227856766800994d-05,0.1998743612862110d-05,
     6      0.9185390342817816d-05,-.7918594853513108d-05,
     7      0.9999611646260791d+00,-.6169447485339584d+01,
     8      0.2069318415169349d+02,-.4988926991628394d+02/
         data arr1490/
     1      0.9660932054917039d+02,-.1594058896201602d+03,
     2      0.2323732043936049d+03,-.3066151757270085d+03,
     3      0.3725672816510016d+03,-.4222917143451592d+03,
     4      0.4508738611912254d+03,-.4570041693793770d+03,
     5      0.4423070727973455d+03,-.4112229875556918d+03,
     6      0.3683185210683109d+03,-.3195530860996149d+03,
     7      0.2672482623703348d+03,-.2191987523992242d+03,
     8      0.1723415282928539d+03,-.1349069595746730d+03/
         data arr1491/
     1      0.9307365805636221d+02,-.7024671233427777d+02,
     2      0.4179798532389194d+02,-.3043611769462133d+02,
     3      -.1773170143383996d-05,0.1463141461160184d-05,
     4      0.7541420159469422d-05,-.6876260328023826d-05,
     5      -.3108734578350786d-04,0.2723776239849872d-04,
     6      0.1315018679187284d-03,0.9998834951931212d+00,
     7      -.6708591412456990d+01,0.2425963667751411d+02,
     8      -.6263508135706191d+02,0.1291874914807626d+03/
         data arr1492/
     1      -.2259904388680441d+03,0.3478898585759051d+03,
     2      -.4830748692716261d+03,0.6159722878760187d+03,
     3      -.7306264873459395d+03,0.8143869845365365d+03,
     4      -.8591014135580244d+03,0.8645016418651302d+03,
     5      -.8321793555644995d+03,0.7717278062578290d+03,
     6      -.6843978846803042d+03,0.5936640457989252d+03,
     7      -.4892392632399728d+03,0.4008588073662598d+03,
     8      -.2846637628770745d+03,0.2228982332608770d+03/
         data arr1493/
     1      -.1354538725454727d+03,0.1013148671341845d+03,
     2      0.5935554410274342d-05,-.5128315417487436d-05,
     3      -.2524155634657005d-04,0.2410464298117506d-04,
     4      0.1039814352694933d-03,-.9539612364663182d-04,
     5      -.4406904211162706d-03,0.4091116583933377d-03,
     6      0.1001288811706871d+01,-.7233766204322446d+01,
     7      0.2800462374802746d+02,-.7702653886198624d+02,
     8      0.1684456016822683d+03,-.3111618254924982d+03/
         data arr1494/
     1      0.5039925479612929d+03,-.7345388382775493d+03,
     2      0.9802266056280403d+03,-.1214300912447776d+04,
     3      0.1408546015369328d+04,-.1547592398899113d+04,
     4      0.1614083123646096d+04,-.1614740816587351d+04,
     5      0.1530307156026173d+04,-.1420833192782771d+04,
     6      0.1240083328988524d+04,-.1081038589060798d+04,
     7      0.7954932792507911d+03,-.6603606126383447d+03,
     8      0.4148435457003241d+03,-.3271944515489489d+03/
         data arr1495/
     1      -.1032618533902591d-04,0.8562552487540592d-05,
     2      0.4391752164066020d-04,-.4024009251490922d-04,
     3      -.1810378775315125d-03,0.1594203196949898d-03,
     4      0.7657732037848824d-03,-.6815850286429791d-03,
     5      -.2256685833849782d-02,0.1001732799614472d+01,
     6      -.7732762958068647d+01,0.3194018594267827d+02,
     7      -.9316176931537796d+02,0.2150674023607568d+03,
     8      -.4175865694971416d+03,0.7089061095003253d+03/
         data arr1496/
     1      -.1077377346335529d+04,0.1492614547918097d+04,
     2      -.1905223702898947d+04,0.2272451824749099d+04,
     3      -.2538005064345420d+04,0.2685476585709742d+04,
     4      -.2658644316222424d+04,0.2548893588977338d+04,
     5      -.2272905637399947d+04,0.1999180101935936d+04,
     6      -.1482285541947957d+04,0.1217613621717422d+04,
     7      -.7591202120427127d+03,0.5823962540710803d+03,
     8      0.3165074000820838d-04,-.2825600666797720d-04/
         data arr1497/
     1      -.1345866122796228d-03,0.1328197678710483d-03,
     2      0.5541813362776301d-03,-.5254323039886049d-03,
     3      -.2351550843433335d-02,0.2255975528948166d-02,
     4      0.6844178900698742d-02,-.5644375250833439d-02,
     5      0.9590065944238794d+00,-.8210098219298786d+01,
     6      0.3609374150506833d+02,-.1110728111068921d+03,
     7      0.2691186913728318d+03,-.5496122987697718d+03,
     8      0.9765691702020084d+03,-.1552001567127424d+04/
         data arr1498/
     1      0.2232618379324871d+04,-.2981774016004889d+04,
     2      0.3685549310882662d+04,-.4303626326923354d+04,
     3      0.4626266320814203d+04,-.4861471020778227d+04,
     4      0.4669912377387258d+04,-.4480120720030957d+04,
     5      0.3469326169819292d+04,-.3106229358889723d+04,
     6      0.2029707573712004d+04,-.1689350278979218d+04,
     7      -.3341011037762182d-04,0.2891717472067852d-04,
     8      0.1420783834398775d-03,-.1359075272141268d-03/
         data arr1499/
     1      -.5853636017610778d-03,0.5381519581599251d-03,
     2      0.2479694845747783d-02,-.2304200920692443d-02,
     3      -.7264753793984914d-02,0.5825494453727635d-02,
     4      0.4297614561633233d-01,0.9595302078788425d+00,
     5      -.8764286640738293d+01,0.4013240330244191d+02,
     6      -.1275779159785872d+03,0.3204088225519638d+03,
     7      -.6666109258241531d+03,0.1199325472884039d+04,
     8      -.1900264590899008d+04,0.2742920072818014d+04/
         data arr1500/
     1      -.3598609745262458d+04,0.4398965126908598d+04,
     2      -.4889104176272950d+04,0.5257543570314220d+04,
     3      -.5125559937367719d+04,0.4941599157184878d+04,
     4      -.3848979747967445d+04,0.3417019108742315d+04,
     5      -.2221554207635711d+04,0.1811876463757079d+04,
     6      0.8682866217921093d-04,-.8199145405271556d-04,
     7      -.3691609172696139d-03,0.3854690130784307d-03,
     8      0.1518699689792649d-02,-.1523310516187142d-02/
         data arr1501/
     1      -.6460916973802657d-02,0.6560400647321064d-02,
     2      0.1861282556287714d-01,-.1622419164002759d-01,
     3      -.1136296720024760d+00,0.1169214242608337d+00,
     4      0.1031138808699744d+01,-.9204770401949204d+01,
     5      0.4239141478925248d+02,-.1477870117053272d+03,
     6      0.3893865601477567d+03,-.8530661659803656d+03,
     7      0.1575768510971497d+04,-.2651393820655158d+04,
     8      0.3948018881085712d+04,-.5469858204235280d+04/
         data arr1502/
     1      0.6662264889581546d+04,-.8024250928783136d+04,
     2      0.8495640585668447d+04,-.9080215898752480d+04,
     3      0.7358942503868734d+04,-.7229247734437757d+04,
     4      0.4941399136558515d+04,-.4429229377096598d+04,
     5      0.9999999998549654d+00,-.2165063509972262d+01,
     6      0.3380204321322571d+01,-.4391014215304590d+01,
     7      0.5030538755167765d+01,-.5246010227505860d+01,
     8      0.5079427561311630d+01,-.4628574200243629d+01/
         data arr1503/
     1      0.4008462839705755d+01,-.3323641976006605d+01,
     2      0.2653715335666391d+01,-.2049710740634052d+01,
     3      0.1537281802461704d+01,-.1123000598143578d+01,
     4      0.8010895231420010d+00,-.5591672365858763d+00,
     5      0.3824295288145071d+00,-.2563644679936632d+00,
     6      0.1680813710225277d+00,-.1071877294685179d+00,
     7      0.6553426788306431d-01,-.3764063926914644d-01,
     8      0.1859726009933034d-01,-.6542944192798946d-02/
         data arr1504/
     1      -.1484986915165845d-02,0.3990683358875559d-02,
     2      -.6598367386587133d-02,0.5524713249625453d-02,
     3      -.5615577585553032d-02,0.1723884190705038d-09,
     4      0.1000000000234708d+01,-.3122498999881849d+01,
     5      0.6084367776289026d+01,-.9294025295822121d+01,
     6      0.1211514165051862d+02,-.1407652256071592d+02,
     7      0.1496492802997607d+02,-.1481143751143066d+02,
     8      0.1381611971700753d+02,-.1225698562627912d+02/
         data arr1505/
     1      0.1041393039726518d+02,-.8520488414092753d+01,
     2      0.6743051086552536d+01,-.5180464851979670d+01,
     3      0.3875368999133297d+01,-.2829981028020024d+01,
     4      0.2021527461108334d+01,-.1414725940051285d+01,
     5      0.9708369786762601d+00,-.6531472244995042d+00,
     6      0.4302168364008154d+00,-.2760911181391317d+00,
     7      0.1713594743214269d+00,-.1010610318796270d+00,
     8      0.5620869330405214d-01,-.2751214130563625d-01/
         data arr1506/
     1      0.1099904400493794d-01,-.1540865048839194d-02,
     2      0.3755764486449989d-08,0.1570872620501313d-07,
     3      0.9999999851037789d+00,-.3897114388353986d+01,
     4      0.8929410734585388d+01,-.1551980182642278d+02,
     5      0.2254047543941755d+02,-.2875567659752064d+02,
     6      0.3320419484811165d+02,-.3539759127534111d+02,
     7      0.3532838844603624d+02,-.3335127672435407d+02,
     8      0.3001616100275154d+02,-.2591411992010597d+02/
         data arr1507/
     1      0.2156865471091224d+02,-.1737813634605474d+02,
     2      0.1360212177569922d+02,-.1037454966072579d+02,
     3      0.7735946723489001d+01,-.5656084318847580d+01,
     4      0.4071747558838933d+01,-.2887386070831133d+01,
     5      0.2042139506164966d+01,-.1427963153704709d+01,
     6      0.1012986244736620d+01,-.6597588342273147d+00,
     7      0.4750749650640841d+00,-.2852068347093845d+00,
     8      0.2064799147817475d+00,-.1774534666630202d-07/
         data arr1508/
     1      -.7502706019587901d-07,0.7038167678725999d-07,
     2      0.1000000340656596d+01,-.4582575977198210d+01,
     3      0.1194714784419824d+02,-.2313555389265829d+02,
     4      0.3689355378461173d+02,-.5112120463784828d+02,
     5      0.6358116993508681d+02,-.7252213978624976d+02,
     6      0.7702149341302680d+02,-.7702147707433338d+02,
     7      0.7314471820514137d+02,-.6641221296172580d+02,
     8      0.5796308254791215d+02,-.4884512700482315d+02/
         data arr1509/
     1      0.3988680981779801d+02,-.3167376145269004d+02,
     2      0.2452213102415826d+02,-.1857247637118645d+02,
     3      0.1374665820587096d+02,-.1005112779198919d+02,
     4      0.7185489029809745d+01,-.5143718204577287d+01,
     5      0.3357788667862160d+01,-.2386090221865355d+01,
     6      0.1414027413784206d+01,-.1001775044621097d+01,
     7      0.6204667285821486d-07,0.2821745722189757d-06,
     8      -.2461367191440295d-06,-.1281569059151513d-05/
         data arr1510/
     1      0.1000000987620272d+01,-.5214158151076148d+01,
     2      0.1514577206838847d+02,-.3220334779364346d+02,
     3      0.5577781579809799d+02,-.8324724132524008d+02,
     4      0.1107793646399033d+03,-.1344598207675150d+03,
     5      0.1512671225016370d+03,-.1596134396645329d+03,
     6      0.1594106494600885d+03,-.1517657493776707d+03,
     7      0.1385168268371615d+03,-.1217387623261307d+03,
     8      0.1034439589549355d+03,-.8520088689346677d+02/
         data arr1511/
     1      0.6822482180367088d+02,-.5301128695615477d+02,
     2      0.4033774188641308d+02,-.2970930137783704d+02,
     3      0.2160550459853980d+02,-.1425224847109986d+02,
     4      0.9983982572329833d+01,-.5820216014078734d+01,
     5      0.3932380527508160d+01,-.3103954780117101d-06,
     6      -.1362456127704818d-05,0.1231259551279895d-05,
     7      0.6187275022557024d-05,-.4939734661716641d-05,
     8      0.9999746338996448d+00,-.5809455248355792d+01/
         data arr1512/
     1      0.1852846501988777d+02,-.4278951841298086d+02,
     2      0.7982768843065826d+02,-.1274749032320619d+03,
     3      0.1805124293755538d+03,-.2320869059065481d+03,
     4      0.2755010594429323d+03,-.3057303897999583d+03,
     5      0.3201948587588543d+03,-.3188557565887940d+03,
     6      0.3036390732306460d+03,-.2780338926144764d+03,
     7      0.2455823414137872d+03,-.2101337478483029d+03,
     8      0.1736338578308172d+03,-.1404446423643211d+03/
         data arr1513/
     1      0.1094060869493408d+03,-.8426361054465487d+02,
     2      0.5789548233717980d+02,-.4283592799114608d+02,
     3      0.2590880663999182d+02,-.1836420430292836d+02,
     4      0.1100416930556140d-05,0.4779110636994334d-05,
     5      -.4365036750968997d-05,-.2170263339515575d-04,
     6      0.1751213841531453d-04,0.8898029103829698d-04,
     7      0.9999299090235853d+00,-.6378981519815162d+01,
     8      0.2209660290831625d+02,-.5496271190146460d+02/
         data arr1514/
     1      0.1097121179052627d+03,-.1864341180874159d+03,
     2      0.2796477556092302d+03,-.3793575740972686d+03,
     3      0.4735716013893903d+03,-.5509698548534361d+03,
     4      0.6032466753623935d+03,-.6259901156920333d+03,
     5      0.6200480001070138d+03,-.5882482336025914d+03,
     6      0.5373249237304323d+03,-.4703516993066118d+03,
     7      0.4014729063139352d+03,-.3273910353988962d+03,
     8      0.2630882288907514d+03,-.1859315123079658d+03/
         data arr1515/
     1      0.1421539721397354d+03,-.8772303719294304d+02,
     2      0.6355849773117916d+02,-.4212213909228869d-05,
     3      -.1734269619827296d-04,0.1670659266478612d-04,
     4      0.7873914340293047d-04,-.6699989657941160d-04,
     5      -.3230217823087435d-03,0.2684170398125074d-03,
     6      0.1001108198564149d+01,-.6929054290018744d+01,
     7      0.2584565320530593d+02,-.6879586557791242d+02,
     8      0.1461451917669490d+03,-.2630509839574931d+03/
         data arr1516/
     1      0.4162641956249826d+03,-.5939500709037972d+03,
     2      0.7775449506823488d+03,-.9461972540863964d+03,
     3      0.1080032196522636d+04,-.1168258815182160d+04,
     4      0.1201827046800880d+04,-.1184741559217961d+04,
     5      0.1109974807538386d+04,-.1014998348944799d+04,
     6      0.8793561594126274d+03,-.7530719289856163d+03,
     7      0.5533914755483613d+03,-.4499097895025375d+03,
     8      0.2886925931841113d+03,-.2215637867861682d+03/
         data arr1517/
     1      0.6950325697898205d-05,0.3017535432971213d-04,
     2      -.2757077589848321d-04,-.1370335706928589d-03,
     3      0.1106237623127896d-03,0.5617890463040360d-03,
     4      -.4426310834601988d-03,-.1933307198848973d-02,
     5      0.1001410691295383d+01,-.7453956965506243d+01,
     6      0.2978451685383965d+02,-.8438718303903346d+02,
     7      0.1898079773399610d+03,-.3600717762453883d+03,
     8      0.5983011407133913d+03,-.8917595861423377d+03/
         data arr1518/
     1      0.1212918996312646d+04,-.1522558322925035d+04,
     2      0.1785853647010557d+04,-.1964922779692887d+04,
     3      0.2045058954079063d+04,-.1998193942675926d+04,
     4      0.1881988702805986d+04,-.1661260011068375d+04,
     5      0.1430405206254538d+04,-.1056543583259932d+04,
     6      0.8457217369610133d+03,-.5356803100016504d+03,
     7      0.3969374840705014d+03,-.2385453990995627d-04,
     8      -.9600905097309850d-04,0.9461029007175390d-04/
         data arr1519/
     1      0.4358684699287354d-03,-.3794069741408307d-03,
     2      -.1788430414685465d-02,0.1520095670814724d-02,
     3      0.6130429832885615d-02,-.4818115748403529d-02,
     4      0.9729590291899094d+00,-.7961041244995396d+01,
     5      0.3396548272840539d+02,-.1017842260407790d+03,
     6      0.2411021806732792d+03,-.4817454332873937d+03,
     7      0.8397840075625726d+03,-.1309649478940358d+04,
     8      0.1853831767616446d+04,-.2432447551087089d+04/
         data arr1520/
     1      0.2963319031399365d+04,-.3397886652805105d+04,
     2      0.3608524612816089d+04,-.3716262079245761d+04,
     3      0.3540726570332701d+04,-.3315272284150179d+04,
     4      0.2565327270907369d+04,-.2232227759556013d+04,
     5      0.1488734640973927d+04,-.1194675126487644d+04,
     6      0.2536650083896793d-04,0.1057379147904238d-03,
     7      -.1006185583334620d-03,-.4801187145069173d-03,
     8      0.4036611248073891d-03,0.1968965270048837d-02/
         data arr1521/
     1      -.1615583679406990d-02,-.6765185659337888d-02,
     2      0.5142702745869162d-02,0.2967337994170311d-01,
     3      0.9753347041233490d+00,-.8548644465172991d+01,
     4      0.3801897341491388d+02,-.1182217184729095d+03,
     5      0.2901835484049771d+03,-.5923367524975565d+03,
     6      0.1045396066987448d+04,-.1630594078358167d+04,
     7      0.2312935989344432d+04,-.2993580947369339d+04,
     8      0.3596859806774510d+04,-.3954482535796511d+04/
         data arr1522/
     1      0.4174531948618519d+04,-.4041987421549749d+04,
     2      0.3810779785284510d+04,-.2968049680702477d+04,
     3      0.2565174896833826d+04,-.1701233888185001d+04,
     4      0.1337861791016231d+04,-.7375378289040538d-04,
     5      -.2795896104311900d-03,0.2924776132495324d-03,
     6      0.1268970507785491d-02,-.1172413069581508d-02,
     7      -.5210593645842471d-02,0.4702041226886585d-02,
     8      0.1780046664885206d-01,-.1484060581079390d-01/
         data arr1523/
     1      -.7914638385207159d-01,0.7246337956750457d-01,
     2      0.1132168962625692d+01,-.9082396308645921d+01,
     3      0.4115582971976897d+02,-.1383541294051616d+03,
     4      0.3574782260655033d+03,-.7638415954479685d+03,
     5      0.1389716384537239d+04,-.2285092240147138d+04,
     6      0.3355824335936908d+04,-.4543691876902495d+04,
     7      0.5478779592802380d+04,-.6441144941797589d+04,
     8      0.6789609792821868d+04,-.7060930618104800d+04/
         data arr1524/
     1      0.5741480774183835d+04,-.5473988086509558d+04,
     2      0.3840335988559171d+04,-.3319457933953923d+04,
     3      0.1000000001300240d+01,-.2250000001156605d+01,
     4      0.3645416638062042d+01,-.4907792347937801d+01,
     5      0.5819925813359125d+01,-.6275002880993742d+01,
     6      0.6275002793211368d+01,-.5899599209794438d+01,
     7      0.5266446018216022d+01,-.4497084489572706d+01,
     8      0.3694731054849975d+01,-.2934188231883789d+01/
         data arr1525/
     1      0.2260946709279157d+01,-.1695697553688698d+01,
     2      0.1241054419660595d+01,-.8882455988131456d+00,
     3      0.6226675981134098d+00,-.4276695828498785d+00,
     4      0.2874625119201026d+00,-.1881818173947627d+00,
     5      0.1192732903813291d+00,-.7099258182030826d-01,
     6      0.3839634635335459d-01,-.1584420775336907d-01,
     7      0.4816859302580268d-02,0.4444845052208266d-02,
     8      -.6599831680637225d-02,0.8999945641230892d-02/
         data arr1526/
     1      0.1261029286395400d-07,0.9999999915129383d+00,
     2      -.3240370395744135d+01,0.6543723175466578d+01,
     3      -.1034653456409467d+02,0.1394445064856388d+02,
     4      -.1673334161615362d+02,0.1835430940821289d+02,
     5      -.1872513791405583d+02,0.1798833465072381d+02,
     6      -.1642103618098590d+02,0.1434494318848016d+02,
     7      -.1205847523087984d+02,0.9798077987177078d+01,
     8      -.7724906111222474d+01,0.5929441639889067d+01/
         data arr1527/
     1      -.4445202358288695d+01,0.3267357167474446d+01,
     2      -.2364508656185707d+01,0.1694486574638875d+01,
     3      -.1205346278948195d+01,0.8650407883344516d+00,
     4      -.6221670688101034d+00,0.4589324755868435d+00,
     5      -.3102092002206571d+00,0.2353727878377387d+00,
     6      -.1513183061612138d+00,0.1142452804057453d+00,
     7      -.5427227439401006d-07,0.3584629705739991d-07,
     8      0.1000000200308546d+01,-.4038873765779621d+01/
         data arr1528/
     1      0.9579029047920823d+01,-.1721340313313963d+02,
     2      0.2582010848416065d+02,-.3398557839464186d+02,
     3      0.4045091566809108d+02,-.4441056099529631d+02,
     4      0.4560878593779770d+02,-.4426941383480035d+02,
     5      0.4093409159200699d+02,-.3628263281478975d+02,
     6      0.3098300840516665d+02,-.2559483701592154d+02,
     7      0.2052447538492587d+02,-.1603000649875569d+02,
     8      0.1222729645231058d+02,-.9138010767062961d+01/
         data arr1529/
     1      0.6689660493822812d+01,-.4847972743372858d+01,
     2      0.3455129770216587d+01,-.2468282222993812d+01,
     3      0.1617670646403001d+01,-.1155989650031372d+01,
     4      0.7099006713902448d+00,-.5082555731561331d+00,
     5      0.1523407064207797d-06,-.8399761674526633d-07,
     6      -.5626120986928295d-06,0.1000000376083735d+01,
     7      -.4743414291583658d+01,0.1278579383665495d+02,
     8      -.2557159862949936d+02,0.4207309232196514d+02/
         data arr1530/
     1      -.6009235737965009d+02,0.7697044662932253d+02,
     2      -.9033964012740362d+02,0.9864732820741105d+02,
     3      -.1013487013844879d+03,0.9880936357714647d+02,
     4      -.9202809017550812d+02,0.8231096846731855d+02,
     5      -.7098408085693147d+02,0.5922043060123415d+02,
     6      -.4789597800352329d+02,0.3761408155002357d+02,
     7      -.2864118851412070d+02,0.2124780821773353d+02,
     8      -.1524275319083225d+02,0.1067007156101500d+02/
         data arr1531/
     1      -.6857267102826691d+01,0.4536203589325507d+01,
     2      -.2585749394387035d+01,0.1610634857526967d+01,
     3      -.1033369913991819d-05,0.6289180904240305d-06,
     4      0.3815190814569800d-05,-.2815394443153238d-05,
     5      0.9999850897338429d+00,-.5390953399504795d+01,
     6      0.1617294781247919d+02,-.3547918167258480d+02,
     7      0.6334273078678413d+02,-.9736063859141930d+02,
     8      0.1333172978530532d+03,-.1663740064812656d+03/
         data arr1532/
     1      0.1922962268582762d+03,-.2083206457266496d+03,
     2      0.2134637226287067d+03,-.2083683949182983d+03,
     3      0.1948270315415192d+03,-.1753739109024918d+03,
     4      0.1524758931813334d+03,-.1284605903415738d+03,
     5      0.1046717413892617d+03,-.8335374314411140d+02,
     6      0.6416102806232047d+02,-.4853166461819498d+02,
     7      0.3310298907950596d+02,-.2394684528932158d+02,
     8      0.1465645102259532d+02,-.1008646078589118d+02/
         data arr1533/
     1      0.3895741050118858d-05,-.2394850517061674d-05,
     2      -.1438266355522046d-04,0.1072076943110362d-04,
     3      0.5620902217446309d-04,0.9999571098937543d+00,
     4      -.6000202885404529d+01,0.1974382019113887d+02,
     5      -.4699855130656549d+02,0.9029937647486269d+02,
     6      -.1483800257787995d+03,0.2160311604398458d+03,
     7      -.2853432104523018d+03,0.3477263719806559d+03,
     8      -.3957978838735783d+03,0.4247274294464123d+03/
         data arr1534/
     1      -.4326767311443062d+03,0.4211487973095538d+03,
     2      -.3931392073120350d+03,0.3533409824426086d+03,
     3      -.3048763130673416d+03,0.2559681248370688d+03,
     4      -.2062421794663686d+03,0.1626289809064957d+03,
     5      -.1141610753835919d+03,0.8530061354433669d+02,
     6      -.5333108370571042d+02,0.3750952462044947d+02,
     7      -.1569999611376771d-04,0.1026863912685534d-04,
     8      0.5794964589494950d-04,-.4596175221402502d-04/
         data arr1535/
     1      -.2264865813631567d-03,0.1839276757812147d-03,
     2      0.1000816559989847d+01,-.6581866895669078d+01,
     3      0.2349650391855821d+02,-.6019740664008376d+02,
     4      0.1236564201400080d+03,-.2160367231683583d+03,
     5      0.3328800577807636d+03,-.4636663479527431d+03,
     6      0.5939063614291843d+03,-.7084158987358959d+03,
     7      0.7940944145533649d+03,-.8443748917943441d+03,
     8      0.8554851453924576d+03,-.8304803134732519d+03/
         data arr1536/
     1      0.7683694520732245d+03,-.6923117405773147d+03,
     2      0.5949605752083633d+03,-.5014930157583166d+03,
     3      0.3675818575897847d+03,-.2934935383034212d+03,
     4      0.1922864382921478d+03,-.1442456157396504d+03,
     5      0.2520472506665008d-04,-.1522819555851917d-04,
     6      -.9306044060519707d-04,0.6817667518246460d-04,
     7      0.3636776721345373d-03,-.2727057785340715d-03,
     8      -.1313252137538880d-02,0.1000956611894229d+01/
         data arr1537/
     1      -.7136360601597636d+01,0.2743789148885464d+02,
     2      -.7516532828892424d+02,0.1640963109312079d+03,
     3      -.3030915303848532d+03,0.4914180102251461d+03,
     4      -.7161176290723522d+03,0.9534743618779919d+03,
     5      -.1173233839013775d+04,0.1348756050739705d+04,
     6      -.1455871330096259d+04,0.1484384640446141d+04,
     7      -.1424040265262426d+04,0.1310623279065924d+04,
     8      -.1136767651058116d+04,0.9519129496239915d+03/
         data arr1538/
     1      -.6955283199516374d+03,0.5378296628530292d+03,
     2      -.3425839038632301d+03,0.2428444047158189d+03,
     3      -.9487510294196305d-04,0.6329977957156114d-04,
     4      0.3501679124947222d-03,-.2833241764499799d-03,
     5      -.1368569666363983d-02,0.1133780092725811d-02,
     6      0.4932942276150687d-02,-.3967392470079278d-02,
     7      0.9808775212145143d+00,-.7669325860956590d+01,
     8      0.3161900418453047d+02,-.9196457789661654d+02/
         data arr1539/
     1      0.2121988859118882d+03,-.4137688131980599d+03,
     2      0.7058171721296149d+03,-.1078528396716666d+04,
     3      0.1499608375789562d+04,-.1932787408965875d+04,
     4      0.2319439547266440d+04,-.2615917300526048d+04,
     5      0.2744780966263479d+04,-.2780521987668779d+04,
     6      0.2630702468535264d+04,-.2419035109268312d+04,
     7      0.1869522045737592d+04,-.1593842213220914d+04,
     8      0.1086930229141661d+04,-.8501895682766153d+03/
         data arr1540/
     1      0.1082552979836384d-03,-.6965234690156672d-04,
     2      -.3996132761805949d-03,0.3118008787880407d-03,
     3      0.1561720628419634d-02,-.1247379211960050d-02,
     4      -.5634051006432875d-02,0.4371702426231787d-02,
     5      0.2179133758397719d-01,0.9825610080934649d+00,
     6      -.8271865073516627d+01,0.3569354303988379d+02,
     7      -.1081637014282475d+03,0.2589511271213854d+03,
     8      -.5172611377043389d+03,0.8942968356010556d+03/
         data arr1541/
     1      -.1370401815552936d+04,0.1909161695520752d+04,
     2      -.2434508571950090d+04,0.2877110888021599d+04,
     3      -.3125870239346032d+04,0.3246294199212306d+04,
     4      -.3121056748810248d+04,0.2890268477401132d+04,
     5      -.2247731358650089d+04,0.1903483117260412d+04,
     6      -.1288967527870125d+04,0.9875163912270006d+03,
     7      -.3073443514590013d-03,0.2178712778748786d-03,
     8      0.1134077879971417d-02,-.9750329848706823d-03/
         data arr1542/
     1      -.4432615974886375d-02,0.3902765620529806d-02,
     2      0.1595764108618545d-01,-.1363750598064411d-01,
     3      -.6204670258048614d-01,0.5479653875684502d-01,
     4      0.1156501742680036d+01,-.8855599593789576d+01,
     5      0.3925748705174743d+02,-.1280435684619498d+03,
     6      0.3242009466308111d+03,-.6779615455824353d+03,
     7      0.1214669569416500d+04,-.1961168060830419d+04,
     8      0.2846826703081253d+04,-.3791639170394594d+04/
         data arr1543/
     1      0.4535056398537819d+04,-.5247370851747332d+04,
     2      0.5524779293452212d+04,-.5645494475157552d+04,
     3      0.4605186154048598d+04,-.4306478820026106d+04,
     4      0.3109358550892516d+04,-.2622256246799636d+04,
     5      0.9999999908204002d+00,-.2331844793838916d+01,
     6      0.3910622585096015d+01,-.5443356086995547d+01,
     7      0.6666722492829133d+01,-.7416261239304000d+01,
     8      0.7644507017399702d+01,-.7401759759112508d+01/
         data arr1544/
     1      0.6798950624415277d+01,-.5969289619434429d+01,
     2      0.5038678642014756d+01,-.4108340197387370d+01,
     3      0.3248581884450247d+01,-.2500152558418716d+01,
     4      0.1879775854755504d+01,-.1386996819171858d+01,
     5      0.1011536177022947d+01,-.7361715956875357d+00,
     6      0.5414307280934086d+00,-.4048270886680189d+00,
     7      0.3161004030996336d+00,-.2536742108552305d+00,
     8      0.2113753974532033d+00,-.1563880632024020d+00/
         data arr1545/
     1      0.1327391128663603d+00,-.9507396978383186d-01,
     2      0.7666597691803279d-01,0.3001750645926076d-07,
     3      0.1000000100182566d+01,-.3354102072038612d+01,
     4      0.7003068083326352d+01,-.1143596261096675d+02,
     5      0.1590213385400098d+02,-.1966985261401719d+02,
     6      0.2221945384064933d+02,-.2332556885577591d+02,
     7      0.2303909744350033d+02,-.2160803746541767d+02,
     8      0.1937951473823188d+02,-.1671379904279244d+02/
         data arr1546/
     1      0.1392462111879814d+02,-.1124881940104737d+02,
     2      0.8840018719649122d+01,-.6781227494843841d+01,
     3      0.5094499648472062d+01,-.3762642582850829d+01,
     4      0.2734554009895590d+01,-.1982456467108909d+01,
     5      0.1429855669983949d+01,-.1043852019036742d+01,
     6      0.6993459748902984d+00,-.5223083776665213d+00,
     7      0.3443727031049337d+00,-.2597146149498094d+00,
     8      -.1828782291872026d-07,-.1185990068805437d-06/
         data arr1547/
     1      0.1000000064585484d+01,-.4175822750427231d+01,
     2      0.1022863602814295d+02,-.1896440121178780d+02,
     3      0.2932208378348280d+02,-.3974737118412907d+02,
     4      0.4868039486209854d+02,-.5495143198838590d+02,
     5      0.5798024530748602d+02,-.5777708871406785d+02,
     6      0.5480635115469141d+02,-.4979120639613546d+02,
     7      0.4352672413742848d+02,-.3674090200310046d+02,
     8      0.3001946105220901d+02,-.2377150250110180d+02/
         data arr1548/
     1      0.1824639710439252d+02,-.1355144851916902d+02,
     2      0.9737105627621650d+01,-.6727647019422070d+01,
     3      0.4461312830321742d+01,-.2740482369350011d+01,
     4      0.1645566906528939d+01,-.8657444589686989d+00,
     5      0.4451662344834492d+00,0.3648851424939018d-06,
     6      0.1519282065289779d-05,-.1286853583968196d-05,
     7      0.9999933181585839d+00,-.4898974612841152d+01,
     8      0.1362445214670001d+02,-.2808749239389124d+02/
         data arr1549/
     1      0.4759217144974943d+02,-.6994599694813981d+02,
     2      0.9211622328176834d+02,-.1110784628015181d+03,
     3      0.1245270337869576d+03,-.1312618343937308d+03,
     4      0.1312161906812175d+03,-.1252282896266758d+03,
     5      0.1146916123061351d+03,-.1012521082701762d+03,
     6      0.8642344428821568d+02,-.7147751695970386d+02,
     7      0.5721352468040719d+02,-.4461992048415040d+02,
     8      0.3366983671516334d+02,-.2474753777897059d+02/
         data arr1550/
     1      0.1659888877691214d+02,-.1151677242489038d+02,
     2      0.6984583114320039d+01,-.4504154644505389d+01,
     3      -.1772061105762122d-05,-.7010095351528415d-05,
     4      0.6248707110160266d-05,0.3082982709730709d-04,
     5      0.9999763392721260d+00,-.5562266730857726d+01,
     6      0.1720008004243487d+02,-.3885848524675360d+02,
     7      0.7138808932180200d+02,-.1128198469723445d+03,
     8      0.1587161529673824d+03,-.2033392789303101d+03/
         data arr1551/
     1      0.2411003883783480d+03,-.2677212741430363d+03,
     2      0.2808753658136028d+03,-.2802784598527188d+03,
     3      0.2675846157239038d+03,-.2453347865776109d+03,
     4      0.2166397375874509d+03,-.1839375711570716d+03,
     5      0.1516917838671295d+03,-.1204484632654968d+03,
     6      0.9298907500570436d+02,-.6463300885992808d+02,
     7      0.4700996063885792d+02,-.2960149291536873d+02,
     8      0.2001637690418920d+02,0.8939879131621215d-05/
         data arr1552/
     1      0.3244577424444395d-04,-.3151603595185137d-04,
     2      -.1426864449547437d-03,0.1193299255586586d-03,
     3      0.1000545173962756d+01,-.6185084630450999d+01,
     4      0.2095691840484309d+02,-.5133715367126945d+02,
     5      0.1014224245566172d+03,-.1712147934407135d+03,
     6      0.2558953192336875d+03,-.3468078302649174d+03,
     7      0.4333838601926435d+03,-.5054289302819753d+03,
     8      0.5550772747862168d+03,-.5790292110105240d+03/
         data arr1553/
     1      0.5765480300653955d+03,-.5502264079302556d+03,
     2      0.5016657620008519d+03,-.4447136092632963d+03,
     3      0.3781409964851650d+03,-.3132251330555852d+03,
     4      0.2283707793408925d+03,-.1788264062892927d+03,
     5      0.1193820236054074d+03,-.8727079881716336d+02,
     6      -.1146030669684838d-04,-.4756964700726489d-04,
     7      0.4042074586183272d-04,0.2092108311896708d-03,
     8      -.1530543275370335d-03,-.8001318032933616d-03/
         data arr1554/
     1      0.1000547573959367d+01,-.6774754021500677d+01,
     2      0.2490093308691716d+02,-.6560122006486202d+02,
     3      0.1383843252895774d+03,-.2479143247930415d+03,
     4      0.3909850458050966d+03,-.5555541274761362d+03,
     5      0.7225656624416502d+03,-.8699663201015736d+03,
     6      0.9790994324820794d+03,-.1035606887312045d+04,
     7      0.1033960110767219d+04,-.9729832680962292d+03,
     8      0.8750112603825555d+03,-.7441026768230295d+03/
         data arr1555/
     1      0.6053515015436910d+03,-.4361903776344608d+03,
     2      0.3246614514504024d+03,-.2062623476778001d+03,
     3      0.1381114892176762d+03,0.5663579397879974d-04,
     4      0.2049903844117103d-03,-.1996731218871077d-03,
     5      -.9014698359858815d-03,0.7560061408413140d-03,
     6      0.3444516496314742d-02,-.2700816767058744d-02,
     7      0.9872024311735068d+00,-.7338556043353917d+01,
     8      0.2907151906710068d+02,-.8171617318341244d+02/
         data arr1556/
     1      0.1829568017487751d+03,-.3470010017170896d+03,
     2      0.5772950657181843d+03,-.8618564394395268d+03,
     3      0.1173378408058793d+04,-.1480865612263630d+04,
     4      0.1743333469065934d+04,-.1926284209982176d+04,
     5      0.1987277299957650d+04,-.1969826375023386d+04,
     6      0.1837112761013503d+04,-.1646943580332306d+04,
     7      0.1263629109159194d+04,-.1045529378383869d+04,
     8      0.7225009503324269d+03,-.5432354121006576d+03/
         data arr1557/
     1      -.6100507546562226d-04,-.2335960235044861d-03,
     2      0.2151316411044609d-03,0.1027287860310930d-02,
     3      -.8145376999785076d-03,-.3927173053654925d-02,
     4      0.2912686536821100d-02,0.1457459081237565d-01,
     5      0.9893322679626321d+00,-.7945980504524987d+01,
     6      0.3315528847752303d+02,-.9750827598114027d+02,
     7      0.2268106224162175d+03,-.4414334055719581d+03,
     8      0.7448591298940109d+03,-.1116733173106308d+04/
         data arr1558/
     1      0.1521520295896609d+04,-.1901232403085787d+04,
     2      0.2198507785251646d+04,-.2346445655801523d+04,
     3      0.2380428061830505d+04,-.2251365285407539d+04,
     4      0.2027126051179293d+04,-.1562883912827642d+04,
     5      0.1278286556146487d+04,-.8717620252599754d+03,
     6      0.6358725708951978d+03,0.2352684258500225d-03,
     7      0.7853835077346756d-03,-.8292549115889154d-03,
     8      -.3453643231525145d-02,0.3139631474421454d-02/
         data arr1559/
     1      0.1318804935898208d-01,-.1120680165968524d-01,
     2      -.4906550432156951d-01,0.4120999448985318d-01,
     3      0.1147411318542600d+01,-.8555284059223746d+01,
     4      0.3699268443484212d+02,-.1169245459061574d+03,
     5      0.2888036355221604d+03,-.5895805303414405d+03,
     6      0.1036100684315898d+04,-.1638190211685908d+04,
     7      0.2340302949635157d+04,-.3057886947849697d+04,
     8      0.3612772412882712d+04,-.4104430584812663d+04/
         data arr1560/
     1      0.4297669897567442d+04,-.4305856775895697d+04,
     2      0.3510007774245013d+04,-.3215599840854609d+04,
     3      0.2385373062697783d+04,-.1959344938414857d+04,
     4      0.1000000109894578d+01,-.2410912758859704d+01,
     5      0.4175822904569408d+01,-.5997069299981849d+01,
     6      0.7570930580384694d+01,-.8673590215752650d+01,
     7      0.9199725769772907d+01,-.9158564122401939d+01,
     8      0.8643224245561803d+01,-.7790895998935272d+01/
         data arr1561/
     1      0.6747069655821063d+01,-.5640599452023239d+01,
     2      0.4570363422828522d+01,-.3601740289769070d+01,
     3      0.2770165743793478d+01,-.2089630942977912d+01,
     4      0.1555834079947721d+01,-.1152538906709327d+01,
     5      0.8531188047341039d+00,-.6492726450835394d+00,
     6      0.5080876476461532d+00,-.4131274818847350d+00,
     7      0.3000614841247699d+00,-.2564641044596555d+00,
     8      0.1946207699624001d+00,-.1631697152359683d+00/
         data arr1562/
     1      0.7849500737065848d-07,0.9999999357518597d+00,
     2      -.3464101877466885d+01,0.7462406056403803d+01,
     3      -.1256109972099372d+02,0.1798818476941567d+02,
     4      -.2289522608591406d+02,0.2659158364990126d+02,
     5      -.2868027864696536d+02,0.2908337587632340d+02,
     6      -.2798412791126652d+02,0.2572782572583814d+02,
     7      -.2271982915712782d+02,0.1934551033738716d+02,
     8      -.1592159838871217d+02,0.1267622610262826d+02/
         data arr1563/
     1      -.9754954777018345d+01,0.7236182265193935d+01,
     2      -.5151625751154995d+01,0.3483572876300490d+01,
     3      -.2207395902026013d+01,0.1276242133620260d+01,
     4      -.6717781519818533d+00,0.2666854090890644d+00,
     5      -.5011879464477936d-01,-.6261136709245456d-01,
     6      0.7548501599365741d-06,-.2749814877608951d-06,
     7      0.9999974719291566d+00,-.4308420794312016d+01,
     8      0.1087824144062542d+02,-.2077097236507477d+02/
         data arr1564/
     1      0.3304637495549992d+02,-.4605795107836071d+02,
     2      0.5795510980514855d+02,-.6716568239769317d+02,
     3      0.7270835577477099d+02,-.7428862247443211d+02,
     4      0.7221076170824503d+02,-.6718526761974888d+02,
     5      0.6011462577498085d+02,-.5192114287072517d+02,
     6      0.4339432606290892d+02,-.3513687814296425d+02,
     7      0.2753509866717065d+02,-.2094023240769371d+02,
     8      0.1537571081395546d+02,-.1088332142407149d+02/
         data arr1565/
     1      0.7105620441488895d+01,-.4635251842918736d+01,
     2      0.2695804332417056d+01,-.1545172213324405d+01,
     3      -.6202206502758205d-05,0.2975775165318021d-05,
     4      0.2076036056422351d-04,0.9999871172944817d+00,
     5      -.5049827635830387d+01,0.1446309433568598d+02,
     6      -.3068048569946094d+02,0.5345091046527265d+02,
     7      -.8071022902154415d+02,0.1091259615487245d+03,
     8      -.1350027194386714d+03,0.1551757785102219d+03/
         data arr1566/
     1      -.1675947922140695d+03,0.1715204808064213d+03,
     2      -.1674196532713246d+03,0.1567452062357648d+03,
     3      -.1413130019963326d+03,0.1229778779867292d+03,
     4      -.1032016747025784d+03,0.8426038891397191d+02,
     5      -.6655422845773963d+02,0.5100428052136303d+02,
     6      -.3542138912248119d+02,0.2558503939638388d+02,
     7      -.1647180142806978d+02,0.1097231558723589d+02,
     8      0.2938416773883542d-04,-.1530310996501967d-04/
         data arr1567/
     1      -.9833636672101864d-04,0.6624676398472580d-04,
     2      0.1000355917255503d+01,-.5728470198063371d+01,
     3      0.1822581802020395d+02,-.4233866356886760d+02,
     4      0.7991824048461990d+02,-.1296634277312752d+03,
     5      0.1871332577453911d+03,-.2458340435986165d+03,
     6      0.2987311145232692d+03,-.3396913128195446d+03,
     7      0.3646185331520226d+03,-.3724183414872167d+03,
     8      0.3638144066089504d+03,-.3409760820298375d+03/
         data arr1568/
     1      0.3060239983492652d+03,-.2668806182806679d+03,
     2      0.2243430033296645d+03,-.1827602801508974d+03,
     3      0.1323906543112917d+03,-.1017797461063227d+03,
     4      0.6912836225039953d+02,-.4926245792212355d+02,
     5      -.4174931643132237d-04,0.1834329948343537d-04,
     6      0.1397789794585735d-03,-.7943181663098697d-04,
     7      -.5062394148214199d-03,0.1000300702204992d+01,
     8      -.6362162320662011d+01,0.2217311790827740d+02/
         data arr1569/
     1      -.5580964650557866d+02,0.1131482493631374d+03,
     2      -.1957287604581127d+03,0.2991500604869457d+03,
     3      -.4131781207715160d+03,0.5236265717617997d+03,
     4      -.6155663907256196d+03,0.6772851485183812d+03,
     5      -.7012523026474453d+03,0.6855974134802670d+03,
     6      -.6327586778144220d+03,0.5571160810519677d+03,
     7      -.4650816491845879d+03,0.3693754970060679d+03,
     8      -.2625481284878361d+03,0.1896762491606330d+03/
         data arr1570/
     1      -.1204591019752504d+03,0.7713488185552978d+02,
     2      0.2014389490147975d-03,-.1033632910902128d-03,
     3      -.6741579929969324d-03,0.4474519615914520d-03,
     4      0.2440323717558987d-02,-.1692959047902583d-02,
     5      0.9913264397445782d+00,-.6962560769439411d+01,
     6      0.2633401209850758d+02,-.7115529142332752d+02,
     7      0.1538765858224120d+03,-.2828390575052614d+03,
     8      0.4574722775634453d+03,-.6656731209489954d+03/
         data arr1571/
     1      0.8855252103827416d+03,-.1093081666241394d+04,
     2      0.1261003182072207d+04,-.1365369677284951d+04,
     3      0.1384417660958860d+04,-.1344836357404607d+04,
     4      0.1236086225382246d+04,-.1083294315626904d+04,
     5      0.8242726824079162d+03,-.6639687667006316d+03,
     6      0.4640020243567620d+03,-.3359852637019123d+03,
     7      -.2883020104004609d-03,0.1433756346566946d-03,
     8      0.9649423669148827d-03,-.6206691036002537d-03/
         data arr1572/
     1      -.3493515952116612d-02,0.2349150803965059d-02,
     2      0.1241472234079550d-01,0.9915137255402929d+00,
     3      -.7589703200226158d+01,0.3047239703701886d+02,
     4      -.8671837965287345d+02,0.1960452146606105d+03,
     5      -.3724678462510192d+03,0.6155779158971616d+03,
     6      -.9070599515945044d+03,0.1217561429869076d+04,
     7      -.1503722933846784d+04,0.1720162611041544d+04,
     8      -.1821736782035532d+04,0.1833560753849221d+04/
         data arr1573/
     1      -.1731174175543870d+04,0.1546730794635958d+04,
     2      -.1193106425157250d+04,0.9679195853004161d+03,
     3      -.6771321734532489d+03,0.4859977367662393d+03,
     4      0.8829028109237698d-03,-.4950910914659167d-03,
     5      -.2954058443389811d-02,0.2142903409671873d-02,
     6      0.1068925862686518d-01,-.8104928174603926d-02,
     7      -.3800188545371174d-01,0.2931212340212021d-01,
     8      0.1121595477928523d+01,-.8203468251520734d+01/
         data arr1574/
     1      0.3446697423843021d+02,-.1053032005710360d+03,
     2      0.2527755442637570d+03,-.5029043752465145d+03,
     3      0.8648302731920607d+03,-.1337133736826091d+04,
     4      0.1874859033063463d+04,-.2400655465021633d+04,
     5      0.2795311182815413d+04,-.3113125835108371d+04,
     6      0.3227797464946958d+04,-.3162750618761838d+04,
     7      0.2568617827956376d+04,-.2294765408249031d+04,
     8      0.1736872455020369d+04,-.1378751546240307d+04/
         data arr1575/
     1      0.9999996331203153d+00,-.2487469655521040d+01,
     2      0.4441020915375609d+01,-.6568352277567694d+01,
     3      0.8532541537453962d+01,-.1005068915688110d+02,
     4      0.1095248091727953d+02,-.1119421556509958d+02,
     5      0.1083843032694188d+02,-.1001479434772666d+02,
     6      0.8877580796389320d+01,-.7572711410429393d+01,
     7      0.6219312241397993d+01,-.4902182311176863d+01,
     8      0.3669692417796903d+01,-.2554240273204336d+01/
         data arr1576/
     1      0.1585551460394059d+01,-.7956052024532220d+00,
     2      0.1491304218040334d+00,0.3276250537351158d+00,
     3      -.6302744730032444d+00,0.6434190945975678d+00,
     4      -.7060462554837772d+00,0.6259962825820827d+00,
     5      -.5411795752248302d+00,0.1958407966319759d-06,
     6      0.1000000166920325d+01,-.3570714845742372d+01,
     7      0.7921735616682935d+01,-.1372084755677721d+02,
     8      0.2020261438763138d+02,-.2641835067895818d+02/
         data arr1577/
     1      0.3150185777920624d+02,-.3485889079049171d+02,
     2      0.3624395073506376d+02,-.3573540013665961d+02,
     3      0.3364631543659987d+02,-.3041337836205638d+02,
     4      0.2649606021300218d+02,-.2230340604095894d+02,
     5      0.1815775343725086d+02,-.1428932759564802d+02,
     6      0.1084756829039865d+02,-.7901704570704219d+01,
     7      0.5473380546712180d+01,-.3555989742947984d+01,
     8      0.2148929729365515d+01,-.1152068789137149d+01/
         data arr1578/
     1      0.4926628278616384d+00,-.9641697144883460d-01,
     2      0.3105161728379536d-05,0.1080721886210943d-04,
     3      0.9999899722783846d+00,-.4437105460371347d+01,
     4      0.1152785508880389d+02,-.2263128207941848d+02,
     5      0.3699295647782925d+02,-.5293429694973176d+02,
     6      0.6833823110181824d+02,-.8120690901348153d+02,
     7      0.9009963608903598d+02,-.9433523865485634d+02,
     8      0.9396641395577588d+02,-.8962700433830158d+02/
         data arr1579/
     1      0.8235223256212699d+02,-.7322417003764770d+02,
     2      0.6315810065082660d+02,-.5280892485783025d+02,
     3      0.4322859122665100d+02,-.3452436815346962d+02,
     4      0.2680761130440402d+02,-.1888056812694256d+02,
     5      0.1394092644922863d+02,-.9444397615584262d+01,
     6      0.6429316870023370d+01,-.1459496573982774d-04,
     7      -.4799273149355420d-04,0.4713005087768132d-04,
     8      0.1000202555589541d+01,-.5196319081375859d+01/
         data arr1580/
     1      0.1530090010251015d+02,-.3334860440912701d+02,
     2      0.5965209429116131d+02,-.9241053485414260d+02,
     3      0.1280988516719813d+03,-.1623983069485214d+03,
     4      0.1911955565460522d+03,-.2113464999599464d+03,
     5      0.2211931904200775d+03,-.2208840103713567d+03,
     6      0.2115874750564968d+03,-.1949036137932418d+03,
     7      0.1724515293471839d+03,-.1485998713655546d+03,
     8      0.1242097339391977d+03,-.1004353319593042d+03/
         data arr1581/
     1      0.7261817182085989d+02,-.5563506566937791d+02,
     2      0.3897587342732555d+02,-.2763388809512717d+02,
     3      0.7202436310216753d-05,0.3991862520323048d-04,
     4      -.2332168802516776d-04,-.1685775511277486d-03,
     5      0.1000082501939414d+01,-.5888981284599970d+01,
     6      0.1925387283104146d+02,-.4592037447680392d+02,
     7      0.8889014976400743d+02,-.1476603768260168d+03,
     8      0.2176412844818252d+03,-.2908142125773790d+03/
         data arr1582/
     1      0.3573999841177029d+03,-.4080962166173401d+03,
     2      0.4362621397467913d+03,-.4387485898071025d+03,
     3      0.4162034046862061d+03,-.3726052912372052d+03,
     4      0.3164359204375809d+03,-.2540164533467222d+03,
     5      0.1920558887375949d+03,-.1317164193849492d+03,
     6      0.8833324959821058d+02,-.5277439170117048d+02,
     7      0.2936816327749724d+02,-.9553384047079881d-04,
     8      -.3322202244525222d-03,0.3086067803310791d-03/
         data arr1583/
     1      0.1402234129877689d-02,-.1091296283811422d-02,
     2      0.9947779617274701d+00,-.6534562543012927d+01,
     3      0.2340709146737148d+02,-.6040344888094352d+02,
     4      0.1254887510898949d+03,-.2225498176972324d+03,
     5      0.3486082681588531d+03,-.4928096309996206d+03,
     6      0.6386112337459663d+03,-.7690477344341151d+03,
     7      0.8671095218613014d+03,-.9182288094565740d+03,
     8      0.9127851239887760d+03,-.8677790058224385d+03/
         data arr1584/
     1      0.7839701465418274d+03,-.6713993415782813d+03,
     2      0.5050501420386390d+03,-.3963499572235957d+03,
     3      0.2793466985658738d+03,-.1951602261457622d+03,
     4      0.1501445073083830d-03,0.5362368048908755d-03,
     5      -.4850775128388279d-03,-.2263530088605093d-02,
     6      0.1715649741923707d-02,0.8429612657956222d-02,
     7      0.9940483156095450d+00,-.7183032643121647d+01,
     8      0.2757429319504879d+02,-.7544790970283359d+02/
         data arr1585/
     1      0.1646826745386162d+03,-.3033671720966692d+03,
     2      0.4878450509683525d+03,-.7016421222961307d+03,
     3      0.9209833005673768d+03,-.1114951289830070d+04,
     4      0.1251353775132864d+04,-.1303822878679825d+04,
     5      0.1289598744385574d+04,-.1202410182481063d+04,
     6      0.1054920154368388d+04,-.8072784310239251d+03,
     7      0.6418189265979954d+03,-.4550075685148272d+03,
     8      0.3169674559974982d+03,-.6495192216505389d-03/
         data arr1586/
     1      -.1991131779089033d-02,0.2097105712422068d-02,
     2      0.8402527297827417d-02,-.7415090749080606d-02,
     3      -.3128393349055569d-01,0.2571589596116168d-01,
     4      0.1105521032570794d+01,-.7828306595198230d+01,
     5      0.3167962632078227d+02,-.9346674945960177d+02,
     6      0.2180052040782251d+03,-.4229602378483868d+03,
     7      0.7121848594780566d+03,-.1081069758148617d+04,
     8      0.1494990766667725d+04,-.1888343282418145d+04/
         data arr1587/
     1      0.2177010586292606d+04,-.2401420304931852d+04,
     2      0.2489644555559489d+04,-.2418844750295555d+04,
     3      0.1962838801034126d+04,-.1742463264602924d+04,
     4      0.1365449598395465d+04,-.1072314710602569d+04,
     5      0.1000004161321503d+01,-.2561740102379724d+01,
     6      0.4706199828352648d+01,-.7156683460045996d+01,
     7      0.9551615783819805d+01,-.1155112213166794d+02,
     8      0.1291436207339711d+02,-.1353372653220459d+02/
         data arr1588/
     1      0.1342778552827486d+02,-.1270625603372882d+02,
     2      0.1152761054456488d+02,-.1006239647258604d+02,
     3      0.8460021696241798d+01,-.6820999815354965d+01,
     4      0.5219811216473918d+01,-.3734361512481740d+01,
     5      0.2437995861318391d+01,-.1267563528311183d+01,
     6      0.2725330507117940d+00,0.4584364348439304d+00,
     7      -.6627806220099949d+00,0.9894632510222877d+00,
     8      -.1090542060257750d+01,0.1070956080147920d+01/
         data arr1589/
     1      0.9686640655375668d-05,0.9999959132259065d+00,
     2      -.3674264497934521d+01,0.8381078272364860d+01,
     3      -.1491410577672051d+02,0.2254534769912037d+02,
     4      -.3024817853258059d+02,0.3698283944702561d+02,
     5      -.4194083568594712d+02,0.4468665272159747d+02,
     6      -.4517472315346437d+02,0.4366943874946329d+02,
     7      -.4063466878069563d+02,0.3663357670780303d+02,
     8      -.3216730298821716d+02,0.2757382509940056d+02/
         data arr1590/
     1      -.2305913001374333d+02,0.1900614869437292d+02,
     2      -.1540729541655747d+02,0.1213523901921037d+02,
     3      -.8671663937416172d+01,0.6511456363526210d+01,
     4      -.4610057147295854d+01,0.3148048633602891d+01,
     5      -.5177817169988773d-04,0.2422861273683501d-04,
     6      0.1000159678039476d+01,-.4562172817901272d+01,
     7      0.1217685475177400d+02,-.2454396391303373d+02,
     8      0.4116389652483389d+02,-.6039180508585632d+02/
         data arr1591/
     1      0.7988426431234283d+02,-.9722143621585723d+02,
     2      0.1104288061180642d+03,-.1182711184313323d+03,
     3      0.1204089574080382d+03,-.1174518164639364d+03,
     4      0.1104238038086038d+03,-.1002676416387467d+03,
     5      0.8786261535283281d+02,-.7548582294233979d+02,
     6      0.6356877257308765d+02,-.5185222607262566d+02,
     7      0.3778192710352173d+02,-.2955146823625092d+02,
     8      0.2194140995598120d+02,-.1594810329427978d+02/
         data arr1592/
     1      0.2414094363343761d-04,-.2876394857669910d-05,
     2      -.7460402950831723d-04,0.1000012007212225d+01,
     3      -.5338283825391437d+01,0.1614021003320131d+02,
     4      -.3609155247714353d+02,0.6616300995135355d+02,
     5      -.1048701073864173d+03,0.1483356820190242d+03,
     6      -.1910657590820533d+03,0.2271608283916605d+03,
     7      -.2516339924938476d+03,0.2614627192388226d+03,
     8      -.2559217158040596d+03,0.2364727562895480d+03/
         data arr1593/
     1      -.2063941610494533d+03,0.1705784916617614d+03,
     2      -.1330634005804418d+03,0.9728909604342184d+02,
     3      -.6499370331507361d+02,0.4145775512186142d+02,
     4      -.2357107720247234d+02,0.1158750178298348d+02,
     5      -.2551473749953748d-03,0.9351324590148230d-04,
     6      0.7871019160357009d-03,-.3888660366823001d-03,
     7      0.9973099458693330d+00,-.6045263435198597d+01,
     8      0.2029010829911364d+02,-.4959713296448023d+02/
         data arr1594/
     1      0.9834635944898880d+02,-.1673682865204909d+03,
     2      0.2526638289965338d+03,-.3454732946957845d+03,
     3      0.4342294942201458d+03,-.5077577638653114d+03,
     4      0.5563014327537674d+03,-.5725780833248364d+03,
     5      0.5541392955284125d+03,-.5107063521716203d+03,
     6      0.4470778400705859d+03,-.3683964137957978d+03,
     7      0.2708264699460108d+03,-.2018423211170342d+03,
     8      0.1382361155622461d+03,-.8861075264632055d+02/
         data arr1595/
     1      0.6128852130405207d-03,-.2386955831598111d-03,
     2      -.1890449135012580d-02,0.9926541946330535d-03,
     3      0.6460005638573659d-02,0.9963505705465435d+00,
     4      -.6729526504653914d+01,0.2450631640745449d+02,
     5      -.6415067022912759d+02,0.1348364790649152d+03,
     6      -.2405705262732611d+03,0.3765376007835761d+03,
     7      -.5293278655324526d+03,0.6811616505407931d+03,
     8      -.8107545911303109d+03,0.8960919027466145d+03/
         data arr1596/
     1      -.9218652196875780d+03,0.8999013603829942d+03,
     2      -.8308745417108753d+03,0.7180866150843768d+03,
     3      -.5459849960580135d+03,0.4260812144599524d+03,
     4      -.3048601415072403d+03,0.2046332408784701d+03,
     5      -.2428827331778754d-02,0.1149092439270189d-02,
     6      0.7488692186824639d-02,-.4781992735883507d-02,
     7      -.2556550588844008d-01,0.1754431910175845d-01,
     8      0.1084300827205042d+01,-.7394499130763647d+01/
         data arr1597/
     1      0.2869081391087620d+02,-.8121012856605152d+02,
     2      0.1827480711225794d+03,-.3437590843727154d+03,
     3      0.5635521308673136d+03,-.8345187995611285d+03,
     4      0.1129610760694403d+04,-.1397773830727904d+04,
     5      0.1584608446328412d+04,-.1717242538608472d+04,
     6      0.1762394391814528d+04,-.1681895353840313d+04,
     7      0.1354874845286670d+04,-.1182113446527719d+04,
     8      0.9483321400092056d+03,-.7266798895130089d+03/
         data arr1598/
     1      0.9999858555225127d+00,-.2633954007546965d+01,
     2      0.4971444953591419d+01,-.7761435092181967d+01,
     3      0.1062786668205878d+02,-.1317888487247917d+02,
     4      0.1510269786390165d+02,-.1623558846168830d+02,
     5      0.1659196671241975d+02,-.1633551096994868d+02,
     6      0.1570231333105987d+02,-.1494465813366497d+02,
     7      0.1431163441627529d+02,-.1391189027204923d+02,
     8      0.1360564014438399d+02,-.1317351794512423d+02/
         data arr1599/
     1      0.1283671890021833d+02,-.1240532152187963d+02,
     2      0.1138071417797739d+02,-.8996846474121908d+01,
     3      0.7745862493538889d+01,-.6408026530788770d+01,
     4      0.4850612965410391d+01,0.2337690837091993d-04,
     5      0.1000065742584219d+01,-.3774987294030337d+01,
     6      0.8840114793478195d+01,-.1614002094763205d+02,
     7      0.2501752619778598d+02,-.3439287161196205d+02,
     8      0.4305996552067945d+02,-.4998514300667752d+02/
         data arr1600/
     1      0.5449529746631133d+02,-.5632649936255812d+02,
     2      0.5562411526870209d+02,-.5291809807450178d+02,
     3      0.4883170749199975d+02,-.4378267667348154d+02,
     4      0.3811165237611591d+02,-.3279995741823128d+02,
     5      0.2799920834152842d+02,-.2315062972986774d+02,
     6      0.1704695527052899d+02,-.1362578669793731d+02,
     7      0.1072774335309225d+02,-.7928924158787090d+01,
     8      0.3288206395151436d-04,0.7140035956608019d-04/
         data arr1601/
     1      0.9999019586123997d+00,-.4684039321526832d+01,
     2      0.1282730350221251d+02,-.2650719395705502d+02,
     3      0.4552351651504392d+02,-.6823035800406705d+02,
     4      0.9180056884117240d+02,-.1128426383443590d+03,
     5      0.1281841270166520d+03,-.1355257371171626d+03,
     6      0.1337945448914145d+03,-.1234274465551428d+03,
     7      0.1063859669649448d+03,-.8548685802649365d+02,
     8      0.6292607439984222d+02,-.4127614742484349d+02/
         data arr1602/
     1      0.2322617691301258d+02,-.1142720699936924d+02,
     2      0.1886391546320690d+01,0.3968075340997719d+01,
     3      -.6327621361583804d+01,0.6444928172018713d-04,
     4      0.2728211705888179d-03,-.1932720882233581d-03,
     5      0.9988914051885953d+00,-.5476579069692916d+01,
     6      0.1698278113158541d+02,-.3890553231440923d+02,
     7      0.7302694175748234d+02,-.1185040363202182d+03,
     8      0.1715645472119513d+03,-.2260289288448130d+03/
         data arr1603/
     1      0.2747490714352464d+03,-.3114487378801620d+03,
     2      0.3314232504082940d+03,-.3318548982983170d+03,
     3      0.3130590963918575d+03,-.2808797782929420d+03,
     4      0.2394860224259555d+03,-.1916117910139203d+03,
     5      0.1380711675409880d+03,-.9919446000449739d+02,
     6      0.6659558897491328d+02,-.4002265211012967d+02,
     7      -.4312009034912848d-03,-.1399873474116899d-02,
     8      0.1290069237800938d-02,0.5690695533342703d-02/
         data arr1604/
     1      0.9956768613724578d+00,-.6219943868632648d+01,
     2      0.2129618146112312d+02,-.5309647086683785d+02,
     3      0.1075040889347671d+03,-.1865157070878649d+03,
     4      0.2859681936241491d+03,-.3962991724416568d+03,
     5      0.5059821508655958d+03,-.6011159982879117d+03,
     6      0.6653009488907955d+03,-.6871884108491026d+03,
     7      0.6773927453357861d+03,-.6367489920699160d+03,
     8      0.5588189293222187d+03,-.4294138739351631d+03/
         data arr1605/
     1      0.3433116438254689d+03,-.2606244944429009d+03,
     2      0.1801660639738580d+03,0.1448752133122098d-02,
     3      0.4181722571169766d-02,-.4334829471355516d-02,
     4      -.1699007006911206d-01,0.1450867441006556d-01,
     5      0.1060118145913073d+01,-.6920836525581771d+01,
     6      0.2552114889624525d+02,-.6896469133031897d+02,
     7      0.1493826589859240d+03,-.2722989288437137d+03,
     8      0.4347810465243875d+03,-.6293843773164267d+03/
         data arr1606/
     1      0.8364546635564941d+03,-.1018278599849260d+04,
     2      0.1139305325364120d+04,-.1219687273412466d+04,
     3      0.1245180723362263d+04,-.1174700431693238d+04,
     4      0.9412315784922691d+03,-.8122777167940375d+03,
     5      0.6691235982293212d+03,-.5031020830466451d+03,
     6      0.1000204849286085d+01,-.2704259173379492d+01,
     7      0.5236002678091188d+01,-.8382250840851005d+01,
     8      0.1176373400710573d+02,-.1493703930925105d+02/
         data arr1607/
     1      0.1751323838228386d+02,-.1926583440288811d+02,
     2      0.2015629138169659d+02,-.2027778923782830d+02,
     3      0.1987176047253111d+02,-.1939478424097417d+02,
     4      0.1918136933890671d+02,-.1903171944902491d+02,
     5      0.1866827281769924d+02,-.1893830725099785d+02,
     6      0.1966888200671847d+02,-.1914318086509663d+02,
     7      0.1540660866368915d+02,-.1443438047974702d+02,
     8      0.1378861890978124d+02,-.1140557711031843d+02/
         data arr1608/
     1      0.1905579133491381d-03,0.9999116903480811d+00,
     2      -.3873531860128621d+01,0.9300057894704560d+01,
     3      -.1739640002207696d+02,0.2758811104434753d+02,
     4      -.3867640092261736d+02,0.4905763697910383d+02,
     5      -.5707648998697342d+02,0.6142358549623404d+02,
     6      -.6135419741552551d+02,0.5669667056711934d+02,
     7      -.4806485141431411d+02,0.3700687709927889d+02,
     8      -.2528163325534173d+02,0.1345914438488841d+02/
         data arr1609/
     1      -.2710829061611690d+01,-.4789833185009135d+01,
     2      0.7086446366427024d+01,-.9930903422303800d+01,
     3      0.1148507782361781d+02,-.1027431264955688d+02,
     4      -.2307900293988594d-03,0.1591032314872005d-03,
     5      0.1000664888431783d+01,-.4802993901001541d+01,
     6      0.1347445183428810d+02,-.2851961061186752d+02,
     7      0.5014264073670007d+02,-.7687653437979261d+02,
     8      0.1057425118394847d+03,-.1328859688391865d+03/
         data arr1610/
     1      0.1543335767540572d+03,-.1666425756545128d+03,
     2      0.1678194381177584d+03,-.1581477730326938d+03,
     3      0.1396632765595004d+03,-.1141329955878160d+03,
     4      0.8470612400374063d+02,-.5657357021910536d+02,
     5      0.3530313577493266d+02,-.1598890907248217d+02,
     6      0.7825474809549379d+00,0.7690360934853438d+01,
     7      -.1732912545214904d-02,0.6340100743874570d-03,
     8      0.4973840294903050d-02,0.9974595468970397d+00/
         data arr1611/
     1      -.5628433512371777d+01,0.1783357257120401d+02,
     2      -.4178637892446007d+02,0.8042261905201094d+02,
     3      -.1338427423984656d+03,0.1982734231908214d+03,
     4      -.2670556251840988d+03,0.3330475513692345d+03,
     5      -.3881725857471014d+03,0.4226247402376977d+03,
     6      -.4305772789471149d+03,0.4198975424380836d+03,
     7      -.3927234083284829d+03,0.3417989060814868d+03,
     8      -.2609102231537135d+03,0.2078570859063144d+03/
         data arr1612/
     1      -.1626625936717920d+03,0.1115907327754987d+03,
     2      0.7246494412218052d-02,-.3085128398785561d-02,
     3      -.2080790321669731d-01,0.1241963549673600d-01,
     4      0.1066520716745878d+01,-.6392373106428749d+01,
     5      0.2211355138289731d+02,-.5698147049216393d+02,
     6      0.1190138382306023d+03,-.2106165468764871d+03,
     7      0.3287495076961367d+03,-.4694588023209577d+03,
     8      0.6203358988116111d+03,-.7518913172014826d+03/
         data arr1613/
     1      0.8387851929523957d+03,-.9034912483693221d+03,
     2      0.9396106242999945d+03,-.8951464717132342d+03,
     3      0.7176388158954060d+03,-.6321405582590763d+03,
     4      0.5564335073682168d+03,-.4267084360946751d+03,
     5      0.9995823484559013d+00,-.2773665090393257d+01,
     6      0.5502958829491805d+01,-.9015428730106207d+01,
     7      0.1289128405765046d+02,-.1646219120954724d+02,
     8      0.1883265134515624d+02,-.1908521681887716d+02/
         data arr1614/
     1      0.1663901601788075d+02,-.1129941656551210d+02,
     2      0.3007025213188719d+01,0.7596489454604830d+01,
     3      -.1840905771172353d+02,0.2746532906614717d+02,
     4      -.3589021244565126d+02,0.4315645595302999d+02,
     5      -.4469474042124850d+02,0.3712944716603267d+02,
     6      -.3470408421364957d+02,0.3363451882570337d+02,
     7      -.2666872087132461d+02,0.4091890694456197d-03,
     8      0.1000828997375556d+01,-.3969794124204686d+01/
         data arr1615/
     1      0.9755871668536701d+01,-.1868359883847893d+02,
     2      0.3032652524043154d+02,-.4346361887117771d+02,
     3      0.5631387619591591d+02,-.6699836409210346d+02,
     4      0.7381803062986196d+02,-.7528549143148125d+02,
     5      0.7080836317380732d+02,-.6157507030902057d+02,
     6      0.4942046183073558d+02,-.3419314223827382d+02,
     7      0.1726157624871463d+02,-.3705242021038729d+01,
     8      -.1878400448954520d+01,0.9831913824637156d+01/
         data arr1616/
     1      -.1741257614456140d+02,0.1831130451664003d+02,
     2      0.1243023147204734d-02,0.3472145670597520d-02,
     3      0.9965467896272480d+00,-.4931652432517607d+01,
     4      0.1425392065671393d+02,-.3129668807878533d+02,
     5      0.5766412945598310d+02,-.9342069376136686d+02,
     6      0.1363202713241579d+03,-.1824879132193674d+03,
     7      0.2281700654222689d+03,-.2685887944337742d+03,
     8      0.2960512514388519d+03,-.3055509095584127d+03/
         data arr1617/
     1      0.3038883256812046d+03,-.2926274137408752d+03,
     2      0.2604718253821210d+03,-.2009175076320158d+03,
     3      0.1648699154315784d+03,-.1385388169383995d+03,
     4      0.9817475365042338d+02,-.3917729569927115d-02,
     5      -.9907645210297798d-02,0.1095953737727235d-01,
     6      0.1038473850393250d+01,-.5779002977788768d+01,
     7      0.1854561243889982d+02,-.4477340400123466d+02,
     8      0.8877937140054226d+02,-.1507329179233950d+03/
         data arr1618/
     1      0.2272603104646654d+03,-.3151187654331543d+03,
     2      0.4066948509534595d+03,-.4831615917915598d+03,
     3      0.5296169261674962d+03,-.5623109115745862d+03,
     4      0.5815018494678979d+03,-.5482492267267202d+03,
     5      0.4346065407386622d+03,-.3800797247892978d+03,
     6      0.3467260711455720d+03,-.2641705349904081d+03,
     7      0.1005040758504559d+01,-.2841746108175086d+01,
     8      0.5753693103550209d+01,-.9663296300948128d+01/
         data arr1619/
     1      0.1417735964766516d+02,-.1844936297409723d+02,
     2      0.2138567971909625d+02,-.2215707750980189d+02,
     3      0.1996830979486342d+02,-.1335272468473351d+02,
     4      0.1888457061912743d+01,0.1128307346298889d+02,
     5      -.2332784853909093d+02,0.3847551272826965d+02,
     6      -.5653324332296743d+02,0.6447072502690395d+02,
     7      -.5376508117245956d+02,0.5618703172923842d+02,
     8      -.6557249888960687d+02,0.5660872239153113d+02/
         data arr1620/
     1      0.4752470802733289d-02,0.9983922699476503d+00,
     2      -.4075008150148464d+01,0.1039265267852928d+02,
     3      -.2095188001964694d+02,0.3641759981438375d+02,
     4      -.5671603957993329d+02,0.8056927089747935d+02,
     5      -.1059877551793111d+03,0.1313250895667433d+03,
     6      -.1541632888207845d+03,0.1697322140655345d+03,
     7      -.1751524715904526d+03,0.1752767836246621d+03,
     8      -.1711659221230644d+03,0.1532290407110872d+03/
         data arr1621/
     1      -.1179839648257558d+03,0.9817609946789799d+02,
     2      -.8692314671114182d+02,0.6178543782022457d+02,
     3      -.1888353341801235d-01,0.7509146016501318d-02,
     4      0.1050776039456273d+01,-.5060798563813799d+01,
     5      0.1476202703494463d+02,-.3350887652814331d+02,
     6      0.6381978496605488d+02,-.1052938721788989d+03,
     7      0.1559442791870257d+03,-.2156299153706079d+03,
     8      0.2806374754624923d+03,-.3357602036720747d+03/
         data arr1622/
     1      0.3699332802165585d+03,-.4005992812971669d+03,
     2      0.4293278049543012d+03,-.4122128166661065d+03,
     3      0.3256761705472635d+03,-.2940367762508558d+03,
     4      0.2922012808234028d+03,-.2278405772320040d+03,
     5      0.9909157851925223d+00,-.2926690393288211d+01,
     6      0.6574126003601540d+01,-.1291252716996290d+02,
     7      0.2338703875256918d+02,-.3925923439403114d+02,
     8      0.6029974401841706d+02,-.8545119715544974d+02/
         data arr1623/
     1      0.1150753252996895d+03,-.1478743703043697d+03,
     2      0.1754378983687333d+03,-.1915571681195981d+03,
     3      0.2071734539531499d+03,-.2248423672314858d+03,
     4      0.2164651703683718d+03,-.1688629181394928d+03,
     5      0.1533408063457081d+03,-.1613860906224531d+03,
     6      0.1266930496135357d+03,0.1037794747426203d-01,
     7      0.1023806236180949d+01,-.4183478358640272d+01,
     8      0.1078329489774003d+02,-.2239218457772719d+02/
         data arr1624/
     1      0.4019807892108937d+02,-.6371369301846804d+02,
     2      0.9163274328128828d+02,-.1243656185935403d+03,
     3      0.1605774316473829d+03,-.1910417018188049d+03,
     4      0.2089408274383531d+03,-.2265034996181187d+03,
     5      0.2466056229638278d+03,-.2379277444125444d+03,
     6      0.1856470111298222d+03,-.1690238745352143d+03,
     7      0.1786479803149268d+03,-.1406643221492282d+03,
     8      0.1104847887617452d+01,-.3025767454908793d+01/
         data arr1625/
     1      0.6634223539514593d+01,-.1382241879386943d+02,
     2      0.2651829044517035d+02,-.4438584866733812d+02,
     3      0.6726199833846008d+02,-.1001206912865292d+03,
     4      0.1442455916193414d+03,-.1835203296749132d+03,
     5      0.2075194871889430d+03,-.2449779288392651d+03,
     6      0.3029547835102293d+03,-.3098541052085361d+03,
     7      0.2351655900596560d+03,-.2345924262965386d+03,
     8      0.2988659052398949d+03,-.2516016901181309d+03/
        do 1200 i=1,10000
        arr(i)=arr1001(i)
 1200 continue
c
        do 1300 i=1,24
        imap(i)=iimap(i)
 1300   continue
c
        return
        end
c
	subroutine lol1get(arr,imap)
        implicit double precision (a-h,o-z)
c
c	LOLO matrix for nmultdad=2,nmultson=1
c
        integer imap(1),iimap(1),nsstored(1)
c
        real *8 arr1001( 6),arr(1)
c
c
         data arr1001/
     1      0.1000431133759722D+01,-.4374154724529144D+00,
     2      0.2170586369472096D+00,-.2640088218716800D-02,
     3      0.1023330570183862D+01,-.8593871103899803D+00/
	data iimap/1/
	data nsstored/6/
	do i=1,6
	  arr(i)=arr1001(i)
	enddo
c
	imap(1)=iimap(1)
c
	return
	end
c
c
c
c
c
	subroutine lol2get(arr,imap)
        implicit double precision (a-h,o-z)
c
c	LOLO matrix for nmultdad=3,nmultson=2
c
        integer imap(1),iimap(2),nsstored(2)
c
        real *8 arr1001(18),arr(1)
c
c
        data arr1001/
     1      0.1000216532119655D+01,-.4329915130752896D+00,
     2      0.1870027404335694D+00,-.8035730648549652D-01,
     3      -.2640088218717517D-02,0.9996399931299077D+00,
     4      -.8593871103899806D+00,0.6326778696611493D+00,
     5      0.7006209453211485D-02,0.1055214906361936D-02,
     6      0.9812502188389414D+00,-.1261879360070806D+01,
     7      0.9995941363840158D+00,-.7496686480237587D+00,
     8      0.4391370356989053D+00,0.2423528729382510D-02,
     9      0.9958040138307395D+00,-.1201708694599128D+01/
	data iimap/1,13/
	data nsstored/12,6/
	do i=1,18
	  arr(i)=arr1001(i)
	enddo
c
	imap(1)=iimap(1)
	imap(2)=iimap(2)
c
	return
	end
c
c

c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c  this subroutine provides the matrix for the compressed lolo and
c  tata operators for 3 digits of accuracy.
c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c
        subroutine lol3get(arr,imap)
        implicit real *8(a-h,o-z)
        integer imap(1)
        integer iimap(5)
        real *8 arr(1)
          real *8
     1  ar1001(16),ar1002(16),ar1003(16),ar1004(16),
     2  ar1005(16),ar1006(16),ar1007(16),ar1008(16),
     3  ar1009(16),ar1010(16),ar1011(16),ar1012(14)
         real *8
     1  ar2001(2),ar2002(2),ar2003(2),ar2004(2),
     2  ar2005(2),ar2006(2),ar2007(2),ar2008(2)
         real *8
     1  ar2009(2),ar2010(2),ar2011(2)
         equivalence
     1  (ar1001(16),ar2001(1)),(ar1002(1),ar2001(2)),
     2  (ar1002(16),ar2002(1)),(ar1003(1),ar2002(2)),
     3  (ar1003(16),ar2003(1)),(ar1004(1),ar2003(2)),
     4  (ar1004(16),ar2004(1)),(ar1005(1),ar2004(2)),
     5  (ar1005(16),ar2005(1)),(ar1006(1),ar2005(2)),
     6  (ar1006(16),ar2006(1)),(ar1007(1),ar2006(2)),
     7  (ar1007(16),ar2007(1)),(ar1008(1),ar2007(2)),
     8  (ar1008(16),ar2008(1)),(ar1009(1),ar2008(2)),
     9  (ar1009(16),ar2009(1)),(ar1010(1),ar2009(2)),
     a  (ar1010(16),ar2010(1)),(ar1011(1),ar2010(2))
         equivalence
     1  (ar1011(16),ar2011(1)),(ar1012(1),ar2011(2))
c
c
c
         data iimap/1,67,117,153,177/
         data ar1001/
     1       .1000000067501924d+01,-.4330130848002339d+00,
     2       .1874999710785659d+00,-.8118623586144579d-01,
     3       .3515166879858397d-01,-.1520446675983663d-01,
     4       .7031279410965006d-02,-.4034161094524841d-02,
     5       .3401468611609194d-02,-.2880939708667100d-02,
     6       .2639406520577744d-02, .7360638716066873d-07,
     7       .1000000018082423d+01,-.8660254185905665d+00,
     8       .5624991996599173d+00,-.3247644732908767d+00/
         data ar1002/
     1       .1757895724958993d+00,-.9137484697881657d-01,
     2       .4597072527523650d-01,-.2247869485792703d-01,
     3       .1016917119509857d-01,-.4097839771352959d-02,
     4       .1833775837931380d-05,-.9419663020188062d-05,
     5       .9999992856778498d+00,-.1298950838821404d+01,
     6       .1124875593133234d+01,-.8114072315531085d+00,
     7       .5289917937569014d+00,-.3212673916438475d+00,
     8       .1927532505836900d+00,-.1093395199440208d+00/
         data ar1003/
     1       .7028143741430749d-01,-.1151477002988081d-04,
     2       .5802079057391099d-04, .4429920107892400d-05,
     3       .9994640233794024d+00,-.1731270329354124d+01,
     4       .1871955085564468d+01,-.1619695685194202d+01,
     5       .1211539542170832d+01,-.8690968687039290d+00,
     6       .5633686235434661d+00,-.4050122276302828d+00,
     7       .6263983435093782d-04,-.3109722431809056d-03,
     8      -.2424299420420126d-04, .2873984011289286d-02/
         data ar1004/
     1       .9957551044354925d+00,-.2148740808479698d+01,
     2       .2910601756339144d+01,-.3028186613595130d+01,
     3       .2935073657168841d+01,-.2344886814254428d+01,
     4       .1994929897359914d+01,-.1273324953744604d-03,
     5       .6196494752494040d-03, .4923721103172030d-04,
     6      -.5715259675375899d-02, .8629192771797255d-02,
     7       .9672611531303400d+00,-.2553080686214832d+01,
     8       .3662373136897427d+01,-.4460404329245944d+01/
         data ar1005/
     1       .4033660617426261d+01,-.3763709717168596d+01,
     2       .9999992193211115d+00,-.7499995396031841d+00,
     3       .4592606831929999d+00,-.2567117754261879d+00,
     4       .1360420760927890d+00,-.6961277807425643d-01,
     5       .3488918181323398d-01,-.1984913485380982d-01,
     6       .1271766462441046d-01,-.1144893204320817d-01,
     7       .5552706994757331d-05, .9999974028994407d+00,
     8      -.1224616915104507d+01, .1026777844413320d+01/
         data ar1006/
     1      -.7254124380781241d+00, .4729593491548357d+00,
     2      -.2974647201736195d+00, .1980561248824710d+00,
     3      -.1287660146378782d+00, .9774287082395101d-01,
     4      -.1444108260269569d-04, .5074038002085710d-05,
     5       .9996790521005743d+00,-.1676615410908241d+01,
     6       .1776935541909582d+01,-.1517055786214263d+01,
     7       .1122699623651663d+01,-.7773602530515871d+00,
     8       .4782768178595680d+00,-.3069617073829860d+00/
         data ar1007/
     1       .5778533362126120d-04,-.2061686476266109d-04,
     2       .1289347521237970d-02, .9982001422924567d+00,
     3      -.2113869187366934d+01, .2700314104261014d+01,
     4      -.2610609407277743d+01, .2227392486413918d+01,
     5      -.1580324112377901d+01, .1141724517343723d+01,
     6      -.1933800013286344d-03, .8402570197560051d-04,
     7      -.4420421678997357d-02, .6841626226685144d-02,
     8       .9736167918810855d+00,-.2532046316593382d+01/
         data ar1008/
     1       .3589909204475083d+01,-.4207089464680500d+01,
     2       .3690090242165575d+01,-.3277147797786897d+01,
     3       .1000000069340970d+01,-.9682504829633017d+00,
     4       .7261874133974344d+00,-.4803288780102072d+00,
     5       .2882924681939784d+00,-.1541825877103064d+00,
     6       .6874061683366842d-01,-.2197350229162389d-01,
     7       .1318261416026540d-02, .5785337030012175d-05,
     8       .9998057582816655d+00,-.1499790246996729d+01/
         data ar1009/
     1       .1487614734583049d+01,-.1214225813980603d+01,
     2       .8727344237803051d+00,-.5921049298522069d+00,
     3       .3664269651605856d+00,-.2343657744990409d+00,
     4      -.2053464326579412d-04, .7562733288672208d-03,
     5       .9992509532747151d+00,-.1982097180876482d+01,
     6       .2416210132436164d+01,-.2271268217554069d+01,
     7       .1882339764295155d+01,-.1326435890221113d+01,
     8       .9144605523041315d+00, .6915256509435579d-04/
         data ar1010/
     1      -.2375443305906985d-02, .2526220081231610d-02,
     2       .9927762567710789d+00,-.2439206715024512d+01,
     3       .3359434608083496d+01,-.3710685662557972d+01,
     4       .3165403710419904d+01,-.2561379878579316d+01,
     5       .9999985444124548d+00,-.1145670265724526d+01,
     6       .9922002919278728d+00,-.7441673883796815d+00,
     7       .5000407207860668d+00,-.2985825164685798d+00,
     8       .1486311601508692d+00,-.5342547084785215d-01/
         data ar1011/
     1       .4245812948523879d-04, .1000007115051578d+01,
     2      -.1732161744920051d+01, .1860174762279119d+01,
     3      -.1531649057555548d+01, .1043753857680819d+01,
     4      -.5837170991306112d+00, .2653365711592428d+00,
     5      -.7254773672106960d-03, .1352098552256776d-02,
     6       .9996386298092335d+00,-.2248773412713195d+01,
     7       .2942596378295846d+01,-.3071356138364182d+01,
     8       .2575654156418870d+01,-.1988645700814801d+01/
         data ar1012/
     1       .9999307211283807d+00,-.1299792335645297d+01,
     2       .1279393242683012d+01,-.1085751788481727d+01,
     3       .8440679475494810d+00,-.5877805418472455d+00,
     4       .3624329747499411d+00, .2517113784580546d-03,
     5       .1002326972451956d+01,-.1937336718656736d+01,
     6       .2292120168880192d+01,-.2140422019954681d+01,
     7       .1644882925253921d+01,-.1081001130389303d+01/
       do 1200 i=1,191
       arr(i)=ar1001(i)
1200   continue
c
        do 1300 i=1,5
        imap(i)=iimap(i)
 1300   continue
c
        return
        end
c
c
c
c
c 
c

        subroutine lol6get(arr,imap)
        implicit real *8 (a-h,o-z)
        integer imap(1)
        integer iimap(11)
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16)
         real *8
     1  arr1069(12)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2))
C
C
c
	data iimap/1,221,411,573,709,821,911,981,1033,1069,1091/
         data arr1001/
     1       .9999999999972455d+00,-.4330127018889983d+00,
     2       .1874999999977911d+00,-.8118988160861999d-01,
     3       .3515625011704544d-01,-.1522310304903595d-01,
     4       .6591797849441537d-02,-.2854333394951394d-02,
     5       .1235970152341580d-02,-.5351995705783185d-03,
     6       .2317820400894776d-03,-.1004019765311584d-03,
     7       .4359387518642311d-04,-.1875734198617075d-04,
     8       .7841656680901259d-05,-.2222231744289716d-05/
         data arr1002/
     1       .3015705872275766d-07, .2348691189662942d-05,
     2      -.2393863289955726d-05, .3676329239391304d-05,
     3      -.3596082689700194d-10, .1000000000029197d+01,
     4      -.8660254038032038d+00, .5624999999769814d+00,
     5      -.3247595249110005d+00, .1757812475250815d+00,
     6      -.9133860535600562d-01, .4614256322007294d-01,
     7      -.2283455158219065d-01, .1112353766057688d-01,
     8      -.5351414088519565d-02, .2550371734101445d-02/
         data arr1003/
     1      -.1210607171532456d-02, .5870038456966834d-03,
     2      -.3044034430601627d-03, .1908014107627012d-03,
     3      -.1306906103757078d-03, .1179808862330800d-03,
     4      -.8244293975320846d-04, .7670354277289792d-04,
     5      -.5924729638006251d-10, .8463014355699827d-10,
     6       .9999999999410000d+00,-.1299038105784318d+01,
     7       .1125000002548798d+01,-.8118988224488222d+00,
     8       .5273437724886383d+00,-.3196852012796951d+00/
         data arr1004/
     1       .1845704956128752d+00,-.1027562645770387d+00,
     2       .5561919083135916d-01,-.2943671963198290d-01,
     3       .1529778134709605d-01,-.7824153520235204d-02,
     4       .3940052459104990d-02,-.1932462010482060d-02,
     5       .9161187581272483d-03,-.3791354145150107d-03,
     6       .1271879073858664d-03, .1468120664781296d-04,
     7       .7534342585238436d-08,-.7640418704679846d-08,
     8       .5117129922666490d-08, .1000000007917302d+01/
         data arr1005/
     1      -.1732051126010556d+01, .1875000611245849d+01,
     2      -.1623800181690693d+01, .1230472614498899d+01,
     3      -.8525158416221090d+00, .5537410120547991d+00,
     4      -.3426220800482765d+00, .2038143862147105d+00,
     5      -.1169724695912407d+00, .6325025114148947d-01,
     6      -.3080498451877485d-01, .9525600759059614d-02,
     7       .7276921739067995d-03,-.9584608641603000d-02,
     8       .9482184156383973d-02,-.1223031237493494d-01/
         data arr1006/
     1      -.8223743405420983d-08, .1191215836935325d-07,
     2      -.8352426655760767d-08,-.1575205172117921d-07,
     3       .1000000353023999d+01,-.2165064394697391d+01,
     4       .2812503130806069d+01,-.2841651811364966d+01,
     5       .2460962956722740d+01,-.1918155599206486d+01,
     6       .1384403622687324d+01,-.9421294512204705d+00,
     7       .6121929375783639d+00,-.3822908422956638d+00,
     8       .2301472184762970d+00,-.1312453490019407d+00/
         data arr1007/
     1       .7093586930311249d-01,-.3130908445067267d-01,
     2       .1070662888945723d-01, .3592983776397756d-02,
     3      -.5568997294390007d-07, .3493565984359234d-07,
     4      -.2120305156998463d-07,-.1631899074528126d-07,
     5       .2320698219529596d-05, .9999968089557565d+00,
     6      -.2598059458183330d+01, .3937481919682886d+01,
     7      -.4546478256472491d+01, .4429536878599874d+01,
     8      -.3835554032848703d+01, .3046495367909175d+01/
         data arr1008/
     1      -.2265847765634355d+01, .1612096587663059d+01,
     2      -.1108913643029745d+01, .7625869307051386d+00,
     3      -.4996600776004779d+00, .3535947233052726d+00,
     4      -.2091852670469352d+00, .1524141019042937d+00,
     5       .1575789535478808d-06,-.8841085233280900d-07,
     6       .5223818895284117d-07, .3038299911033256d-07,
     7      -.6546905778634151d-05, .8292354286676837d-05,
     8       .9999536060741840d+00,-.3031042933890030d+01/
         data arr1009/
     1       .5249565022725061d+01,-.6819561697301836d+01,
     2       .7380964119899719d+01,-.7031530478885446d+01,
     3       .6081812927174768d+01,-.4895696676462732d+01,
     4       .3698289662402138d+01,-.2690588407250964d+01,
     5       .1806869289871519d+01,-.1244290390683888d+01,
     6       .7111033449807524d+00,-.4774586562802425d+00,
     7      -.1079612283736545d-05, .8493689187924624d-06,
     8      -.5453657535115825d-06,-.6815411826923476d-06/
         data arr1010/
     1       .4522321956467926d-04,-.7186636624527683d-04,
     2       .3413979603190327d-03, .9995663911340704d+00,
     3      -.3461030007059422d+01, .6746526776723958d+01,
     4      -.9729130161020366d+01, .1159942611837802d+02,
     5      -.1204942402877203d+02, .1142483259616057d+02,
     6      -.9957412951704415d+01, .8393282186765271d+01,
     7      -.6302576811626785d+01, .5060138805733010d+01,
     8      -.3192821975112011d+01, .2543330843033019d+01/
         data arr1011/
     1       .3153020632779872d-05,-.2564303481416451d-05,
     2       .1656427909715211d-05, .2152299922085774d-05,
     3      -.1321879995500774d-03, .2150152558504424d-03,
     4      -.1004920134467923d-02, .1306984784479892d-02,
     5       .9909987289670500d+00,-.3886692530357529d+01,
     6       .8397283648319840d+01,-.1335243852238357d+02,
     7       .1721240798510096d+02,-.1949600902404405d+02,
     8       .1949704697760229d+02,-.1851912604345839d+02/
         data arr1012/
     1       .1502998332997749d+02,-.1304574046319256d+02,
     2       .8573569461876213d+01,-.7143210322801096d+01,
     3      -.1018780416130288d-04, .8803598189326249d-05,
     4      -.5743755557791489d-05,-.7842149557701945d-05,
     5       .4280160965971965d-03,-.7292327096097193d-03,
     6       .3297303453149541d-02,-.4477894571269183d-02,
     7       .2927959570155495d-01, .9645172761028904d+00,
     8      -.4198098705364253d+01, .1025256483148541d+02/
         data arr1013/
     1      -.1764288211903847d+02, .2575309102442169d+02,
     2      -.3113002864548529d+02, .3562474854542975d+02,
     3      -.3233872644710534d+02, .3242853198939199d+02,
     4      -.2295184438916914d+02, .2115212649067757d+02,
     5       .1881626264366220d-04,-.1701112641674189d-04,
     6       .1118245745934422d-04, .1581933449027737d-04,
     7      -.7918452524186657d-03, .1396156073051692d-02,
     8      -.6163807887879602d-02, .8639636709070964d-02/
         data arr1014/
     1      -.5436451585677583d-01, .6813223343498766d-01,
     2       .7530918921680012d+00,-.4473025051606574d+01,
     3       .1116043825232808d+02,-.2219548814794676d+02,
     4       .3229684917923716d+02,-.4409813729915125d+02,
     5       .4359997458628342d+02,-.4923947481407879d+02,
     6       .3676046657385184d+02,-.3657294609195052d+02,
     7       .1000000000008922d+01,-.7499999999687551d+00,
     8       .4592793265864079d+00,-.2567449469807819d+00/
         data arr1015/
     1       .1361595679552193d+00,-.6976100945642486d-01,
     2       .3488049300420239d-01,-.1712588610865929d-01,
     3       .8290951979894318d-02,-.3968589781081031d-02,
     4       .1883390737712085d-02,-.8903581731076911d-03,
     5       .4302172035215533d-03,-.2222117834527435d-03,
     6       .1412323703172532d-03,-.9736560249808629d-04,
     7       .9401587356480957d-04,-.6840775712389445d-04,
     8       .6980263993463587d-04,-.3314845347565174d-10/
         data arr1016/
     1       .9999999998897501d+00,-.1224744870729775d+01,
     2       .1026979788463275d+01,-.7261843673446532d+00,
     3       .4650734307923493d+00,-.2790440215223585d+00,
     4       .1598421935056639d+00,-.8843776130041454d-01,
     5       .4762695262092981d-01,-.2510047948982897d-01,
     6       .1299242797327475d-01,-.6640458671810402d-02,
     7       .3367915343921922d-02,-.1752028687501100d-02,
     8       .9168198165483688d-03,-.5794605672395674d-03/
         data arr1017/
     1       .3357421976991471d-03,-.2833625110959529d-03,
     2      -.8559133761851388d-09,-.3367208325667088d-08,
     3       .1000000019241926d+01,-.1677051159078415d+01,
     4       .1778781472777059d+01,-.1518924725100005d+01,
     5       .1139194517190823d+01,-.7830755664078354d+00,
     6       .5054802987279801d+00,-.3111545818594901d+00,
     7       .1844026104752998d+00,-.1057399928164141d+00,
     8       .5807837012154255d-01,-.2991492761452135d-01/
         data arr1018/
     1       .1266646007664089d-01,-.3806811284705530d-02,
     2      -.2522505644544753d-02, .3687915489594303d-02,
     3      -.5519987835410312d-02, .1768049089108033d-08,
     4       .9738814092182724d-08,-.5107036429639747d-07,
     5       .1000000359195489d+01,-.2121321092114022d+01,
     6       .2717135700382497d+01,-.2717138010588838d+01,
     7       .2334671603784358d+01,-.1808448140195467d+01,
     8       .1298669921222683d+01,-.8801088556709101d+00/
         data arr1019/
     1       .5698495432379781d+00,-.3546653329016282d+00,
     2       .2126916162146751d+00,-.1206062738197590d+00,
     3       .6453606516994734d-01,-.2781374177888825d-01,
     4       .8950975462341821d-02, .3885309185486963d-02,
     5       .1155041445789653d-07, .2580350159129360d-07,
     6      -.1797313231092154d-06, .2425552709718024d-05,
     7       .9999971717979825d+00,-.2561724113112455d+01,
     8       .3842589927105454d+01,-.4402125962767888d+01/
         data arr1020/
     1       .4262337352962387d+01,-.3672345726468965d+01,
     2       .2904410323545062d+01,-.2151408037674526d+01,
     3       .1522445554749093d+01,-.1039360045176409d+01,
     4       .7054335076832637d+00,-.4557143005214336d+00,
     5       .3158618782764311d+00,-.1849204236794396d+00,
     6       .1329456727620108d+00,-.4900411520021519d-07,
     7      -.1242895709051564d-06, .8256066728363110d-06,
     8      -.1042313503376135d-04, .1284358894771705d-04/
         data arr1021/
     1       .9999403993016276d+00,-.2999923297073438d+01,
     2       .5154822940004787d+01,-.6654990196509512d+01,
     3       .7166331804838251d+01,-.6798396737469944d+01,
     4       .5858252109858419d+01,-.4706742404817033d+01,
     5       .3555994211484725d+01,-.2609312738065572d+01,
     6       .1768832936897662d+01,-.1265015733859688d+01,
     7       .7493840886018533d+00,-.5470635635632132d+00,
     8       .2692250033129677d-06, .7767813804911043d-06/
         data arr1022/
     1      -.4925989448101345d-05, .5703840956471103d-04,
     2      -.7578431846865958d-04, .3351583169448501d-03,
     3       .9995399846468350d+00,-.3433759869980340d+01,
     4       .6652035717448699d+01,-.9544674846061133d+01,
     5       .1133711307250797d+02,-.1175374807661742d+02,
     6       .1115985017728237d+02,-.9775126366937108d+01,
     7       .8325996620613662d+01,-.6323310726615211d+01,
     8       .5175719345657937d+01,-.3327026994495641d+01/
         data arr1023/
     1       .2695223577454402d+01,-.6261327372775392d-06,
     2      -.1749147471464454d-05, .1125182758167286d-04,
     3      -.1335199543274272d-03, .1734994797176499d-03,
     4      -.7782246973488188d-03, .1049754164933718d-02,
     5       .9925928764353917d+00,-.3864852806633261d+01,
     6       .8311405611822224d+01,-.1315755909926711d+02,
     7       .1691703607349663d+02,-.1907393693855048d+02,
     8       .1901113922252019d+02,-.1787853850657456d+02/
         data arr1024/
     1       .1445156670056213d+02,-.1230066137121496d+02,
     2       .8033386549800962d+01,-.6469889110107145d+01,
     3       .1708249661924869d-05, .5031363967398901d-05,
     4      -.3169592122298050d-04, .3600787624407822d-03,
     5      -.4867315226884867d-03, .2127802046294226d-02,
     6      -.2962680857503898d-02, .2006047748875000d-01,
     7       .9771531936164950d+00,-.4221558680432022d+01,
     8       .1013398957914772d+02,-.1723031110589775d+02/
         data arr1025/
     1       .2446658515012599d+02,-.2893000519883881d+02,
     2       .3181051038185860d+02,-.2834374147621689d+02,
     3       .2703540869700177d+02,-.1876480763267911d+02,
     4       .1632246461248888d+02,-.3911740287441174d-05,
     5      -.1255993325357308d-04, .7657929234852589d-04,
     6      -.8133199148576962d-03, .1168211503719416d-02,
     7      -.4916574130790631d-02, .7178962815494446d-02,
     8      -.4563191250290568d-01, .5497336904557843d-01/
         data arr1026/
     1       .7997999935531572d+00,-.4509086999329905d+01,
     2       .1123090122722433d+02,-.2196931854188702d+02,
     3       .3180258915811819d+02,-.4258776840981871d+02,
     4       .4200901213238306d+02,-.4636447755755229d+02,
     5       .3453681618090512d+02,-.3337494618201909d+02,
     6       .9999999999445592d+00,-.9682458365517300d+00,
     7       .7261843765475356d+00,-.4803258156096749d+00,
     8       .2941382847639910d+00,-.1708788974678338d+00/
         data arr1027/
     1       .9552414187128631d-01,-.5185143050512808d-01,
     2       .2749810717343580d-01,-.1431029371463285d-01,
     3       .7330827254948945d-02,-.3709485342557018d-02,
     4       .1859435942212885d-02,-.9367517004637612d-03,
     5       .4686804152999086d-03,-.2563690301921029d-03,
     6       .1317759820103501d-03,-.8929223495810572d-04,
     7      -.2887194034852199d-08, .1000000000316711d+01,
     8      -.1500000047508936d+01, .1488235210778643d+01/
         data arr1028/
     1      -.1215139221011306d+01, .8824153825634614d+00,
     2      -.5919457821217506d+00, .3748693142767214d+00,
     3      -.2272198257590883d+00, .1329537814668868d+00,
     4      -.7538050356464544d-01, .4099419673448831d-01,
     5      -.2085211018398875d-01, .8787461671772927d-02,
     6      -.2541280321694244d-02,-.1553305628756756d-02,
     7       .2383829146912578d-02,-.3330746987221134d-02,
     8       .6991295574365602d-09,-.2164830119771432d-08/
         data arr1029/
     1       .1000000024567729d+01,-.1984313597883523d+01,
     2       .2430278050290858d+01,-.2353107054527242d+01,
     3       .1973141913490168d+01,-.1499462844445680d+01,
     4       .1060289870722676d+01,-.7094685338619311d+00,
     5       .4543477734932116d+00,-.2805607534804758d+00,
     6       .1675867628658432d+00,-.9658718116306170d-01,
     7       .5306748534560159d-01,-.2713459682721715d-01,
     8       .1189818867113896d-01,-.3686096451274993d-02/
         data arr1030/
     1       .9450243509629115d-07, .5025045820939272d-08,
     2       .1453127713099962d-05, .9999975036855039d+00,
     3      -.2449480214907794d+01, .3557550374743300d+01,
     4      -.3977358673651407d+01, .3778144904119114d+01,
     5      -.3205463339851756d+01, .2504061312226115d+01,
     6      -.1838492815768456d+01, .1297831833630489d+01,
     7      -.8929204693006787d+00, .6219012707000322d+00,
     8      -.4160874543355605d+00, .3072470147167408d+00/
         data arr1031/
     1      -.1911346724951550d+00, .1481617511053192d+00,
     2      -.2681892610887706d-06,-.1418333878544824d-07,
     3      -.4089618489999020d-05, .6781411683303501d-05,
     4       .9999734683811909d+00,-.2904704968018589d+01,
     5       .4871064275554091d+01,-.6169544195633689d+01,
     6       .6542742741978891d+01,-.6128808125620238d+01,
     7       .5227481135158730d+01,-.4160329152204804d+01,
     8       .3119224673621348d+01,-.2264160855078419d+01/
         data arr1032/
     1       .1524884268207973d+01,-.1069804469042068d+01,
     2       .6320236687549416d+00,-.4490817499483749d+00,
     3       .1189137832126627d-05, .2029544451079432d-07,
     4       .1836845144902431d-04,-.3170194397179517d-04,
     5       .1213929081715071d-03, .9998444129573255d+00,
     6      -.3352620603452190d+01, .6370582227094834d+01,
     7      -.9005230136663103d+01, .1055023446318018d+02,
     8      -.1079797578010022d+02, .1005781501703089d+02/
         data arr1033/
     1      -.8622115334817803d+01, .7071066776832306d+01,
     2      -.5219221822177371d+01, .4017457710326579d+01,
     3      -.2511310723470516d+01, .1898806908357205d+01,
     4      -.3863124066976744d-05,-.3014186877084729d-07,
     5      -.5999280607751532d-04, .1055119900115848d-03,
     6      -.3993502676683322d-03, .5206594756910758d-03,
     7       .9951550939501544d+00,-.3794137365471733d+01,
     8       .8039027314404557d+01,-.1256131473204731d+02/
         data arr1034/
     1       .1599934739573938d+02,-.1786711223953468d+02,
     2       .1771673887310809d+02,-.1653254706870600d+02,
     3       .1335834679821527d+02,-.1128164078772893d+02,
     4       .7443049783913661d+01,-.5955338955324098d+01,
     5       .9448350870096385d-05, .1021170731311947d-06,
     6       .1470461449303846d-03,-.2613460112947700d-03,
     7       .9813018915711008d-03,-.1287593363950499d-02,
     8       .1187991492705267d-01, .9862999218023566d+00/
         data arr1035/
     1      -.4190351971326225d+01, .9869762258051919d+01,
     2      -.1659894003897725d+02, .2315455868743982d+02,
     3      -.2710700435010889d+02, .2921221851504387d+02,
     4      -.2589810150937655d+02, .2407811795449060d+02,
     5      -.1674468560362500d+02, .1414054993650859d+02,
     6      -.2075483804229547d-04, .2752574592346713d-06,
     7      -.3276308467841717d-03, .6083340954579936d-03,
     8      -.2226916815861113d-02, .3035268145203242d-02/
         data arr1036/
     1      -.2655957810156578d-01, .3200933950430395d-01,
     2       .8817702905778149d+00,-.4550805465357850d+01,
     3       .1125551455045165d+02,-.2137723709256300d+02,
     4       .3072398898482955d+02,-.3998084904946698d+02,
     5       .3940199092486248d+02,-.4196221736138864d+02,
     6       .3132835791530231d+02,-.2906205623909036d+02,
     7       .1000000000460406d+01,-.1145643935040596d+01,
     8       .9921567571855829d+00,-.7441175813578084d+00/
         data arr1037/
     1       .5094625344886683d+00,-.3272090751032262d+00,
     2       .2003744313477087d+00,-.1182432520886342d+00,
     3       .6770078460075610d-01,-.3771793546236222d-01,
     4       .2030076267160700d-01,-.1033907863606488d-01,
     5       .4591891062791427d-02,-.1589051823057809d-02,
     6      -.2267758108681171d-03, .7508354926294426d-03,
     7      -.1136813145608887d-02,-.1172783749050246d-08,
     8       .1000000014329965d+01,-.1732050847679580d+01/
         data arr1038/
     1       .1948557245708745d+01,-.1778781403827724d+01,
     2       .1428055068948567d+01,-.1049403923769335d+01,
     3       .7224638793091216d+00,-.4729725836400114d+00,
     4       .2974238072646950d+00,-.1807370780228392d+00,
     5       .1062972930611310d+00,-.6004912822400454d-01,
     6       .3216767025318866d-01,-.1546942797583633d-01,
     7       .6150010262647099d-02,-.1026716118509112d-02,
     8      -.2281188377220187d-07, .7014067609041890d-06/
         data arr1039/
     1       .9999992347747141d+00,-.2249998966072938d+01,
     2       .3080936234617849d+01,-.3297896828090594d+01,
     3       .3029303554765866d+01,-.2502467266102915d+01,
     4       .1912428983295670d+01,-.1378315244731585d+01,
     5       .9556569155753573d+00,-.6463170112840130d+00,
     6       .4397720242437450d+00,-.2891933823488020d+00,
     7       .2073284917658533d+00,-.1293242913802684d+00,
     8       .9765776632784239d-01, .9201755541188905d-07/
         data arr1040/
     1      -.2803862338652400d-05, .3089121671775692d-05,
     2       .9999957180645191d+00,-.2738599806913468d+01,
     3       .4397057007613971d+01,-.5385301887879949d+01,
     4       .5560684938205680d+01,-.5096266352545775d+01,
     5       .4269717337277248d+01,-.3349321348443949d+01,
     6       .2488561844143856d+01,-.1800367032467891d+01,
     7       .1218679049813082d+01,-.8706369553746205d+00,
     8       .5350895542911598d+00,-.3946401945602735d+00/
         data arr1041/
     1      -.3322873356415361d-06, .1046232418023865d-04,
     2      -.1113691831169424d-04, .1497204085866428d-04,
     3       .9999537412690812d+00,-.3210538682118015d+01,
     4       .5898738208514804d+01,-.8120174501475367d+01,
     5       .9306359124759854d+01,-.9357872525801659d+01,
     6       .8575599946972325d+01,-.7263237853564583d+01,
     7       .5866276530153001d+01,-.4302788203929109d+01,
     8       .3251479876760211d+01,-.2050178662088594d+01/
         data arr1042/
     1       .1506136101770837d+01, .9997576737816852d-06,
     2      -.3185017949989760d-04, .3347230545745667d-04,
     3      -.4415299366750433d-04, .1377155527687822d-03,
     4       .9976658013753578d+00,-.3671799810695162d+01,
     5       .7579877051792743d+01,-.1158200384415701d+02,
     6       .1450878733744929d+02,-.1590936047431803d+02,
     7       .1556044567694719d+02,-.1417392633629081d+02,
     8       .1132422968307280d+02,-.9206494049335806d+01/
         data arr1043/
     1       .6049357802705280d+01,-.4563071805667250d+01,
     2      -.1999461345947766d-05, .6460274776401891d-04,
     3      -.6687067775371540d-04, .8599974711244392d-04,
     4      -.2710657012946823d-03, .4713743175919501d-02,
     5       .9951498173820414d+00,-.4113310772722283d+01,
     6       .9366247046430146d+01,-.1532942143643145d+02,
     7       .2052138187483437d+02,-.2320941474933675d+02,
     8       .2366779273089484d+02,-.2036653473865912d+02/
         data arr1044/
     1       .1761307804621718d+02,-.1196990405012137d+02,
     2       .9226750997402515d+01, .6519693260970764d-05,
     3      -.1900829364749253d-03, .2188479664291722d-03,
     4      -.3087610000775058d-03, .9240041733909900d-03,
     5      -.1419279135930846d-01, .1599992377127107d-01,
     6       .9457324279620419d+00,-.4518247299905672d+01,
     7       .1102303533089853d+02,-.2025813705289314d+02,
     8       .2877326360217334d+02,-.3620365241649557d+02/
         data arr1045/
     1       .3552503220323061d+02,-.3643664198468667d+02,
     2       .2745423594769268d+02,-.2430484043955541d+02,
     3       .1000000000545745d+01,-.1299038113092383d+01,
     4       .1257788244824819d+01,-.1042902915257589d+01,
     5       .7821773153489470d+00,-.5461259953891516d+00,
     6       .3612290253320594d+00,-.2289719818332774d+00,
     7       .1401971347217072d+00,-.8333081928196799d-01,
     8       .4813359411385271d-01,-.2688019684440589d-01/
         data arr1046/
     1       .1430912127628467d-01,-.7041847717012311d-02,
     2       .2953195942232343d-02,-.8272227084735096d-03,
     3       .1377950077067949d-06, .9999996031379995d+00,
     4      -.1936492187037422d+01, .2408481532369687d+01,
     5      -.2408460831447152d+01, .2102015290570976d+01,
     6      -.1668384804019920d+01, .1234796305523249d+01,
     7      -.8678233613899563d+00, .5908273838933887d+00,
     8      -.3963991204237420d+00, .2699208917200534d+00/
         data arr1047/
     1      -.1799567707315720d+00, .1304188370420736d+00,
     2      -.8399752267842865d-01, .6297455976255047d-01,
     3      -.5171147305520778d-06, .1486399267056102d-05,
     4       .1000001876141944d+01,-.2487470011940259d+01,
     5       .3731126436397469d+01,-.4341864801899053d+01,
     6       .4307680834823188d+01,-.3822623859834804d+01,
     7       .3119632037151814d+01,-.2391332707451810d+01,
     8       .1742588216316109d+01,-.1232368772247140d+01/
         data arr1048/
     1       .8211144690738152d+00,-.5671478162617675d+00,
     2       .3466902306399542d+00,-.2443958492114940d+00,
     3       .1532158639963706d-05,-.4118510991134780d-05,
     4      -.5899984832960995d-05, .1000004017982888d+01,
     5      -.2999775084607837d+01, .5236351527846004d+01,
     6      -.6926745274246331d+01, .7677063101239441d+01,
     7      -.7488980818107400d+01, .6630858488213046d+01,
     8      -.5404119077992201d+01, .4130954212606576d+01/
         data arr1049/
     1      -.2880962660586773d+01, .1990506836578482d+01,
     2      -.1188073882153267d+01, .7810734974937620d+00,
     3      -.7395803048695310d-05, .2057514102646166d-04,
     4       .2822999753618350d-04,-.2144000072323750d-04,
     5       .9989140339822974d+00,-.3489877750830990d+01,
     6       .6924388124489221d+01,-.1024228685389541d+02,
     7       .1250723490021308d+02,-.1339662951280296d+02,
     8       .1287752597344550d+02,-.1149286476741375d+02/
         data arr1050/
     1       .9095976097365957d+01,-.7226721346325109d+01,
     2       .4782401321773838d+01,-.3507193058021476d+01,
     3       .1556862917548960d-04,-.4222634635560878d-04,
     4      -.6201116556638235d-04, .4829442558918454d-04,
     5       .2271409710029945d-02, .9976022242385602d+00,
     6      -.3962581112020587d+01, .8722033164073920d+01,
     7      -.1392481792479364d+02, .1819050159841262d+02,
     8      -.2024032728274814d+02, .2020698514209752d+02/
         data arr1051/
     1      -.1725405898446492d+02, .1455777256169096d+02,
     2      -.9961144930496886d+01, .7422021575030751d+01,
     3      -.4337990644311685d-04, .1266573911923275d-03,
     4       .1607308122631945d-03,-.1360369053422675d-03,
     5      -.6388894795441648d-02, .7249993141363568d-02,
     6       .9822400057843635d+00,-.4416315093529298d+01,
     7       .1053684176907035d+02,-.1865236342715918d+02,
     8       .2597705380350948d+02,-.3149048668000114d+02/
         data arr1052/
     1       .3060836705694378d+02,-.2998889442594731d+02,
     2       .2262544514828159d+02,-.1891809905182862d+02,
     3       .9999998973030558d+00,-.1436141499839421d+01,
     4       .1523257728493064d+01,-.1373037660513817d+01,
     5       .1112286540889134d+01,-.8342180667809612d+00,
     6       .5905305123777751d+00,-.4008879332349195d+00,
     7       .2662703669230613d+00,-.1767109271384353d+00,
     8       .1206054464784177d+00,-.8182731363180580d-01/
         data arr1053/
     1       .6066284982602867d-01,-.4101625304108053d-01,
     2       .3102044668875953d-01, .4855380267220932d-06,
     3       .1000003929898463d+01,-.2121322799627613d+01,
     4       .2868161527829404d+01,-.3097972987382054d+01,
     5       .2904369739520416d+01,-.2464398060334577d+01,
     6       .1939828367561397d+01,-.1443929041341836d+01,
     7       .1030093560428260d+01,-.7179578947029703d+00,
     8       .4772725234011913d+00,-.3314966811506689d+00/
         data arr1054/
     1       .2105335814022445d+00,-.1502447961234877d+00,
     2      -.7634535631037029d-06,-.8093786343498711d-05,
     3       .1000003934751335d+01,-.2704090543198123d+01,
     4       .4381190271975499d+01,-.5476552344933676d+01,
     5       .5800373378911772d+01,-.5445906685580858d+01,
     6       .4650405419257602d+01,-.3656858249372998d+01,
     7       .2674961862818017d+01,-.1790151992397820d+01,
     8       .1149311493322474d+01,-.6492614017949387d+00/
         data arr1055/
     1       .3739131030128036d+00, .5085611787493828d-05,
     2       .4949544840572281d-04,-.2661394866395880d-04,
     3       .9995518290627879d+00,-.3240005834591606d+01,
     4       .6075650526914179d+01,-.8591859749067119d+01,
     5       .1012067521896522d+02,-.1047706520125013d+02,
     6       .9764038154664220d+01,-.8373089761693205d+01,
     7       .6430000157772064d+01,-.4804895326918819d+01,
     8       .3084936861645553d+01,-.2048780306187679d+01/
         data arr1056/
     1      -.8040772651266111d-05,-.8726434384566351d-04,
     2       .4323278847191841d-04, .7737021097873085d-03,
     3       .9994326384085773d+00,-.3750039598645465d+01,
     4       .7828945741269235d+01,-.1190719347553784d+02,
     5       .1472178886617310d+02,-.1551422926402498d+02,
     6       .1445561366417253d+02,-.1169919977698050d+02,
     7       .8966329711610303d+01,-.5781811188629720d+01,
     8       .3735765645647184d+01, .4932491122585065d-04/
         data arr1057/
     1       .4115326814724628d-03,-.2554282640892447d-03,
     2      -.3817073238311926d-02, .3552744524605168d-02,
     3       .9989933137784911d+00,-.4237857697719638d+01,
     4       .9782954027007547d+01,-.1669508929317057d+02,
     5       .2273880016481832d+02,-.2670375883030972d+02,
     6       .2567569665652643d+02,-.2438649696567975d+02,
     7       .1863244524753413d+02,-.1496931038582250d+02,
     8       .1000001736367612d+01,-.1561251367101152d+01/
         data arr1058/
     1       .1788623230494999d+01,-.1731825943301007d+01,
     2       .1499840103583584d+01,-.1197519839436497d+01,
     3       .8982615972756220d+00,-.6431525324687467d+00,
     4       .4456851931290008d+00,-.3042457370092934d+00,
     5       .2007193221450406d+00,-.1393826479141594d+00,
     6       .9170807286101441d-01,-.6618481894113315d-01,
     7      -.1526913077106709d-05, .1000000720937584d+01,
     8      -.2291276868858699d+01, .3327789455823531d+01/
         data arr1059/
     1      -.3842630568433365d+01, .3825081750828510d+01,
     2      -.3406160810387648d+01, .2762094084507177d+01,
     3      -.2053317602372101d+01, .1400073159854278d+01,
     4      -.8651587337023615d+00, .4876376418476366d+00,
     5      -.2376762894357017d+00, .1035600552996282d+00,
     6       .2574712483564122d-04,-.2081615964837236d-04,
     7       .9998145714059957d+00,-.2904593166618741d+01,
     8       .5031549217568659d+01,-.6695265633298299d+01/
         data arr1060/
     1       .7515413802590308d+01,-.7465876890465735d+01,
     2       .6718541149030077d+01,-.5560851917090047d+01,
     3       .4157722627683331d+01,-.2977379340427398d+01,
     4       .1874638656792146d+01,-.1161688822996973d+01,
     5      -.6772100590213628d-04, .5272504435214953d-04,
     6       .4853338377559317d-03, .9996406279682162d+00,
     7      -.3465173855292975d+01, .6835758791029373d+01,
     8      -.9999072736632733d+01, .1204252426175059d+02/
         data arr1061/
     1      -.1251753143536441d+02, .1157337733974411d+02,
     2      -.9389167856350433d+01, .7195302759780132d+01,
     3      -.4743949918199875d+01, .3024589529909004d+01,
     4       .2443971347245179d-03,-.2283235947551989d-03,
     5      -.1769891111032570d-02, .1587377736284715d-02,
     6       .1003624900246389d+01,-.3994083395118381d+01,
     7       .8794361402481130d+01,-.1425907139832494d+02,
     8       .1863561795085929d+02,-.2082679340559696d+02/
         data arr1062/
     1       .1946594705764065d+02,-.1740218731429924d+02,
     2       .1302283458566063d+02,-.9624046572355127d+01,
     3       .9999948603482941d+00,-.1677082464995666d+01,
     4       .2053988693284173d+01,-.2117056601514078d+01,
     5       .1930029581971565d+01,-.1580676199092211d+01,
     6       .1154466904600999d+01,-.7297857734180195d+00,
     7       .3676398156774374d+00,-.1172630536031103d+00,
     8      -.5060038931800189d-01, .1192295715660110d+00/
         data arr1063/
     1      -.1353808337605071d+00,-.3918029099060949d-05,
     2       .9999447587626176d+00,-.2449467946898415d+01,
     3       .3787531708237623d+01,-.4638563178823126d+01,
     4       .4880715844968069d+01,-.4585616959797078d+01,
     5       .3916501439007715d+01,-.3061854453578034d+01,
     6       .2167261117354841d+01,-.1422249713933416d+01,
     7       .8208292053515781d+00,-.4245033731815090d+00,
     8       .2071453693031488d-04, .2243054789999876d-03/
         data arr1064/
     1       .9998843330389279d+00,-.3093202295522192d+01,
     2       .5599883929339023d+01,-.7642380272117353d+01,
     3       .8657615559801805d+01,-.8517910492592653d+01,
     4       .7454156286608493d+01,-.5775581235708066d+01,
     5       .4157306651928557d+01,-.2624744108404771d+01,
     6       .1515769094438662d+01,-.2024553945928968d-03,
     7      -.1462047570152467d-02, .1145554525630843d-02,
     8       .1005488515922532d+01,-.3677494588868724d+01/
         data arr1065/
     1       .7631615931678968d+01,-.1184453673423412d+02,
     2       .1507840078149538d+02,-.1651057019914611d+02,
     3       .1532867565780633d+02,-.1364553063942150d+02,
     4       .1055370462598210d+02,-.7777295173435000d+01,
     5       .1000057481503153d+01,-.1785420507481686d+01,
     6       .2319020412002704d+01,-.2527093127767599d+01,
     7       .2432805067809496d+01,-.2104002220091419d+01,
     8       .1630161158728260d+01,-.1111682021849487d+01/
         data arr1066/
     1       .6549254485437291d+00,-.2687078891946933d+00,
     2       .4945661441499998d-02, .1423119934776167d+00,
     3       .1227554785018713d-03, .9999760324350049d+00,
     4      -.2598587094227458d+01, .4211689565448911d+01,
     5      -.5343682607220193d+01, .5767909728445340d+01,
     6      -.5500812654140213d+01, .4709398444439381d+01,
     7      -.3604456616721532d+01, .2533991842682678d+01,
     8      -.1563677807444897d+01, .8198608700961921d+00/
         data arr1067/
     1      -.9556261629155489d-03, .5888276279962554d-03,
     2       .1003878910072930d+01,-.3271561103741463d+01,
     3       .6235323788875372d+01,-.9017489733560881d+01,
     4       .1084356369918768d+02,-.1127258561513866d+02,
     5       .1009148105159442d+02,-.8558863115587934d+01,
     6       .6513645119715487d+01,-.4526847849492440d+01,
     7       .9997763901171169d+00,-.1888800850971240d+01,
     8       .2725543315607291d+01,-.3436108930156859d+01/
         data arr1068/
     1       .3955527874681818d+01,-.4203063607658910d+01,
     2       .4083353036492329d+01,-.3539839125090185d+01,
     3       .2932949889368318d+01,-.2247876814334020d+01,
     4       .1507029681388470d+01, .4519412224478792d-03,
     5       .1002606963543738d+01,-.2740356747134406d+01,
     6       .4672399777731371d+01,-.6278963421460567d+01,
     7       .7217161371765582d+01,-.7290954887210682d+01,
     8       .6443626239659024d+01,-.5421149541116662d+01/
         data arr1069/
     1       .4218644049986928d+01,-.2877714302291328d+01,
     2       .1005931358003480d+01,-.1987664590874533d+01,
     3       .2994637166363976d+01,-.4001668636003366d+01,
     4       .4934146277481040d+01,-.5473140622178822d+01,
     5       .5274569779051951d+01,-.5076047312970418d+01,
     6       .4784857973476499d+01,-.3788518453661860d+01/
        do 1200 i=1,1101
        arr(i)=arr1001(i)
 1200 continue
c
	do 1300 i=1,11
        imap(i)=iimap(i)
 1300   continue
c
        return
        end
c
c
c
c 
c

        subroutine lol9get(arr,imap)
        implicit real *8 (a-h,o-z)
        integer imap(1)
        integer iimap(17)
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260( 4)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2)
         real *8
     1  arr2257(2),arr2258(2),arr2259(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2))
C
C
c
         data iimap/1,541,1034,1482,1887,2251,2576,2864,3117,3337,
     1           3526,3686,3819,3927,4012,4076,4121/
         data arr1001/
     1       .1000000000000000d+01,-.4330127018922197d+00,
     2       .1874999999999949d+00,-.8118988160479446d-01,
     3       .3515625000000771d-01,-.1522310280094859d-01,
     4       .6591796875168554d-02,-.2854331775738040d-02,
     5       .1235961915064734d-02,-.5351872115623637d-03,
     6       .2317428680198976d-03,-.1003476251018514d-03,
     7       .4345183025012266d-04,-.1881529174063754d-04,
     8       .8147473584733026d-05,-.3528400167621420d-05/
         data arr1002/
     1       .1528676256969707d-05,-.6636560563856935d-06,
     2       .2909234178780481d-06,-.1299080020489923d-06,
     3       .5954147448554398d-07,-.1880189273772732d-07,
     4      -.7761987878807014d-08, .6087982728740635d-07,
     5      -.1034757035237688d-06, .1867346697884184d-06,
     6      -.1771638135174452d-06, .2596013519399611d-06,
     7      -.1992723644357563d-06, .2274811594597297d-06,
     8      -.1350202945979694d-14, .1000000000000035d+01/
         data arr1003/
     1      -.8660254037844346d+00, .5624999999999983d+00,
     2      -.3247595264191390d+00, .1757812499979877d+00,
     3      -.9133861680493924d-01, .4614257811016382d-01,
     4      -.2283465419809836d-01, .1112365710346830d-01,
     5      -.5351872055677170d-02, .2549170814496011d-02,
     6      -.1204171096841892d-02, .5648697692468239d-03,
     7      -.2634118377668368d-03, .1221942456067131d-03,
     8      -.5644294982868908d-04, .2591254039183238d-04/
         data arr1004/
     1      -.1189622825862808d-04, .5265095326834254d-05,
     2      -.2449732412083323d-05, .5957868823467267d-06,
     3      -.4535134589382053d-06,-.8988022008641393d-06,
     4      -.7644510840624293d-07,-.2294940430012978d-05,
     5      -.7481082548411217d-07,-.2892901594851800d-05,
     6      -.1492856300960079d-06,-.3858956741236080d-05,
     7       .2216175477890238d-15, .2001438419394463d-13,
     8       .9999999999999496d+00,-.1299038105676658d+01/
         data arr1005/
     1       .1125000000000001d+01,-.8118988160479907d+00,
     2       .5273437500005560d+00,-.3196851588204248d+00,
     3       .1845703125046328d+00,-.1027559439173444d+00,
     4       .5561828616377254d-01,-.2943529649765553d-01,
     5       .1529502885210283d-01,-.7827113252646220d-02,
     6       .3954113374877529d-02,-.1975594995669636d-02,
     7       .9776687538756129d-03,-.4797933902371185d-03,
     8       .2337369087392783d-03,-.1131323909001740d-03/
         data arr1006/
     1       .5445527327099144d-04,-.2608047983275638d-04,
     2       .1245103153003766d-04,-.5887665445175503d-05,
     3       .2760056119281850d-05,-.1179377353787976d-05,
     4       .4890027405293229d-06,-.2380372134082017d-07,
     5      -.8537149111578607d-07, .2327534306022543d-06,
     6       .4200096143639089d-13,-.1306492781027581d-11,
     7       .1145633418312701d-12, .9999999999998342d+00,
     8      -.1732050807569476d+01, .1875000000076517d+01/
         data arr1007/
     1      -.1623797632109337d+01, .1230468750561668d+01,
     2      -.8524937569512261d+00, .5537109421782007d+00,
     3      -.3425198137093785d+00, .2039337397624046d+00,
     4      -.1177411893770747d+00, .6627858813356383d-01,
     5      -.3652654547729408d-01, .1977108689769308d-01,
     6      -.1053657597645456d-01, .5542240295898409d-02,
     7      -.2879031243597497d-02, .1486896471152808d-02,
     8      -.7550113712023564d-03, .4010204384392884d-03/
         data arr1008/
     1      -.1927687001639797d-03, .1380966272448792d-03,
     2      -.4796572865981772d-04, .1132121450735869d-03,
     3      -.9660929671134982d-05, .1176812013964667d-03,
     4       .1908257100466601d-05, .1501457246028341d-03,
     5       .3656759213117354d-12,-.8289578213186583d-12,
     6       .2306227516237555d-11, .8804400351644599d-12,
     7       .9999999999872715d+00,-.2165063509432261d+01,
     8       .2812499999794329d+01,-.2841645855771247d+01/
         data arr1009/
     1       .2460937498469566d+01,-.1918110950402583d+01,
     2       .1384277332915444d+01,-.9419294690783881d+00,
     3       .6118010912252847d+00,-.3826587716774457d+00,
     4       .2319743135708657d+00,-.1369740738901369d+00,
     5       .7908106325905141d-01,-.4477852502605899d-01,
     6       .2492592723442423d-01,-.1366941891161153d-01,
     7       .7392712642332038d-02,-.3960682406595333d-02,
     8       .2097516069372032d-02,-.1140435509455366d-02/
         data arr1010/
     1       .6239280045905960d-03,-.4224743996627962d-03,
     2       .2511912574783982d-03,-.2566963940952685d-03,
     3       .1509746315443594d-03,-.1826231822225443d-03,
     4      -.7413300532522182d-12, .6522094409025154d-11,
     5      -.2655203129853414d-11,-.3897386507799224d-11,
     6       .2862418794025631d-10, .9999999997030427d+00,
     7      -.2598076210925729d+01, .3937499997496215d+01,
     8      -.4546633366666307d+01, .4429687480591763d+01/
         data arr1011/
     1      -.3836221883299432d+01, .3045410049619815d+01,
     2      -.2260630648187727d+01, .1590682418636384d+01,
     3      -.1071444187937925d+01, .6959213968519911d+00,
     4      -.4383158242218989d+00, .2688698978594686d+00,
     5      -.1611984545912208d+00, .9470339860843989d-01,
     6      -.5466545628787551d-01, .3099537201466580d-01,
     7      -.1735550519500583d-01, .9474740771815808d-02,
     8      -.5210912991360912d-02, .2609400923170351d-02/
         data arr1012/
     1      -.1497035681827982d-02, .5714112675430157d-03,
     2      -.4508010763507296d-03,-.9503682980574876d-04,
     3       .1565045757201254d-13, .4215094390139349d-12,
     4       .1140820420001580d-10, .1474317296469751d-12,
     5      -.1608950147821220d-10, .1686093868069847d-10,
     6       .9999999996157298d+00,-.3031088912853210d+01,
     7       .5249999997299057d+01,-.6819950052222018d+01,
     8       .7382812479537908d+01,-.7033073476562334d+01/
         data arr1013/
     1       .6090820211842432d+01,-.4898033239805456d+01,
     2       .3711593092625368d+01,-.2678611546022436d+01,
     3       .1855794696762150d+01,-.1241900189464830d+01,
     4       .8066297494536301d+00,-.5104819682608733d+00,
     5       .3157389832547711d+00,-.1913557828682168d+00,
     6       .1137640649516593d+00,-.6647031307190560d-01,
     7       .3798104860566123d-01,-.2131259626156635d-01,
     8       .1132697833009538d-01,-.5964267314722625d-02/
         data arr1014/
     1       .2606168985629671d-02,-.1220387391258648d-02,
     2       .5182342684002511d-11, .1003476635718554d-09,
     3      -.6839280104209417d-10, .5661451742478853d-10,
     4       .1717911427515381d-09,-.6759960771529794d-08,
     5       .4184971883274332d-08, .9999999490006937d+00,
     6      -.3464101587141164d+01, .6749999580278122d+01,
     7      -.9742785578863696d+01, .1160156032813240d+02,
     8      -.1205669638617184d+02, .1131151168111357d+02/
         data arr1015/
     1      -.9796061152580192d+01, .7953367344556833d+01,
     2      -.6122520365899812d+01, .4506742088280642d+01,
     3      -.3193375588144622d+01, .2188842243877848d+01,
     4      -.1458282429022992d+01, .9454736945637504d+00,
     5      -.6007519449993908d+00, .3700690677805221d+00,
     6      -.2267319403000448d+00, .1277865631657043d+00,
     7      -.7661570680449051d-01, .3377986752193544d-01,
     8      -.2073057800458095d-01,-.2478366480224537d-02/
         data arr1016/
     1      -.8664066775441516d-11, .4830888781211421d-10,
     2       .1141193542130743d-09,-.9004880982282091d-10,
     3      -.2074017952140339d-09,-.1448843366514345d-08,
     4      -.7413919791429457d-08,-.1396467664491748d-07,
     5       .9999999689589649d+00,-.3897114426913185d+01,
     6       .8437499674708612d+01,-.1339633111551831d+02,
     7       .1740234262359368d+02,-.1959213688343126d+02,
     8       .1979515882802446d+02,-.1836764164369480d+02/
         data arr1017/
     1       .1590681029496173d+02,-.1301047333985117d+02,
     2       .1014049457028758d+02,-.7584566575968331d+01,
     3       .5472704897884268d+01,-.3827296986422862d+01,
     4       .2599178024430005d+01,-.1721355763698212d+01,
     5       .1104367201204312d+01,-.6926729116036602d+00,
     6       .4060253090747767d+00,-.2363686690514601d+00,
     7       .1117770691010401d+00,-.5553776494840687d-01,
     8      -.1951507096790889d-09, .4844257177510446d-08/
         data arr1018/
     1      -.1439045056792743d-08,-.4417984164558879d-09,
     2       .8488219674978754d-08,-.2703391004380494d-06,
     3       .1444105304332224d-06,-.2008521772930933d-05,
     4       .9368021512568094d-06, .9999834485483691d+00,
     5      -.4330119821767468d+01, .1031241468696405d+02,
     6      -.1786173969675027d+02, .2513625679550204d+02,
     7      -.3047646870510887d+02, .3299008131016021d+02,
     8      -.3265285724341212d+02, .3003868693494027d+02/
         data arr1019/
     1      -.2601797037953684d+02, .2138437940856172d+02,
     2      -.1684573861437183d+02, .1269900327793220d+02,
     3      -.9330288972661663d+01, .6488615399602226d+01,
     4      -.4542102508885313d+01, .2741538602080525d+01,
     5      -.1899734619968511d+01, .8061847470026141d+00,
     6      -.6154018596416447d+00,-.1801635156958607d+00,
     7      -.2944082289157376d-09, .1264169222797461d-08,
     8       .1714664941619575d-08,-.3296718784613437d-09/
         data arr1020/
     1      -.1258478416431446d-08,-.4973569796136974d-07,
     2      -.1046659338190981d-06,-.4932685417918255d-06,
     3      -.1856865247545295d-06,-.3741205606152998d-05,
     4       .9999960139002683d+00,-.4763162269755938d+01,
     5       .1237499382485608d+02,-.2322042848468454d+02,
     6       .3519133998127474d+02,-.4571555336627203d+02,
     7       .5278710051862084d+02,-.5551351988386763d+02,
     8       .5408235222486116d+02,-.4944382976906429d+02/
         data arr1021/
     1       .4279682046814201d+02,-.3535930787006107d+02,
     2       .2794653677107798d+02,-.2129856955841555d+02,
     3       .1547528333591661d+02,-.1089888171344279d+02,
     4       .7008769324824182d+01,-.4477167219088449d+01,
     5       .2252780884371766d+01,-.1196391155692373d+01,
     6      -.3094625043828679d-08,-.1338067978497275d-07,
     7      -.2653782609590530d-07,-.2008272240795689d-07,
     8       .1433270147765213d-06, .1042973657147531d-05/
         data arr1022/
     1       .2509536919654941d-05, .6120435320771628d-05,
     2       .1621652853932660d-04, .5876312487003774d-04,
     3       .1249499632431626d-03, .1000270415126701d+01,
     4      -.5195560429609625d+01, .1462657789301171d+02,
     5      -.2954995092810005d+02, .4799412356811695d+02,
     6      -.6648250559580717d+02, .8160496973271283d+02,
     7      -.9078763245259111d+02, .9348691512339305d+02,
     8      -.8974056208692059d+02, .8194205003683788d+02/
         data arr1023/
     1      -.7026695004678436d+02, .5900470541711433d+02,
     2      -.4560657042892359d+02, .3661876231369638d+02,
     3      -.2395375123537890d+02, .1916023417747961d+02,
     4      -.9265571880688354d+01, .8653770061043035d+01,
     5       .2035729169836950d-07,-.5065584816728261d-07,
     6       .1420205379923750d-06, .1090519118910276d-06,
     7      -.8814388701828620d-06, .1318261815793435d-05,
     8      -.1447716433514172d-04, .1965224083002863d-04/
         data arr1024/
     1      -.9984942346229611d-04, .1162148997496838d-03,
     2      -.7378117996579390d-03, .8035736232875915d-03,
     3       .9963440811803727d+00,-.5625385252687368d+01,
     4       .1704336116356395d+02,-.3692253227349666d+02,
     5       .6390872622803376d+02,-.9412849578312108d+02,
     6       .1220697483862589d+03,-.1435731980695073d+03,
     7       .1548654018775759d+03,-.1568198978878322d+03,
     8       .1477705070692600d+03,-.1347945149802944d+03/
         data arr1025/
     1       .1134527637516698d+03,-.9626406073885605d+02,
     2       .6892532060709267d+02,-.5578798614890292d+02,
     3       .3125315851859385d+02,-.2447739316126160d+02,
     4      -.5517911334128984d-07,-.9457601519302927d-07,
     5      -.3889642632698446d-06,-.3066768870954715d-06,
     6       .2336346323708991d-05, .1004852644065752d-04,
     7       .3874323606555693d-04, .4409162258719695d-04,
     8       .2677863782637407d-03, .5062998504591192d-03/
         data arr1026/
     1       .1975756330462833d-02, .1979357922786940d-02,
     2       .9803161291541667d-02, .1012517040156144d+01,
     3      -.6010898585617381d+01, .1972686493464706d+02,
     4      -.4526341415986178d+02, .8384580701494959d+02,
     5      -.1296171838385167d+03, .1792317250656003d+03,
     6      -.2187494595606415d+03, .2528193753015175d+03,
     7      -.2587353477377388d+03, .2669090193225385d+03,
     8      -.2339983351310906d+03, .2305333070429953d+03/
         data arr1027/
     1      -.1593073424675217d+03, .1579420040035617d+03,
     2      -.7811582950884986d+02, .9228583057348833d+02,
     3       .1972218797073394d-06,-.5038692880866402d-06,
     4       .1283758446633185d-05, .9174159110749808d-06,
     5      -.7931711982319017d-05, .1411636416801394d-04,
     6      -.1289280765573674d-03, .2018936027751980d-03,
     7      -.9121371396986776d-03, .1228366190215583d-02,
     8      -.6630509321485309d-02, .8355819370833840d-02/
         data arr1028/
     1      -.3342423581062492d-01, .3998194010161836d-01,
     2       .8264478993167326d+00,-.6297102937929637d+01,
     3       .2180339058784066d+02,-.5444084138379767d+02,
     4       .1048193215521323d+03,-.1742911706850153d+03,
     5       .2476778171487966d+03,-.3259262064357299d+03,
     6       .3755132340404433d+03,-.4254850613773048d+03,
     7       .4162561097270363d+03,-.4266456432262012d+03,
     8       .3327051879497046d+03,-.3196844521825338d+03/
         data arr1029/
     1       .1902475969282344d+03,-.1743020535148454d+03,
     2      -.3721946240909698d-06, .4508176436440828d-06,
     3      -.2486440440114532d-05,-.1844226351156899d-05,
     4       .1552129011581812d-04, .2792636482001678d-05,
     5       .2511979389818180d-03,-.1798990674848692d-03,
     6       .1785073354919583d-02,-.5796088615403429d-03,
     7       .1294074093289388d-01,-.7183062281868715d-02,
     8       .6542650662434572d-01,-.2796567974769914d-01/
         data arr1030/
     1       .3392352267578957d+00, .8108218646962743d+00,
     2      -.5563104142194721d+01, .2480552423699396d+02,
     3      -.6079113321917899d+02, .1329552773610417d+03,
     4      -.2188431575772753d+03, .3483397257815158d+03,
     5      -.4363434513751729d+03, .5770810331533944d+03,
     6      -.5879606061822282d+03, .6999119246571121d+03,
     7      -.5335849090258702d+03, .6000974245588436d+03,
     8      -.3348713927741363d+03, .3886307793233146d+03/
         data arr1031/
     1       .8282318986795760d-06,-.2171769389520582d-05,
     2       .4889656012064013d-05, .3734734321162919d-05,
     3      -.3197020265103222d-04, .6269101607540724d-04,
     4      -.5066398571348526d-03, .8658233087839246d-03,
     5      -.3643013434270670d-02, .5348855865807488d-02,
     6      -.2618612312606173d-01, .3605729350127283d-01,
     7      -.1335578504306486d+00, .1741638106277581d+00,
     8      -.6896829443094664d+00, .8594553047502697d+00/
         data arr1032/
     1      -.1797030765670890d+01,-.4000351316084252d+01,
     2       .1755652497545849d+02,-.6605435419464865d+02,
     3       .1358358975662205d+03,-.2739431286820893d+03,
     4       .3922804098212291d+03,-.6038214880387191d+03,
     5       .6851729102140118d+03,-.8881206366749044d+03,
     6       .7375532097714762d+03,-.8586487493260646d+03,
     7       .5366877555206845d+03,-.5719211579261937d+03,
     8      -.1421815084559776d-05, .1238149155423058d-04/
         data arr1033/
     1      -.7755632605103007d-05,-.4997018590564952d-05,
     2       .5258733229699430d-04,-.6204083979047821d-03,
     3       .8201133482585016d-03,-.5146736145439101d-02,
     4       .5985849645673670d-02,-.4016484464440313d-01,
     5       .4264690813221687d-01,-.2186063930571009d+00,
     6       .2196536750652612d+00,-.1158921802172673d+01,
     7       .1129394658772479d+01,-.4896190290384267d+01,
     8       .4620161278627367d+01,-.1876660312339090d+02/
         data arr1034/
     1       .1063130484827740d+02,-.3322279496018119d+02,
     2      -.3323519996121027d+02, .1048602764874398d+02,
     3      -.2237206703337710d+03, .1824177437651945d+03,
     4      -.5742514216561809d+03, .2740893036213692d+03,
     5      -.7623122060607632d+03, .2252962779265355d+03,
     6      -.6643265795609304d+03,-.2789055815888526d+03,
     7       .9999999999999973d+00,-.7499999999999912d+00,
     8       .4592793267719465d+00,-.2567449488305682d+00/
         data arr1035/
     1       .1361595707664284d+00,-.6976102089749631d-01,
     2       .3488051045840489d-01,-.1712599065317662d-01,
     3       .8291084649613778d-02,-.3969054578334936d-02,
     4       .1882688286865640d-02,-.8862461086234963d-03,
     5       .4145058102014381d-03,-.1927986485223775d-03,
     6       .8925711822383865d-04,-.4114336372253547d-04,
     7       .1893202038939744d-04,-.8657962087237677d-05,
     8       .4063433690157633d-05,-.1821313852585613d-05/
         data arr1036/
     1       .1162805008031817d-05,-.4127919991599425d-06,
     2       .8921367518243182d-06,-.7869832031319606d-07,
     3       .1517609357787256d-05, .6313338258854874d-07,
     4       .1822127309876242d-05, .1622548386772485d-06,
     5       .2468779268590840d-05,-.3467185197392280d-15,
     6       .9999999999999948d+00,-.1224744871391616d+01,
     7       .1026979795322580d+01,-.7261843774149584d+00,
     8       .4650734726540992d+00,-.2790440835988566d+00/
         data arr1037/
     1       .1598425794465167d+00,-.8843823549863231d-01,
     2       .4762865500198078d-01,-.2510250554137277d-01,
     3       .1299827632562603d-01,-.6632059911382820d-02,
     4       .3341842203384860d-02,-.1665976439217936d-02,
     5       .8228573367942557d-03,-.4031407131032447d-03,
     6       .1961765131521252d-03,-.9485701683808474d-04,
     7       .4571106385947727d-04,-.2161385076615882d-04,
     8       .1008221817112952d-04,-.3417688712769849d-05/
         data arr1038/
     1       .3435584907415039d-06, .3043577078060295d-05,
     2      -.2979729294726700d-05, .5396454116861476d-05,
     3      -.3631351226925599d-05, .4871700652522679d-05,
     4      -.1573739502115938d-12, .2217888435056995d-12,
     5       .1000000000003086d+01,-.1677050983125107d+01,
     6       .1778781183887951d+01,-.1518923601190235d+01,
     7       .1139192701203766d+01,-.7830655174611431d+00,
     8       .5054666204846079d+00,-.3111090700783977d+00/
         data arr1039/
     1       .1844649992821760d+00,-.1061304712766360d+00,
     2       .5956564838074710d-01,-.3274316601968966d-01,
     3       .1768360826369881d-01,-.9405720906928382d-02,
     4       .4938116246709749d-02,-.2561421582037200d-02,
     5       .1318803948519997d-02,-.6693596696853104d-03,
     6       .3486566460933006d-03,-.1694644666988916d-03,
     7       .1082632860029831d-03,-.4172156740731424d-04,
     8       .7285366721742233d-04,-.9479241954949569d-05/
         data arr1040/
     1       .7148875062248044d-04,-.1127773187229452d-05,
     2       .9015613812332213d-04, .4888720971128579d-12,
     3      -.2142747647960582d-12, .1215045292916660d-11,
     4       .9999999999856973d+00,-.2121320343526584d+01,
     5       .2717133139719670d+01,-.2717133139585236d+01,
     6       .2334650302545175d+01,-.1808412347083355d+01,
     7       .1298567244756915d+01,-.8799493185991542d+00,
     8       .5695558260219983d+00,-.3551804225060737d+00/
         data arr1041/
     1       .2147665085886740d+00,-.1265312710496835d+00,
     2       .7290924470461620d-01,-.4121242695086352d-01,
     3       .2290571250669260d-01,-.1254446751998226d-01,
     4       .6776720844321574d-02,-.3627566929756735d-02,
     5       .1921312513449832d-02,-.1045777640034185d-02,
     6       .5752335579523409d-03,-.3906348738578976d-03,
     7       .2351708180967860d-03,-.2381685437025016d-03,
     8       .1414752406648102d-03,-.1671373326971420d-03/
         data arr1042/
     1       .1642573587529858d-11, .2412089098278087d-11,
     2      -.3750715604721027d-10, .3326788561696863d-10,
     3       .9999999995336358d+00,-.2561737691128833d+01,
     4       .3842606533789672d+01,-.4402258828386231d+01,
     5       .4262468757953025d+01,-.3672902827229871d+01,
     6       .2903684512919924d+01,-.2147929617326081d+01,
     7       .1506902441483296d+01,-.1012419713710565d+01,
     8       .6561201170938337d+00,-.4124406950941891d+00/
         data arr1043/
     1       .2525556081828320d+00,-.1511875577972533d+00,
     2       .8868666889624160d-01,-.5114033132418742d-01,
     3       .2892344843108940d-01,-.1621022796221295d-01,
     4       .8745046439349775d-02,-.4864366474974255d-02,
     5       .2206734766671589d-02,-.1392044953980041d-02,
     6       .2289788849618448d-03,-.4055868891165881d-03,
     7      -.4976846433509885d-03, .1789432775147875d-12,
     8       .2217587799867973d-11,-.6640300557502683d-11/
         data arr1044/
     1       .2147211690806341d-10,-.5670684478255469d-10,
     2       .9999999999712891d+00,-.3000000000296808d+01,
     3       .5155397656820010d+01,-.6655589757647725d+01,
     4       .7168772304680517d+01,-.6800894565001063d+01,
     5       .5869261307662774d+01,-.4705878251075815d+01,
     6       .3556875231996431d+01,-.2561243166065457d+01,
     7       .1771011873885557d+01,-.1183112467372692d+01,
     8       .7672651878716500d+00,-.4848994180163472d+00/
         data arr1045/
     1       .2995496735869956d+00,-.1813266839386391d+00,
     2       .1076864956736797d+00,-.6279345497175989d-01,
     3       .3579930715114966d-01,-.1991469941455149d-01,
     4       .1051836073629092d-01,-.5333475038066086d-02,
     5       .2269395587963563d-02,-.8874506926151063d-03,
     6       .3562654256602889d-10, .2263906755570179d-10,
     7      -.5194264020949722d-09, .1655011007412757d-09,
     8      -.7016029427406510d-08, .3867193727956378d-08/
         data arr1046/
     1       .9999999486301441d+00,-.3436931750289022d+01,
     2       .6655589355254291d+01,-.9558362902909764d+01,
     3       .1133482218161426d+02,-.1173852182836975d+02,
     4       .1098037119220274d+02,-.9484996353817769d+01,
     5       .7683683058586188d+01,-.5903356610616608d+01,
     6       .4337888607071923d+01,-.3068997745176177d+01,
     7       .2100658825705937d+01,-.1397828686051935d+01,
     8       .9051792797998571d+00,-.5746793019812840d+00/
         data arr1047/
     1       .3534673319123584d+00,-.2166000958605260d+00,
     2       .1213763748232109d+00,-.7314658245766831d-01,
     3       .3136087500469550d-01,-.1976324056700924d-01,
     4      -.3666211933586729d-02, .7909051073148672d-11,
     5      -.1419166164540043d-09,-.2427349784146486d-10,
     6      -.2684716440246279d-09,-.1022592372722880d-08,
     7      -.1225947312460406d-07,-.7040042542280511d-08,
     8       .9999999500774150d+00,-.3872983405154974d+01/
         data arr1048/
     1       .8343222800646362d+01,-.1319179463997246d+02,
     2       .1707703567679365d+02,-.1916892908150024d+02,
     3       .1931809225356047d+02,-.1788509750159286d+02,
     4       .1545862189350748d+02,-.1262198312861400d+02,
     5       .9822456260450609d+01,-.7336490697936084d+01,
     6       .5287046938402760d+01,-.3693490467209251d+01,
     7       .2505978855676759d+01,-.1659128354294830d+01,
     8       .1064560533558000d+01,-.6694435142364795d+00/
         data arr1049/
     1       .3932226560102758d+00,-.2315011667477038d+00,
     2       .1104460766976895d+00,-.5705092050222427d-01,
     3       .1156319442848855d-08, .1287623333098537d-08,
     4      -.1730224694993915d-07, .7269198524486169d-08,
     5      -.2282567287165019d-06, .1434326079802886d-06,
     6      -.1670296046264356d-05, .7642068673895713d-06,
     7       .9999870572854427d+00,-.4308415757618937d+01,
     8       .1021825280282775d+02,-.1763706015217647d+02/
         data arr1050/
     1       .2474661479903642d+02,-.2992732107532891d+02,
     2       .3232389396218905d+02,-.3193068069841232d+02,
     3       .2932471853202079d+02,-.2535950240504381d+02,
     4       .2081802987755486d+02,-.1637687592284995d+02,
     5       .1234227172278974d+02,-.9052267027085637d+01,
     6       .6311512810011711d+01,-.4399811515917351d+01,
     7       .2698441325859424d+01,-.1837191145358841d+01,
     8       .8341256638326954d+00,-.5932537191937204d+00/
         data arr1051/
     1      -.1050119143193556d+00, .3839680115870976d-09,
     2      -.1991498512279035d-08,-.2508933478683237d-08,
     3      -.8029052620385615d-08,-.1831338543623518d-07,
     4      -.3325653741615281d-06,-.1008276097052015d-06,
     5      -.1429355827717776d-05,-.1066575915810102d-05,
     6       .9999864255706481d+00,-.4743421669253108d+01,
     7       .1228083785790619d+02,-.2297548080632006d+02,
     8       .3473104631917320d+02,-.4501715082332976d+02/
         data arr1052/
     1       .5187845601302755d+02,-.5446293781814737d+02,
     2       .5297435341613775d+02,-.4836266446385368d+02,
     3       .4180462327956027d+02,-.3450591740526037d+02,
     4       .2724446291829163d+02,-.2077516304955768d+02,
     5       .1510283071156272d+02,-.1070270410315622d+02,
     6       .6897689216194065d+01,-.4501952075116829d+01,
     7       .2291654399817875d+01,-.1307632838839863d+01,
     8      -.1425724280830771d-07, .2237601694524276d-07/
         data arr1053/
     1       .1212789294559872d-06, .1472557572040463d-06,
     2       .1634763379368133d-05, .2833632026123168d-05,
     3       .1086670333123634d-04, .1550719981824109d-04,
     4       .9131907447758790d-04, .1244415292081879d-03,
     5       .1000440608721757d+01,-.5177502522776885d+01,
     6       .1453345309235249d+02,-.2928491010556376d+02,
     7       .4746166139299439d+02,-.6561101532040001d+02,
     8       .8041180700389098d+02,-.8930301275514095d+02/
         data arr1054/
     1       .9188114642746588d+02,-.8803688583846782d+02,
     2       .8045709690172288d+02,-.6877706317965306d+02,
     3       .5807530879361936d+02,-.4457017052408217d+02,
     4       .3662139050816899d+02,-.2340174465151259d+02,
     5       .1983936880803347d+02,-.9096860778943990d+01,
     6       .1000012287546483d+02, .2006903146897980d-07,
     7      -.1072070037874120d-06, .1315559076688049d-06,
     8      -.9091014394877140d-06, .1712354494656752d-05/
         data arr1055/
     1      -.1511815851064424d-04, .1802822078419132d-04,
     2      -.8922143793242858d-04, .1078863038095561d-03,
     3      -.6829359222043398d-03, .7299096179756217d-03,
     4       .9966972891408241d+00,-.5609025682023257d+01,
     5       .1695082842678568d+02,-.3663877763867828d+02,
     6       .6329656113231942d+02,-.9306210767292106d+02,
     7       .1205106708364874d+03,-.1415366594544549d+03,
     8       .1525023553116177d+03,-.1542240461871930d+03/
         data arr1056/
     1       .1452109486862719d+03,-.1322632291565134d+03,
     2       .1112822850604495d+03,-.9420848504228583d+02,
     3       .6747868871806932d+02,-.5444272867856921d+02,
     4       .3058840327134992d+02,-.2382221489156498d+02,
     5      -.1275070401624493d-06, .2767740864534664d-06,
     6       .5095058328555848d-06, .2544252771273168d-05,
     7       .6633575562954960d-05, .4213371261215556d-04,
     8       .3082368098101064d-04, .2507355931842121d-03/
         data arr1057/
     1       .3413292991703506d-03, .1910792680955882d-02,
     2       .1225867363047462d-02, .9281588372234239d-02,
     3       .1008244728785107d+01,-.5997168208545319d+01,
     4       .1961648239420199d+02,-.4496502340748348d+02,
     5       .8307301038126937d+02,-.1283342970842600d+03,
     6       .1770005895425808d+03,-.2160177584774792d+03,
     7       .2487830005586423d+03,-.2549703677787681d+03,
     8       .2616006392810557d+03,-.2303990502897259d+03/
         data arr1058/
     1       .2244399541818200d+03,-.1569352051749234d+03,
     2       .1526253015903094d+03,-.7740532029032336d+02,
     3       .8746515537009616d+02, .1766506538425696d-06,
     4      -.9352490362452451d-06, .1389506965347456d-05,
     5      -.8376487396458317d-05, .1740335285545365d-04,
     6      -.1307524008388824d-03, .1799638986845483d-03,
     7      -.7979181187416102d-03, .1100129756147649d-02,
     8      -.5983129393220977d-02, .7348987174002815d-02/
         data arr1059/
     1      -.2948622036121816d-01, .3536588144222138d-01,
     2       .8438166092830660d+00,-.6304570672603116d+01,
     3       .2178113988896732d+02,-.5419651877680877d+02,
     4       .1042667241356675d+03,-.1729789043267656d+03,
     5       .2457056588893596d+03,-.3224752047686026d+03,
     6       .3714404044794348d+03,-.4192587058817826d+03,
     7       .4101133967449348d+03,-.4177620782666937d+03,
     8       .3261514188571172d+03,-.3108157827679857d+03/
         data arr1060/
     1       .1855872091965873d+03,-.1679917386808436d+03,
     2      -.4209698460805707d-06, .1791664374303025d-05,
     3      -.2261070656615893d-05, .1731316599776379d-04,
     4      -.2928309204010842d-04, .2678319004274027d-03,
     5      -.3272742409839720d-03, .1650560264548365d-02,
     6      -.1914156135686352d-02, .1230856321575909d-01,
     7      -.1343389050523603d-01, .6097295328305466d-01,
     8      -.6340525525856244d-01, .3221063537202535d+00/
         data arr1061/
     1       .6727834751809298d+00,-.5620526726928531d+01,
     2       .2413641200936873d+02,-.6066137031666239d+02,
     3       .1303059631189258d+03,-.2176580183291891d+03,
     4       .3397368887896266d+03,-.4331715269836012d+03,
     5       .5589579256691609d+03,-.5838346393799343d+03,
     6       .6653309817743867d+03,-.5303834323713830d+03,
     7       .5592029342852073d+03,-.3346741657450266d+03,
     8       .3382974742552993d+03, .7403507820589313d-06/
         data arr1062/
     1      -.3450982361409537d-05, .5916966728760209d-05,
     2      -.3472674534686622d-04, .7695973133811502d-04,
     3      -.5198786737123001d-03, .7857369964008106d-03,
     4      -.3248653822439156d-02, .4861346007791486d-02,
     5      -.2400089690591027d-01, .3223013347638282d-01,
     6      -.1198763307615106d+00, .1564238415576718d+00,
     7      -.6306341740964335d+00, .7762067388271979d+00,
     8      -.1550647945906517d+01,-.4298702045591023d+01/
         data arr1063/
     1       .1830900060876560d+02,-.6674168413384095d+02,
     2       .1372941667219675d+03,-.2742534798447722d+03,
     3       .3935894397543780d+03,-.6019238494026483d+03,
     4       .6849751793146876d+03,-.8814460925453897d+03,
     5       .7351035908538963d+03,-.8490077929937786d+03,
     6       .5339075291883327d+03,-.5622147289682744d+03,
     7       .1916876171070835d-05, .5141667740583088d-05,
     8      -.4826697652885830d-04, .5452263460138608d-04/
         data arr1064/
     1      -.6406457318230885d-03, .7924395757368124d-03,
     2      -.4963239542562001d-02, .5038386815346223d-02,
     3      -.3709168159958040d-01, .3683120601222557d-01,
     4      -.2011103264386998d+00, .1857314367147155d+00,
     5      -.1070798420888522d+01, .9725554310077593d+00,
     6      -.4530773644358145d+01, .3964346706552696d+01,
     7      -.1742937406269013d+02, .8224492075675796d+01,
     8      -.2895364011209559d+02,-.4023802481026587d+02/
         data arr1065/
     1       .1972270839007297d+02,-.2368087109587202d+03,
     2       .1927587246614532d+03,-.5854914066659267d+03,
     3       .2676573860616226d+03,-.7615654253256287d+03,
     4       .1974818858563731d+03,-.6498760936327418d+03,
     5      -.3254007320675963d+03, .9999999999999810d+00,
     6      -.9682458365515210d+00, .7261843774136839d+00,
     7      -.4803258171545109d+00, .2941382905781504d+00,
     8      -.1708789051330666d+00, .9552421194512566d-01/
         data arr1066/
     1      -.5185151165048774d-01, .2749841658606372d-01,
     2      -.1431062966776183d-01, .7332015676272055d-02,
     3      -.3707432757227054d-02, .1853715197299853d-02,
     4      -.9179011240736666d-03, .4506757125837932d-03,
     5      -.2196277259555066d-03, .1063079219359456d-03,
     6      -.5115701778050599d-04, .2447375036633866d-04,
     7      -.1174416510992929d-04, .5668622374982935d-05,
     8      -.3077202444439318d-05, .1850170040822470d-05/
         data arr1067/
     1      -.1749613337763589d-05, .1282544041779483d-05,
     2      -.1653625347748393d-05, .1076656765428328d-05,
     3      -.1308065560857735d-05, .1173839870042472d-11,
     4       .9999999999991180d+00,-.1499999999999143d+01,
     5       .1488235112502097d+01,-.1215138880955192d+01,
     6       .8824148719131971d+00,-.5919418913039092d+00,
     7       .3748640786511604d+00,-.2272019409093414d+00,
     8       .1330196031857219d+00,-.7572473638183622d-01/
         data arr1068/
     1       .4211928382879813d-01,-.2297413148769637d-01,
     2       .1232432220645233d-01,-.6516502616233573d-02,
     3       .3403637501191455d-02,-.1757240862131255d-02,
     4       .9018746354824076d-03,-.4558971081112108d-03,
     5       .2397760598849792d-03,-.1151834826172749d-03,
     6       .7993360823659367d-04,-.2788319463163568d-04,
     7       .6439921204847923d-04,-.4730881401543293d-05,
     8       .6690133808215524d-04, .2192086223203119d-05/
         data arr1069/
     1       .9042216908243999d-04, .4631851790517310d-11,
     2      -.3262715509936614d-11, .9999999999991113d+00,
     3      -.1984313483293208d+01, .2430277761841316d+01,
     4      -.2353106324508410d+01, .1973139637121304d+01,
     5      -.1499456306394151d+01, .1060275719256791d+01,
     6      -.7094378266721798d+00, .4543483894650818d+00,
     7      -.2807948040762343d+00, .1684767913155719d+00,
     8      -.9859248157213266d-01, .5647556688860640d-01/
         data arr1070/
     1      -.3175671835814659d-01, .1756896912734008d-01,
     2      -.9582150214965397d-02, .5158544909040918d-02,
     3      -.2751356316662868d-02, .1453504452197334d-02,
     4      -.7828493682068861d-03, .4260475364328843d-03,
     5      -.2743881980321483d-03, .1619455963192201d-03,
     6      -.1511669638737466d-03, .8939511395836561d-04,
     7      -.1007824063200368d-03, .7517595542725738d-11,
     8      -.1117402153808149d-10, .1759003319487380d-10/
         data arr1071/
     1       .9999999996397351d+00,-.2449489742612619d+01,
     2       .3557562365428133d+01,-.3977475643008883d+01,
     3       .3778274729967310d+01,-.3205972429067954d+01,
     4       .2502661312323824d+01,-.1831760554763393d+01,
     5       .1273564919154391d+01,-.8490434769625337d+00,
     6       .5465431059636450d+00,-.3415336590401667d+00,
     7       .2080410626693089d+00,-.1239626897125209d+00,
     8       .7240302705409504d-01,-.4160142132324639d-01/
         data arr1072/
     1       .2341152842984680d-01,-.1310680697350447d-01,
     2       .6965789304472919d-02,-.3924732983567120d-02,
     3       .1563065912118123d-02,-.1134599033253776d-02,
     4      -.9062124832776959d-04,-.3436529504925971d-03,
     5      -.8198583546702854d-03, .5573275691164362d-10,
     6      -.6033019613724725d-10, .5967703147816717d-10,
     7      -.6405736878344003d-10, .1000000000348858d+01,
     8      -.2904737510557129d+01, .4871392899037332d+01/
         data arr1073/
     1      -.6169896840494237d+01, .6544163857922529d+01,
     2      -.6130243551613471d+01, .5234692070211262d+01,
     3      -.4159448199183842d+01, .3119586632770778d+01,
     4      -.2231266499125647d+01, .1533744193550382d+01,
     5      -.1019258825556406d+01, .6579361737152672d+00,
     6      -.4140725688974062d+00, .2548462623534808d+00,
     7      -.1537152235067073d+00, .9099435489377473d-01,
     8      -.5277970112770745d-01, .2991059874857955d-01/
         data arr1074/
     1      -.1628707792611088d-01, .8464923483722899d-02,
     2      -.3871627080940924d-02, .1506314448382135d-02,
     3      -.1950216561066299d-03, .1027656673037313d-09,
     4      -.1270127093023329d-09, .1528888046222391d-09,
     5      -.3393762901850072d-08, .1374197357160276d-08,
     6       .9999999800856159d+00,-.3354101959434897d+01,
     7       .6372241840557762d+01,-.9011711057926528d+01,
     8       .1055214604545752d+02,-.1081273288225459d+02/
         data arr1075/
     1       .1002366536495003d+02,-.8591716798011472d+01,
     2       .6913295940305155d+01,-.5280130225029635d+01,
     3       .3859713327796887d+01,-.2717978206569420d+01,
     4       .1852752191450925d+01,-.1228206786649265d+01,
     5       .7929283781302586d+00,-.5017789915445420d+00,
     6       .3082958859497371d+00,-.1881579662683209d+00,
     7       .1059798089546163d+00,-.6318250819663415d-01,
     8       .2785485873502791d-01,-.1679564744080579d-01/
         data arr1076/
     1      -.2524647166993971d-02, .2001719942262870d-09,
     2      -.1440107962559569d-09, .3318859673495259d-11,
     3      -.9572654279201136d-09,-.4796458360357197d-08,
     4      -.5097832885259963d-08, .9999999814243671d+00,
     5      -.3799671084677174d+01, .8060319213476237d+01,
     6      -.1258417001593810d+02, .1611867005555832d+02,
     7      -.1793089120215523d+02, .1793088288112309d+02,
     8      -.1648924542315896d+02, .1416807591498972d+02/
         data arr1077/
     1      -.1150783159195317d+02, .8913785035113044d+01,
     2      -.6629956411851951d+01, .4759973487319090d+01,
     3      -.3313722188220243d+01, .2241381752058477d+01,
     4      -.1479084884118703d+01, .9464768910872833d+00,
     5      -.5925191217163139d+00, .3473056464243473d+00,
     6      -.2026026033507713d+00, .9656314346258393d-01,
     7      -.4862315600453258d-01,-.3925082678675961d-09,
     8      -.1284947440924489d-08, .4010251631392515d-08/
         data arr1078/
     1      -.8009914680725287d-07, .7589226820132887d-07,
     2      -.5287592028753234d-06, .4516013302902887d-06,
     3       .9999947357217008d+00,-.4242636396399820d+01,
     4       .9935702988826630d+01,-.1696847068727418d+02,
     5       .2359515077785477d+02,-.2831425986438761d+02,
     6       .3037683668743228d+02,-.2982967927158305d+02,
     7       .2725461877949197d+02,-.2345759187511392d+02,
     8       .1918373269885587d+02,-.1502886140722809d+02/
         data arr1079/
     1       .1130935114794173d+02,-.8253947293816582d+01,
     2       .5786198928824234d+01,-.3993168491920518d+01,
     3       .2543668706200219d+01,-.1664932476592985d+01,
     4       .8828184705968716d+00,-.5420134567318218d+00,
     5       .6796472939627231d-01, .1434836313455068d-08,
     6       .2847897997629209d-08,-.1332440813052857d-07,
     7      -.4379398719123791d-08,-.2476188808737508d-06,
     8       .1250394774889638d-06,-.1340723039880695d-05/
         data arr1080/
     1       .3243687152398530d-06, .9999863084833018d+00,
     2      -.4683743668547136d+01, .1199847351685606d+02,
     3      -.2224586442568467d+02, .3336843763295869d+02,
     4      -.4296022414616998d+02, .4921582577579019d+02,
     5      -.5139725369883176d+02, .4975889726488993d+02,
     6      -.4523614256755044d+02, .3895443725165169d+02,
     7      -.3204660668880236d+02, .2523011471495430d+02,
     8      -.1920507463524895d+02, .1395008159384812d+02/
         data arr1081/
     1      -.9913036103143904d+01, .6401245197905920d+01,
     2      -.4236248640940660d+01, .2183389180559920d+01,
     3      -.1304911169307504d+01,-.1197236936827838d-07,
     4      -.1483865406216252d-07, .8849565478687721d-07,
     5       .1020262724194133d-05, .1576341662279564d-05,
     6       .4542676831485081d-05, .9488384647606990d-05,
     7       .5859241416743055d-04, .8821611109569147d-04,
     8       .1000265313385771d+01,-.5123049659300589d+01/
         data arr1082/
     1       .1425052979205127d+02,-.2849500270078466d+02,
     2       .4586770855373149d+02,-.6303858723015207d+02,
     3       .7684563305983013d+02,-.8495793667231460d+02,
     4       .8701831415245458d+02,-.8309331838975025d+02,
     5       .7562256200643652d+02,-.6450432029042223d+02,
     6       .5421565655997104d+02,-.4162182744617667d+02,
     7       .3401761969320474d+02,-.2183160180090184d+02,
     8       .1837987181765910d+02,-.8560869369551698d+01/
         data arr1083/
     1       .9381322484613031d+01, .4547727106897562d-07,
     2       .1231366437244096d-06,-.5237415652696642d-06,
     3       .5796044541470199d-06,-.8683575127426416d-05,
     4       .1257964875511518d-04,-.5632301987145701d-04,
     5       .7029813713309734d-04,-.4962110778090352d-03,
     6       .5721846317160973d-03, .9974933955138962d+00,
     7      -.5559399463930910d+01, .1667193054953973d+02,
     8      -.3578963097344047d+02, .6146997351355130d+02/
         data arr1084/
     1      -.8989757949552248d+02, .1158844935267572d+03,
     2      -.1355272019518119d+03, .1455342394741261d+03,
     3      -.1467225730006436d+03, .1378898036378548d+03,
     4      -.1254582251045488d+03, .1056932247765850d+03,
     5      -.8974988835475689d+02, .6454203399277382d+02,
     6      -.5254074685421790d+02, .2990868779832783d+02,
     7      -.2371522772358880d+02,-.1471356665407282d-06,
     8      -.2789676740333518d-06, .1338618577349808d-05/
         data arr1085/
     1       .4849673885907104d-05, .2262907407261197d-04,
     2       .3939283362255069d-05, .1467728269093044d-03,
     3       .2121222594597741d-03, .1292637804089893d-02,
     4       .5079648136346299d-03, .6530619581783264d-02,
     5       .1005202074237620d+01,-.5962185651241757d+01,
     6       .1932276804971382d+02,-.4409447473245435d+02,
     7       .8093250135826197d+02,-.1246160918528539d+03,
     8       .1708928542689720d+03,-.2081996759445182d+03/
         data arr1086/
     1       .2383713651996219d+03,-.2444366310741544d+03,
     2       .2489393518301131d+03,-.2203090846926127d+03,
     3       .2122085938892968d+03,-.1501320791769865d+03,
     4       .1434104100065437d+03,-.7463981160115998d+02,
     5       .8187144735888342d+02, .3747187123470897d-06,
     6       .9859633819858780d-06,-.4201280239669808d-05,
     7       .5421827734030931d-05,-.6861292926065837d-04,
     8       .1086030446032064d-03,-.4551473279552008d-03/
         data arr1087/
     1       .6211062034150907d-03,-.3937008692677145d-02,
     2       .4972642100563919d-02,-.2018338944644640d-01,
     3       .2420342135133554d-01, .8840960040480730d+00,
     4      -.6305918649219109d+01, .2164705234613563d+02,
     5      -.5338830819704881d+02, .1023803037593047d+03,
     6      -.1688570891322027d+03, .2394340927174680d+03,
     7      -.3126968207466311d+03, .3600911445375406d+03,
     8      -.4043765381530977d+03, .3963221254338244d+03/
         data arr1088/
     1      -.4013694962955874d+03, .3147561378589959d+03,
     2      -.2977619252087500d+03, .1796892029858521d+03,
     3      -.1613812333682113d+03,-.7104109541068271d-06,
     4      -.2088977344246517d-05, .8604764767070395d-05,
     5      -.1652616054504861d-04, .1402830669044096d-03,
     6      -.2586232252262817d-03, .9409080490926301d-03,
     7      -.1639174252566777d-02, .8091625898657209d-02,
     8      -.1215031799429766d-01, .4171940018725188d-01/
         data arr1089/
     1      -.6146212106389048d-01, .2388442384603359d+00,
     2       .6805923917962748d+00,-.5886505086365720d+01,
     3       .2383437858944551d+02,-.6066361770661018d+02,
     4       .1276037952831036d+03,-.2151192804093915d+03,
     5       .3295545613503019d+03,-.4256600697112601d+03,
     6       .5370620637185945d+03,-.5717341247542324d+03,
     7       .6277213016239305d+03,-.5183205332861023d+03,
     8       .5170705343186843d+03,-.3274624330108475d+03/
         data arr1090/
     1       .2947971778634272d+03, .1098935045770336d-05,
     2       .3790762019395712d-05,-.1517350862096420d-04,
     3       .2161831455982664d-04,-.2455194957690875d-03,
     4       .4181878647831314d-03,-.1664652653952865d-02,
     5       .2434781095084003d-02,-.1416801611658902d-01,
     6       .1924503808875723d-01,-.7356156455050894d-01,
     7       .9457069909377117d-01,-.4193621664034934d+00,
     8       .5103225055915460d+00,-.7432511785368212d+00/
         data arr1091/
     1      -.5267243292271688d+01, .2086407715817593d+02,
     2      -.6859829918337775d+02, .1408333930785656d+03,
     3      -.2712043724630407d+03, .3900026961395178d+03,
     4      -.5786034937335165d+03, .6594414458409162d+03,
     5      -.8238691760442480d+03, .6920421382446914d+03,
     6      -.7746133376039000d+03, .4918483746557477d+03,
     7      -.5025025679258816d+03,-.1706153016608794d-05,
     8      -.7814162346430016d-05, .2714645302840193d-04/
         data arr1092/
     1      -.3823804087815620d-03, .4281703745972602d-03,
     2      -.2755889414033251d-02, .2981681002204573d-02,
     3      -.2586428238680980d-01, .2498901552324826d-01,
     4      -.1437632070044772d+00, .1316589616995333d+00,
     5      -.8444546161171174d+00, .7447318579717600d+00,
     6      -.3672223515375753d+01, .3129777137612842d+01,
     7      -.1480373649980528d+02, .5517243203611338d+01,
     8      -.2163317631159977d+02,-.4697220535591563d+02/
         data arr1093/
     1       .3339972698784062d+02,-.2482026741239625d+03,
     2       .2129750296150011d+03,-.5993375785774751d+03,
     3       .2785760862822252d+03,-.7734129385297052d+03,
     4       .2009103228868290d+03,-.6601471060337283d+03,
     5      -.3634423673691543d+03, .9999999999998009d+00,
     6      -.1145643923738577d+01, .9921567416507414d+00,
     7      -.7441175562366578d+00, .5094624637447502d+00,
     8      -.3272081918377631d+00, .2003732775962238d+00/
         data arr1094/
     1      -.1182396386875951d+00, .6773026272489253d-01,
     2      -.3786236734002386d-01, .2073807942712708d-01,
     3      -.1116341666409470d-01, .5920323909202582d-02,
     4      -.3099195631751470d-02, .1604122881401781d-02,
     5      -.8217926621307155d-03, .4177074965257441d-03,
     6      -.2101470689803392d-03, .1066130833710426d-03,
     7      -.5217250406794430d-04, .2933509048996214d-04,
     8      -.1269900497225396d-04, .1491155502915644d-04/
         data arr1095/
     1      -.3117899785530375d-05, .1292135245140159d-04,
     2      -.8444547813928520d-06, .1707314703828225d-04,
     3      -.6960677225355745d-12, .1000000000001514d+01,
     4      -.1732050807567995d+01, .1948557158488816d+01,
     5      -.1778781183803287d+01, .1428053625683435d+01,
     6      -.1049400812312339d+01, .7224561242298061d+00,
     7      -.4729585522020527d+00, .2974408444763272d+00,
     8      -.1810167255569099d+00, .1071864618884178d+00/
         data arr1096/
     1      -.6201181505936747d-01, .3516735502938959d-01,
     2      -.1960070817415624d-01, .1075878215010189d-01,
     3      -.5826855656665493d-02, .3117705261976490d-02,
     4      -.1655567941692855d-02, .8737040872844175d-03,
     5      -.4764371190564358d-03, .2678452066539968d-03,
     6      -.1861304097452145d-03, .1181054071889775d-03,
     7      -.1187472767661423d-03, .7456018794844541d-04,
     8      -.8353901833791577d-04,-.1545466627430874d-10/
         data arr1097/
     1       .2155318642029661d-12, .9999999998720143d+00,
     2      -.2249999999951570d+01, .3080939385100000d+01,
     3      -.3297948580866264d+01, .3029359195294014d+01,
     4      -.2502661429585316d+01, .1911439174432977d+01,
     5      -.1373820437689186d+01, .9405900783620629d+00,
     6      -.6188415575239428d+00, .3938263411842814d+00,
     7      -.2436478735046525d+00, .1471066613908769d+00,
     8      -.8696877218629340d-01, .5043538407061331d-01/
         data arr1098/
     1      -.2880141527338257d-01, .1609452253454727d-01,
     2      -.8981825915250190d-02, .4694183303582590d-02,
     3      -.2671065950062197d-02, .8884250968816510d-03,
     4      -.7668769866218031d-03,-.2987030950681424d-03,
     5      -.2259157999311058d-03,-.9450755985420939d-03,
     6       .2603795704820897d-10,-.3177349526961978d-10,
     7      -.1576329184965833d-11, .1000000000233401d+01,
     8      -.2738612788021915d+01, .4397264776266737d+01/
         data arr1099/
     1      -.5385527484191360d+01, .5561469866616940d+01,
     2      -.5097171342294113d+01, .4274108169872016d+01,
     3      -.3344322165522673d+01, .2475367237014153d+01,
     4      -.1750349468600001d+01, .1191172266057868d+01,
     5      -.7846260848008503d+00, .5025091163508917d+00,
     6      -.3140302992749137d+00, .1920474580630075d+00,
     7      -.1151481198294886d+00, .6777819934587652d-01,
     8      -.3903205082074118d-01, .2192639582024668d-01/
         data arr1100/
     1      -.1169134407696959d-01, .5947432789627343d-02,
     2      -.2452842242901740d-02, .8326876113704991d-03,
     3       .1857722750851843d-03,-.1163835529060088d-09,
     4       .2109938093651744d-10,-.5897874313796866d-09,
     5       .6353690324777040d-09, .9999999966800233d+00,
     6      -.3211308144424692d+01, .5899549719194466d+01,
     7      -.8123046614497428d+01, .9306118762978182d+01,
     8      -.9364101565243049d+01, .8548214242293062d+01/
         data arr1101/
     1      -.7231008167024270d+01, .5752224408673619d+01,
     2      -.4349534842027452d+01, .3151500684437734d+01,
     3      -.2201828881374624d+01, .1490530650934908d+01,
     4      -.9817563516360154d+00, .6306762160768983d+00,
     5      -.3967810785001933d+00, .2436494580955522d+00,
     6      -.1474831252625482d+00, .8484967963667460d-01,
     7      -.4913693079162573d-01, .2419058886618219d-01,
     8      -.1289646285398930d-01, .1380894947820188d-02/
         data arr1102/
     1      -.6997920523495749d-10, .4578345194331474d-09,
     2      -.1968297209308416d-09,-.5044495917508551d-08,
     3       .9830417325112684d-09, .9999999919384883d+00,
     4      -.3674234618747956d+01, .7588539627024838d+01,
     5      -.1159168611318103d+02, .1457988556584254d+02,
     6      -.1597146554198636d+02, .1576212418787413d+02,
     7      -.1432994165178503d+02, .1218996939908624d+02,
     8      -.9813882475706734d+01, .7542032125421595d+01/
         data arr1103/
     1      -.5570211929190884d+01, .3973871620285298d+01,
     2      -.2750857432967963d+01, .1851523797013479d+01,
     3      -.1217261608312262d+01, .7772778843392201d+00,
     4      -.4873504291883123d+00, .2865201254437938d+00,
     5      -.1698290953952486d+00, .8256462635084999d-01,
     6      -.4407890222473559d-01,-.1149840093297992d-08,
     7      -.2106666330188452d-08,-.1364437825869472d-07,
     8       .4278540154877059d-07,-.1111655297393361d-06/
         data arr1104/
     1       .1184545803309750d-06, .9999985941475773d+00,
     2      -.4130675585474529d+01, .9464563938504257d+01,
     3      -.1587256000318563d+02, .2173435661619946d+02,
     4      -.2573937935246460d+02, .2730056626133904d+02,
     5      -.2654128787429920d+02, .2403785256290027d+02,
     6      -.2052581229402005d+02, .1667244320800476d+02,
     7      -.1297630329643303d+02, .9721780688903957d+01,
     8      -.7050670463170333d+01, .4947476047343877d+01/
         data arr1105/
     1      -.3383510312869092d+01, .2207856459358782d+01,
     2      -.1403945956726198d+01, .8197760443797375d+00,
     3      -.4588904580398891d+00, .1607405441366747d+00,
     4      -.1178632748060448d-08, .1011435656397736d-07,
     5       .3178570385478307d-08,-.1969264404008211d-06,
     6       .1416429713825011d-06,-.5475373942553538d-06,
     7       .5760017618442206d-06, .9999893769583993d+00,
     8      -.4582568315059611d+01, .1152777414330601d+02/
         data arr1106/
     1      -.2104679111127287d+02, .3115611301423702d+02,
     2      -.3965547621002606d+02, .4497703031553635d+02,
     3      -.4655621333160420d+02, .4471858270160137d+02,
     4      -.4036736449770162d+02, .3454370175139908d+02,
     5      -.2825877259441322d+02, .2214282789008991d+02,
     6      -.1679635292528870d+02, .1218144149474464d+02,
     7      -.8672024984859959d+01, .5615493936922093d+01,
     8      -.3769280237730111d+01, .1979612483838584d+01/
         data arr1107/
     1      -.1236677548365904d+01, .5342419078613975d-07,
     2      -.4458859510691221d-07, .4521088376276249d-06,
     3       .9634326492691230d-06, .2095413667013391d-05,
     4       .3132315490029362d-05, .4244477961357794d-04,
     5       .5437385439282616d-04, .1000190493548964d+01,
     6      -.5030907877401952d+01, .1377990497215067d+02,
     7      -.2719381471412364d+02, .4327378076335508d+02,
     8      -.5888345548628735d+02, .7114683976615774d+02/
         data arr1108/
     1      -.7804486632291915d+02, .7937797370733817d+02,
     2      -.7532545646911669d+02, .6820319109736928d+02,
     3      -.5786092087658000d+02, .4853986449634125d+02,
     4      -.3707716348291559d+02, .3065643884491267d+02,
     5      -.1941336572232446d+02, .1695789079017473d+02,
     6      -.7722771953505743d+01, .9538038144965922d+01,
     7      -.3728699609306882d-07, .1872452761619173d-06,
     8       .1696962658626213d-06,-.4751971692757717d-05/
         data arr1109/
     1       .5570333300379061d-05,-.1857685157824284d-04,
     2       .3053122706246830d-04,-.2816414604962661d-03,
     3       .3209668367113219d-03, .9986498904624227d+00,
     4      -.5475650473994845d+01, .1620694926070837d+02,
     5      -.3439024937559025d+02, .5848728658047010d+02,
     6      -.8477251058847675d+02, .1084550806548357d+03,
     7      -.1259315358893873d+03, .1344685333036729d+03,
     8      -.1347489667576625d+03, .1261651899372997d+03/
         data arr1110/
     1      -.1141612777161444d+03, .9611003326928640d+02,
     2      -.8113882822607614d+02, .5854096961240116d+02,
     3      -.4735215044038841d+02, .2737234921885286d+02,
     4      -.2151024191387468d+02, .2376898254589961d-06,
     5      -.5178540519097979d-06, .8242033155256559d-06,
     6       .1296546892051367d-04,-.7555255787400738d-05,
     7       .5158798767683821d-04, .3963740027626185d-04,
     8       .7743241556453272d-03,-.2563524553913770d-03/
         data arr1111/
     1       .3730827012081263d-02, .1000279455830745d+01,
     2      -.5895569569216080d+01, .1883399627420096d+02,
     3      -.4263476817181478d+02, .7740680277654876d+02,
     4      -.1185008027837359d+03, .1609504828463445d+03,
     5      -.1954860128937296d+03, .2213871571795026d+03,
     6      -.2273748976840523d+03, .2281290265025179d+03,
     7      -.2040255778539116d+03, .1909089560100599d+03,
     8      -.1391030727469083d+03, .1263968968774379d+03/
         data arr1112/
     1      -.7025737303647759d+02, .6863787528939322d+02,
     2      -.2323061586728924d-06, .1246945151177301d-05,
     3       .1506990754980253d-05,-.3630852644165753d-04,
     4       .4665066716336757d-04,-.1519780077747224d-03,
     5       .2643227791108354d-03,-.2198888308127329d-02,
     6       .2720718928170516d-02,-.1078532173952045d-01,
     7       .1354850902744473d-01, .9262639950428644d+00,
     8      -.6280891990112986d+01, .2134692973538029d+02/
         data arr1113/
     1      -.5196068353699847d+02, .9905869113335336d+02,
     2      -.1618782196368014d+03, .2286844661772220d+03,
     3      -.2961130525328737d+03, .3403832878928329d+03,
     4      -.3786654335583108d+03, .3715896511384879d+03,
     5      -.3718267568408888d+03, .2931818750908006d+03,
     6      -.2733513967373051d+03, .1677836027218746d+03,
     7      -.1477996654407102d+03,-.3057458703426375d-06,
     8      -.2535285873387368d-05,-.1227658834743662d-04/
         data arr1114/
     1       .7780729913607384d-04,-.1596390144313358d-03,
     2       .3371873679605022d-03,-.1465832698536967d-02,
     3       .4760475390275395d-02,-.1055876548535759d-01,
     4       .2362989844803619d-01,-.6314383425807715d-01,
     5       .1603682939564993d+00, .6767778810971350d+00,
     6      -.6131963924149139d+01, .2322696356606648d+02,
     7      -.6001773157539782d+02, .1227877980611076d+03,
     8      -.2093475979187747d+03, .3117782517608571d+03/
         data arr1115/
     1      -.4103233403740786d+03, .5002499792340236d+03,
     2      -.5492082382634179d+03, .5655993752404984d+03,
     3      -.4975536242219004d+03, .4498780920996892d+03,
     4      -.3179966307301908d+03, .2201216817882326d+03,
     5      -.8578222404274990d-06, .4180599480656718d-05,
     6       .5904970326350700d-05,-.1304528978359390d-03,
     7       .1824906455625336d-03,-.5828418538028084d-03,
     8       .1061477743508814d-02,-.8072833589717202d-02/
         data arr1116/
     1       .1073860348556525d-01,-.4045728302255162d-01,
     2       .5410691476633206d-01,-.2729537733322105d+00,
     3       .3294279482938376d+00,-.1524153440225187d+00,
     4      -.5887944997153570d+01, .2243292073061946d+02,
     5      -.6904776739790226d+02, .1418006998437003d+03,
     6      -.2662267356340711d+03, .3843792153364943d+03,
     7      -.5598697153475641d+03, .6429561589410139d+03,
     8      -.7887389879753399d+03, .6700201930254337d+03/
         data arr1117/
     1      -.7359737269365136d+03, .4777278215977581d+03,
     2      -.4767506810472365d+03,-.1070623562537254d-04,
     3      -.5943587381133082d-05,-.1362525032800314d-03,
     4       .2136874242048728d-03,-.1104358992393705d-02,
     5       .1015225229742212d-02,-.1422738504416454d-01,
     6       .1347867934849839d-01,-.8214585205626511d-01,
     7       .6901000762372866d-01,-.5588337469536604d+00,
     8       .4596413675400352d+00,-.2518558775300573d+01/
         data arr1118/
     1       .1964776647918790d+01,-.1079634599247539d+02,
     2       .1403160724470474d+01,-.9689349108366251d+01,
     3      -.5773359529668748d+02, .5805868535099349d+02,
     4      -.2646001943922348d+03, .2469076550551999d+03,
     5      -.6083892800284217d+03, .2962053568405036d+03,
     6      -.7642373140124006d+03, .1980515050709954d+03,
     7      -.6408780697762734d+03,-.4096757494194216d+03,
     8       .9999999999999366d+00,-.1299038105675757d+01/
         data arr1119/
     1       .1257788237338153d+01,-.1042902912238032d+01,
     2       .7821771841742429d+00,-.5461254978152621d+00,
     3       .3612280627093994d+00,-.2289700753411259d+00,
     4       .1402149616814271d+00,-.8344459160545328d-01,
     5       .4847691748206786d-01,-.2758772938985057d-01,
     6       .1542197078451825d-01,-.8487439245258717d-02,
     7       .4606884484254608d-02,-.2470184565283980d-02,
     8       .1310059415618952d-02,-.6893973309513038d-03/
         data arr1120/
     1       .3606377484851564d-03,-.1923400025163730d-03,
     2       .1050658609288764d-03,-.6686684407325519d-04,
     3       .4056130810895601d-04,-.3648083376066781d-04,
     4       .2279804890086157d-04,-.2417011164987002d-04,
     5       .2053857345498682d-11, .9999999999015214d+00,
     6      -.1936491673087711d+01, .2408481108562945d+01,
     7      -.2408481108431758d+01, .2102038014679936d+01,
     8      -.1668440953729308d+01, .1233828699192956d+01/
         data arr1121/
     1      -.8635002233855515d+00, .5781208293628007d+00,
     2      -.3731755080922441d+00, .2336064748308972d+00,
     3      -.1424622345334951d+00, .8493149402804677d-01,
     4      -.4965033179053895d-01, .2850334507380834d-01,
     5      -.1613188495016504d-01, .8925832016208536d-02,
     6      -.4954466203222855d-02, .2536874084122834d-02,
     7      -.1465543998053030d-02, .3674220525965138d-03,
     8      -.4362218944330886d-03,-.3087763232869445d-03/
         data arr1122/
     1      -.1516614323997984d-03,-.8185237291439478d-03,
     2       .5779710361867202d-11,-.1740488616532990d-12,
     3       .1000000000119688d+01,-.2487468593052907d+01,
     4       .3731202889547560d+01,-.4341951067113914d+01,
     5       .4307896031132344d+01,-.3822878500902235d+01,
     6       .3121367258883716d+01,-.2388323706832821d+01,
     7       .1734363672493430d+01,-.1206345060032521d+01,
     8       .8092421438446867d+00,-.5263430096819561d+00/
         data arr1123/
     1       .3333273424821440d+00,-.2062208217050188d+00,
     2       .1249766628114562d+00,-.7430171475230062d-01,
     3       .4338035384365332d-01,-.2473026417433211d-01,
     4       .1371154399235063d-01,-.7090231319802801d-02,
     5       .3480762244424030d-02,-.1186632628400809d-02,
     6       .2628140619701499d-03, .4233888683865871d-03,
     7       .4567043928697452d-10,-.7266001898015380d-11,
     8       .3398394576796732d-09, .9999999997343456d+00/
         data arr1124/
     1      -.3000000000226938d+01, .5236590024347874d+01,
     2      -.6927357444951853d+01, .7684274921409668d+01,
     3      -.7529021011544882d+01, .6720995957346515d+01,
     4      -.5577922167655532d+01, .4364720350011622d+01,
     5      -.3253269371480662d+01, .2327575217821292d+01,
     6      -.1607996255825977d+01, .1077773226148482d+01,
     7      -.7034477208892911d+00, .4486104685009691d+00,
     8      -.2799267230414962d+00, .1715843891953820d+00/
         data arr1125/
     1      -.1026598624941101d+00, .6076861969159611d-01,
     2      -.3370840108195339d-01, .1912683454242869d-01,
     3      -.8584084041600236d-02, .4896845494553412d-02,
     4      -.1120500870855565d-09,-.3523008994837509d-09,
     5      -.2015697348354822d-08, .2030484432396062d-08,
     6       .9999999998690704d+00,-.3491060012180542d+01,
     7       .6927357287841930d+01,-.1024569973727114d+02,
     8       .1254836776757272d+02,-.1344199084749533d+02/
         data arr1126/
     1       .1301514602346296d+02,-.1163924644859530d+02,
     2       .9759785665216212d+01,-.7758542051171458d+01,
     3       .5895863578576636d+01,-.4310895007879095d+01,
     4       .3047893286358148d+01,-.2092916071115973d+01,
     5       .1398776753746862d+01,-.9143899331967575d+00,
     6       .5817677102028022d+00,-.3648730567784294d+00,
     7       .2150532969349893d+00,-.1295216591047520d+00,
     8       .6443005372448463d-01,-.3653231871415161d-01/
         data arr1127/
     1       .5160632873699649d-09, .1729676974489154d-08,
     2       .1511152609667449d-07,-.2071644340965420d-07,
     3       .1643910864095736d-07, .9999999111693324d+00,
     4      -.3968625781443188d+01, .8804516386020833d+01,
     5      -.1437771263085352d+02, .1925201309901387d+02,
     6      -.2236878141074741d+02, .2333806759525739d+02,
     7      -.2236508925641127d+02, .2000146888828273d+02,
     8      -.1688788281520255d+02, .1358259507331112d+02/
         data arr1128/
     1      -.1047512456924291d+02, .7791848640347002d+01,
     2      -.5604999195332097d+01, .3924970339873490d+01,
     3      -.2659701367992409d+01, .1770944848033173d+01,
     4      -.1098692445972462d+01, .6980958089615141d+00,
     5      -.3648343149892588d+00, .2138974321519917d+00,
     6      -.3758259128885964d-08,-.1177147075850519d-07,
     7      -.7952172637342775d-07, .1149691800890905d-06,
     8      -.8483365903981000d-07, .1172572358788536d-06/
         data arr1129/
     1       .9999937535704290d+00,-.4437053948366728d+01,
     2       .1086850795479499d+02,-.1940418920595070d+02,
     3       .2818183560564842d+02,-.3528371518535228d+02,
     4       .3944768671507718d+02,-.4031881226479846d+02,
     5       .3829518136795943d+02,-.3422325457849490d+02,
     6       .2902630232848526d+02,-.2355681296701269d+02,
     7       .1833596871621380d+02,-.1383551446265927d+02,
     8       .1000914031023162d+02,-.7130480750131990d+01/
         data arr1130/
     1       .4632573209214223d+01,-.3149888680313744d+01,
     2       .1691123756550827d+01,-.1099229592650981d+01,
     3       .1464986512777228d-07, .4031193184182492d-06,
     4       .3522564623597493d-06,-.9189656411097004d-06,
     5       .4701590646024638d-06, .2133736417301034d-04,
     6       .2772111355743145d-04, .1000054037504147d+01,
     7      -.4898867664692615d+01, .1312042786121524d+02,
     8      -.2540502682834060d+02, .3976312761405430d+02/
         data arr1131/
     1      -.5334009155329280d+02, .6362595875294470d+02,
     2      -.6903247545659912d+02, .6947338882901460d+02,
     3      -.6538103713299247d+02, .5862706745809892d+02,
     4      -.4947828630318534d+02, .4104492635194341d+02,
     5      -.3137801645801214d+02, .2550974434251483d+02,
     6      -.1635936682409706d+02, .1387220406995307d+02,
     7      -.6587861140611620d+01, .7798069765311142d+01,
     8      -.7602717481051292d-07,-.2700745937356261d-06/
         data arr1132/
     1      -.1806982945935819d-05, .3371981555620974d-05,
     2      -.3661196504815366d-05, .6328067289285087d-05,
     3      -.1453099892383528d-03, .1795509849460217d-03,
     4       .9993617554492381d+00,-.5355296917573404d+01,
     5       .1555232441501010d+02,-.3245818571222730d+02,
     6       .5442084910754153d+02,-.7788020465280854d+02,
     7       .9854996828558019d+02,-.1132785695457107d+03,
     8       .1199584139545589d+03,-.1192469340737549d+03/
         data arr1133/
     1       .1110455025305473d+03,-.9988837285976744d+02,
     2       .8404615540336432d+02,-.7074492407388084d+02,
     3       .5128372502686454d+02,-.4149416654220551d+02,
     4       .2448378790712981d+02,-.1933103925871800d+02,
     5       .2031631680435321d-06, .1320696593667904d-05,
     6       .4849251220429617d-05,-.9753007140516478d-05,
     7       .1001227844292802d-04, .1856072077974147d-04,
     8       .3919914851518215d-03,-.3533668315558554d-03/
         data arr1134/
     1       .1724051361172366d-02, .9993591582029678d+00,
     2      -.5794212984368396d+01, .1817295470441206d+02,
     3      -.4059665095915044d+02, .7269249934724378d+02,
     4      -.1101972244880476d+03, .1479481600966582d+03,
     5      -.1785142826120813d+03, .1998925492880809d+03,
     6      -.2048545649895159d+03, .2027930441674250d+03,
     7      -.1823580802502016d+03, .1667736483792346d+03,
     8      -.1240402941320984d+03, .1084342070209433d+03/
         data arr1135/
     1      -.6340955961633291d+02, .5666590970779149d+02,
     2      -.5246540338755534d-06,-.2079118108027702d-05,
     3      -.1293247577862879d-04, .2554575460241418d-04,
     4      -.2912143520309076d-04, .5114604813563443d-04,
     5      -.1055604867901102d-02, .1368694455550643d-02,
     6      -.4730502522654475d-02, .5985133078563582d-02,
     7       .9586524174829575d+00,-.6213324604778043d+01,
     8       .2082384488943036d+02,-.4988441937751652d+02/
         data arr1136/
     1       .9422237602094982d+02,-.1521270068852564d+03,
     2       .2135013403556473d+03,-.2734310296994557d+03,
     3       .3130266996235425d+03,-.3440308954212712d+03,
     4       .3373368128721705d+03,-.3325811584771050d+03,
     5       .2634072379782718d+03,-.2410488242764079d+03,
     6       .1504801336508344d+03,-.1297382725079075d+03,
     7       .1252974408136560d-05,-.6994829292986466d-05,
     8       .2958795244290193d-04,-.4865435839117850d-04/
         data arr1137/
     1       .7192142332768477d-04,-.8503974939292895d-03,
     2       .2400688823559414d-02,-.5949057347545058d-02,
     3       .1098838877615586d-01,-.4385821559683685d-01,
     4       .9468698003176167d-01, .7706033853466842d+00,
     5      -.6308285643581625d+01, .2286691779110740d+02,
     6      -.5868381001607359d+02, .1178013383970847d+03,
     7      -.2003401300278165d+03, .2930748357537339d+03,
     8      -.3873662983162964d+03, .4627879335168598d+03/
         data arr1138/
     1      -.5140990831910618d+03, .5092580322158535d+03,
     2      -.4634178090479876d+03, .3946221450450590d+03,
     3      -.2978741448055778d+03, .1680665675605553d+03,
     4      -.1751362519707520d-05,-.7100852291218080d-05,
     5      -.4375414867583396d-04, .9179675505288956d-04,
     6      -.1102505470100117d-03, .1975064187936570d-03,
     7      -.3611144048002262d-02, .4977684234779384d-02,
     8      -.1663645398951773d-01, .2215864181951729d-01/
         data arr1139/
     1      -.1427365328256575d+00, .1707924644256600d+00,
     2       .3952440910571230d+00,-.6455106919103908d+01,
     3       .2389783571643102d+02,-.6853146531706646d+02,
     4       .1399968491294744d+03,-.2534587268536959d+03,
     5       .3652383539574333d+03,-.5142766942731281d+03,
     6       .5903342233627162d+03,-.6992754563099901d+03,
     7       .5985244989597519d+03,-.6328171587008168d+03,
     8       .4179631857753407d+03,-.4012310072900101d+03/
         data arr1140/
     1       .3283244700719824d-05,-.1047389518419024d-03,
     2       .8354816373592309d-04,-.6625123671162818d-04,
     3       .2497260227594728d-03,-.7994855332754987d-02,
     4       .7100753116676560d-02,-.3869726345926845d-01,
     5       .3416572590630107d-01,-.3553640323105485d+00,
     6       .2848889487726232d+00,-.1596688271661111d+01,
     7       .1233382012790573d+01,-.7558057235225829d+01,
     8      -.1201412487118290d+01, .2561902781590314d+00/
         data arr1141/
     1      -.6359230778768046d+02, .7748069103236169d+02,
     2      -.2702672626712512d+03, .2770420978989019d+03,
     3      -.6069903827855746d+03, .3229031073485457d+03,
     4      -.7550111958904799d+03, .2285146107360914d+03,
     5      -.6370159930263377d+03,-.4243009676362523d+03,
     6       .9999999999912288d+00,-.1436140661631157d+01,
     7       .1523257200970123d+01,-.1373045485864772d+01,
     8       .1112293968210230d+01,-.8342204772521873d+00/
         data arr1142/
     1       .5898829524971788d+00,-.3980539373243978d+00,
     2       .2585435302350941d+00,-.1626634456429348d+00,
     3       .9961029279539604d-01,-.5959628440647559d-01,
     4       .3493916122966803d-01,-.2012457330084322d-01,
     5       .1140229162813064d-01,-.6377341100829670d-02,
     6       .3489525111975957d-02,-.1920148086768634d-02,
     7       .9688836950889904d-03,-.5595681891869718d-03,
     8       .1017844655256423d-03,-.1646483482087435d-03/
         data arr1143/
     1      -.1683495777550167d-03,-.5688700385628486d-04,
     2      -.4350828281869922d-03, .1000750505177336d-11,
     3       .1000000000082407d+01,-.2121320343652669d+01,
     4       .2868198476187520d+01,-.3098008432794058d+01,
     5       .2904382909900950d+01,-.2464450623857609d+01,
     6       .1940184316228330d+01,-.1440213362810018d+01,
     7       .1019378823171498d+01,-.6935995710690319d+00,
     8       .4564739349665963d+00,-.2919622880296261d+00/
         data arr1144/
     1       .1821749217318074d+00,-.1112246610240204d+00,
     2       .6660367294462470d-01,-.3915458107837879d-01,
     3       .2260322760388186d-01,-.1269761827671877d-01,
     4       .6888042822368237d-02,-.3385395251943521d-02,
     5       .1542087688221609d-02,-.3164825726884986d-03,
     6      -.8771405590978596d-04, .4484644486643973d-03,
     7       .1377042279127682d-09, .9501417890303084d-10,
     8       .9999999986477041d+00,-.2704163457100946d+01/
         data arr1145/
     1       .4381245566573889d+01,-.5476556925961897d+01,
     2       .5808765866747780d+01,-.5487669924927546d+01,
     3       .4752462679237569d+01,-.3844317640382203d+01,
     4       .2942696961721550d+01,-.2151835761200258d+01,
     5       .1513980320692729d+01,-.1030518328048423d+01,
     6       .6817205724665656d+00,-.4396597272784024d+00,
     7       .2777371236398460d+00,-.1714246725039126d+00,
     8       .1049215388165682d+00,-.6178360746928123d-01/
         data arr1146/
     1       .3857034167003396d-01,-.1994176607969177d-01,
     2       .1422535317050684d-01,-.4931183594442399d-02,
     3       .8239759356855718d-02,-.3815869394566809d-10,
     4      -.2520815063825538d-08, .1600270675467047d-08,
     5       .1000000008591051d+01,-.3240370351913084d+01,
     6       .6075694297335923d+01,-.8592329343127540d+01,
     7       .1014670507615139d+02,-.1054476518711122d+02,
     8       .9951400221763276d+01,-.8705662062550873d+01/
         data arr1147/
     1       .7161727588093266d+01,-.5598579445390225d+01,
     2       .4191850959668282d+01,-.3024741481159311d+01,
     3       .2113490336548123d+01,-.1436157207139721d+01,
     4       .9512334160602119d+00,-.6175707969007452d+00,
     5       .3915456656569096d+00,-.2461706693202093d+00,
     6       .1459999172716272d+00,-.9014813775735452d-01,
     7       .4650481764882525d-01,-.2833578191986187d-01,
     8       .1057707508734274d-08, .1450555787035393d-07/
         data arr1148/
     1      -.1552806288764203d-07,-.4964853011302183d-07,
     2       .1000000119726389d+01,-.3749999367700566d+01,
     3       .7954950988246765d+01,-.1252536384204869d+02,
     4       .1627092962794821d+02,-.1842639693449894d+02,
     5       .1880638491308054d+02,-.1768121144764034d+02,
     6       .1554991997228748d+02,-.1293605868529356d+02,
     7       .1026810587540736d+02,-.7825667780209404d+01,
     8       .5761356605531351d+01,-.4103990112228050d+01/
         data arr1149/
     1       .2854286468135494d+01,-.1918466518506455d+01,
     2       .1284483438882162d+01,-.7865300115920055d+00,
     3       .5188203657720879d+00,-.2652325418370791d+00,
     4       .1912282886364182d+00,-.2680453948413268d-08,
     5      -.7952709740693250d-07, .5226521822478066d-07,
     6       .2782251609293818d-06,-.8609143589261354d-07,
     7       .9999964155405888d+00,-.4242637519726127d+01,
     8       .1002028535985411d+02,-.1735564534716009d+02/
         data arr1150/
     1       .2456842683468230d+02,-.3009010122021692d+02,
     2       .3300460940079979d+02,-.3317260923007155d+02,
     3       .3104469925366740d+02,-.2737930415173443d+02,
     4       .2295118573794797d+02,-.1842946758440080d+02,
     5       .1421567470193305d+02,-.1063873925295276d+02,
     6       .7657904365609889d+01,-.5430458628686378d+01,
     7       .3530670443221672d+01,-.2405965570946062d+01,
     8       .1318995294295034d+01,-.8699017597500557d+00/
         data arr1151/
     1       .6519323365820666d-07, .3630900619019382d-06,
     2      -.8522853087562881d-06,-.1207605808539432d-05,
     3       .1067992842104735d-04, .1588731049498114d-04,
     4       .1000005763500674d+01,-.4723580781370551d+01,
     5       .1227271970687884d+02,-.2316286650953894d+02,
     6       .3546279675217557d+02,-.4667412788400312d+02,
     7       .5474276338401560d+02,-.5853013335778448d+02,
     8       .5811176510443909d+02,-.5407281464075999d+02/
         data arr1152/
     1       .4792825274539201d+02,-.4012395626163251d+02,
     2       .3291435439223743d+02,-.2510431195176546d+02,
     3       .2018422154700408d+02,-.1301694860358689d+02,
     4       .1089126020097033d+02,-.5338359590377669d+01,
     5       .6325679850209403d+01,-.4446206021076889d-07,
     6      -.1664938540993662d-05, .1350555288773822d-05,
     7       .5261422372283339d-05,-.1446423001718492d-05,
     8      -.7694423794557519d-04, .8214935600805244d-04/
         data arr1153/
     1       .9998294835764341d+00,-.5195880674155869d+01,
     2       .1470832176854493d+02,-.3002617852181053d+02,
     3       .4939637826713227d+02,-.6951028078446258d+02,
     4       .8668836581161405d+02,-.9832576593002848d+02,
     5       .1029636748943634d+03,-.1012187005268002d+03,
     6       .9347894656061082d+02,-.8322472007313898d+02,
     7       .6972419566138890d+02,-.5802460066888138d+02,
     8       .4211981980379076d+02,-.3362298547447654d+02/
         data arr1154/
     1       .2022029257368517d+02,-.1567193930963992d+02,
     2      -.4955170546371624d-07, .4871461991753049d-05,
     3      -.2631182836955571d-05,-.1506947252148665d-04,
     4      -.1984331410300991d-04, .2234664520149495d-03,
     5      -.2911174201941018d-03, .5057436464526900d-03,
     6       .9981067036630801d+00,-.5653728207873923d+01,
     7       .1732426543741570d+02,-.3800153177460585d+02,
     8       .6683378878203926d+02,-.9996787956198958d+02/
         data arr1155/
     1       .1322295868235556d+03,-.1580791236855809d+03,
     2       .1743023183481168d+03,-.1781123306791678d+03,
     3       .1729475481272472d+03,-.1568051153890766d+03,
     4       .1374304783016953d+03,-.1062028367992176d+03,
     5       .8588752822306404d+02,-.5518959665096586d+02,
     6       .3818032690574064d+02,-.3052510156871329d-06,
     7      -.1235284937652125d-04, .1062400123405816d-04,
     8       .3775954870183960d-04,-.1004472753482602d-04/
         data arr1156/
     1      -.5743967921309746d-03, .6420271550834257d-03,
     2      -.1329857291173525d-02, .2164091550155593d-02,
     3       .9776861229359514d+00,-.6099345737127901d+01,
     4       .2006693288632921d+02,-.4716258041742063d+02,
     5       .8791180810362367d+02,-.1398620650275226d+03,
     6       .1943834514518647d+03,-.2456659811714902d+03,
     7       .2793509882968806d+03,-.3028581277508707d+03,
     8       .2962523770438939d+03,-.2873522510174633d+03/
         data arr1157/
     1       .2284122088371287d+03,-.2050481548283058d+03,
     2       .1307324608180575d+03,-.1099049956141212d+03,
     3      -.2635531809721344d-05, .2896860826075874d-04,
     4       .6066880510732505d-05,-.8612867262554832d-04,
     5      -.5278807689211349d-03, .1357849006152957d-02,
     6      -.2688458526779368d-02, .3318861732726366d-02,
     7      -.3026594586700140d-01, .5343179913534352d-01,
     8       .8492395380635357d+00,-.6376829057291721d+01/
         data arr1158/
     1       .2226549996051417d+02,-.5646391587126255d+02,
     2       .1112080658494384d+03,-.1878469162523831d+03,
     3       .2693882335396412d+03,-.3566610712689492d+03,
     4       .4168141702181578d+03,-.4679982254604906d+03,
     5       .4412922958643859d+03,-.4186282817649711d+03,
     6       .3297772820748078d+03,-.2713573832772172d+03,
     7       .1038742505265034d+03,-.9292785193502839d-06,
     8      -.4361180136666520d-04, .4052764208129713d-04/
         data arr1159/
     1       .1268001483320570d-03,-.3236394739386174d-04,
     2      -.2045043334907907d-02, .2435918980165010d-02,
     3      -.5041196998690755d-02, .8420257221929522d-02,
     4      -.8055098318150146d-01, .9312834361391051d-01,
     5       .6909603889818394d+00,-.6667955873109248d+01,
     6       .2423033022858697d+02,-.6661855440708608d+02,
     7       .1354104967817683d+03,-.2393856667987876d+03,
     8       .3445955949611505d+03,-.4757004483969735d+03/
         data arr1160/
     1       .5484584473728729d+03,-.6362469185172596d+03,
     2       .5499993569185390d+03,-.5686968175839704d+03,
     3       .3859024445954773d+03,-.3599895128161161d+03,
     4      -.2124047332981685d-04, .7756501110300406d-04,
     5       .1553052666662638d-03,-.2161317572136767d-03,
     6      -.3957078088216760d-02, .3779357350569506d-02,
     7      -.1280726448746002d-01, .1019804848950632d-01,
     8      -.1975266516001902d+00, .1521083156911618d+00/
         data arr1161/
     1      -.8405201657996717d+00, .6016082374676679d+00,
     2      -.4447329476552093d+01,-.3689391570302492d+01,
     3       .1027217610582570d+02,-.6880872371415855d+02,
     4       .9804585598611338d+02,-.2704148062704695d+03,
     5       .3034714491676298d+03,-.5828551940149600d+03,
     6       .3429895845259135d+03,-.7052616540559305d+03,
     7       .2472388148379727d+03,-.5866144194319551d+03,
     8      -.4172248840944688d+03, .1000000000023470d+01/
         data arr1162/
     1      -.1561249499674203d+01, .1788636002492449d+01,
     2      -.1731839362401957d+01, .1499816884971247d+01,
     3      -.1197507752445911d+01, .8981308137101039d+00,
     4      -.6407196078435536d+00, .4386707927531177d+00,
     5      -.2901535065166064d+00, .1863546393604998d+00,
     6      -.1166834051713561d+00, .7145480882791309d-01,
     7      -.4290431517790975d-01, .2530702169240925d-01,
     8      -.1466410182257577d-01, .8337396593858732d-02/
         data arr1163/
     1      -.4579110537559838d-02, .2388663858535766d-02,
     2      -.1052192983127223d-02, .3896016089906837d-03,
     3       .9190655925452112d-04,-.1954019505443661d-03,
     4       .3357490020539425d-03,-.1058313733052030d-10,
     5       .9999999968628862d+00,-.2291287847565030d+01,
     6       .3327794900090363d+01,-.3842606538449694d+01,
     7       .3835094077882147d+01,-.3451584700425956d+01,
     8       .2872723714183087d+01,-.2247793132063120d+01/
         data arr1164/
     1       .1672624254977572d+01,-.1193623854686928d+01,
     2       .8221286331821583d+00,-.5492046044737927d+00,
     3       .3573322945755198d+00,-.2270413089580395d+00,
     4       .1416284269787961d+00,-.8627973692131728d-01,
     5       .5244725992718575d-01,-.3035069893812719d-01,
     6       .1975554525467563d-01,-.9462470168101773d-02,
     7       .7976502669621787d-02,-.2095785208338355d-02,
     8       .6962872198457294d-02,-.9720743918917768d-09/
         data arr1165/
     1       .1955495021014265d-08, .1000000006964751d+01,
     2      -.2904737517651380d+01, .5031152888378423d+01,
     3      -.6695089084452336d+01, .7531975305069382d+01,
     4      -.7522554394741888d+01, .6867118960210500d+01,
     5      -.5839935412488774d+01, .4688453319077004d+01,
     6      -.3587961230782558d+01, .2636555393544730d+01,
     7      -.1871104678400437d+01, .1288236641343396d+01,
     8      -.8640981316595973d+00, .5661184955869439d+00/
         data arr1166/
     1      -.3648087849224345d+00, .2307997156626308d+00,
     2      -.1463228041310333d+00, .8793192637412517d-01,
     3      -.5670974856676674d-01, .3093989686458260d-01,
     4      -.2086267195075698d-01, .4777534030418154d-08,
     5      -.2035383242376113d-07,-.3493661520108259d-07,
     6       .1000000113271444d+01,-.3464101313505118d+01,
     7       .6914657938553751d+01,-.1037198761500489d+02,
     8       .1294877057400278d+02,-.1418465359082702d+02/
         data arr1167/
     1       .1407340687364288d+02,-.1291255815321735d+02,
     2       .1111695647845340d+02,-.9076632454883113d+01,
     3       .7085650756208892d+01,-.5320768863463678d+01,
     4       .3865161031861451d+01,-.2721054849943135d+01,
     5       .1872441107631212d+01,-.1248918403333998d+01,
     6       .8319579206041882d+00,-.5082319415992462d+00,
     7       .3372303637359452d+00,-.1757157636437725d+00,
     8       .1333557356136517d+00,-.2781800710918237d-07/
         data arr1168/
     1       .5324051991988343d-07, .2028160143352478d-06,
     2      -.2136119634737455d-06, .9999982244519061d+00,
     3      -.3992178018103762d+01, .8982405137407302d+01,
     4      -.1495194849502729d+02, .2047373457437401d+02,
     5      -.2437580138238912d+02, .2609262184609262d+02,
     6      -.2567322883702650d+02, .2358086775929218d+02,
     7      -.2045346592529515d+02, .1689452467526155d+02,
     8      -.1338667504179230d+02, .1020835534950947d+02/
         data arr1169/
     1      -.7560275145195605d+01, .5404307249823771d+01,
     2      -.3806599036332430d+01, .2473680857833660d+01,
     3      -.1683638412458044d+01, .9421088586980949d+00,
     4      -.6270015906212315d+00, .1225190133827038d-06,
     5      -.9939453080666352d-06,-.9285315633879133d-06,
     6       .6197500010309800d-05, .7865740618624471d-05,
     7       .9999847535879990d+00,-.4500002112793236d+01,
     8       .1123610539873922d+02,-.2051361288150113d+02/
         data arr1170/
     1       .3052965327814840d+02,-.3921506411174197d+02,
     2       .4502055839317213d+02,-.4724978933178206d+02,
     3       .4612053561915629d+02,-.4230549718150112d+02,
     4       .3694383069209003d+02,-.3062357217362423d+02,
     5       .2471857396852121d+02,-.1881107736396199d+02,
     6       .1471170499438052d+02,-.9648100771363083d+01,
     7       .7648145118813427d+01,-.3991635344006413d+01,
     8       .4225992822636317d+01,-.6004721946204594d-06/
         data arr1171/
     1       .1304851074598873d-05, .4327797490469733d-05,
     2      -.5181235545099198d-05,-.3898275329266113d-04,
     3       .4606604412002166d-04, .1000000284494826d+01,
     4      -.4993712496367813d+01, .1367445656043643d+02,
     5      -.2713577524107831d+02, .4356881717351091d+02,
     6      -.6001702168886827d+02, .7347419910015034d+02,
     7      -.8195681677478956d+02, .8460005038342990d+02,
     8      -.8204442149875625d+02, .7496433070564352d+02/
         data arr1172/
     1      -.6596570647497454d+02, .5494379081958282d+02,
     2      -.4523140906518595d+02, .3285330241138860d+02,
     3      -.2593138200199903d+02, .1591111527952674d+02,
     4      -.1218831126664913d+02, .1790657448384912d-05,
     5       .1012075992584821d-05,-.1317661514313107d-04,
     6      -.1761432398358253d-04, .1172584597874353d-03,
     7      -.9526554151095472d-04, .2918975506990926d-05,
     8       .9987144215494802d+00,-.5472734088937218d+01/
         data arr1173/
     1       .1629524447001661d+02,-.3488880526906910d+02,
     2       .6004977600080753d+02,-.8820415300390154d+02,
     3       .1147054592313829d+03,-.1352588105680521d+03,
     4       .1469444210314708d+03,-.1488519475414712d+03,
     5       .1424642949411915d+03,-.1289295756396629d+03,
     6       .1101738550994920d+03,-.8652590910570257d+02,
     7       .6713331976405988d+02,-.4539354592456471d+02,
     8       .2633234976312515d+02,-.4323301101367163d-05/
         data arr1174/
     1       .9569009746681782d-05, .3118382160682625d-04,
     2      -.3809252831635442d-04,-.2815793426370963d-03,
     3       .3385931316979906d-03,-.4602688046695650d-05,
     4       .2479966018040648d-03, .9892767657880216d+00,
     5      -.5941389862724723d+01, .1908485454448623d+02,
     6      -.4385232599342944d+02, .8033032502683862d+02,
     7      -.1255088248311559d+03, .1720448317434599d+03,
     8      -.2138301431718815d+03, .2404749497268604d+03/
         data arr1175/
     1      -.2558809817911937d+03, .2481871659250741d+03,
     2      -.2351631185343068d+03, .1866201321497317d+03,
     3      -.1625782656869766d+03, .1051120960013167d+03,
     4      -.8523510166684002d+02, .1117228427676169d-04,
     5       .5007702620116748d-04,-.8125687652145500d-04,
     6      -.4148179026509722d-03, .7383084338615994d-03,
     7      -.2428810411401394d-03, .1238239448358902d-03,
     8      -.1900326253219880d-01, .2875181978214379d-01/
         data arr1176/
     1       .9252336017867034d+00,-.6333736315573646d+01,
     2       .2151736468584006d+02,-.5340016643751453d+02,
     3       .1034871800115445d+03,-.1721178771337729d+03,
     4       .2431897390213793d+03,-.3193161517692552d+03,
     5       .3684621041143996d+03,-.4121789848576214d+03,
     6       .3773070405387730d+03,-.3646098605635158d+03,
     7       .2756986511335915d+03,-.2376088866909463d+03,
     8       .6075381504769946d+02,-.1534286678423161d-04/
         data arr1177/
     1       .3608083848002740d-04, .1096234034764812d-03,
     2      -.1434477899916208d-03,-.1003518245104648d-02,
     3       .1284364388605639d-02,-.1415679155220848d-03,
     4       .1043303351953131d-02,-.3884493914221428d-01,
     5       .4429631473913151d-01, .8808149693296048d+00,
     6      -.6745395868304096d+01, .2409090047408070d+02,
     7      -.6345626871324080d+02, .1272467662504807d+03,
     8      -.2180687605511327d+03, .3107673110764961d+03/
         data arr1178/
     1      -.4154705284911635d+03, .4754967733943137d+03,
     2      -.5327651629861545d+03, .4615417503130392d+03,
     3      -.4588770778968162d+03, .3168840657168973d+03,
     4      -.2834296949208709d+03, .3289018152554012d-04,
     5       .4022815353462435d-03,-.2308208380271463d-03,
     6      -.2999243229983874d-02, .2201867403015478d-02,
     7       .1401748390967878d-02, .9197698182097098d-03,
     8      -.1194223791850448d+00, .8796934596990544d-01/
         data arr1179/
     1      -.3769061412961602d+00, .2876170335752804d+00,
     2      -.2522683205708047d+01,-.4931619567382028d+01,
     3       .1670050918657798d+02,-.6975425083685678d+02,
     4       .1090717684164474d+03,-.2617913975798152d+03,
     5       .3181415961649064d+03,-.5533414607303494d+03,
     6       .3602557986320629d+03,-.6625566046605311d+03,
     7       .2860455685902963d+03,-.5572946433122546d+03,
     8      -.3875556504908070d+03, .9999999978344218d+00/
         data arr1180/
     1      -.1677050982935819d+01, .2053959605556889d+01,
     2      -.2117173086952384d+01, .1944747609826382d+01,
     3      -.1641555956247679d+01, .1297764417204917d+01,
     4      -.9733229975944052d+00, .6989147383842285d+00,
     5      -.4838016894594719d+00, .3245573982661537d+00,
     6      -.2118609405817775d+00, .1350672612963591d+00,
     7      -.8426693899121976d-01, .5181335709269901d-01,
     8      -.3103113699006831d-01, .1878607532616811d-01/
         data arr1181/
     1      -.1056166937450221d-01, .7719316409124950d-02,
     2      -.3094647083059819d-02, .3742436263179313d-02,
     3      -.4938957260882186d-03, .5414592915681011d-02,
     4       .8496385390853918d-09, .1000000006372570d+01,
     5      -.2449489747544810d+01, .3787314313515608d+01,
     6      -.4638493794503299d+01, .4894174374002065d+01,
     7      -.4643021444744128d+01, .4062642648104997d+01,
     8      -.3334014862163778d+01, .2596350089971670d+01/
         data arr1182/
     1      -.1935203987736292d+01, .1389594065612192d+01,
     2      -.9662623843408095d+00, .6533802759156652d+00,
     3      -.4313922673450076d+00, .2789358645915312d+00,
     4      -.1780972415917133d+00, .1124129111285115d+00,
     5      -.7180476032564156d-01, .4381625561962877d-01,
     6      -.2934340564432282d-01, .1697429268488814d-01,
     7      -.1217724752359870d-01, .2863499265050125d-08,
     8      -.3306720060186809d-07, .9999999761674332d+00/
         data arr1183/
     1      -.3092329025686923d+01, .5680971529620241d+01,
     2      -.7992153624412007d+01, .9477526470973888d+01,
     3      -.9951398734527096d+01, .9527738262510040d+01,
     4      -.8479642075509926d+01, .7110351019414926d+01,
     5      -.5672936863701878d+01, .4338861064945801d+01,
     6      -.3199780441710890d+01, .2285558003450222d+01,
     7      -.1587050082215350d+01, .1075395939077269d+01,
     8      -.7126567605776353d+00, .4609188095985636d+00/
         data arr1184/
     1      -.2876579397822956d+00, .1785093446178749d+00,
     2      -.1030851040535456d+00, .5045735014857691d-01,
     3       .2172436831341492d-07, .1881953805099229d-06,
     4      -.1269847635247357d-06, .9999989024366028d+00,
     5      -.3674233760564085d+01, .7753530252335748d+01,
     6      -.1225940457643307d+02, .1609043656440550d+02,
     7      -.1848651304759413d+02, .1919505711688534d+02,
     8      -.1839489092950901d+02, .1651031820314238d+02/
         data arr1185/
     1      -.1403117152870370d+02, .1138167050544071d+02,
     2      -.8871382206367405d+01, .6667450105000929d+01,
     3      -.4869004291087080d+01, .3442056938480094d+01,
     4      -.2392267076482650d+01, .1545066781896512d+01,
     5      -.1037357510276264d+01, .5886955628688343d+00,
     6      -.3862464276589620d+00,-.4163798640639216d-06,
     7      -.9478081159879616d-06, .2752957329306325d-05,
     8       .5486213060559187d-05, .9999886249855239d+00/
         data arr1186/
     1      -.4220499950672491d+01, .1000983402016134d+02,
     2      -.1751692961101882d+02, .2515690455862465d+02,
     3      -.3134528174222884d+02, .3504683685719255d+02,
     4      -.3594608529597472d+02, .3437153484348401d+02,
     5      -.3097162548652254d+02, .2658423627374764d+02,
     6      -.2174866399993267d+02, .1726725245310876d+02,
     7      -.1306135059696943d+02, .9969211504910088d+01,
     8      -.6606705439211669d+01, .5014261582016216d+01/
         data arr1187/
     1      -.2764013413227820d+01, .2639091624843139d+01,
     2       .5799412941392554d-06, .4548936334411678d-05,
     3      -.3449692846168269d-05,-.2650562434304190d-04,
     4       .2280730049472899d-04, .1000066490078958d+01,
     5      -.4743449416466439d+01, .1245072092341447d+02,
     6      -.2384203871931200d+02, .3713394048515708d+02,
     7      -.4982024212620853d+02, .5960752831476056d+02,
     8      -.6514085270917255d+02, .6605019079976950d+02/
         data arr1188/
     1      -.6298406622638737d+02, .5674216116843225d+02,
     2      -.4916588684322637d+02, .4053551675752043d+02,
     3      -.3280572348124456d+02, .2373197156501226d+02,
     4      -.1834921767479554d+02, .1144614470180598d+02,
     5      -.8523754428418254d+01, .3920720618342873d-05,
     6      -.1512660567591498d-04,-.2857891433159507d-04,
     7       .8807005548045038d-04, .5806166464987336d-04,
     8      -.2183775313524262d-03, .9988246850859778d+00/
         data arr1189/
     1      -.5247496442911173d+01, .1507619261531073d+02,
     2      -.3131157576400129d+02, .5247664229585903d+02,
     3      -.7535584031641719d+02, .9600063493949230d+02,
     4      -.1112585611181593d+03, .1186852834045440d+03,
     5      -.1188880185015334d+03, .1118127084029078d+03,
     6      -.1008410398855905d+03, .8290607796451852d+02,
     7      -.6677020885809715d+02, .4852431820185911d+02,
     8      -.3536896956487190d+02, .1300620957947229d+02/
         data arr1190/
     1       .4648559781141671d-05, .3596336849615547d-04,
     2      -.2790091402261864d-04,-.2087496687685281d-03,
     3       .1822860175842364d-03, .5236580640523670d-03,
     4      -.2655453164565287d-03, .9940954865047502d+00,
     5      -.5738897693950419d+01, .1788667918949111d+02,
     6      -.4000124535060143d+02, .7166130876961006d+02,
     7      -.1096206412104972d+03, .1476956027473408d+03,
     8      -.1802619040818597d+03, .2000469194296127d+03/
         data arr1191/
     1      -.2091742222722142d+03, .2011314314158670d+03,
     2      -.1868650880574974d+03, .1480277161108730d+03,
     3      -.1260311899403146d+03, .8304127352846371d+02,
     4      -.6529014583445216d+02, .4063627277252460d-04,
     5      -.9758437273985227d-04,-.2897220791771759d-03,
     6       .5691556376745908d-03, .7160815443512068d-03,
     7      -.1386869897215424d-02,-.1103622276859650d-01,
     8       .1633264149938230d-01, .9756227426424514d+00/
         data arr1192/
     1      -.6207179936817730d+01, .2054081864665021d+02,
     2      -.4958529645478641d+02, .9443999021546523d+02,
     3      -.1538435743449560d+03, .2144329099530331d+03,
     4      -.2770751650928759d+03, .3169393390612674d+03,
     5      -.3494043058544969d+03, .3149387702415787d+03,
     6      -.3032348926749258d+03, .2266171350163147d+03,
     7      -.1972576989707551d+03, .3519243023602842d+02,
     8       .1876659325615646d-04, .1367638520913113d-03/
         data arr1193/
     1      -.1127601392009168d-03,-.7962203980577750d-03,
     2       .7379955773478000d-03, .1957920474344723d-02,
     3      -.1048379741221228d-02,-.2277560707533457d-01,
     4       .2307706464661370d-01, .9689306399156608d+00,
     5      -.6660601532540451d+01, .2331805729909532d+02,
     6      -.5952715187614241d+02, .1176870549144138d+03,
     7      -.1970258710689894d+03, .2782310408071166d+03,
     8      -.3641840448530878d+03, .4154855168309156d+03/
         data arr1194/
     1      -.4548592426075098d+03, .3956744955975316d+03,
     2      -.3833400238225827d+03, .2713678668189092d+03,
     3      -.2343711637279916d+03, .2780681781996645d-03,
     4      -.2871023052374900d-03,-.1942503184452322d-02,
     5       .1688603411972554d-02, .5688651714459769d-02,
     6      -.3933619052842154d-02,-.6776138490644537d-01,
     7       .4955757401485598d-01,-.1008346232031799d+00,
     8       .7789565465073561d-01,-.1024754303800822d+01/
         data arr1195/
     1      -.5848347162232118d+01, .2136842294470728d+02,
     2      -.6887526613353779d+02, .1158448983711607d+03,
     3      -.2449025090611291d+03, .3165606141294043d+03,
     4      -.4972635046801359d+03, .3563100034162464d+03,
     5      -.5772103103146795d+03, .2957862587912698d+03,
     6      -.4786590939228115d+03,-.3292131131357616d+03,
     7       .1000000004005163d+01,-.1785357112042100d+01,
     8       .2319246892138167d+01,-.2527340705489970d+01/
         data arr1196/
     1       .2447087223839509d+01,-.2171574492453132d+01,
     2       .1800573810939628d+01,-.1413274135753985d+01,
     3       .1059956200450761d+01,-.7649571724490545d+00,
     4       .5340967911328294d+00,-.3623853341198509d+00,
     5       .2398861675930586d+00,-.1556629162959957d+00,
     6       .9949348822375635d-01,-.6360497853588788d-01,
     7       .4103033552355898d-01,-.2775596258959502d-01,
     8       .1809557713112528d-01,-.1378893857843839d-01/
         data arr1197/
     1       .9083821594821932d-02,-.7478361602317749d-02,
     2      -.1638889716340322d-07, .9999999245976736d+00,
     3      -.2598076120925442d+01, .4246782190870894d+01,
     4      -.5482572162276020d+01, .6081622783681250d+01,
     5      -.6051137999867200d+01, .5541146382095183d+01,
     6      -.4749554056342988d+01, .3856102665960647d+01,
     7      -.2991515994284268d+01, .2232321409162602d+01,
     8      -.1610815226160583d+01, .1127873105992318d+01/
         data arr1198/
     1      -.7703234534382010d+00, .5133368333106012d+00,
     2      -.3372689689589660d+00, .2108294947581532d+00,
     3      -.1352023983481150d+00, .7823595231265418d-01,
     4      -.5080300740882129d-01, .6228430684521036d-02,
     5       .7986963619855252d-07,-.6984379718256538d-07,
     6       .9999995642600242d+00,-.3269173835712595d+01,
     7       .6330730302088329d+01,-.9363275095928570d+01,
     8       .1164541424045507d+02,-.1279671860318930d+02/
         data arr1199/
     1       .1279673399268699d+02,-.1187388253055075d+02,
     2       .1036281760903590d+02,-.8592144587173454d+01,
     3       .6818596157097857d+01,-.5209322788358166d+01,
     4       .3844042511752252d+01,-.2754364553007547d+01,
     5       .1912150995461277d+01,-.1296710848471959d+01,
     6       .8227152056427265d+00,-.5310085720239246d+00,
     7       .2977381286272716d+00,-.1834104275506482d+00,
     8      -.5236759260731615d-06, .1230584708029513d-05/
         data arr1200/
     1       .2883883760627151d-05, .9999940746674059d+00,
     2      -.3872994372565775d+01, .8592356134432736d+01,
     3      -.1424869520785898d+02, .1957171673291491d+02,
     4      -.2348620450765408d+02, .2542493391744793d+02,
     5      -.2535787402378196d+02, .2365454692705077d+02,
     6      -.2085899059147009d+02, .1754431678396557d+02,
     7      -.1412036441483743d+02, .1100049106007010d+02,
     8      -.8236853053644186d+01, .6100342591505179d+01/
         data arr1201/
     1      -.4075178122915552d+01, .2925019883223833d+01,
     2      -.1697475273672744d+01, .1360239503799323d+01,
     3       .2743222619434023d-05,-.2836272404752730d-05,
     4      -.1490259546809565d-04, .1484150981231885d-04,
     5       .1000056821012554d+01,-.4437106630401940d+01,
     6       .1103667399417822d+02,-.2021332256067446d+02,
     7       .3032067892985890d+02,-.3938742391807311d+02,
     8       .4582622590966589d+02,-.4885866493012983d+02/
         data arr1202/
     1       .4847908650235423d+02,-.4531846605635075d+02,
     2       .4013510788979190d+02,-.3417380163736527d+02,
     3       .2781750051799418d+02,-.2211985515137620d+02,
     4       .1590084982220026d+02,-.1204606551102056d+02,
     5       .7624142522948489d+01,-.5539234463418888d+01,
     6      -.9980498215425706d-05,-.3341420488946695d-04,
     7       .5461525984381990d-04, .1397133477865840d-03,
     8      -.2066791704503527d-03, .9990793084987478d+00/
         data arr1203/
     1      -.4973566600233739d+01, .1366712480190194d+02,
     2      -.2733442746698536d+02, .4435905546844562d+02,
     3      -.6194626275153315d+02, .7702346812492314d+02,
     4      -.8734736111192260d+02, .9137338359133797d+02,
     5      -.9005543115244387d+02, .8343376444860016d+02,
     6      -.7435328836078095d+02, .5970389355841989d+02,
     7      -.4831906984125530d+02, .3423278407616888d+02,
     8      -.2567631244795732d+02, .6172863514793577d+01/
         data arr1204/
     1       .2180644865115437d-04,-.2220074625002758d-04,
     2      -.1183262170413783d-03, .1158687091617978d-03,
     3       .4530047124058395d-03,-.3687206061715320d-03,
     4       .9970486496658216d+00,-.5491601052433973d+01,
     5       .1648441449907452d+02,-.3568621877620512d+02,
     6       .6219816496265022d+02,-.9273821868304684d+02,
     7       .1221897935575985d+03,-.1457579733133375d+03,
     8       .1586646421972699d+03,-.1618650117507426d+03/
         data arr1205/
     1       .1528065074657198d+03,-.1377172430702764d+03,
     2       .1078430192637020d+03,-.8825107644056294d+02,
     3       .5835341245539233d+02,-.4361427352908225d+02,
     4      -.7078295726041918d-04,-.3270423833793622d-03,
     5       .3872715535408794d-03, .1388785727679798d-02,
     6      -.1458816614210637d-02,-.8806464541197432d-02,
     7       .9767668535515785d-02, .1004090086764194d+01,
     8      -.6003414732339034d+01, .1924972068094306d+02/
         data arr1206/
     1      -.4510911827725847d+02, .8405300799718411d+02,
     2      -.1336615562150789d+03, .1829381927212677d+03,
     3      -.2323972054355758d+03, .2629602077973719d+03,
     4      -.2853890623106366d+03, .2512052992758725d+03,
     5      -.2429544457236731d+03, .1789517437564166d+03,
     6      -.1584135328208533d+03, .8076582969113129d+01,
     7       .9559441379625612d-04,-.1053909340220160d-03,
     8      -.5171722225063484d-03, .5487262700832403d-03/
         data arr1207/
     1       .1966395016974481d-02,-.1732366141878558d-02,
     2      -.1303296843264782d-01, .1295214130657288d-01,
     3       .1005197258878757d+01,-.6492439755296541d+01,
     4       .2217007004133429d+02,-.5471519309296394d+02,
     5       .1058100164974515d+03,-.1722746183441237d+03,
     6       .2391585331448639d+03,-.3044705187837522d+03,
     7       .3429746923870087d+03,-.3646355736395147d+03,
     8       .3160716728754395d+03,-.2963003200012311d+03/
         data arr1208/
     1       .2133085617744231d+03,-.1774826145508274d+03,
     2      -.2334961631364181d-03,-.1919240508722764d-02,
     3       .1278259796111137d-02, .8301706535597518d-02,
     4      -.4760433022942070d-02,-.5024874263969459d-01,
     5       .3272411408600460d-01, .3970466841130716d-01,
     6      -.6493179132968156d-02,-.2800530754662043d+00,
     7      -.6156893200131705d+01, .2337847334742830d+02,
     8      -.6570505614279021d+02, .1146428277656135d+03/
         data arr1209/
     1      -.2244854821028543d+03, .3047712484303868d+03,
     2      -.4457829221413230d+03, .3457115005949951d+03,
     3      -.5099730201282476d+03, .3124711654758528d+03,
     4      -.4280795093231488d+03,-.2689444303483772d+03,
     5       .9999998530410017d+00,-.1887458555002956d+01,
     6       .2584509794324069d+01,-.2960927432737788d+01,
     7       .3006832616851766d+01,-.2792473594237365d+01,
     8       .2418362079601828d+01,-.1978982727316142d+01/
         data arr1210/
     1       .1544774861979594d+01,-.1158605621678911d+01,
     2       .8394902419281290d+00,-.5902900936877253d+00,
     3       .4032202187402261d+00,-.2706575192143422d+00,
     4       .1769366677598464d+00,-.1164041914385676d+00,
     5       .6506844819941042d-01,-.4823076943321631d-01,
     6       .2190337232378390d-01,-.2160764763091735d-01,
     7      -.2630520628579989d-01,-.1973470340134865d-07,
     8       .9999998465416160d+00,-.2738612692868740d+01/
         data arr1211/
     1       .4706213345077765d+01,-.6372242424805186d+01,
     2       .7397443105893855d+01,-.7687649910955527d+01,
     3       .7339433879642866d+01,-.6547817757746843d+01,
     4       .5524597892388772d+01,-.4447373907904056d+01,
     5       .3438296173071445d+01,-.2565042366915673d+01,
     6       .1851416612682650d+01,-.1296562357964584d+01,
     7       .8791013749321968d+00,-.5777381268996501d+00,
     8       .3567046273109333d+00,-.2179635833785282d+00/
         data arr1212/
     1       .1180060396165818d+00,-.6541672588258532d-01,
     2       .8506803736320845d-06, .1525068170283374d-05,
     3       .9999961369101800d+00,-.3436938629959536d+01,
     4       .6980458825165614d+01,-.1080462884209705d+02,
     5       .1403560934895792d+02,-.1607994942792762d+02,
     6       .1673676096782070d+02,-.1613807981027051d+02,
     7       .1461650153142647d+02,-.1255982901348785d+02,
     8       .1032172680925064d+02,-.8138645157606685d+01/
         data arr1213/
     1       .6214937412319616d+01,-.4576657373330716d+01,
     2       .3327786465508379d+01,-.2190650600270284d+01,
     3       .1533723623088546d+01,-.8886542927045911d+00,
     4       .7322063976609881d+00,-.1601252575364345d-05,
     5      -.9173562882099102d-05, .7657775374182271d-05,
     6       .1000041326473679d+01,-.4062049210709613d+01,
     7       .9430880848959628d+01,-.1633495480243632d+02,
     8       .2339319949839243d+02,-.2921779276781118d+02/
         data arr1214/
     1       .3286585401173848d+02,-.3402112500615082d+02,
     2       .3289244131326006d+02,-.3003177728495436d+02,
     3       .2605130993820995d+02,-.2172745612737345d+02,
     4       .1739061002865757d+02,-.1353080817856952d+02,
     5       .9620770319609669d+01,-.7099795602690053d+01,
     6       .4535054436045306d+01,-.3173938410989433d+01,
     7      -.3311831636689682d-04, .3867015911248252d-04,
     8       .1452668115198477d-03,-.1738292560430791d-03/
         data arr1215/
     1       .9992787675708142d+00,-.4642692200284421d+01,
     2       .1206588211594270d+02,-.2303735236990029d+02,
     3       .3594817697668135d+02,-.4853455383430215d+02,
     4       .5861657879792729d+02,-.6476633291692326d+02,
     5       .6621734878605898d+02,-.6396833330572411d+02,
     6       .5828886054010701d+02,-.5109976322477724d+02,
     7       .4008612018382816d+02,-.3239713528318270d+02,
     8       .2262147898346526d+02,-.1721636359876376d+02/
         data arr1216/
     1       .1911858279977846d+01,-.1425548681743692d-04,
     2      -.8354717341012852d-04, .6781492574774609d-04,
     3       .3775273499918473d-03,-.2676838418642699d-03,
     4       .9981683073929790d+00,-.5194748663168966d+01,
     5       .1488623003887228d+02,-.3098211167675463d+02,
     6       .5222012852110798d+02,-.7556971795463821d+02,
     7       .9701133215467318d+02,-.1129169564568169d+03,
     8       .1203768891813429d+03,-.1200648138931239d+03/
         data arr1217/
     1       .1114246201614152d+03,-.9799016913947324d+02,
     2       .7594547236082254d+02,-.6034155365529777d+02,
     3       .4023475292626478d+02,-.2881058113313660d+02,
     4      -.2361529171563678d-03, .2904890535741202d-03,
     5       .1034578538686733d-02,-.1306972638417607d-02,
     6      -.5149488176035624d-02, .6402723150250852d-02,
     7       .1011255608989112d+01,-.5741244406877556d+01,
     8       .1777005325945270d+02,-.4011407309496722d+02/
         data arr1218/
     1       .7275438159716435d+02,-.1124497497186199d+03,
     2       .1512866747684261d+03,-.1870760748440925d+03,
     3       .2096128687114289d+03,-.2210422277765362d+03,
     4       .1963464548563610d+03,-.1819561237419226d+03,
     5       .1395838305067103d+03,-.1165199542555410d+03,
     6       .1392780936143724d+02,-.7362517773044474d-04,
     7      -.4001839631270775d-03, .3502335327503422d-03,
     8       .1805319376917798d-02,-.1380163273071867d-02/
         data arr1219/
     1      -.8801815750719495d-02, .7264974098842455d-02,
     2       .1018239041886927d+01,-.6255287898640230d+01,
     3       .2071372836333591d+02,-.4941018839186820d+02,
     4       .9310573649999354d+02,-.1474044017101848d+03,
     5       .2007019601743490d+03,-.2488298274068495d+03,
     6       .2761109637462591d+03,-.2850716512598751d+03,
     7       .2456425329529437d+03,-.2224911559388507d+03,
     8       .1623211518148932d+03,-.1286707907876947d+03/
         data arr1220/
     1      -.1657510899996126d-02, .1060180458429534d-02,
     2       .7312209811393248d-02,-.4760620130601677d-02,
     3      -.3573252012348933d-01, .2354348579348491d-01,
     4       .8561114711171779d-01,-.4561120769559191d-01,
     5       .2293926764435289d+00,-.6260867426670265d+01,
     6       .2375029999475771d+02,-.6101353769385443d+02,
     7       .1086542551931078d+03,-.1979737158188293d+03,
     8       .2759517107880476d+03,-.3768341218027769d+03/
         data arr1221/
     1       .3116807512052732d+03,-.4167240300862146d+03,
     2       .2928122760309027d+03,-.3461719935692152d+03,
     3      -.1963362279112590d+03, .1000000101058850d+01,
     4      -.1984313588926269d+01, .2849752881159786d+01,
     5      -.3416733683498010d+01, .3623995595788815d+01,
     6      -.3508919073407645d+01, .3162890080365315d+01,
     7      -.2689784168406166d+01, .2178898393279633d+01,
     8      -.1692933039198302d+01, .1267351500444603d+01/
         data arr1222/
     1      -.9158199278392675d+00, .6380392056517207d+00,
     2      -.4247586275810535d+00, .2661104929498663d+00,
     3      -.1514198666045906d+00, .7734088506663761d-01,
     4      -.2599294681945402d-01,-.6305761677096642d-03,
     5       .1565502704637819d-01, .6904523757870393d-06,
     6       .9999996097152275d+00,-.2872284169144583d+01,
     7       .5165618260403932d+01,-.7305272590494782d+01,
     8       .8841631837168348d+01,-.9563733399364999d+01/
         data arr1223/
     1       .9488705916159846d+01,-.8784605482599579d+01,
     2       .7681605371656332d+01,-.6401116988452769d+01,
     3       .5116603370236056d+01,-.3939303985578869d+01,
     4       .2936341321247065d+01,-.2118553947019868d+01,
     5       .1482297824123957d+01,-.9710648072738455d+00,
     6       .6364642180539934d+00,-.3749021348228427d+00,
     7       .2242537698567093d+00,-.6129815957078372d-05,
     8       .4307126088234301d-05, .1000025245406381d+01/
         data arr1224/
     1      -.3596893019719920d+01, .7630011377056247d+01,
     2      -.1231296883999047d+02, .1664858691037121d+02,
     3      -.1982143900280190d+02, .2140775234202112d+02,
     4      -.2139633042704150d+02, .2006729748895835d+02,
     5      -.1784125500947548d+02, .1513075002670135d+02,
     6      -.1237201469560909d+02, .9763628098476419d+01,
     7      -.7492152613017873d+01, .5298899992296050d+01,
     8      -.3871888839207276d+01, .2528304736617196d+01/
         data arr1225/
     1      -.1748914872121630d+01, .2766720286944860d-04,
     2      -.2028937208980001d-04,-.1137147365183224d-03,
     3       .1000091285828045d+01,-.4242145276053872d+01,
     4       .1026939041415195d+02,-.1851562011857602d+02,
     5       .2755443592556424d+02,-.3570460213595191d+02,
     6       .4163169465719346d+02,-.4461663074545996d+02,
     7       .4458948877768619d+02,-.4189327666864960d+02,
     8       .3757891253988795d+02,-.3218047385977012d+02/
         data arr1226/
     1       .2656703528868145d+02,-.1981731119350208d+02,
     2       .1536094976187589d+02,-.1048750479048490d+02,
     3       .7612876404206413d+01,-.5516876300727951d-04,
     4       .3542521509541391d-04, .2276347296081624d-03,
     5      -.1597327051378520d-03, .9990123202607627d+00,
     6      -.4840521890908495d+01, .1309448050420398d+02,
     7      -.2597945574302379d+02, .4204784291853255d+02,
     8      -.5870872169733164d+02, .7300282294778553d+02/
         data arr1227/
     1      -.8246940917167105d+02, .8556596537512148d+02,
     2      -.8287902355414504d+02, .7490093579850955d+02,
     3      -.6369428810870085d+02, .4834750926211909d+02,
     4      -.3678879448320788d+02, .2429337319229715d+02,
     5      -.1637336441014821d+02, .2420159173701737d-03,
     6      -.1806171714009130d-03,-.9948503949626466d-03,
     7       .8134230123233777d-03, .4332416074991422d-02,
     8       .9963765442287220d+00,-.5421263216160197d+01/
         data arr1228/
     1       .1610703140061511d+02,-.3469916369063196d+02,
     2       .6072958244655013d+02,-.9107725352264468d+02,
     3       .1208476833130329d+03,-.1440912372306535d+03,
     4       .1597435394600404d+03,-.1636766430715307d+03,
     5       .1575760454806533d+03,-.1307487103078330d+03,
     6       .1131768547141817d+03,-.8321619019851295d+02,
     7       .6427667004952268d+02,-.3780561887422045d-03,
     8       .2783216613181034d-03, .1555238909980074d-02/
         data arr1229/
     1      -.1252750669724696d-02,-.6768984910947246d-02,
     2       .5570478121791380d-02, .1020293267533194d+01,
     3      -.5967385741289562d+01, .1901386119706835d+02,
     4      -.4378021573294605d+02, .8026202008797334d+02,
     5      -.1238833703778213d+03, .1655499401372658d+03,
     6      -.2013217559450277d+03, .2212858009064153d+03,
     7      -.2248220581328007d+03, .1931632155173149d+03,
     8      -.1723907301132081d+03, .1289614448234831d+03/
         data arr1230/
     1      -.1003835659964205d+03, .1008277427595009d-02,
     2      -.8344266758352979d-03,-.4137111331187308d-02,
     3       .3747654274202215d-02, .1807907767681442d-01,
     4      -.1677530413298156d-01,-.5316900050188384d-01,
     5       .1042319173333221d+01,-.6159872247607483d+01,
     6       .2218334330012352d+02,-.5537011950681241d+02,
     7       .1076468270274284d+03,-.1710564836889535d+03,
     8       .2473060670957781d+03,-.3143781107097595d+03/
         data arr1231/
     1       .3656066727534871d+03,-.3388243682622096d+03,
     2       .3432180421229048d+03,-.2819840340722046d+03,
     3       .2464591620661838d+03, .1000000252611562d+01,
     4      -.2076655565539671d+01, .3114982988463418d+01,
     5      -.3893731803531597d+01, .4298565438937361d+01,
     6      -.4325338030054021d+01, .4045976919579970d+01,
     7      -.3565983339141011d+01, .2990063850409586d+01,
     8      -.2401960698981393d+01, .1857414892879501d+01/
         data arr1232/
     1      -.1386142963734126d+01, .9964214374690286d+00,
     2      -.6851424446769210d+00, .4440192470966822d+00,
     3      -.2690377769558874d+00, .1415781908256536d+00,
     4      -.5660329892662857d-01, .3005245094894505d-02,
     5       .2633721614462877d-05, .1000011965615170d+01,
     6      -.3000010176143672d+01, .5624945405225356d+01,
     7      -.8279734420581253d+01, .1041439846053294d+02,
     8      -.1169004798093399d+02, .1201962655370293d+02/
         data arr1233/
     1      -.1152089977259015d+02, .1042446073047221d+02,
     2      -.8985772772617393d+01, .7424598067576008d+01,
     3      -.5939222128787097d+01, .4615228312757131d+01,
     4      -.3493412890303216d+01, .2456886325916746d+01,
     5      -.1782470296297829d+01, .1194050000984617d+01,
     6      -.8177318607441786d+00,-.1501333455913443d-04,
     7      -.6416689687819378d-04, .1000057867044954d+01,
     8      -.3749706838342042d+01, .8279539798029536d+01/
         data arr1234/
     1      -.1388664322009163d+02, .1948394210081260d+02,
     2      -.2403559295068735d+02, .2687445502141684d+02,
     3      -.2778067636115217d+02, .2690108667524885d+02,
     4      -.2460009567064659d+02, .2154610147217414d+02,
     5      -.1813433906674761d+02, .1471870107017956d+02,
     6      -.1088702537535506d+02, .8354606841912753d+01,
     7      -.5862310040046815d+01, .4223562233753341d+01,
     8       .1728662841014812d-04, .1024585720280550d-03/
         data arr1235/
     1      -.6681580366520055d-04, .9995329506673594d+00,
     2      -.4415609376324290d+01, .1111016078304835d+02,
     3      -.2078295834979435d+02, .3202420154924605d+02,
     4      -.4285158262159563d+02, .5131862202844430d+02,
     5      -.5601090469639892d+02, .5631475740406030d+02,
     6      -.5278768019310621d+02, .4620815244543017d+02,
     7      -.3781823860223858d+02, .2792694306115223d+02,
     8      -.2015046857010728d+02, .1290924772339325d+02/
         data arr1236/
     1      -.7920300663119912d+01,-.1309640120392657d-03,
     2      -.5867012563839859d-03, .5052337427097340d-03,
     3       .2678924138645831d-02, .9979424586068303d+00,
     4      -.5040662336190267d+01, .1412522247326453d+02,
     5      -.2899264437874622d+02, .4863590241972155d+02,
     6      -.7031855982623171d+02, .9025375349127960d+02,
     7      -.1046131947874270d+03, .1125639827595867d+03,
     8      -.1125294522682405d+03, .1049741350056441d+03/
         data arr1237/
     1      -.8570979342652427d+02, .7151293901891515d+02,
     2      -.5268597196872150d+02, .3865420136493227d+02,
     3       .2015305054529807d-03, .9332766347812711d-03,
     4      -.7775745180724692d-03,-.4259709807503141d-02,
     5       .3162858615519824d-02, .1015155634241075d+01,
     6      -.5622664538911776d+01, .1708706029387110d+02,
     7      -.3759842006341628d+02, .6625614142301973d+02,
     8      -.9856773956832406d+02, .1277068353981136d+03/
         data arr1238/
     1      -.1500355078512487d+03, .1602889571523144d+03,
     2      -.1570178457411176d+03, .1325039666691623d+03,
     3      -.1133131770730137d+03, .8448436336639686d+02,
     4      -.6190613895643450d+02,-.8494031485485550d-03,
     5      -.3261694197018817d-02, .3272320949110659d-02,
     6       .1491195028984039d-01,-.1335461080045474d-01,
     7      -.5251026270321710d-01, .1042241973812020d+01,
     8      -.5931760223680492d+01, .2032545045584182d+02/
         data arr1239/
     1      -.4907255061665965d+02, .9229766917699469d+02,
     2      -.1434154028461016d+03, .2022048308743486d+03,
     3      -.2544750122623997d+03, .2895679353407870d+03,
     4      -.2671110317379851d+03, .2657573494195376d+03,
     5      -.2255304537998314d+03, .1928288655430796d+03,
     6       .1000012335446461d+01,-.2165070882430312d+01,
     7       .3380159827481602d+01,-.4390981543542066d+01,
     8       .5030699020474620d+01,-.5246127403826822d+01/
         data arr1240/
     1       .5080105037208635d+01,-.4636373419654682d+01,
     2       .4038174540486218d+01,-.3393007075874724d+01,
     3       .2776547752586143d+01,-.2253349323480624d+01,
     4       .1831227091417275d+01,-.1483230450425026d+01,
     5       .1116797779713279d+01,-.9017500972369706d+00,
     6       .6923428280590538d+00,-.5248248866648966d+00,
     7      -.4467417667476862d-04, .1000026083853234d+01,
     8      -.3122337855327623d+01, .6084251918962998d+01/
         data arr1241/
     1      -.9294605338706308d+01, .1211555604888036d+02,
     2      -.1407427900178057d+02, .1496364324286274d+02,
     3      -.1481939155552017d+02, .1382952441630083d+02,
     4      -.1225359289091830d+02, .1044356328558436d+02,
     5      -.8613782611331542d+01, .6864203347578801d+01,
     6      -.5024354874830122d+01, .3817525554444608d+01,
     7      -.2754602938105292d+01, .1972960517607219d+01,
     8       .5680106968084050d-04,-.1810343358645320d-04/
         data arr1242/
     1       .9997950439310547d+00,-.3897034246108254d+01,
     2       .8930155415032544d+01,-.1552009534643258d+02,
     3       .2251877560350050d+02,-.2863411645936866d+02,
     4       .3279752004081703d+02,-.3438777257368864d+02,
     5       .3332265737227386d+02,-.3010089006365568d+02,
     6       .2539393094302442d+02,-.1995003709608683d+02,
     7       .1424249069307383d+02,-.9726512368239554d+01,
     8       .5966995518467561d+01,-.3306924777069703d+01/
         data arr1243/
     1      -.4601812300456521d-03, .2367040215073205d-03,
     2       .1659576783362655d-02, .9989506334922449d+00,
     3      -.4588569200257799d+01, .1195092984768711d+02,
     4      -.2311254778139167d+02, .3685575109914470d+02,
     5      -.5101894764350506d+02, .6303007164030453d+02,
     6      -.7069818019267029d+02, .7364532068098087d+02,
     7      -.7157324711344081d+02, .6467667568172764d+02,
     8      -.5179964691873792d+02, .4167593834912239d+02/
         data arr1244/
     1      -.3055366827585681d+02, .2124267660229086d+02,
     2       .1095500503005562d-02,-.5893328041081368d-03,
     3      -.3950091078109133d-02, .2610532038072272d-02,
     4       .1014260421114783d+01,-.5223568156982553d+01,
     5       .1499396113013746d+02,-.3154693068676122d+02,
     6       .5375295769525565d+02,-.7790742704673080d+02,
     7       .9909415471181674d+02,-.1149598966384260d+03,
     8       .1224090558463873d+03,-.1193329225775110d+03/
         data arr1245/
     1       .1008160000064917d+03,-.8631846604186688d+02,
     2       .6670947371170594d+02,-.4872927137993224d+02,
     3      -.3195669308271468d-02, .1975759758473230d-02,
     4       .1152412957607070d-01,-.8771010743286399d-02,
     5      -.4146073215718191d-01, .1031401523185968d+01,
     6      -.5648953894865143d+01, .1824654856597040d+02,
     7      -.4208844374117437d+02, .7608426728899447d+02,
     8      -.1147439008319456d+03, .1562697812371183d+03/
         data arr1246/
     1      -.1919894129847298d+03, .2114264570744039d+03,
     2      -.1926395213004555d+03, .1852115575333213d+03,
     3      -.1591788041687561d+03, .1302860418384805d+03,
     4       .1000031099709563d+01,-.2249901525403370d+01,
     5       .3645311068604955d+01,-.4908203164992203d+01,
     6       .5820297198470400d+01,-.6273441372040201d+01,
     7       .6275294798938389d+01,-.5914755762259033d+01,
     8       .5307942606923899d+01,-.4573395051517785d+01/
         data arr1247/
     1       .3866976861525182d+01,-.3262522050886228d+01,
     2       .2718770819436491d+01,-.2075443943200573d+01,
     3       .1744440346750170d+01,-.1472916668089913d+01,
     4       .1192055232203358d+01, .3100844733739674d-04,
     5       .1000055823750016d+01,-.3240476405680937d+01,
     6       .6543492164258663d+01,-.1034616304584263d+02,
     7       .1392584227179295d+02,-.1661771608963733d+02,
     8       .1797040582738976d+02,-.1782943027540268d+02/
         data arr1248/
     1       .1633103951843988d+02,-.1379519823916799d+02,
     2       .1067395670327422d+02,-.7486919987477226d+01,
     3       .4752080766551440d+01,-.2488717787373608d+01,
     4       .8432056117775286d+00, .1545604415570916d+00,
     5       .1353735674681075d-03, .6429131092461529d-03,
     6       .9995362281686063d+00,-.4041564779195487d+01,
     7       .9580672940558845d+01,-.1720324482263475d+02,
     8       .2579399834241841d+02,-.3388191003009921d+02/
         data arr1249/
     1       .3999541668807296d+02,-.4310312932855835d+02,
     2       .4315885645943488d+02,-.4038150379670227d+02,
     3       .3503992485809487d+02,-.2725334529785069d+02,
     4       .2087049763072728d+02,-.1486892649158833d+02,
     5       .9563014045036660d+01,-.6549150363062293d-03,
     6      -.2552536028277720d-02, .2241427381487863d-02,
     7       .1010669842761961d+01,-.4751334481879395d+01,
     8       .1269003223536789d+02,-.2521070361895320d+02/
         data arr1250/
     1       .4107966729842700d+02,-.5745718275583621d+02,
     2       .7108567434837590d+02,-.8070888436796909d+02,
     3       .8490306878344929d+02,-.8174934980486493d+02,
     4       .6859005542275098d+02,-.5846000780591243d+02,
     5       .4672150560092265d+02,-.3402687498542534d+02,
     6       .2531726953170097d-02, .8535230045840442d-02,
     7      -.8643936696914517d-02,-.3563286624430211d-01,
     8       .1030467372226952d+01,-.5255763563400721d+01/
         data arr1251/
     1       .1597557700760476d+02,-.3528739310726530d+02,
     2       .6156871117556162d+02,-.9039879321211498d+02,
     3       .1208434346542986d+03,-.1478852778562160d+03,
     4       .1614215407824868d+03,-.1464072655274970d+03,
     5       .1409139598267585d+03,-.1270830561245620d+03,
     6       .1041088966596794d+03, .1000428262631484d+01,
     7      -.2332097141444074d+01, .3909263002027227d+01,
     8      -.5442320323853081d+01, .6643500949410226d+01/
         data arr1252/
     1      -.7264866789192909d+01, .7154870033207927d+01,
     2      -.6334917810754210d+01, .4960934577029142d+01,
     3      -.3136756223201765d+01, .1110573645373115d+01,
     4       .5910423547137383d+00,-.1401175911655634d+01,
     5       .2300477375245178d+01,-.2911548687734341d+01,
     6       .2795691854702844d+01, .5930799010576890d-04,
     7       .1000087664597933d+01,-.3354295684095390d+01,
     8       .7002712326372856d+01,-.1143530061258263d+02/
         data arr1253/
     1       .1588297388226037d+02,-.1954551622706033d+02,
     2       .2179018780577710d+02,-.2229372132386290d+02,
     3       .2107782616192375d+02,-.1840817793607605d+02,
     4       .1475779368869852d+02,-.1077629532491797d+02,
     5       .7170536339674932d+01,-.4039942894476695d+01,
     6       .1585323801915841d+01,-.2952001506825325d-02,
     7       .1356139306140557d-02, .1009392383578487d+01,
     8      -.4181400368598951d+01, .1020083977716972d+02/
         data arr1254/
     1      -.1896914915300064d+02, .2947505489162979d+02,
     2      -.3983388364181300d+02, .4811924951833812d+02,
     3      -.5382857832142368d+02, .5634870257816078d+02,
     4      -.5394239884746476d+02, .4512582021058095d+02,
     5      -.3851747699270800d+02, .3195834325181138d+02,
     6      -.2316523691367232d+02, .9954424399751796d-02,
     7      -.5286333785443617d-02,-.3164290861299053d-01,
     8       .1021712773665453d+01,-.4790078337048696d+01/
         data arr1255/
     1       .1349792393695524d+02,-.2812227364228556d+02,
     2       .4682107439366750d+02,-.6625451700543613d+02,
     3       .8599022252909654d+02,-.1034988577553208d+03,
     4       .1107196141917174d+03,-.9900589737216573d+02,
     5       .9432238730816682d+02,-.8836530692559442d+02,
     6       .7161955714525728d+02, .1000942458617207d+01,
     7      -.2408768103688855d+01, .4172955459950564d+01,
     8      -.6005605792696028d+01, .7548951586307645d+01/
         data arr1256/
     1      -.8465373071504549d+01, .8602030286285322d+01,
     2      -.7950491438617407d+01, .6340197107400385d+01,
     3      -.3855617627867573d+01, .1398815240502147d+01,
     4      -.2073802330562752d-01,-.1952240656768524d+01,
     5       .4074458484556648d+01,-.4652304555893532d+01,
     6       .1610211966235223d-02, .1005429115813200d+01,
     7      -.3469030256784486d+01, .7511497224272797d+01,
     8      -.1290185275478867d+02, .1905802788794498d+02/
         data arr1257/
     1      -.2496027090716630d+02, .2960245774999610d+02,
     2      -.3289628061347084d+02, .3462128379446565d+02,
     3      -.3329208416618041d+02, .2792231570462072d+02,
     4      -.2411749390906986d+02, .2102692850154403d+02,
     5      -.1535556325402995d+02,-.6687680459119238d-02,
     6      -.1939945544547825d-01, .1020438149576015d+01,
     7      -.4231158016297556d+01, .1083212908674016d+02,
     8      -.2114905155964830d+02, .3362137301010204d+02/
         data arr1258/
     1      -.4596617090508246d+02, .5838939628058080d+02,
     2      -.6996868412311431d+02, .7432702866674188d+02,
     3      -.6585949976815378d+02, .6292101530970504d+02,
     4      -.6213536258341110d+02, .5052548073845999d+02,
     5       .1018101116387476d+01,-.2495993564098432d+01,
     6       .4729277863715357d+01,-.8044460189612360d+01,
     7       .1259004851528444d+02,-.1772650533857193d+02,
     8       .2262718681167981d+02,-.2781207795100413d+02/
         data arr1259/
     1       .3308722158923562d+02,-.3478920812411308d+02,
     2       .3040519093464062d+02,-.2928555617770775d+02,
     3       .3064402855675959d+02,-.2485886329652321d+02,
     4      -.2400297548614043d-01, .1011377296403737d+01,
     5      -.3501864330074512d+01, .7964049686431208d+01,
     6      -.1438104477068002d+02, .2164727177286392d+02,
     7      -.2850935540324464d+02, .3563024112481136d+02,
     8      -.4280732527815422d+02, .4523978323517801d+02/
         data arr1260/
     1      -.3960873839545371d+02, .3831807532702800d+02,
     2      -.4033721897140766d+02, .3287112196986785d+02/
        do 1200 i=1,4149
        arr(i)=arr1001(i)
 1200 continue
C
        do 1300 i=1,17
        imap(i)=iimap(i)
 1300   continue
c
        return
        end
c
c
c 
c
        subroutine lolget(ndigit,arr,imap)
        implicit real *8 (a-h,o-z)
        integer imap(1)
c
        real *8 arr(1)
      	if (ndigit .eq. 1) call lol1get(arr,imap)
      	if (ndigit .eq. 2) call lol2get(arr,imap)
      	if (ndigit .eq. 3) call lol3get(arr,imap)
      	if (ndigit .eq. 6) call lol6get(arr,imap)
      	if (ndigit .eq. 9) call lol9get(arr,imap)
      	if (ndigit .eq. 12) call lol12get(arr,imap)
c
        return
        end
c
c
C
C///////////////////////////////////////////////////////////////////////
      subroutine mptoxf12(mpole,nterms,nlambs,numtets,
     1                      nexptot,mexpup)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 mpole(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
c
      integer *4  nlambs,numtets(nlambs),nexptot
      parameter (nNLAMBS = 35)
      parameter (NMAXNF = 23)
      parameter (nNTERMS = 34)
c
      real *8 lambda(nNLAMBS),weights(nNLAMBS),dtmp(nNLAMBS)
      complex *16 mult(0:nNTERMS,0:nNTERMS),cd(NMAXNF),eye
c
      complex *16 expcoefs(nNLAMBS,NMAXNF)
      save
c
c ... first initializing....
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,weights,NLAMBS)
c
         cd(1) = 0.5d0
         cd(2) = eye
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*eye
         enddo
c
         do i = 1, NLAMBS
            dtmp(i) = 0.5d0*dexp(lambda(i)*1.5d0)/weights(i)
         enddo
c
         do i = 1, nexptot
            mexpup(i) = 0.0d0
         enddo
c
         ifinit = 1
      endif
c
c you don't want to mess the input data:
c
      do i=0,nNTERMS
         do j = 0, i
            mult(i,j)=mpole(i,j)
         enddo
      enddo
c
c generate MEXPUP: using Vladimir's shceme:
c
      call alota12(mult,expcoefs)
c
c the expcoefs needs to be normalized back to Leslie's notation:
c
      ntot = 0
      do i = 1, NLAMBS
         mexpup(ntot+1) = expcoefs(i,1)*(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j
            mexpup(ncurrent) = expcoefs(i,j)*dtmp(i)/cd(j)
         enddo
         ntot = ntot + numtets(i)
      enddo
c-----------End of MPOLETOEXP-------------------------------------------
      return
      end
c
c
C///////////////////////////////////////////////////////////////////////
      subroutine xftota12(local,nterms,rlams,whts,nlambs,numtets,
     1                      nthmax,nexptot,mexpup,scale)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 local(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
      real *8     rlams(nlambs)
      real *8     whts(nlambs)
C
      integer *4  nlambs,numtets(nlambs),nexptot,nthmax
      parameter (nNLAMBS = 35)
      parameter (NMAXNF = 23)
      parameter (nNTERMS = 34)
C
      real *8 dtmp(nNLAMBS)
      complex *16 expcoefs(nNLAMBS,NMAXNF)
C
      complex *16 taylor(0:nNTERMS,0:nNTERMS),cd(NMAXNF),eye
C
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
C
         cd(1) = 0.5d0
         cd(2) = eye
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*eye
         enddo
C
         do i = 1, nlambs
            dtmp(i) = 0.5d0*dexp(-rlams(i)*0.5d0)/whts(i)
         enddo
C
         do i = 1, nlambs
            do j = 1, NMAXNF
              expcoefs(i,j) = 0.0d0
            enddo
         enddo
C
         ifinit = 1
      endif
C
C     initialize LOCAL expansion
C
         do nm = 0,nterms
            do mth = 0,nm
               local(nm,mth) = 0.0d0
            enddo
         enddo
C
      ntot = 0
      do i = 1, nlambs
         expcoefs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j
            expcoefs(i,j) = mexpup(ncurrent)*cd(j)/dtmp(i)
         enddo
         ntot = ntot + numtets(i)
      enddo
C
      call atalo12(expcoefs,taylor)
C
      do l=0,nNTERMS
         do m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
         enddo
      enddo
C-----------End of EXPTOLOCAL-------------------------------------------
      RETURN
      END
c
c
c
c
c
        subroutine alota12(mult,expcoefs)
        implicit real *8 (a-h,o-z)
        complex *16 mult(0:34,0:34),expcoefs(35,23)
        real *8 arr(15400)
c
        dimension map(23),nsstored(23),num1s(23),num2s(23)
c
 	save
c
c       this subroutine transforms a multipole expansion of
c       order 34 into a Bessel expansion of order (35,23)
c       the accuracy of the resulting scheme is about 12 digits.
c
c ... one wave number m after another, calcolate the coefficients of the
c         exponential expansion
c
        data ifinit/0/
        data map/1,1226,2382,3504,4560,5552,6512,7411,8251,9061,9841,
     1      10566,11238,11859,12453,12999,13499,13936,14332,14655,
     2      14927,15137,15277/
        data nsstored/1225,1156,1122,1056,992,960,899,840,810,780,725,
     1      672,621,594,546,500,437,396,323,272,210,140,65/
        data num1s/1,1,1,2,3,3,4,5,5,5,6,7,8,8,9,10,12,13,15,17,19,22,
     1      24/
        data num2s/35,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,
     1      34,33,33,32,31,28/
        if(ifinit .eq. 0) then
          call lot12get(arr)
          ifinit=1
        endif
c
        do 1400 i=1,23
        do 1200 j=1,35
c
        expcoefs(j,i)=0
 1200 continue
 1400 continue
c
        do 2000 m=0,22
c
        iarr=map(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
cccc        nnmult=15-m+1
        nnmult=34-m+1
        num1=num1s(m+1)
c
        call matvec34(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcoefs(num1,m+1) )
 2000 continue
        return
        end
c
c
c
c
c
        subroutine atalo12(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:34,0:34),expcoefs(35,23)
        real *8 arr(19400)
c
        dimension map(23),nsstored(23),num1s(23),num2s(23)
c
ccc        data map/1,1226,2416,3571,4691,5776,6826,7841,8821,9766,10676,
ccc     1       11551,12391,13196,13966,14701,15401,16066,16696,17291,
ccc     2       17851,18376,18866/
c
c
 	save
c
c       this subroutine transforms a Bessel expansion of order (35,23)
c       into a local expansion of order 34; the accuracy of the
c       resulting scheme is about 12 digits.
c
c ... one wave number m after another, calculate the coefficients of the
c         taylor series
c
        data ifinit/0/
        data map/1,1226,2416,3571,4691,5776,6826,7841,8902,9844,10751,
     1       11623,12460,13262,14029,14761,15610,16264,16883,17467,
     2       18121,18628,19100/
        data nsstored/1225,1190,1155,1120,1085,1050,1015,980,945,910,
     1       875,840,805,770,735,700,665,630,595,560,525,490,455/
        data num1s/1,1,1,1,1,1,1,1,4,4,
     1       4,4,4,4,4,4,12,12,12,12,19,19,19/
        data num2s/35,34,34,34,34,34,34,34,34,34,
     1       34,34,34,34,34,34,33,33,33,33,32,32,32/
        if(ifinit .eq. 0) then
ccc           do i = 1, 23
ccc              map(i) = map(i) + (num1s(i)-1)*(34-(i-1)+1)
ccc              print *, map(i),','
ccc           enddo
ccc           pause 'check'
          call lot12geta(arr(1))
          call lot12getb(arr(16001))
        ifinit=1
        endif
c
        do 1400 i=0,34
        do 1200 j=0,i
c
        taylor(i,j)=0
 1200 continue
 1400 continue
c
        ntaylor=34
cccc        numexp=35
c
        do 2000 m=0,22
c
        nntaylor=ntaylor-m+1
        iarr=map(m+1)
        num1=num1s(m+1)
        numexp=num2s(m+1)-num1+1
c
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(num1,m+1),taylor(m,m) )
 2000 continue
        return
        end
c
c
c
c
c
        subroutine atalo12_old(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:34,0:34),expcoefs(35,23)
        real *8 arr(19400)
c
        dimension map(23),nsstored(23)
c
 	save
c
c       this subroutine transforms a Bessel expansion of order (35,23)
c       into a local expansion of order 34; the accuracy of the
c       resulting scheme is about 12 digits.
c
c ... one wave number m after another, calculate the coefficients of the
c         taylor series
c
        data ifinit/0/
        data map/1,1226,2416,3571,4691,5776,6826,7841,8821,9766,10676,
     1       11551,12391,13196,13966,14701,15401,16066,16696,17291,
     2       17851,18376,18866/
        data nsstored/1225,1190,1155,1120,1085,1050,1015,980,945,910,
     1       875,840,805,770,735,700,665,630,595,560,525,490,455/
        if(ifinit .eq. 0) then
          call lot12geta(arr(1))
          call lot12getb(arr(16001))
c
        ntaylor=34
        numexp=35

        do 1400 i=0,34
        do 1200 j=0,i
c
        taylor(i,j)=0
 1200 continue
 1400 continue
        ifinit=1
        endif
c
        do 2000 m=0,22
c
        nntaylor=ntaylor-m+1
        iarr=map(m+1)
c
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(1,m+1),taylor(m,m) )
 2000 continue
        return
        end
c
c
c
c
c
        subroutine lot12get(arr)
        implicit real *8 (a-h,o-z)
c
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260(16),
     6  arr1261(16),arr1262(16),arr1263(16),arr1264(16),
     7  arr1265(16),arr1266(16),arr1267(16),arr1268(16),
     8  arr1269(16),arr1270(16),arr1271(16),arr1272(16),
     9  arr1273(16),arr1274(16),arr1275(16),arr1276(16),
     a  arr1277(16),arr1278(16),arr1279(16),arr1280(16)
         real *8
     1  arr1281(16),arr1282(16),arr1283(16),arr1284(16),
     2  arr1285(16),arr1286(16),arr1287(16),arr1288(16),
     3  arr1289(16),arr1290(16),arr1291(16),arr1292(16),
     4  arr1293(16),arr1294(16),arr1295(16),arr1296(16),
     5  arr1297(16),arr1298(16),arr1299(16),arr1300(16),
     6  arr1301(16),arr1302(16),arr1303(16),arr1304(16),
     7  arr1305(16),arr1306(16),arr1307(16),arr1308(16),
     8  arr1309(16),arr1310(16),arr1311(16),arr1312(16),
     9  arr1313(16),arr1314(16),arr1315(16),arr1316(16),
     a  arr1317(16),arr1318(16),arr1319(16),arr1320(16)
         real *8
     1  arr1321(16),arr1322(16),arr1323(16),arr1324(16),
     2  arr1325(16),arr1326(16),arr1327(16),arr1328(16),
     3  arr1329(16),arr1330(16),arr1331(16),arr1332(16),
     4  arr1333(16),arr1334(16),arr1335(16),arr1336(16),
     5  arr1337(16),arr1338(16),arr1339(16),arr1340(16),
     6  arr1341(16),arr1342(16),arr1343(16),arr1344(16),
     7  arr1345(16),arr1346(16),arr1347(16),arr1348(16),
     8  arr1349(16),arr1350(16),arr1351(16),arr1352(16),
     9  arr1353(16),arr1354(16),arr1355(16),arr1356(16),
     a  arr1357(16),arr1358(16),arr1359(16),arr1360(16)
         real *8
     1  arr1361(16),arr1362(16),arr1363(16),arr1364(16),
     2  arr1365(16),arr1366(16),arr1367(16),arr1368(16),
     3  arr1369(16),arr1370(16),arr1371(16),arr1372(16),
     4  arr1373(16),arr1374(16),arr1375(16),arr1376(16),
     5  arr1377(16),arr1378(16),arr1379(16),arr1380(16),
     6  arr1381(16),arr1382(16),arr1383(16),arr1384(16),
     7  arr1385(16),arr1386(16),arr1387(16),arr1388(16),
     8  arr1389(16),arr1390(16),arr1391(16),arr1392(16),
     9  arr1393(16),arr1394(16),arr1395(16),arr1396(16),
     a  arr1397(16),arr1398(16),arr1399(16),arr1400(16)
         real *8
     1  arr1401(16),arr1402(16),arr1403(16),arr1404(16),
     2  arr1405(16),arr1406(16),arr1407(16),arr1408(16),
     3  arr1409(16),arr1410(16),arr1411(16),arr1412(16),
     4  arr1413(16),arr1414(16),arr1415(16),arr1416(16),
     5  arr1417(16),arr1418(16),arr1419(16),arr1420(16),
     6  arr1421(16),arr1422(16),arr1423(16),arr1424(16),
     7  arr1425(16),arr1426(16),arr1427(16),arr1428(16),
     8  arr1429(16),arr1430(16),arr1431(16),arr1432(16),
     9  arr1433(16),arr1434(16),arr1435(16),arr1436(16),
     a  arr1437(16),arr1438(16),arr1439(16),arr1440(16)
         real *8
     1  arr1441(16),arr1442(16),arr1443(16),arr1444(16),
     2  arr1445(16),arr1446(16),arr1447(16),arr1448(16),
     3  arr1449(16),arr1450(16),arr1451(16),arr1452(16),
     4  arr1453(16),arr1454(16),arr1455(16),arr1456(16),
     5  arr1457(16),arr1458(16),arr1459(16),arr1460(16),
     6  arr1461(16),arr1462(16),arr1463(16),arr1464(16),
     7  arr1465(16),arr1466(16),arr1467(16),arr1468(16),
     8  arr1469(16),arr1470(16),arr1471(16),arr1472(16),
     9  arr1473(16),arr1474(16),arr1475(16),arr1476(16),
     a  arr1477(16),arr1478(16),arr1479(16),arr1480(16)
         real *8
     1  arr1481(16),arr1482(16),arr1483(16),arr1484(16),
     2  arr1485(16),arr1486(16),arr1487(16),arr1488(16),
     3  arr1489(16),arr1490(16),arr1491(16),arr1492(16),
     4  arr1493(16),arr1494(16),arr1495(16),arr1496(16),
     5  arr1497(16),arr1498(16),arr1499(16),arr1500(16),
     6  arr1501(16),arr1502(16),arr1503(16),arr1504(16),
     7  arr1505(16),arr1506(16),arr1507(16),arr1508(16),
     8  arr1509(16),arr1510(16),arr1511(16),arr1512(16),
     9  arr1513(16),arr1514(16),arr1515(16),arr1516(16),
     a  arr1517(16),arr1518(16),arr1519(16),arr1520(16)
         real *8
     1  arr1521(16),arr1522(16),arr1523(16),arr1524(16),
     2  arr1525(16),arr1526(16),arr1527(16),arr1528(16),
     3  arr1529(16),arr1530(16),arr1531(16),arr1532(16),
     4  arr1533(16),arr1534(16),arr1535(16),arr1536(16),
     5  arr1537(16),arr1538(16),arr1539(16),arr1540(16),
     6  arr1541(16),arr1542(16),arr1543(16),arr1544(16),
     7  arr1545(16),arr1546(16),arr1547(16),arr1548(16),
     8  arr1549(16),arr1550(16),arr1551(16),arr1552(16),
     9  arr1553(16),arr1554(16),arr1555(16),arr1556(16),
     a  arr1557(16),arr1558(16),arr1559(16),arr1560(16)
         real *8
     1  arr1561(16),arr1562(16),arr1563(16),arr1564(16),
     2  arr1565(16),arr1566(16),arr1567(16),arr1568(16),
     3  arr1569(16),arr1570(16),arr1571(16),arr1572(16),
     4  arr1573(16),arr1574(16),arr1575(16),arr1576(16),
     5  arr1577(16),arr1578(16),arr1579(16),arr1580(16),
     6  arr1581(16),arr1582(16),arr1583(16),arr1584(16),
     7  arr1585(16),arr1586(16),arr1587(16),arr1588(16),
     8  arr1589(16),arr1590(16),arr1591(16),arr1592(16),
     9  arr1593(16),arr1594(16),arr1595(16),arr1596(16),
     a  arr1597(16),arr1598(16),arr1599(16),arr1600(16)
         real *8
     1  arr1601(16),arr1602(16),arr1603(16),arr1604(16),
     2  arr1605(16),arr1606(16),arr1607(16),arr1608(16),
     3  arr1609(16),arr1610(16),arr1611(16),arr1612(16),
     4  arr1613(16),arr1614(16),arr1615(16),arr1616(16),
     5  arr1617(16),arr1618(16),arr1619(16),arr1620(16),
     6  arr1621(16),arr1622(16),arr1623(16),arr1624(16),
     7  arr1625(16),arr1626(16),arr1627(16),arr1628(16),
     8  arr1629(16),arr1630(16),arr1631(16),arr1632(16),
     9  arr1633(16),arr1634(16),arr1635(16),arr1636(16),
     a  arr1637(16),arr1638(16),arr1639(16),arr1640(16)
         real *8
     1  arr1641(16),arr1642(16),arr1643(16),arr1644(16),
     2  arr1645(16),arr1646(16),arr1647(16),arr1648(16),
     3  arr1649(16),arr1650(16),arr1651(16),arr1652(16),
     4  arr1653(16),arr1654(16),arr1655(16),arr1656(16),
     5  arr1657(16),arr1658(16),arr1659(16),arr1660(16),
     6  arr1661(16),arr1662(16),arr1663(16),arr1664(16),
     7  arr1665(16),arr1666(16),arr1667(16),arr1668(16),
     8  arr1669(16),arr1670(16),arr1671(16),arr1672(16),
     9  arr1673(16),arr1674(16),arr1675(16),arr1676(16),
     a  arr1677(16),arr1678(16),arr1679(16),arr1680(16)
         real *8
     1  arr1681(16),arr1682(16),arr1683(16),arr1684(16),
     2  arr1685(16),arr1686(16),arr1687(16),arr1688(16),
     3  arr1689(16),arr1690(16),arr1691(16),arr1692(16),
     4  arr1693(16),arr1694(16),arr1695(16),arr1696(16),
     5  arr1697(16),arr1698(16),arr1699(16),arr1700(16),
     6  arr1701(16),arr1702(16),arr1703(16),arr1704(16),
     7  arr1705(16),arr1706(16),arr1707(16),arr1708(16),
     8  arr1709(16),arr1710(16),arr1711(16),arr1712(16),
     9  arr1713(16),arr1714(16),arr1715(16),arr1716(16),
     a  arr1717(16),arr1718(16),arr1719(16),arr1720(16)
         real *8
     1  arr1721(16),arr1722(16),arr1723(16),arr1724(16),
     2  arr1725(16),arr1726(16),arr1727(16),arr1728(16),
     3  arr1729(16),arr1730(16),arr1731(16),arr1732(16),
     4  arr1733(16),arr1734(16),arr1735(16),arr1736(16),
     5  arr1737(16),arr1738(16),arr1739(16),arr1740(16),
     6  arr1741(16),arr1742(16),arr1743(16),arr1744(16),
     7  arr1745(16),arr1746(16),arr1747(16),arr1748(16),
     8  arr1749(16),arr1750(16),arr1751(16),arr1752(16),
     9  arr1753(16),arr1754(16),arr1755(16),arr1756(16),
     a  arr1757(16),arr1758(16),arr1759(16),arr1760(16)
         real *8
     1  arr1761(16),arr1762(16),arr1763(16),arr1764(16),
     2  arr1765(16),arr1766(16),arr1767(16),arr1768(16),
     3  arr1769(16),arr1770(16),arr1771(16),arr1772(16),
     4  arr1773(16),arr1774(16),arr1775(16),arr1776(16),
     5  arr1777(16),arr1778(16),arr1779(16),arr1780(16),
     6  arr1781(16),arr1782(16),arr1783(16),arr1784(16),
     7  arr1785(16),arr1786(16),arr1787(16),arr1788(16),
     8  arr1789(16),arr1790(16),arr1791(16),arr1792(16),
     9  arr1793(16),arr1794(16),arr1795(16),arr1796(16),
     a  arr1797(16),arr1798(16),arr1799(16),arr1800(16)
         real *8
     1  arr1801(16),arr1802(16),arr1803(16),arr1804(16),
     2  arr1805(16),arr1806(16),arr1807(16),arr1808(16),
     3  arr1809(16),arr1810(16),arr1811(16),arr1812(16),
     4  arr1813(16),arr1814(16),arr1815(16),arr1816(16),
     5  arr1817(16),arr1818(16),arr1819(16),arr1820(16),
     6  arr1821(16),arr1822(16),arr1823(16),arr1824(16),
     7  arr1825(16),arr1826(16),arr1827(16),arr1828(16),
     8  arr1829(16),arr1830(16),arr1831(16),arr1832(16),
     9  arr1833(16),arr1834(16),arr1835(16),arr1836(16),
     a  arr1837(16),arr1838(16),arr1839(16),arr1840(16)
         real *8
     1  arr1841(16),arr1842(16),arr1843(16),arr1844(16),
     2  arr1845(16),arr1846(16),arr1847(16),arr1848(16),
     3  arr1849(16),arr1850(16),arr1851(16),arr1852(16),
     4  arr1853(16),arr1854(16),arr1855(16),arr1856(16),
     5  arr1857(16),arr1858(16),arr1859(16),arr1860(16),
     6  arr1861(16),arr1862(16),arr1863(16),arr1864(16),
     7  arr1865(16),arr1866(16),arr1867(16),arr1868(16),
     8  arr1869(16),arr1870(16),arr1871(16),arr1872(16),
     9  arr1873(16),arr1874(16),arr1875(16),arr1876(16),
     a  arr1877(16),arr1878(16),arr1879(16),arr1880(16)
         real *8
     1  arr1881(16),arr1882(16),arr1883(16),arr1884(16),
     2  arr1885(16),arr1886(16),arr1887(16),arr1888(16),
     3  arr1889(16),arr1890(16),arr1891(16),arr1892(16),
     4  arr1893(16),arr1894(16),arr1895(16),arr1896(16),
     5  arr1897(16),arr1898(16),arr1899(16),arr1900(16),
     6  arr1901(16),arr1902(16),arr1903(16),arr1904(16),
     7  arr1905(16),arr1906(16),arr1907(16),arr1908(16),
     8  arr1909(16),arr1910(16),arr1911(16),arr1912(16),
     9  arr1913(16),arr1914(16),arr1915(16),arr1916(16),
     a  arr1917(16),arr1918(16),arr1919(16),arr1920(16)
         real *8
     1  arr1921(16),arr1922(16),arr1923(16),arr1924(16),
     2  arr1925(16),arr1926(16),arr1927(16),arr1928(16),
     3  arr1929(16),arr1930(16),arr1931(16),arr1932(16),
     4  arr1933(16),arr1934(16),arr1935(16),arr1936(16),
     5  arr1937(16),arr1938(16),arr1939(16),arr1940(16),
     6  arr1941(16),arr1942(16),arr1943(16),arr1944(16),
     7  arr1945(16),arr1946(16),arr1947(16),arr1948(16),
     8  arr1949(16),arr1950(16),arr1951(16),arr1952(16),
     9  arr1953(16),arr1954(16),arr1955(16),arr1956(16)
         real *8
     1  arr1957(16),arr1958(16),arr1959(13)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2),
     5  arr2257(2),arr2258(2),arr2259(2),arr2260(2),
     6  arr2261(2),arr2262(2),arr2263(2),arr2264(2),
     7  arr2265(2),arr2266(2),arr2267(2),arr2268(2),
     8  arr2269(2),arr2270(2),arr2271(2),arr2272(2),
     9  arr2273(2),arr2274(2),arr2275(2),arr2276(2),
     a  arr2277(2),arr2278(2),arr2279(2),arr2280(2)
         real *8
     1  arr2281(2),arr2282(2),arr2283(2),arr2284(2),
     2  arr2285(2),arr2286(2),arr2287(2),arr2288(2),
     3  arr2289(2),arr2290(2),arr2291(2),arr2292(2),
     4  arr2293(2),arr2294(2),arr2295(2),arr2296(2),
     5  arr2297(2),arr2298(2),arr2299(2),arr2300(2),
     6  arr2301(2),arr2302(2),arr2303(2),arr2304(2),
     7  arr2305(2),arr2306(2),arr2307(2),arr2308(2),
     8  arr2309(2),arr2310(2),arr2311(2),arr2312(2),
     9  arr2313(2),arr2314(2),arr2315(2),arr2316(2),
     a  arr2317(2),arr2318(2),arr2319(2),arr2320(2)
         real *8
     1  arr2321(2),arr2322(2),arr2323(2),arr2324(2),
     2  arr2325(2),arr2326(2),arr2327(2),arr2328(2),
     3  arr2329(2),arr2330(2),arr2331(2),arr2332(2),
     4  arr2333(2),arr2334(2),arr2335(2),arr2336(2),
     5  arr2337(2),arr2338(2),arr2339(2),arr2340(2),
     6  arr2341(2),arr2342(2),arr2343(2),arr2344(2),
     7  arr2345(2),arr2346(2),arr2347(2),arr2348(2),
     8  arr2349(2),arr2350(2),arr2351(2),arr2352(2),
     9  arr2353(2),arr2354(2),arr2355(2),arr2356(2),
     a  arr2357(2),arr2358(2),arr2359(2),arr2360(2)
         real *8
     1  arr2361(2),arr2362(2),arr2363(2),arr2364(2),
     2  arr2365(2),arr2366(2),arr2367(2),arr2368(2),
     3  arr2369(2),arr2370(2),arr2371(2),arr2372(2),
     4  arr2373(2),arr2374(2),arr2375(2),arr2376(2),
     5  arr2377(2),arr2378(2),arr2379(2),arr2380(2),
     6  arr2381(2),arr2382(2),arr2383(2),arr2384(2),
     7  arr2385(2),arr2386(2),arr2387(2),arr2388(2),
     8  arr2389(2),arr2390(2),arr2391(2),arr2392(2),
     9  arr2393(2),arr2394(2),arr2395(2),arr2396(2),
     a  arr2397(2),arr2398(2),arr2399(2),arr2400(2)
         real *8
     1  arr2401(2),arr2402(2),arr2403(2),arr2404(2),
     2  arr2405(2),arr2406(2),arr2407(2),arr2408(2),
     3  arr2409(2),arr2410(2),arr2411(2),arr2412(2),
     4  arr2413(2),arr2414(2),arr2415(2),arr2416(2),
     5  arr2417(2),arr2418(2),arr2419(2),arr2420(2),
     6  arr2421(2),arr2422(2),arr2423(2),arr2424(2),
     7  arr2425(2),arr2426(2),arr2427(2),arr2428(2),
     8  arr2429(2),arr2430(2),arr2431(2),arr2432(2),
     9  arr2433(2),arr2434(2),arr2435(2),arr2436(2),
     a  arr2437(2),arr2438(2),arr2439(2),arr2440(2)
         real *8
     1  arr2441(2),arr2442(2),arr2443(2),arr2444(2),
     2  arr2445(2),arr2446(2),arr2447(2),arr2448(2),
     3  arr2449(2),arr2450(2),arr2451(2),arr2452(2),
     4  arr2453(2),arr2454(2),arr2455(2),arr2456(2),
     5  arr2457(2),arr2458(2),arr2459(2),arr2460(2),
     6  arr2461(2),arr2462(2),arr2463(2),arr2464(2),
     7  arr2465(2),arr2466(2),arr2467(2),arr2468(2),
     8  arr2469(2),arr2470(2),arr2471(2),arr2472(2),
     9  arr2473(2),arr2474(2),arr2475(2),arr2476(2),
     a  arr2477(2),arr2478(2),arr2479(2),arr2480(2)
         real *8
     1  arr2481(2),arr2482(2),arr2483(2),arr2484(2),
     2  arr2485(2),arr2486(2),arr2487(2),arr2488(2),
     3  arr2489(2),arr2490(2),arr2491(2),arr2492(2),
     4  arr2493(2),arr2494(2),arr2495(2),arr2496(2),
     5  arr2497(2),arr2498(2),arr2499(2),arr2500(2),
     6  arr2501(2),arr2502(2),arr2503(2),arr2504(2),
     7  arr2505(2),arr2506(2),arr2507(2),arr2508(2),
     8  arr2509(2),arr2510(2),arr2511(2),arr2512(2),
     9  arr2513(2),arr2514(2),arr2515(2),arr2516(2),
     a  arr2517(2),arr2518(2),arr2519(2),arr2520(2)
         real *8
     1  arr2521(2),arr2522(2),arr2523(2),arr2524(2),
     2  arr2525(2),arr2526(2),arr2527(2),arr2528(2),
     3  arr2529(2),arr2530(2),arr2531(2),arr2532(2),
     4  arr2533(2),arr2534(2),arr2535(2),arr2536(2),
     5  arr2537(2),arr2538(2),arr2539(2),arr2540(2),
     6  arr2541(2),arr2542(2),arr2543(2),arr2544(2),
     7  arr2545(2),arr2546(2),arr2547(2),arr2548(2),
     8  arr2549(2),arr2550(2),arr2551(2),arr2552(2),
     9  arr2553(2),arr2554(2),arr2555(2),arr2556(2),
     a  arr2557(2),arr2558(2),arr2559(2),arr2560(2)
         real *8
     1  arr2561(2),arr2562(2),arr2563(2),arr2564(2),
     2  arr2565(2),arr2566(2),arr2567(2),arr2568(2),
     3  arr2569(2),arr2570(2),arr2571(2),arr2572(2),
     4  arr2573(2),arr2574(2),arr2575(2),arr2576(2),
     5  arr2577(2),arr2578(2),arr2579(2),arr2580(2),
     6  arr2581(2),arr2582(2),arr2583(2),arr2584(2),
     7  arr2585(2),arr2586(2),arr2587(2),arr2588(2),
     8  arr2589(2),arr2590(2),arr2591(2),arr2592(2),
     9  arr2593(2),arr2594(2),arr2595(2),arr2596(2),
     a  arr2597(2),arr2598(2),arr2599(2),arr2600(2)
         real *8
     1  arr2601(2),arr2602(2),arr2603(2),arr2604(2),
     2  arr2605(2),arr2606(2),arr2607(2),arr2608(2),
     3  arr2609(2),arr2610(2),arr2611(2),arr2612(2),
     4  arr2613(2),arr2614(2),arr2615(2),arr2616(2),
     5  arr2617(2),arr2618(2),arr2619(2),arr2620(2),
     6  arr2621(2),arr2622(2),arr2623(2),arr2624(2),
     7  arr2625(2),arr2626(2),arr2627(2),arr2628(2),
     8  arr2629(2),arr2630(2),arr2631(2),arr2632(2),
     9  arr2633(2),arr2634(2),arr2635(2),arr2636(2),
     a  arr2637(2),arr2638(2),arr2639(2),arr2640(2)
         real *8
     1  arr2641(2),arr2642(2),arr2643(2),arr2644(2),
     2  arr2645(2),arr2646(2),arr2647(2),arr2648(2),
     3  arr2649(2),arr2650(2),arr2651(2),arr2652(2),
     4  arr2653(2),arr2654(2),arr2655(2),arr2656(2),
     5  arr2657(2),arr2658(2),arr2659(2),arr2660(2),
     6  arr2661(2),arr2662(2),arr2663(2),arr2664(2),
     7  arr2665(2),arr2666(2),arr2667(2),arr2668(2),
     8  arr2669(2),arr2670(2),arr2671(2),arr2672(2),
     9  arr2673(2),arr2674(2),arr2675(2),arr2676(2),
     a  arr2677(2),arr2678(2),arr2679(2),arr2680(2)
         real *8
     1  arr2681(2),arr2682(2),arr2683(2),arr2684(2),
     2  arr2685(2),arr2686(2),arr2687(2),arr2688(2),
     3  arr2689(2),arr2690(2),arr2691(2),arr2692(2),
     4  arr2693(2),arr2694(2),arr2695(2),arr2696(2),
     5  arr2697(2),arr2698(2),arr2699(2),arr2700(2),
     6  arr2701(2),arr2702(2),arr2703(2),arr2704(2),
     7  arr2705(2),arr2706(2),arr2707(2),arr2708(2),
     8  arr2709(2),arr2710(2),arr2711(2),arr2712(2),
     9  arr2713(2),arr2714(2),arr2715(2),arr2716(2),
     a  arr2717(2),arr2718(2),arr2719(2),arr2720(2)
         real *8
     1  arr2721(2),arr2722(2),arr2723(2),arr2724(2),
     2  arr2725(2),arr2726(2),arr2727(2),arr2728(2),
     3  arr2729(2),arr2730(2),arr2731(2),arr2732(2),
     4  arr2733(2),arr2734(2),arr2735(2),arr2736(2),
     5  arr2737(2),arr2738(2),arr2739(2),arr2740(2),
     6  arr2741(2),arr2742(2),arr2743(2),arr2744(2),
     7  arr2745(2),arr2746(2),arr2747(2),arr2748(2),
     8  arr2749(2),arr2750(2),arr2751(2),arr2752(2),
     9  arr2753(2),arr2754(2),arr2755(2),arr2756(2),
     a  arr2757(2),arr2758(2),arr2759(2),arr2760(2)
         real *8
     1  arr2761(2),arr2762(2),arr2763(2),arr2764(2),
     2  arr2765(2),arr2766(2),arr2767(2),arr2768(2),
     3  arr2769(2),arr2770(2),arr2771(2),arr2772(2),
     4  arr2773(2),arr2774(2),arr2775(2),arr2776(2),
     5  arr2777(2),arr2778(2),arr2779(2),arr2780(2),
     6  arr2781(2),arr2782(2),arr2783(2),arr2784(2),
     7  arr2785(2),arr2786(2),arr2787(2),arr2788(2),
     8  arr2789(2),arr2790(2),arr2791(2),arr2792(2),
     9  arr2793(2),arr2794(2),arr2795(2),arr2796(2),
     a  arr2797(2),arr2798(2),arr2799(2),arr2800(2)
         real *8
     1  arr2801(2),arr2802(2),arr2803(2),arr2804(2),
     2  arr2805(2),arr2806(2),arr2807(2),arr2808(2),
     3  arr2809(2),arr2810(2),arr2811(2),arr2812(2),
     4  arr2813(2),arr2814(2),arr2815(2),arr2816(2),
     5  arr2817(2),arr2818(2),arr2819(2),arr2820(2),
     6  arr2821(2),arr2822(2),arr2823(2),arr2824(2),
     7  arr2825(2),arr2826(2),arr2827(2),arr2828(2),
     8  arr2829(2),arr2830(2),arr2831(2),arr2832(2),
     9  arr2833(2),arr2834(2),arr2835(2),arr2836(2),
     a  arr2837(2),arr2838(2),arr2839(2),arr2840(2)
         real *8
     1  arr2841(2),arr2842(2),arr2843(2),arr2844(2),
     2  arr2845(2),arr2846(2),arr2847(2),arr2848(2),
     3  arr2849(2),arr2850(2),arr2851(2),arr2852(2),
     4  arr2853(2),arr2854(2),arr2855(2),arr2856(2),
     5  arr2857(2),arr2858(2),arr2859(2),arr2860(2),
     6  arr2861(2),arr2862(2),arr2863(2),arr2864(2),
     7  arr2865(2),arr2866(2),arr2867(2),arr2868(2),
     8  arr2869(2),arr2870(2),arr2871(2),arr2872(2),
     9  arr2873(2),arr2874(2),arr2875(2),arr2876(2),
     a  arr2877(2),arr2878(2),arr2879(2),arr2880(2)
         real *8
     1  arr2881(2),arr2882(2),arr2883(2),arr2884(2),
     2  arr2885(2),arr2886(2),arr2887(2),arr2888(2),
     3  arr2889(2),arr2890(2),arr2891(2),arr2892(2),
     4  arr2893(2),arr2894(2),arr2895(2),arr2896(2),
     5  arr2897(2),arr2898(2),arr2899(2),arr2900(2),
     6  arr2901(2),arr2902(2),arr2903(2),arr2904(2),
     7  arr2905(2),arr2906(2),arr2907(2),arr2908(2),
     8  arr2909(2),arr2910(2),arr2911(2),arr2912(2),
     9  arr2913(2),arr2914(2),arr2915(2),arr2916(2),
     a  arr2917(2),arr2918(2),arr2919(2),arr2920(2)
         real *8
     1  arr2921(2),arr2922(2),arr2923(2),arr2924(2),
     2  arr2925(2),arr2926(2),arr2927(2),arr2928(2),
     3  arr2929(2),arr2930(2),arr2931(2),arr2932(2),
     4  arr2933(2),arr2934(2),arr2935(2),arr2936(2),
     5  arr2937(2),arr2938(2),arr2939(2),arr2940(2),
     6  arr2941(2),arr2942(2),arr2943(2),arr2944(2),
     7  arr2945(2),arr2946(2),arr2947(2),arr2948(2),
     8  arr2949(2),arr2950(2),arr2951(2),arr2952(2),
     9  arr2953(2),arr2954(2),arr2955(2),arr2956(2)
         real *8
     1  arr2957(2),arr2958(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2)),
     a  (arr1260(16),arr2260(1)),(arr1261(1),arr2260(2))
         equivalence
     1  (arr1261(16),arr2261(1)),(arr1262(1),arr2261(2)),
     2  (arr1262(16),arr2262(1)),(arr1263(1),arr2262(2)),
     3  (arr1263(16),arr2263(1)),(arr1264(1),arr2263(2)),
     4  (arr1264(16),arr2264(1)),(arr1265(1),arr2264(2)),
     5  (arr1265(16),arr2265(1)),(arr1266(1),arr2265(2)),
     6  (arr1266(16),arr2266(1)),(arr1267(1),arr2266(2)),
     7  (arr1267(16),arr2267(1)),(arr1268(1),arr2267(2)),
     8  (arr1268(16),arr2268(1)),(arr1269(1),arr2268(2)),
     9  (arr1269(16),arr2269(1)),(arr1270(1),arr2269(2)),
     a  (arr1270(16),arr2270(1)),(arr1271(1),arr2270(2))
         equivalence
     1  (arr1271(16),arr2271(1)),(arr1272(1),arr2271(2)),
     2  (arr1272(16),arr2272(1)),(arr1273(1),arr2272(2)),
     3  (arr1273(16),arr2273(1)),(arr1274(1),arr2273(2)),
     4  (arr1274(16),arr2274(1)),(arr1275(1),arr2274(2)),
     5  (arr1275(16),arr2275(1)),(arr1276(1),arr2275(2)),
     6  (arr1276(16),arr2276(1)),(arr1277(1),arr2276(2)),
     7  (arr1277(16),arr2277(1)),(arr1278(1),arr2277(2)),
     8  (arr1278(16),arr2278(1)),(arr1279(1),arr2278(2)),
     9  (arr1279(16),arr2279(1)),(arr1280(1),arr2279(2)),
     a  (arr1280(16),arr2280(1)),(arr1281(1),arr2280(2))
         equivalence
     1  (arr1281(16),arr2281(1)),(arr1282(1),arr2281(2)),
     2  (arr1282(16),arr2282(1)),(arr1283(1),arr2282(2)),
     3  (arr1283(16),arr2283(1)),(arr1284(1),arr2283(2)),
     4  (arr1284(16),arr2284(1)),(arr1285(1),arr2284(2)),
     5  (arr1285(16),arr2285(1)),(arr1286(1),arr2285(2)),
     6  (arr1286(16),arr2286(1)),(arr1287(1),arr2286(2)),
     7  (arr1287(16),arr2287(1)),(arr1288(1),arr2287(2)),
     8  (arr1288(16),arr2288(1)),(arr1289(1),arr2288(2)),
     9  (arr1289(16),arr2289(1)),(arr1290(1),arr2289(2)),
     a  (arr1290(16),arr2290(1)),(arr1291(1),arr2290(2))
         equivalence
     1  (arr1291(16),arr2291(1)),(arr1292(1),arr2291(2)),
     2  (arr1292(16),arr2292(1)),(arr1293(1),arr2292(2)),
     3  (arr1293(16),arr2293(1)),(arr1294(1),arr2293(2)),
     4  (arr1294(16),arr2294(1)),(arr1295(1),arr2294(2)),
     5  (arr1295(16),arr2295(1)),(arr1296(1),arr2295(2)),
     6  (arr1296(16),arr2296(1)),(arr1297(1),arr2296(2)),
     7  (arr1297(16),arr2297(1)),(arr1298(1),arr2297(2)),
     8  (arr1298(16),arr2298(1)),(arr1299(1),arr2298(2)),
     9  (arr1299(16),arr2299(1)),(arr1300(1),arr2299(2)),
     a  (arr1300(16),arr2300(1)),(arr1301(1),arr2300(2))
         equivalence
     1  (arr1301(16),arr2301(1)),(arr1302(1),arr2301(2)),
     2  (arr1302(16),arr2302(1)),(arr1303(1),arr2302(2)),
     3  (arr1303(16),arr2303(1)),(arr1304(1),arr2303(2)),
     4  (arr1304(16),arr2304(1)),(arr1305(1),arr2304(2)),
     5  (arr1305(16),arr2305(1)),(arr1306(1),arr2305(2)),
     6  (arr1306(16),arr2306(1)),(arr1307(1),arr2306(2)),
     7  (arr1307(16),arr2307(1)),(arr1308(1),arr2307(2)),
     8  (arr1308(16),arr2308(1)),(arr1309(1),arr2308(2)),
     9  (arr1309(16),arr2309(1)),(arr1310(1),arr2309(2)),
     a  (arr1310(16),arr2310(1)),(arr1311(1),arr2310(2))
         equivalence
     1  (arr1311(16),arr2311(1)),(arr1312(1),arr2311(2)),
     2  (arr1312(16),arr2312(1)),(arr1313(1),arr2312(2)),
     3  (arr1313(16),arr2313(1)),(arr1314(1),arr2313(2)),
     4  (arr1314(16),arr2314(1)),(arr1315(1),arr2314(2)),
     5  (arr1315(16),arr2315(1)),(arr1316(1),arr2315(2)),
     6  (arr1316(16),arr2316(1)),(arr1317(1),arr2316(2)),
     7  (arr1317(16),arr2317(1)),(arr1318(1),arr2317(2)),
     8  (arr1318(16),arr2318(1)),(arr1319(1),arr2318(2)),
     9  (arr1319(16),arr2319(1)),(arr1320(1),arr2319(2)),
     a  (arr1320(16),arr2320(1)),(arr1321(1),arr2320(2))
         equivalence
     1  (arr1321(16),arr2321(1)),(arr1322(1),arr2321(2)),
     2  (arr1322(16),arr2322(1)),(arr1323(1),arr2322(2)),
     3  (arr1323(16),arr2323(1)),(arr1324(1),arr2323(2)),
     4  (arr1324(16),arr2324(1)),(arr1325(1),arr2324(2)),
     5  (arr1325(16),arr2325(1)),(arr1326(1),arr2325(2)),
     6  (arr1326(16),arr2326(1)),(arr1327(1),arr2326(2)),
     7  (arr1327(16),arr2327(1)),(arr1328(1),arr2327(2)),
     8  (arr1328(16),arr2328(1)),(arr1329(1),arr2328(2)),
     9  (arr1329(16),arr2329(1)),(arr1330(1),arr2329(2)),
     a  (arr1330(16),arr2330(1)),(arr1331(1),arr2330(2))
         equivalence
     1  (arr1331(16),arr2331(1)),(arr1332(1),arr2331(2)),
     2  (arr1332(16),arr2332(1)),(arr1333(1),arr2332(2)),
     3  (arr1333(16),arr2333(1)),(arr1334(1),arr2333(2)),
     4  (arr1334(16),arr2334(1)),(arr1335(1),arr2334(2)),
     5  (arr1335(16),arr2335(1)),(arr1336(1),arr2335(2)),
     6  (arr1336(16),arr2336(1)),(arr1337(1),arr2336(2)),
     7  (arr1337(16),arr2337(1)),(arr1338(1),arr2337(2)),
     8  (arr1338(16),arr2338(1)),(arr1339(1),arr2338(2)),
     9  (arr1339(16),arr2339(1)),(arr1340(1),arr2339(2)),
     a  (arr1340(16),arr2340(1)),(arr1341(1),arr2340(2))
         equivalence
     1  (arr1341(16),arr2341(1)),(arr1342(1),arr2341(2)),
     2  (arr1342(16),arr2342(1)),(arr1343(1),arr2342(2)),
     3  (arr1343(16),arr2343(1)),(arr1344(1),arr2343(2)),
     4  (arr1344(16),arr2344(1)),(arr1345(1),arr2344(2)),
     5  (arr1345(16),arr2345(1)),(arr1346(1),arr2345(2)),
     6  (arr1346(16),arr2346(1)),(arr1347(1),arr2346(2)),
     7  (arr1347(16),arr2347(1)),(arr1348(1),arr2347(2)),
     8  (arr1348(16),arr2348(1)),(arr1349(1),arr2348(2)),
     9  (arr1349(16),arr2349(1)),(arr1350(1),arr2349(2)),
     a  (arr1350(16),arr2350(1)),(arr1351(1),arr2350(2))
         equivalence
     1  (arr1351(16),arr2351(1)),(arr1352(1),arr2351(2)),
     2  (arr1352(16),arr2352(1)),(arr1353(1),arr2352(2)),
     3  (arr1353(16),arr2353(1)),(arr1354(1),arr2353(2)),
     4  (arr1354(16),arr2354(1)),(arr1355(1),arr2354(2)),
     5  (arr1355(16),arr2355(1)),(arr1356(1),arr2355(2)),
     6  (arr1356(16),arr2356(1)),(arr1357(1),arr2356(2)),
     7  (arr1357(16),arr2357(1)),(arr1358(1),arr2357(2)),
     8  (arr1358(16),arr2358(1)),(arr1359(1),arr2358(2)),
     9  (arr1359(16),arr2359(1)),(arr1360(1),arr2359(2)),
     a  (arr1360(16),arr2360(1)),(arr1361(1),arr2360(2))
         equivalence
     1  (arr1361(16),arr2361(1)),(arr1362(1),arr2361(2)),
     2  (arr1362(16),arr2362(1)),(arr1363(1),arr2362(2)),
     3  (arr1363(16),arr2363(1)),(arr1364(1),arr2363(2)),
     4  (arr1364(16),arr2364(1)),(arr1365(1),arr2364(2)),
     5  (arr1365(16),arr2365(1)),(arr1366(1),arr2365(2)),
     6  (arr1366(16),arr2366(1)),(arr1367(1),arr2366(2)),
     7  (arr1367(16),arr2367(1)),(arr1368(1),arr2367(2)),
     8  (arr1368(16),arr2368(1)),(arr1369(1),arr2368(2)),
     9  (arr1369(16),arr2369(1)),(arr1370(1),arr2369(2)),
     a  (arr1370(16),arr2370(1)),(arr1371(1),arr2370(2))
         equivalence
     1  (arr1371(16),arr2371(1)),(arr1372(1),arr2371(2)),
     2  (arr1372(16),arr2372(1)),(arr1373(1),arr2372(2)),
     3  (arr1373(16),arr2373(1)),(arr1374(1),arr2373(2)),
     4  (arr1374(16),arr2374(1)),(arr1375(1),arr2374(2)),
     5  (arr1375(16),arr2375(1)),(arr1376(1),arr2375(2)),
     6  (arr1376(16),arr2376(1)),(arr1377(1),arr2376(2)),
     7  (arr1377(16),arr2377(1)),(arr1378(1),arr2377(2)),
     8  (arr1378(16),arr2378(1)),(arr1379(1),arr2378(2)),
     9  (arr1379(16),arr2379(1)),(arr1380(1),arr2379(2)),
     a  (arr1380(16),arr2380(1)),(arr1381(1),arr2380(2))
         equivalence
     1  (arr1381(16),arr2381(1)),(arr1382(1),arr2381(2)),
     2  (arr1382(16),arr2382(1)),(arr1383(1),arr2382(2)),
     3  (arr1383(16),arr2383(1)),(arr1384(1),arr2383(2)),
     4  (arr1384(16),arr2384(1)),(arr1385(1),arr2384(2)),
     5  (arr1385(16),arr2385(1)),(arr1386(1),arr2385(2)),
     6  (arr1386(16),arr2386(1)),(arr1387(1),arr2386(2)),
     7  (arr1387(16),arr2387(1)),(arr1388(1),arr2387(2)),
     8  (arr1388(16),arr2388(1)),(arr1389(1),arr2388(2)),
     9  (arr1389(16),arr2389(1)),(arr1390(1),arr2389(2)),
     a  (arr1390(16),arr2390(1)),(arr1391(1),arr2390(2))
         equivalence
     1  (arr1391(16),arr2391(1)),(arr1392(1),arr2391(2)),
     2  (arr1392(16),arr2392(1)),(arr1393(1),arr2392(2)),
     3  (arr1393(16),arr2393(1)),(arr1394(1),arr2393(2)),
     4  (arr1394(16),arr2394(1)),(arr1395(1),arr2394(2)),
     5  (arr1395(16),arr2395(1)),(arr1396(1),arr2395(2)),
     6  (arr1396(16),arr2396(1)),(arr1397(1),arr2396(2)),
     7  (arr1397(16),arr2397(1)),(arr1398(1),arr2397(2)),
     8  (arr1398(16),arr2398(1)),(arr1399(1),arr2398(2)),
     9  (arr1399(16),arr2399(1)),(arr1400(1),arr2399(2)),
     a  (arr1400(16),arr2400(1)),(arr1401(1),arr2400(2))
         equivalence
     1  (arr1401(16),arr2401(1)),(arr1402(1),arr2401(2)),
     2  (arr1402(16),arr2402(1)),(arr1403(1),arr2402(2)),
     3  (arr1403(16),arr2403(1)),(arr1404(1),arr2403(2)),
     4  (arr1404(16),arr2404(1)),(arr1405(1),arr2404(2)),
     5  (arr1405(16),arr2405(1)),(arr1406(1),arr2405(2)),
     6  (arr1406(16),arr2406(1)),(arr1407(1),arr2406(2)),
     7  (arr1407(16),arr2407(1)),(arr1408(1),arr2407(2)),
     8  (arr1408(16),arr2408(1)),(arr1409(1),arr2408(2)),
     9  (arr1409(16),arr2409(1)),(arr1410(1),arr2409(2)),
     a  (arr1410(16),arr2410(1)),(arr1411(1),arr2410(2))
         equivalence
     1  (arr1411(16),arr2411(1)),(arr1412(1),arr2411(2)),
     2  (arr1412(16),arr2412(1)),(arr1413(1),arr2412(2)),
     3  (arr1413(16),arr2413(1)),(arr1414(1),arr2413(2)),
     4  (arr1414(16),arr2414(1)),(arr1415(1),arr2414(2)),
     5  (arr1415(16),arr2415(1)),(arr1416(1),arr2415(2)),
     6  (arr1416(16),arr2416(1)),(arr1417(1),arr2416(2)),
     7  (arr1417(16),arr2417(1)),(arr1418(1),arr2417(2)),
     8  (arr1418(16),arr2418(1)),(arr1419(1),arr2418(2)),
     9  (arr1419(16),arr2419(1)),(arr1420(1),arr2419(2)),
     a  (arr1420(16),arr2420(1)),(arr1421(1),arr2420(2))
         equivalence
     1  (arr1421(16),arr2421(1)),(arr1422(1),arr2421(2)),
     2  (arr1422(16),arr2422(1)),(arr1423(1),arr2422(2)),
     3  (arr1423(16),arr2423(1)),(arr1424(1),arr2423(2)),
     4  (arr1424(16),arr2424(1)),(arr1425(1),arr2424(2)),
     5  (arr1425(16),arr2425(1)),(arr1426(1),arr2425(2)),
     6  (arr1426(16),arr2426(1)),(arr1427(1),arr2426(2)),
     7  (arr1427(16),arr2427(1)),(arr1428(1),arr2427(2)),
     8  (arr1428(16),arr2428(1)),(arr1429(1),arr2428(2)),
     9  (arr1429(16),arr2429(1)),(arr1430(1),arr2429(2)),
     a  (arr1430(16),arr2430(1)),(arr1431(1),arr2430(2))
         equivalence
     1  (arr1431(16),arr2431(1)),(arr1432(1),arr2431(2)),
     2  (arr1432(16),arr2432(1)),(arr1433(1),arr2432(2)),
     3  (arr1433(16),arr2433(1)),(arr1434(1),arr2433(2)),
     4  (arr1434(16),arr2434(1)),(arr1435(1),arr2434(2)),
     5  (arr1435(16),arr2435(1)),(arr1436(1),arr2435(2)),
     6  (arr1436(16),arr2436(1)),(arr1437(1),arr2436(2)),
     7  (arr1437(16),arr2437(1)),(arr1438(1),arr2437(2)),
     8  (arr1438(16),arr2438(1)),(arr1439(1),arr2438(2)),
     9  (arr1439(16),arr2439(1)),(arr1440(1),arr2439(2)),
     a  (arr1440(16),arr2440(1)),(arr1441(1),arr2440(2))
         equivalence
     1  (arr1441(16),arr2441(1)),(arr1442(1),arr2441(2)),
     2  (arr1442(16),arr2442(1)),(arr1443(1),arr2442(2)),
     3  (arr1443(16),arr2443(1)),(arr1444(1),arr2443(2)),
     4  (arr1444(16),arr2444(1)),(arr1445(1),arr2444(2)),
     5  (arr1445(16),arr2445(1)),(arr1446(1),arr2445(2)),
     6  (arr1446(16),arr2446(1)),(arr1447(1),arr2446(2)),
     7  (arr1447(16),arr2447(1)),(arr1448(1),arr2447(2)),
     8  (arr1448(16),arr2448(1)),(arr1449(1),arr2448(2)),
     9  (arr1449(16),arr2449(1)),(arr1450(1),arr2449(2)),
     a  (arr1450(16),arr2450(1)),(arr1451(1),arr2450(2))
         equivalence
     1  (arr1451(16),arr2451(1)),(arr1452(1),arr2451(2)),
     2  (arr1452(16),arr2452(1)),(arr1453(1),arr2452(2)),
     3  (arr1453(16),arr2453(1)),(arr1454(1),arr2453(2)),
     4  (arr1454(16),arr2454(1)),(arr1455(1),arr2454(2)),
     5  (arr1455(16),arr2455(1)),(arr1456(1),arr2455(2)),
     6  (arr1456(16),arr2456(1)),(arr1457(1),arr2456(2)),
     7  (arr1457(16),arr2457(1)),(arr1458(1),arr2457(2)),
     8  (arr1458(16),arr2458(1)),(arr1459(1),arr2458(2)),
     9  (arr1459(16),arr2459(1)),(arr1460(1),arr2459(2)),
     a  (arr1460(16),arr2460(1)),(arr1461(1),arr2460(2))
         equivalence
     1  (arr1461(16),arr2461(1)),(arr1462(1),arr2461(2)),
     2  (arr1462(16),arr2462(1)),(arr1463(1),arr2462(2)),
     3  (arr1463(16),arr2463(1)),(arr1464(1),arr2463(2)),
     4  (arr1464(16),arr2464(1)),(arr1465(1),arr2464(2)),
     5  (arr1465(16),arr2465(1)),(arr1466(1),arr2465(2)),
     6  (arr1466(16),arr2466(1)),(arr1467(1),arr2466(2)),
     7  (arr1467(16),arr2467(1)),(arr1468(1),arr2467(2)),
     8  (arr1468(16),arr2468(1)),(arr1469(1),arr2468(2)),
     9  (arr1469(16),arr2469(1)),(arr1470(1),arr2469(2)),
     a  (arr1470(16),arr2470(1)),(arr1471(1),arr2470(2))
         equivalence
     1  (arr1471(16),arr2471(1)),(arr1472(1),arr2471(2)),
     2  (arr1472(16),arr2472(1)),(arr1473(1),arr2472(2)),
     3  (arr1473(16),arr2473(1)),(arr1474(1),arr2473(2)),
     4  (arr1474(16),arr2474(1)),(arr1475(1),arr2474(2)),
     5  (arr1475(16),arr2475(1)),(arr1476(1),arr2475(2)),
     6  (arr1476(16),arr2476(1)),(arr1477(1),arr2476(2)),
     7  (arr1477(16),arr2477(1)),(arr1478(1),arr2477(2)),
     8  (arr1478(16),arr2478(1)),(arr1479(1),arr2478(2)),
     9  (arr1479(16),arr2479(1)),(arr1480(1),arr2479(2)),
     a  (arr1480(16),arr2480(1)),(arr1481(1),arr2480(2))
         equivalence
     1  (arr1481(16),arr2481(1)),(arr1482(1),arr2481(2)),
     2  (arr1482(16),arr2482(1)),(arr1483(1),arr2482(2)),
     3  (arr1483(16),arr2483(1)),(arr1484(1),arr2483(2)),
     4  (arr1484(16),arr2484(1)),(arr1485(1),arr2484(2)),
     5  (arr1485(16),arr2485(1)),(arr1486(1),arr2485(2)),
     6  (arr1486(16),arr2486(1)),(arr1487(1),arr2486(2)),
     7  (arr1487(16),arr2487(1)),(arr1488(1),arr2487(2)),
     8  (arr1488(16),arr2488(1)),(arr1489(1),arr2488(2)),
     9  (arr1489(16),arr2489(1)),(arr1490(1),arr2489(2)),
     a  (arr1490(16),arr2490(1)),(arr1491(1),arr2490(2))
         equivalence
     1  (arr1491(16),arr2491(1)),(arr1492(1),arr2491(2)),
     2  (arr1492(16),arr2492(1)),(arr1493(1),arr2492(2)),
     3  (arr1493(16),arr2493(1)),(arr1494(1),arr2493(2)),
     4  (arr1494(16),arr2494(1)),(arr1495(1),arr2494(2)),
     5  (arr1495(16),arr2495(1)),(arr1496(1),arr2495(2)),
     6  (arr1496(16),arr2496(1)),(arr1497(1),arr2496(2)),
     7  (arr1497(16),arr2497(1)),(arr1498(1),arr2497(2)),
     8  (arr1498(16),arr2498(1)),(arr1499(1),arr2498(2)),
     9  (arr1499(16),arr2499(1)),(arr1500(1),arr2499(2)),
     a  (arr1500(16),arr2500(1)),(arr1501(1),arr2500(2))
         equivalence
     1  (arr1501(16),arr2501(1)),(arr1502(1),arr2501(2)),
     2  (arr1502(16),arr2502(1)),(arr1503(1),arr2502(2)),
     3  (arr1503(16),arr2503(1)),(arr1504(1),arr2503(2)),
     4  (arr1504(16),arr2504(1)),(arr1505(1),arr2504(2)),
     5  (arr1505(16),arr2505(1)),(arr1506(1),arr2505(2)),
     6  (arr1506(16),arr2506(1)),(arr1507(1),arr2506(2)),
     7  (arr1507(16),arr2507(1)),(arr1508(1),arr2507(2)),
     8  (arr1508(16),arr2508(1)),(arr1509(1),arr2508(2)),
     9  (arr1509(16),arr2509(1)),(arr1510(1),arr2509(2)),
     a  (arr1510(16),arr2510(1)),(arr1511(1),arr2510(2))
         equivalence
     1  (arr1511(16),arr2511(1)),(arr1512(1),arr2511(2)),
     2  (arr1512(16),arr2512(1)),(arr1513(1),arr2512(2)),
     3  (arr1513(16),arr2513(1)),(arr1514(1),arr2513(2)),
     4  (arr1514(16),arr2514(1)),(arr1515(1),arr2514(2)),
     5  (arr1515(16),arr2515(1)),(arr1516(1),arr2515(2)),
     6  (arr1516(16),arr2516(1)),(arr1517(1),arr2516(2)),
     7  (arr1517(16),arr2517(1)),(arr1518(1),arr2517(2)),
     8  (arr1518(16),arr2518(1)),(arr1519(1),arr2518(2)),
     9  (arr1519(16),arr2519(1)),(arr1520(1),arr2519(2)),
     a  (arr1520(16),arr2520(1)),(arr1521(1),arr2520(2))
         equivalence
     1  (arr1521(16),arr2521(1)),(arr1522(1),arr2521(2)),
     2  (arr1522(16),arr2522(1)),(arr1523(1),arr2522(2)),
     3  (arr1523(16),arr2523(1)),(arr1524(1),arr2523(2)),
     4  (arr1524(16),arr2524(1)),(arr1525(1),arr2524(2)),
     5  (arr1525(16),arr2525(1)),(arr1526(1),arr2525(2)),
     6  (arr1526(16),arr2526(1)),(arr1527(1),arr2526(2)),
     7  (arr1527(16),arr2527(1)),(arr1528(1),arr2527(2)),
     8  (arr1528(16),arr2528(1)),(arr1529(1),arr2528(2)),
     9  (arr1529(16),arr2529(1)),(arr1530(1),arr2529(2)),
     a  (arr1530(16),arr2530(1)),(arr1531(1),arr2530(2))
         equivalence
     1  (arr1531(16),arr2531(1)),(arr1532(1),arr2531(2)),
     2  (arr1532(16),arr2532(1)),(arr1533(1),arr2532(2)),
     3  (arr1533(16),arr2533(1)),(arr1534(1),arr2533(2)),
     4  (arr1534(16),arr2534(1)),(arr1535(1),arr2534(2)),
     5  (arr1535(16),arr2535(1)),(arr1536(1),arr2535(2)),
     6  (arr1536(16),arr2536(1)),(arr1537(1),arr2536(2)),
     7  (arr1537(16),arr2537(1)),(arr1538(1),arr2537(2)),
     8  (arr1538(16),arr2538(1)),(arr1539(1),arr2538(2)),
     9  (arr1539(16),arr2539(1)),(arr1540(1),arr2539(2)),
     a  (arr1540(16),arr2540(1)),(arr1541(1),arr2540(2))
         equivalence
     1  (arr1541(16),arr2541(1)),(arr1542(1),arr2541(2)),
     2  (arr1542(16),arr2542(1)),(arr1543(1),arr2542(2)),
     3  (arr1543(16),arr2543(1)),(arr1544(1),arr2543(2)),
     4  (arr1544(16),arr2544(1)),(arr1545(1),arr2544(2)),
     5  (arr1545(16),arr2545(1)),(arr1546(1),arr2545(2)),
     6  (arr1546(16),arr2546(1)),(arr1547(1),arr2546(2)),
     7  (arr1547(16),arr2547(1)),(arr1548(1),arr2547(2)),
     8  (arr1548(16),arr2548(1)),(arr1549(1),arr2548(2)),
     9  (arr1549(16),arr2549(1)),(arr1550(1),arr2549(2)),
     a  (arr1550(16),arr2550(1)),(arr1551(1),arr2550(2))
         equivalence
     1  (arr1551(16),arr2551(1)),(arr1552(1),arr2551(2)),
     2  (arr1552(16),arr2552(1)),(arr1553(1),arr2552(2)),
     3  (arr1553(16),arr2553(1)),(arr1554(1),arr2553(2)),
     4  (arr1554(16),arr2554(1)),(arr1555(1),arr2554(2)),
     5  (arr1555(16),arr2555(1)),(arr1556(1),arr2555(2)),
     6  (arr1556(16),arr2556(1)),(arr1557(1),arr2556(2)),
     7  (arr1557(16),arr2557(1)),(arr1558(1),arr2557(2)),
     8  (arr1558(16),arr2558(1)),(arr1559(1),arr2558(2)),
     9  (arr1559(16),arr2559(1)),(arr1560(1),arr2559(2)),
     a  (arr1560(16),arr2560(1)),(arr1561(1),arr2560(2))
         equivalence
     1  (arr1561(16),arr2561(1)),(arr1562(1),arr2561(2)),
     2  (arr1562(16),arr2562(1)),(arr1563(1),arr2562(2)),
     3  (arr1563(16),arr2563(1)),(arr1564(1),arr2563(2)),
     4  (arr1564(16),arr2564(1)),(arr1565(1),arr2564(2)),
     5  (arr1565(16),arr2565(1)),(arr1566(1),arr2565(2)),
     6  (arr1566(16),arr2566(1)),(arr1567(1),arr2566(2)),
     7  (arr1567(16),arr2567(1)),(arr1568(1),arr2567(2)),
     8  (arr1568(16),arr2568(1)),(arr1569(1),arr2568(2)),
     9  (arr1569(16),arr2569(1)),(arr1570(1),arr2569(2)),
     a  (arr1570(16),arr2570(1)),(arr1571(1),arr2570(2))
         equivalence
     1  (arr1571(16),arr2571(1)),(arr1572(1),arr2571(2)),
     2  (arr1572(16),arr2572(1)),(arr1573(1),arr2572(2)),
     3  (arr1573(16),arr2573(1)),(arr1574(1),arr2573(2)),
     4  (arr1574(16),arr2574(1)),(arr1575(1),arr2574(2)),
     5  (arr1575(16),arr2575(1)),(arr1576(1),arr2575(2)),
     6  (arr1576(16),arr2576(1)),(arr1577(1),arr2576(2)),
     7  (arr1577(16),arr2577(1)),(arr1578(1),arr2577(2)),
     8  (arr1578(16),arr2578(1)),(arr1579(1),arr2578(2)),
     9  (arr1579(16),arr2579(1)),(arr1580(1),arr2579(2)),
     a  (arr1580(16),arr2580(1)),(arr1581(1),arr2580(2))
         equivalence
     1  (arr1581(16),arr2581(1)),(arr1582(1),arr2581(2)),
     2  (arr1582(16),arr2582(1)),(arr1583(1),arr2582(2)),
     3  (arr1583(16),arr2583(1)),(arr1584(1),arr2583(2)),
     4  (arr1584(16),arr2584(1)),(arr1585(1),arr2584(2)),
     5  (arr1585(16),arr2585(1)),(arr1586(1),arr2585(2)),
     6  (arr1586(16),arr2586(1)),(arr1587(1),arr2586(2)),
     7  (arr1587(16),arr2587(1)),(arr1588(1),arr2587(2)),
     8  (arr1588(16),arr2588(1)),(arr1589(1),arr2588(2)),
     9  (arr1589(16),arr2589(1)),(arr1590(1),arr2589(2)),
     a  (arr1590(16),arr2590(1)),(arr1591(1),arr2590(2))
         equivalence
     1  (arr1591(16),arr2591(1)),(arr1592(1),arr2591(2)),
     2  (arr1592(16),arr2592(1)),(arr1593(1),arr2592(2)),
     3  (arr1593(16),arr2593(1)),(arr1594(1),arr2593(2)),
     4  (arr1594(16),arr2594(1)),(arr1595(1),arr2594(2)),
     5  (arr1595(16),arr2595(1)),(arr1596(1),arr2595(2)),
     6  (arr1596(16),arr2596(1)),(arr1597(1),arr2596(2)),
     7  (arr1597(16),arr2597(1)),(arr1598(1),arr2597(2)),
     8  (arr1598(16),arr2598(1)),(arr1599(1),arr2598(2)),
     9  (arr1599(16),arr2599(1)),(arr1600(1),arr2599(2)),
     a  (arr1600(16),arr2600(1)),(arr1601(1),arr2600(2))
         equivalence
     1  (arr1601(16),arr2601(1)),(arr1602(1),arr2601(2)),
     2  (arr1602(16),arr2602(1)),(arr1603(1),arr2602(2)),
     3  (arr1603(16),arr2603(1)),(arr1604(1),arr2603(2)),
     4  (arr1604(16),arr2604(1)),(arr1605(1),arr2604(2)),
     5  (arr1605(16),arr2605(1)),(arr1606(1),arr2605(2)),
     6  (arr1606(16),arr2606(1)),(arr1607(1),arr2606(2)),
     7  (arr1607(16),arr2607(1)),(arr1608(1),arr2607(2)),
     8  (arr1608(16),arr2608(1)),(arr1609(1),arr2608(2)),
     9  (arr1609(16),arr2609(1)),(arr1610(1),arr2609(2)),
     a  (arr1610(16),arr2610(1)),(arr1611(1),arr2610(2))
         equivalence
     1  (arr1611(16),arr2611(1)),(arr1612(1),arr2611(2)),
     2  (arr1612(16),arr2612(1)),(arr1613(1),arr2612(2)),
     3  (arr1613(16),arr2613(1)),(arr1614(1),arr2613(2)),
     4  (arr1614(16),arr2614(1)),(arr1615(1),arr2614(2)),
     5  (arr1615(16),arr2615(1)),(arr1616(1),arr2615(2)),
     6  (arr1616(16),arr2616(1)),(arr1617(1),arr2616(2)),
     7  (arr1617(16),arr2617(1)),(arr1618(1),arr2617(2)),
     8  (arr1618(16),arr2618(1)),(arr1619(1),arr2618(2)),
     9  (arr1619(16),arr2619(1)),(arr1620(1),arr2619(2)),
     a  (arr1620(16),arr2620(1)),(arr1621(1),arr2620(2))
         equivalence
     1  (arr1621(16),arr2621(1)),(arr1622(1),arr2621(2)),
     2  (arr1622(16),arr2622(1)),(arr1623(1),arr2622(2)),
     3  (arr1623(16),arr2623(1)),(arr1624(1),arr2623(2)),
     4  (arr1624(16),arr2624(1)),(arr1625(1),arr2624(2)),
     5  (arr1625(16),arr2625(1)),(arr1626(1),arr2625(2)),
     6  (arr1626(16),arr2626(1)),(arr1627(1),arr2626(2)),
     7  (arr1627(16),arr2627(1)),(arr1628(1),arr2627(2)),
     8  (arr1628(16),arr2628(1)),(arr1629(1),arr2628(2)),
     9  (arr1629(16),arr2629(1)),(arr1630(1),arr2629(2)),
     a  (arr1630(16),arr2630(1)),(arr1631(1),arr2630(2))
         equivalence
     1  (arr1631(16),arr2631(1)),(arr1632(1),arr2631(2)),
     2  (arr1632(16),arr2632(1)),(arr1633(1),arr2632(2)),
     3  (arr1633(16),arr2633(1)),(arr1634(1),arr2633(2)),
     4  (arr1634(16),arr2634(1)),(arr1635(1),arr2634(2)),
     5  (arr1635(16),arr2635(1)),(arr1636(1),arr2635(2)),
     6  (arr1636(16),arr2636(1)),(arr1637(1),arr2636(2)),
     7  (arr1637(16),arr2637(1)),(arr1638(1),arr2637(2)),
     8  (arr1638(16),arr2638(1)),(arr1639(1),arr2638(2)),
     9  (arr1639(16),arr2639(1)),(arr1640(1),arr2639(2)),
     a  (arr1640(16),arr2640(1)),(arr1641(1),arr2640(2))
         equivalence
     1  (arr1641(16),arr2641(1)),(arr1642(1),arr2641(2)),
     2  (arr1642(16),arr2642(1)),(arr1643(1),arr2642(2)),
     3  (arr1643(16),arr2643(1)),(arr1644(1),arr2643(2)),
     4  (arr1644(16),arr2644(1)),(arr1645(1),arr2644(2)),
     5  (arr1645(16),arr2645(1)),(arr1646(1),arr2645(2)),
     6  (arr1646(16),arr2646(1)),(arr1647(1),arr2646(2)),
     7  (arr1647(16),arr2647(1)),(arr1648(1),arr2647(2)),
     8  (arr1648(16),arr2648(1)),(arr1649(1),arr2648(2)),
     9  (arr1649(16),arr2649(1)),(arr1650(1),arr2649(2)),
     a  (arr1650(16),arr2650(1)),(arr1651(1),arr2650(2))
         equivalence
     1  (arr1651(16),arr2651(1)),(arr1652(1),arr2651(2)),
     2  (arr1652(16),arr2652(1)),(arr1653(1),arr2652(2)),
     3  (arr1653(16),arr2653(1)),(arr1654(1),arr2653(2)),
     4  (arr1654(16),arr2654(1)),(arr1655(1),arr2654(2)),
     5  (arr1655(16),arr2655(1)),(arr1656(1),arr2655(2)),
     6  (arr1656(16),arr2656(1)),(arr1657(1),arr2656(2)),
     7  (arr1657(16),arr2657(1)),(arr1658(1),arr2657(2)),
     8  (arr1658(16),arr2658(1)),(arr1659(1),arr2658(2)),
     9  (arr1659(16),arr2659(1)),(arr1660(1),arr2659(2)),
     a  (arr1660(16),arr2660(1)),(arr1661(1),arr2660(2))
         equivalence
     1  (arr1661(16),arr2661(1)),(arr1662(1),arr2661(2)),
     2  (arr1662(16),arr2662(1)),(arr1663(1),arr2662(2)),
     3  (arr1663(16),arr2663(1)),(arr1664(1),arr2663(2)),
     4  (arr1664(16),arr2664(1)),(arr1665(1),arr2664(2)),
     5  (arr1665(16),arr2665(1)),(arr1666(1),arr2665(2)),
     6  (arr1666(16),arr2666(1)),(arr1667(1),arr2666(2)),
     7  (arr1667(16),arr2667(1)),(arr1668(1),arr2667(2)),
     8  (arr1668(16),arr2668(1)),(arr1669(1),arr2668(2)),
     9  (arr1669(16),arr2669(1)),(arr1670(1),arr2669(2)),
     a  (arr1670(16),arr2670(1)),(arr1671(1),arr2670(2))
         equivalence
     1  (arr1671(16),arr2671(1)),(arr1672(1),arr2671(2)),
     2  (arr1672(16),arr2672(1)),(arr1673(1),arr2672(2)),
     3  (arr1673(16),arr2673(1)),(arr1674(1),arr2673(2)),
     4  (arr1674(16),arr2674(1)),(arr1675(1),arr2674(2)),
     5  (arr1675(16),arr2675(1)),(arr1676(1),arr2675(2)),
     6  (arr1676(16),arr2676(1)),(arr1677(1),arr2676(2)),
     7  (arr1677(16),arr2677(1)),(arr1678(1),arr2677(2)),
     8  (arr1678(16),arr2678(1)),(arr1679(1),arr2678(2)),
     9  (arr1679(16),arr2679(1)),(arr1680(1),arr2679(2)),
     a  (arr1680(16),arr2680(1)),(arr1681(1),arr2680(2))
         equivalence
     1  (arr1681(16),arr2681(1)),(arr1682(1),arr2681(2)),
     2  (arr1682(16),arr2682(1)),(arr1683(1),arr2682(2)),
     3  (arr1683(16),arr2683(1)),(arr1684(1),arr2683(2)),
     4  (arr1684(16),arr2684(1)),(arr1685(1),arr2684(2)),
     5  (arr1685(16),arr2685(1)),(arr1686(1),arr2685(2)),
     6  (arr1686(16),arr2686(1)),(arr1687(1),arr2686(2)),
     7  (arr1687(16),arr2687(1)),(arr1688(1),arr2687(2)),
     8  (arr1688(16),arr2688(1)),(arr1689(1),arr2688(2)),
     9  (arr1689(16),arr2689(1)),(arr1690(1),arr2689(2)),
     a  (arr1690(16),arr2690(1)),(arr1691(1),arr2690(2))
         equivalence
     1  (arr1691(16),arr2691(1)),(arr1692(1),arr2691(2)),
     2  (arr1692(16),arr2692(1)),(arr1693(1),arr2692(2)),
     3  (arr1693(16),arr2693(1)),(arr1694(1),arr2693(2)),
     4  (arr1694(16),arr2694(1)),(arr1695(1),arr2694(2)),
     5  (arr1695(16),arr2695(1)),(arr1696(1),arr2695(2)),
     6  (arr1696(16),arr2696(1)),(arr1697(1),arr2696(2)),
     7  (arr1697(16),arr2697(1)),(arr1698(1),arr2697(2)),
     8  (arr1698(16),arr2698(1)),(arr1699(1),arr2698(2)),
     9  (arr1699(16),arr2699(1)),(arr1700(1),arr2699(2)),
     a  (arr1700(16),arr2700(1)),(arr1701(1),arr2700(2))
         equivalence
     1  (arr1701(16),arr2701(1)),(arr1702(1),arr2701(2)),
     2  (arr1702(16),arr2702(1)),(arr1703(1),arr2702(2)),
     3  (arr1703(16),arr2703(1)),(arr1704(1),arr2703(2)),
     4  (arr1704(16),arr2704(1)),(arr1705(1),arr2704(2)),
     5  (arr1705(16),arr2705(1)),(arr1706(1),arr2705(2)),
     6  (arr1706(16),arr2706(1)),(arr1707(1),arr2706(2)),
     7  (arr1707(16),arr2707(1)),(arr1708(1),arr2707(2)),
     8  (arr1708(16),arr2708(1)),(arr1709(1),arr2708(2)),
     9  (arr1709(16),arr2709(1)),(arr1710(1),arr2709(2)),
     a  (arr1710(16),arr2710(1)),(arr1711(1),arr2710(2))
         equivalence
     1  (arr1711(16),arr2711(1)),(arr1712(1),arr2711(2)),
     2  (arr1712(16),arr2712(1)),(arr1713(1),arr2712(2)),
     3  (arr1713(16),arr2713(1)),(arr1714(1),arr2713(2)),
     4  (arr1714(16),arr2714(1)),(arr1715(1),arr2714(2)),
     5  (arr1715(16),arr2715(1)),(arr1716(1),arr2715(2)),
     6  (arr1716(16),arr2716(1)),(arr1717(1),arr2716(2)),
     7  (arr1717(16),arr2717(1)),(arr1718(1),arr2717(2)),
     8  (arr1718(16),arr2718(1)),(arr1719(1),arr2718(2)),
     9  (arr1719(16),arr2719(1)),(arr1720(1),arr2719(2)),
     a  (arr1720(16),arr2720(1)),(arr1721(1),arr2720(2))
         equivalence
     1  (arr1721(16),arr2721(1)),(arr1722(1),arr2721(2)),
     2  (arr1722(16),arr2722(1)),(arr1723(1),arr2722(2)),
     3  (arr1723(16),arr2723(1)),(arr1724(1),arr2723(2)),
     4  (arr1724(16),arr2724(1)),(arr1725(1),arr2724(2)),
     5  (arr1725(16),arr2725(1)),(arr1726(1),arr2725(2)),
     6  (arr1726(16),arr2726(1)),(arr1727(1),arr2726(2)),
     7  (arr1727(16),arr2727(1)),(arr1728(1),arr2727(2)),
     8  (arr1728(16),arr2728(1)),(arr1729(1),arr2728(2)),
     9  (arr1729(16),arr2729(1)),(arr1730(1),arr2729(2)),
     a  (arr1730(16),arr2730(1)),(arr1731(1),arr2730(2))
         equivalence
     1  (arr1731(16),arr2731(1)),(arr1732(1),arr2731(2)),
     2  (arr1732(16),arr2732(1)),(arr1733(1),arr2732(2)),
     3  (arr1733(16),arr2733(1)),(arr1734(1),arr2733(2)),
     4  (arr1734(16),arr2734(1)),(arr1735(1),arr2734(2)),
     5  (arr1735(16),arr2735(1)),(arr1736(1),arr2735(2)),
     6  (arr1736(16),arr2736(1)),(arr1737(1),arr2736(2)),
     7  (arr1737(16),arr2737(1)),(arr1738(1),arr2737(2)),
     8  (arr1738(16),arr2738(1)),(arr1739(1),arr2738(2)),
     9  (arr1739(16),arr2739(1)),(arr1740(1),arr2739(2)),
     a  (arr1740(16),arr2740(1)),(arr1741(1),arr2740(2))
         equivalence
     1  (arr1741(16),arr2741(1)),(arr1742(1),arr2741(2)),
     2  (arr1742(16),arr2742(1)),(arr1743(1),arr2742(2)),
     3  (arr1743(16),arr2743(1)),(arr1744(1),arr2743(2)),
     4  (arr1744(16),arr2744(1)),(arr1745(1),arr2744(2)),
     5  (arr1745(16),arr2745(1)),(arr1746(1),arr2745(2)),
     6  (arr1746(16),arr2746(1)),(arr1747(1),arr2746(2)),
     7  (arr1747(16),arr2747(1)),(arr1748(1),arr2747(2)),
     8  (arr1748(16),arr2748(1)),(arr1749(1),arr2748(2)),
     9  (arr1749(16),arr2749(1)),(arr1750(1),arr2749(2)),
     a  (arr1750(16),arr2750(1)),(arr1751(1),arr2750(2))
         equivalence
     1  (arr1751(16),arr2751(1)),(arr1752(1),arr2751(2)),
     2  (arr1752(16),arr2752(1)),(arr1753(1),arr2752(2)),
     3  (arr1753(16),arr2753(1)),(arr1754(1),arr2753(2)),
     4  (arr1754(16),arr2754(1)),(arr1755(1),arr2754(2)),
     5  (arr1755(16),arr2755(1)),(arr1756(1),arr2755(2)),
     6  (arr1756(16),arr2756(1)),(arr1757(1),arr2756(2)),
     7  (arr1757(16),arr2757(1)),(arr1758(1),arr2757(2)),
     8  (arr1758(16),arr2758(1)),(arr1759(1),arr2758(2)),
     9  (arr1759(16),arr2759(1)),(arr1760(1),arr2759(2)),
     a  (arr1760(16),arr2760(1)),(arr1761(1),arr2760(2))
         equivalence
     1  (arr1761(16),arr2761(1)),(arr1762(1),arr2761(2)),
     2  (arr1762(16),arr2762(1)),(arr1763(1),arr2762(2)),
     3  (arr1763(16),arr2763(1)),(arr1764(1),arr2763(2)),
     4  (arr1764(16),arr2764(1)),(arr1765(1),arr2764(2)),
     5  (arr1765(16),arr2765(1)),(arr1766(1),arr2765(2)),
     6  (arr1766(16),arr2766(1)),(arr1767(1),arr2766(2)),
     7  (arr1767(16),arr2767(1)),(arr1768(1),arr2767(2)),
     8  (arr1768(16),arr2768(1)),(arr1769(1),arr2768(2)),
     9  (arr1769(16),arr2769(1)),(arr1770(1),arr2769(2)),
     a  (arr1770(16),arr2770(1)),(arr1771(1),arr2770(2))
         equivalence
     1  (arr1771(16),arr2771(1)),(arr1772(1),arr2771(2)),
     2  (arr1772(16),arr2772(1)),(arr1773(1),arr2772(2)),
     3  (arr1773(16),arr2773(1)),(arr1774(1),arr2773(2)),
     4  (arr1774(16),arr2774(1)),(arr1775(1),arr2774(2)),
     5  (arr1775(16),arr2775(1)),(arr1776(1),arr2775(2)),
     6  (arr1776(16),arr2776(1)),(arr1777(1),arr2776(2)),
     7  (arr1777(16),arr2777(1)),(arr1778(1),arr2777(2)),
     8  (arr1778(16),arr2778(1)),(arr1779(1),arr2778(2)),
     9  (arr1779(16),arr2779(1)),(arr1780(1),arr2779(2)),
     a  (arr1780(16),arr2780(1)),(arr1781(1),arr2780(2))
         equivalence
     1  (arr1781(16),arr2781(1)),(arr1782(1),arr2781(2)),
     2  (arr1782(16),arr2782(1)),(arr1783(1),arr2782(2)),
     3  (arr1783(16),arr2783(1)),(arr1784(1),arr2783(2)),
     4  (arr1784(16),arr2784(1)),(arr1785(1),arr2784(2)),
     5  (arr1785(16),arr2785(1)),(arr1786(1),arr2785(2)),
     6  (arr1786(16),arr2786(1)),(arr1787(1),arr2786(2)),
     7  (arr1787(16),arr2787(1)),(arr1788(1),arr2787(2)),
     8  (arr1788(16),arr2788(1)),(arr1789(1),arr2788(2)),
     9  (arr1789(16),arr2789(1)),(arr1790(1),arr2789(2)),
     a  (arr1790(16),arr2790(1)),(arr1791(1),arr2790(2))
         equivalence
     1  (arr1791(16),arr2791(1)),(arr1792(1),arr2791(2)),
     2  (arr1792(16),arr2792(1)),(arr1793(1),arr2792(2)),
     3  (arr1793(16),arr2793(1)),(arr1794(1),arr2793(2)),
     4  (arr1794(16),arr2794(1)),(arr1795(1),arr2794(2)),
     5  (arr1795(16),arr2795(1)),(arr1796(1),arr2795(2)),
     6  (arr1796(16),arr2796(1)),(arr1797(1),arr2796(2)),
     7  (arr1797(16),arr2797(1)),(arr1798(1),arr2797(2)),
     8  (arr1798(16),arr2798(1)),(arr1799(1),arr2798(2)),
     9  (arr1799(16),arr2799(1)),(arr1800(1),arr2799(2)),
     a  (arr1800(16),arr2800(1)),(arr1801(1),arr2800(2))
         equivalence
     1  (arr1801(16),arr2801(1)),(arr1802(1),arr2801(2)),
     2  (arr1802(16),arr2802(1)),(arr1803(1),arr2802(2)),
     3  (arr1803(16),arr2803(1)),(arr1804(1),arr2803(2)),
     4  (arr1804(16),arr2804(1)),(arr1805(1),arr2804(2)),
     5  (arr1805(16),arr2805(1)),(arr1806(1),arr2805(2)),
     6  (arr1806(16),arr2806(1)),(arr1807(1),arr2806(2)),
     7  (arr1807(16),arr2807(1)),(arr1808(1),arr2807(2)),
     8  (arr1808(16),arr2808(1)),(arr1809(1),arr2808(2)),
     9  (arr1809(16),arr2809(1)),(arr1810(1),arr2809(2)),
     a  (arr1810(16),arr2810(1)),(arr1811(1),arr2810(2))
         equivalence
     1  (arr1811(16),arr2811(1)),(arr1812(1),arr2811(2)),
     2  (arr1812(16),arr2812(1)),(arr1813(1),arr2812(2)),
     3  (arr1813(16),arr2813(1)),(arr1814(1),arr2813(2)),
     4  (arr1814(16),arr2814(1)),(arr1815(1),arr2814(2)),
     5  (arr1815(16),arr2815(1)),(arr1816(1),arr2815(2)),
     6  (arr1816(16),arr2816(1)),(arr1817(1),arr2816(2)),
     7  (arr1817(16),arr2817(1)),(arr1818(1),arr2817(2)),
     8  (arr1818(16),arr2818(1)),(arr1819(1),arr2818(2)),
     9  (arr1819(16),arr2819(1)),(arr1820(1),arr2819(2)),
     a  (arr1820(16),arr2820(1)),(arr1821(1),arr2820(2))
         equivalence
     1  (arr1821(16),arr2821(1)),(arr1822(1),arr2821(2)),
     2  (arr1822(16),arr2822(1)),(arr1823(1),arr2822(2)),
     3  (arr1823(16),arr2823(1)),(arr1824(1),arr2823(2)),
     4  (arr1824(16),arr2824(1)),(arr1825(1),arr2824(2)),
     5  (arr1825(16),arr2825(1)),(arr1826(1),arr2825(2)),
     6  (arr1826(16),arr2826(1)),(arr1827(1),arr2826(2)),
     7  (arr1827(16),arr2827(1)),(arr1828(1),arr2827(2)),
     8  (arr1828(16),arr2828(1)),(arr1829(1),arr2828(2)),
     9  (arr1829(16),arr2829(1)),(arr1830(1),arr2829(2)),
     a  (arr1830(16),arr2830(1)),(arr1831(1),arr2830(2))
         equivalence
     1  (arr1831(16),arr2831(1)),(arr1832(1),arr2831(2)),
     2  (arr1832(16),arr2832(1)),(arr1833(1),arr2832(2)),
     3  (arr1833(16),arr2833(1)),(arr1834(1),arr2833(2)),
     4  (arr1834(16),arr2834(1)),(arr1835(1),arr2834(2)),
     5  (arr1835(16),arr2835(1)),(arr1836(1),arr2835(2)),
     6  (arr1836(16),arr2836(1)),(arr1837(1),arr2836(2)),
     7  (arr1837(16),arr2837(1)),(arr1838(1),arr2837(2)),
     8  (arr1838(16),arr2838(1)),(arr1839(1),arr2838(2)),
     9  (arr1839(16),arr2839(1)),(arr1840(1),arr2839(2)),
     a  (arr1840(16),arr2840(1)),(arr1841(1),arr2840(2))
         equivalence
     1  (arr1841(16),arr2841(1)),(arr1842(1),arr2841(2)),
     2  (arr1842(16),arr2842(1)),(arr1843(1),arr2842(2)),
     3  (arr1843(16),arr2843(1)),(arr1844(1),arr2843(2)),
     4  (arr1844(16),arr2844(1)),(arr1845(1),arr2844(2)),
     5  (arr1845(16),arr2845(1)),(arr1846(1),arr2845(2)),
     6  (arr1846(16),arr2846(1)),(arr1847(1),arr2846(2)),
     7  (arr1847(16),arr2847(1)),(arr1848(1),arr2847(2)),
     8  (arr1848(16),arr2848(1)),(arr1849(1),arr2848(2)),
     9  (arr1849(16),arr2849(1)),(arr1850(1),arr2849(2)),
     a  (arr1850(16),arr2850(1)),(arr1851(1),arr2850(2))
         equivalence
     1  (arr1851(16),arr2851(1)),(arr1852(1),arr2851(2)),
     2  (arr1852(16),arr2852(1)),(arr1853(1),arr2852(2)),
     3  (arr1853(16),arr2853(1)),(arr1854(1),arr2853(2)),
     4  (arr1854(16),arr2854(1)),(arr1855(1),arr2854(2)),
     5  (arr1855(16),arr2855(1)),(arr1856(1),arr2855(2)),
     6  (arr1856(16),arr2856(1)),(arr1857(1),arr2856(2)),
     7  (arr1857(16),arr2857(1)),(arr1858(1),arr2857(2)),
     8  (arr1858(16),arr2858(1)),(arr1859(1),arr2858(2)),
     9  (arr1859(16),arr2859(1)),(arr1860(1),arr2859(2)),
     a  (arr1860(16),arr2860(1)),(arr1861(1),arr2860(2))
         equivalence
     1  (arr1861(16),arr2861(1)),(arr1862(1),arr2861(2)),
     2  (arr1862(16),arr2862(1)),(arr1863(1),arr2862(2)),
     3  (arr1863(16),arr2863(1)),(arr1864(1),arr2863(2)),
     4  (arr1864(16),arr2864(1)),(arr1865(1),arr2864(2)),
     5  (arr1865(16),arr2865(1)),(arr1866(1),arr2865(2)),
     6  (arr1866(16),arr2866(1)),(arr1867(1),arr2866(2)),
     7  (arr1867(16),arr2867(1)),(arr1868(1),arr2867(2)),
     8  (arr1868(16),arr2868(1)),(arr1869(1),arr2868(2)),
     9  (arr1869(16),arr2869(1)),(arr1870(1),arr2869(2)),
     a  (arr1870(16),arr2870(1)),(arr1871(1),arr2870(2))
         equivalence
     1  (arr1871(16),arr2871(1)),(arr1872(1),arr2871(2)),
     2  (arr1872(16),arr2872(1)),(arr1873(1),arr2872(2)),
     3  (arr1873(16),arr2873(1)),(arr1874(1),arr2873(2)),
     4  (arr1874(16),arr2874(1)),(arr1875(1),arr2874(2)),
     5  (arr1875(16),arr2875(1)),(arr1876(1),arr2875(2)),
     6  (arr1876(16),arr2876(1)),(arr1877(1),arr2876(2)),
     7  (arr1877(16),arr2877(1)),(arr1878(1),arr2877(2)),
     8  (arr1878(16),arr2878(1)),(arr1879(1),arr2878(2)),
     9  (arr1879(16),arr2879(1)),(arr1880(1),arr2879(2)),
     a  (arr1880(16),arr2880(1)),(arr1881(1),arr2880(2))
         equivalence
     1  (arr1881(16),arr2881(1)),(arr1882(1),arr2881(2)),
     2  (arr1882(16),arr2882(1)),(arr1883(1),arr2882(2)),
     3  (arr1883(16),arr2883(1)),(arr1884(1),arr2883(2)),
     4  (arr1884(16),arr2884(1)),(arr1885(1),arr2884(2)),
     5  (arr1885(16),arr2885(1)),(arr1886(1),arr2885(2)),
     6  (arr1886(16),arr2886(1)),(arr1887(1),arr2886(2)),
     7  (arr1887(16),arr2887(1)),(arr1888(1),arr2887(2)),
     8  (arr1888(16),arr2888(1)),(arr1889(1),arr2888(2)),
     9  (arr1889(16),arr2889(1)),(arr1890(1),arr2889(2)),
     a  (arr1890(16),arr2890(1)),(arr1891(1),arr2890(2))
         equivalence
     1  (arr1891(16),arr2891(1)),(arr1892(1),arr2891(2)),
     2  (arr1892(16),arr2892(1)),(arr1893(1),arr2892(2)),
     3  (arr1893(16),arr2893(1)),(arr1894(1),arr2893(2)),
     4  (arr1894(16),arr2894(1)),(arr1895(1),arr2894(2)),
     5  (arr1895(16),arr2895(1)),(arr1896(1),arr2895(2)),
     6  (arr1896(16),arr2896(1)),(arr1897(1),arr2896(2)),
     7  (arr1897(16),arr2897(1)),(arr1898(1),arr2897(2)),
     8  (arr1898(16),arr2898(1)),(arr1899(1),arr2898(2)),
     9  (arr1899(16),arr2899(1)),(arr1900(1),arr2899(2)),
     a  (arr1900(16),arr2900(1)),(arr1901(1),arr2900(2))
         equivalence
     1  (arr1901(16),arr2901(1)),(arr1902(1),arr2901(2)),
     2  (arr1902(16),arr2902(1)),(arr1903(1),arr2902(2)),
     3  (arr1903(16),arr2903(1)),(arr1904(1),arr2903(2)),
     4  (arr1904(16),arr2904(1)),(arr1905(1),arr2904(2)),
     5  (arr1905(16),arr2905(1)),(arr1906(1),arr2905(2)),
     6  (arr1906(16),arr2906(1)),(arr1907(1),arr2906(2)),
     7  (arr1907(16),arr2907(1)),(arr1908(1),arr2907(2)),
     8  (arr1908(16),arr2908(1)),(arr1909(1),arr2908(2)),
     9  (arr1909(16),arr2909(1)),(arr1910(1),arr2909(2)),
     a  (arr1910(16),arr2910(1)),(arr1911(1),arr2910(2))
         equivalence
     1  (arr1911(16),arr2911(1)),(arr1912(1),arr2911(2)),
     2  (arr1912(16),arr2912(1)),(arr1913(1),arr2912(2)),
     3  (arr1913(16),arr2913(1)),(arr1914(1),arr2913(2)),
     4  (arr1914(16),arr2914(1)),(arr1915(1),arr2914(2)),
     5  (arr1915(16),arr2915(1)),(arr1916(1),arr2915(2)),
     6  (arr1916(16),arr2916(1)),(arr1917(1),arr2916(2)),
     7  (arr1917(16),arr2917(1)),(arr1918(1),arr2917(2)),
     8  (arr1918(16),arr2918(1)),(arr1919(1),arr2918(2)),
     9  (arr1919(16),arr2919(1)),(arr1920(1),arr2919(2)),
     a  (arr1920(16),arr2920(1)),(arr1921(1),arr2920(2))
         equivalence
     1  (arr1921(16),arr2921(1)),(arr1922(1),arr2921(2)),
     2  (arr1922(16),arr2922(1)),(arr1923(1),arr2922(2)),
     3  (arr1923(16),arr2923(1)),(arr1924(1),arr2923(2)),
     4  (arr1924(16),arr2924(1)),(arr1925(1),arr2924(2)),
     5  (arr1925(16),arr2925(1)),(arr1926(1),arr2925(2)),
     6  (arr1926(16),arr2926(1)),(arr1927(1),arr2926(2)),
     7  (arr1927(16),arr2927(1)),(arr1928(1),arr2927(2)),
     8  (arr1928(16),arr2928(1)),(arr1929(1),arr2928(2)),
     9  (arr1929(16),arr2929(1)),(arr1930(1),arr2929(2)),
     a  (arr1930(16),arr2930(1)),(arr1931(1),arr2930(2))
         equivalence
     1  (arr1931(16),arr2931(1)),(arr1932(1),arr2931(2)),
     2  (arr1932(16),arr2932(1)),(arr1933(1),arr2932(2)),
     3  (arr1933(16),arr2933(1)),(arr1934(1),arr2933(2)),
     4  (arr1934(16),arr2934(1)),(arr1935(1),arr2934(2)),
     5  (arr1935(16),arr2935(1)),(arr1936(1),arr2935(2)),
     6  (arr1936(16),arr2936(1)),(arr1937(1),arr2936(2)),
     7  (arr1937(16),arr2937(1)),(arr1938(1),arr2937(2)),
     8  (arr1938(16),arr2938(1)),(arr1939(1),arr2938(2)),
     9  (arr1939(16),arr2939(1)),(arr1940(1),arr2939(2)),
     a  (arr1940(16),arr2940(1)),(arr1941(1),arr2940(2))
         equivalence
     1  (arr1941(16),arr2941(1)),(arr1942(1),arr2941(2)),
     2  (arr1942(16),arr2942(1)),(arr1943(1),arr2942(2)),
     3  (arr1943(16),arr2943(1)),(arr1944(1),arr2943(2)),
     4  (arr1944(16),arr2944(1)),(arr1945(1),arr2944(2)),
     5  (arr1945(16),arr2945(1)),(arr1946(1),arr2945(2)),
     6  (arr1946(16),arr2946(1)),(arr1947(1),arr2946(2)),
     7  (arr1947(16),arr2947(1)),(arr1948(1),arr2947(2)),
     8  (arr1948(16),arr2948(1)),(arr1949(1),arr2948(2)),
     9  (arr1949(16),arr2949(1)),(arr1950(1),arr2949(2)),
     a  (arr1950(16),arr2950(1)),(arr1951(1),arr2950(2))
         equivalence
     1  (arr1951(16),arr2951(1)),(arr1952(1),arr2951(2)),
     2  (arr1952(16),arr2952(1)),(arr1953(1),arr2952(2)),
     3  (arr1953(16),arr2953(1)),(arr1954(1),arr2953(2)),
     4  (arr1954(16),arr2954(1)),(arr1955(1),arr2954(2)),
     5  (arr1955(16),arr2955(1)),(arr1956(1),arr2955(2)),
     6  (arr1956(16),arr2956(1)),(arr1957(1),arr2956(2)),
     7  (arr1957(16),arr2957(1)),(arr1958(1),arr2957(2)),
     8  (arr1958(16),arr2958(1)),(arr1959(1),arr2958(2))
c
         data arr1001/
     1      0.6861780839185092d-01,0.1314525655271178d+00,
     2      0.1469638412086802d+00,0.1250290095434518d+00,
     3      0.8797255293505495d-01,0.5343141705456949d-01,
     4      0.2878248685168925d-01,0.1401536607135610d-01,
     5      0.6257243698249477d-02,0.2589706775696078d-02,
     6      0.1002423377970602d-02,0.3655551627766180d-03,
     7      0.1263623611604901d-03,0.4162101333752484d-04,
     8      0.1312154466237655d-04,0.3974799556754996d-05/
         data arr1002/
     1      0.1160797830358170d-05,0.3277670342554647d-06,
     2      0.8970677881544351d-07,0.2384890616285972d-07,
     3      0.6170088943559936d-08,0.1555856719661534d-08,
     4      0.3828852010303049d-09,0.9205488255150368d-10,
     5      0.2163968074091483d-10,0.4977079826060199d-11,
     6      0.1121172923283106d-11,0.2477429187903371d-12,
     7      0.5337554605428225d-13,0.1066916205027696d-13,
     8      0.1886210514726575d-14,0.5623785417583358d-15/
         data arr1003/
     1      0.3152699735058238d-15,0.4659059397356086d-15,
     2      0.1749763536343730d-15,0.1917397671796251d-02,
     3      0.1917902056116398d-01,0.5189500034173218d-01,
     4      0.8032759614947202d-01,0.8849115853944299d-01,
     5      0.7669894069078870d-01,0.5537696344174641d-01,
     6      0.3454969123689870d-01,0.1910617663056638d-01,
     7      0.9541058461835637d-02,0.4363907686863819d-02,
     8      0.1848714589490649d-02,0.7319988761597487d-03/
         data arr1004/
     1      0.2729228131723436d-03,0.9642090464497411d-04,
     2      0.3244867385888050d-04,0.1044880878940904d-04,
     3      0.3231806666915038d-05,0.9632890919183587d-06,
     4      0.2774715589571404d-06,0.7742306017086414d-07,
     5      0.2096984267080626d-07,0.5522513910890670d-08,
     6      0.1416167071300925d-08,0.3540247933085922d-09,
     7      0.8635404268578763d-10,0.2056364630957158d-10,
     8      0.4782152805600139d-11,0.1087550250681774d-11/
         data arr1005/
     1      0.2433682768205669d-12,0.5423391479635945d-13,
     2      0.1185238963357572d-13,0.1963665959612921d-14,
     3      -.1435962432682803d-15,0.1052224111114309d-15,
     4      0.2678906801996983d-04,0.1399116199301039d-02,
     5      0.9162427439985096d-02,0.2580410228467489d-01,
     6      0.4450641068780812d-01,0.5504933077882574d-01,
     7      0.5327211814442234d-01,0.4258473016206091d-01,
     8      0.2916987119631716d-01,0.1757569571673356d-01/
         data arr1006/
     1      0.9498825904509650d-02,0.4674733092673234d-02,
     2      0.2120181792267301d-02,0.8948227827496781d-03,
     3      0.3542643449259725d-03,0.1324489979457498d-03,
     4      0.4702696805086640d-04,0.1593292362346081d-04,
     5      0.5171994346650100d-05,0.1614129961219885d-05,
     6      0.4857570029794206d-06,0.1413158019718807d-06,
     7      0.3982695026970819d-07,0.1089312578777106d-07,
     8      0.2895715260526165d-08,0.7490317304109853d-09/
         data arr1007/
     1      0.1887050738394189d-09,0.4633313999657922d-10,
     2      0.1109013696945468d-10,0.2586120729373527d-11,
     3      0.5865972345888427d-12,0.1298994988507254d-12,
     4      0.2908613374434685d-13,0.7413497039427745d-14,
     5      0.2605955840125732d-14,0.2495225490469153d-06,
     6      0.6804401023228747d-04,0.1078460684879080d-02,
     7      0.5526134868280606d-02,0.1492292657490415d-01,
     8      0.2634046652197376d-01,0.3416485117231120d-01/
         data arr1008/
     1      0.3499229039053452d-01,0.2968957463531043d-01,
     2      0.2158426350465381d-01,0.1378392945613897d-01,
     3      0.7880477102781806d-02,0.4093968792036475d-02,
     4      0.1955883431436769d-02,0.8677456171091549d-03,
     5      0.3604202157587725d-03,0.1411028931179959d-03,
     6      0.5236659284341675d-04,0.1851263243422988d-04,
     7      0.6259898063614172d-05,0.2031779551185941d-05,
     8      0.6348849577955500d-06,0.1914809802809057d-06/
         data arr1009/
     1      0.5585976280105333d-07,0.1579034349529498d-07,
     2      0.4331490566048819d-08,0.1154344455290485d-08,
     3      0.2991238978820663d-09,0.7540906876699014d-10,
     4      0.1850189864781723d-10,0.4420093683907046d-11,
     5      0.1029313605041480d-11,0.2335784929052191d-12,
     6      0.5196864057329933d-13,0.1356244875223181d-13,
     7      0.1743215652244635d-08,0.2481917209116956d-05,
     8      0.9520491031539826d-04,0.8875962703430668d-03/
         data arr1010/
     1      0.3752724620536611d-02,0.9452705874737040d-02,
     2      0.1643313279460658d-01,0.2156513113000358d-01,
     3      0.2266390300698586d-01,0.1988031250137924d-01,
     4      0.1500159439405039d-01,0.9963443602468163d-02,
     5      0.5928942224892593d-02,0.3206344377194661d-02,
     6      0.1594111431401870d-02,0.7355816235936449d-03,
     7      0.3175309924112896d-03,0.1290845975195541d-03,
     8      0.4969807635505094d-04,0.1820779220409519d-04/
         data arr1011/
     1      0.6373754887603084d-05,0.2139245367733523d-05,
     2      0.6904552685653338d-06,0.2148359876693355d-06,
     3      0.6457850640262453d-07,0.1878595865122966d-07,
     4      0.5296028301177041d-08,0.1448447124964905d-08,
     5      0.3846004110944008d-09,0.9918342499202807d-10,
     6      0.2484332468087333d-10,0.6043051959324692d-11,
     7      0.1427746178069164d-11,0.3300414218113043d-12,
     8      0.8811074697679337d-13,0.9925623715864308d-11/
         data arr1012/
     1      0.7242210388000140d-07,0.6723639477960741d-05,
     2      0.1140510904272085d-03,0.7549694499808473d-03,
     3      0.2713806098201951d-02,0.6323407693809999d-02,
     4      0.1063216783952079d-01,0.1384061592853944d-01,
     5      0.1464870274836526d-01,0.1306146175978249d-01,
     6      0.1007758359042146d-01,0.6869100902683822d-02,
     7      0.4205013079971369d-02,0.2342798355329512d-02,
     8      0.1200998837035666d-02,0.5716448694182977d-03/
         data arr1013/
     1      0.2545566921893976d-03,0.1067335529717558d-03,
     2      0.4236793548966950d-04,0.1599573198526366d-04,
     3      0.5766551204520943d-05,0.1991752787473996d-05,
     4      0.6610053041883152d-06,0.2112878363068051d-06,
     5      0.6518082937620254d-07,0.1943819637774756d-07,
     6      0.5611048945579158d-08,0.1569255596872624d-08,
     7      0.4254621264472847d-09,0.1118539357456401d-09,
     8      0.2851400759440173d-10,0.7053096288218464d-11/
         data arr1014/
     1      0.1707635999019723d-11,0.4787568972129253d-12,
     2      -.1507963995588346d-11,0.1764963769717280d-08,
     3      0.3956976630541305d-06,0.1221243552713186d-04,
     4      0.1265700078911407d-03,0.6492623776846504d-03,
     5      0.2027686247850187d-02,0.4368278290411608d-02,
     6      0.7043603258258174d-02,0.8994849058018737d-02,
     7      0.9476869525792126d-02,0.8494192626759624d-02,
     8      0.6631951285365776d-02,0.4595611315847304d-02/
         data arr1015/
     1      0.2869259965981604d-02,0.1634079029310228d-02,
     2      0.8576009495876437d-03,0.4183245637692003d-03,
     3      0.1910209972773551d-03,0.8215539157859270d-04,
     4      0.3345273523542498d-04,0.1295359930352472d-04,
     5      0.4787999254747389d-05,0.1694812300571465d-05,
     6      0.5760759140908256d-06,0.1884625437534583d-06,
     7      0.5945385167628409d-07,0.1811348427434372d-07,
     8      0.5335640554433831d-08,0.1520763453450281d-08/
         data arr1016/
     1      0.4195453319252976d-09,0.1120235026722291d-09,
     2      0.2895259933749684d-10,0.7285042033740998d-11,
     3      0.2089283789884628d-11,0.6565232844046117d-12,
     4      0.3505518477665884d-10,0.1996299323870018d-07,
     5      0.1120875973317794d-05,0.1818802239513647d-04,
     6      0.1331419364689467d-03,0.5573186017894951d-03,
     7      0.1538338761089184d-02,0.3072469387120312d-02,
     8      0.4734147704682537d-02,0.5893743485010845d-02/
         data arr1017/
     1      0.6136786468339359d-02,0.5488276327157383d-02,
     2      0.4304992900717273d-02,0.3012021707284201d-02,
     3      0.1905709665580578d-02,0.1102801648919621d-02,
     4      0.5892443475175484d-03,0.2930316024628382d-03,
     5      0.1365488503289847d-03,0.5996700488876716d-04,
     6      0.2494123627670867d-04,0.9865655037667255d-05,
     7      0.3724701533095602d-05,0.1346288610516237d-05,
     8      0.4670717452911864d-06,0.1558683184204235d-06/
         data arr1018/
     1      0.5012049226102550d-07,0.1555037228031660d-07,
     2      0.4659630424692182d-08,0.1349268270691994d-08,
     3      0.3776421168600305d-09,0.1022050174375159d-09,
     4      0.2692859096538662d-10,0.8127931466983763d-11,
     5      0.2671041114923443d-11,-.5860392839970341d-11,
     6      0.8881292201467844d-09,0.9001139124147436d-07,
     7      0.2286908106789394d-05,0.2389007597252503d-04,
     8      0.1340338142920023d-03,0.4740255170202613d-03/
         data arr1019/
     1      0.1172703702268232d-02,0.2180207255505550d-02,
     2      0.3207196812284690d-02,0.3879430463435965d-02,
     3      0.3974098840385579d-02,0.3528658599784036d-02,
     4      0.2766650813693740d-02,0.1944681442079923d-02,
     5      0.1240845223912782d-02,0.7262489816665526d-03,
     6      0.3933289067210511d-03,0.1985857489640459d-03,
     7      0.9405916871402383d-04,0.4201975791765650d-04,
     8      0.1778712796769473d-04,0.7162578680527787d-05/
         data arr1020/
     1      0.2752990169836571d-05,0.1012861393063958d-05,
     2      0.3575552310500910d-06,0.1213486638577977d-06,
     3      0.3965493576206209d-07,0.1249172265630929d-07,
     4      0.3795930748582170d-08,0.1113029760047166d-08,
     5      0.3150124493430591d-09,0.8661360212492607d-10,
     6      0.2727592209689491d-10,-.2930582860766205d-11,
     7      0.7370969143212796d-11,0.2623562355011540d-10,
     8      0.6432464146838076d-08,0.2555942740832366d-06/
         data arr1021/
     1      0.3810377558777728d-05,0.2865316930705871d-04,
     2      0.1298371395976263d-03,0.3978657043015423d-03,
     3      0.8924856361596781d-03,0.1551341714873369d-02,
     4      0.2179929301935540d-02,0.2557931067876702d-02,
     5      0.2570954094214201d-02,0.2258905581001260d-02,
     6      0.1763955725751827d-02,0.1241038623103399d-02,
     7      0.7956519386961014d-03,0.4692937250422473d-03,
     8      0.2567175669555192d-03,0.1311406682443015d-03/
         data arr1022/
     1      0.6292693700380857d-04,0.2850579848201410d-04,
     2      0.1224319653203338d-04,0.5004015818475731d-05,
     3      0.1952378777435007d-05,0.7290822055741139d-06,
     4      0.2611586621676739d-06,0.8988965190383613d-07,
     5      0.2976948118849470d-07,0.9494771918257747d-08,
     6      0.2917944714224571d-08,0.8647128740264671d-09,
     7      0.2490433694154172d-09,0.8293281892482803d-10,
     8      -.4460589524277591d-12,0.1386423701120791d-11/
         data arr1023/
     1      -.6132739256444524d-12,0.4148210764082466d-09,
     2      0.2570875611145126d-07,0.5469676709963606d-06,
     3      0.5512814992105612d-05,0.3200653602458045d-04,
     4      0.1214862766254668d-03,0.3288116524532465d-03,
     5      0.6753545637455176d-03,0.1102451152680887d-02,
     6      0.1481772459516618d-02,0.1685860020329358d-02,
     7      0.1659909143404334d-02,0.1440022906214189d-02,
     8      0.1117108847128004d-02,0.7845185623760957d-03/
         data arr1024/
     1      0.5039368755523371d-03,0.2986796309772373d-03,
     2      0.1645569231270324d-03,0.8481294628081120d-04,
     3      0.4111526543161128d-04,0.1883487447957156d-04,
     4      0.8186064448127471d-05,0.3387041522038432d-05,
     5      0.1337986490246551d-05,0.5058405913878231d-06,
     6      0.1833814352241441d-06,0.6384610227793478d-07,
     7      0.2137042368418315d-07,0.6881193979866193d-08,
     8      0.2133095513652376d-08,0.6416690446053865d-09/
         data arr1025/
     1      0.2236755224225582d-09,0.1893104658377825d-11,
     2      -.4758677656351543d-11,0.5282623010219512d-11,
     3      0.2064150545823825d-10,0.2352336318712289d-08,
     4      0.7137778351488664d-07,0.9642311853784206d-06,
     5      0.7172751392046421d-05,0.3372292551990358d-04,
     6      0.1101286921499614d-03,0.2672781897235871d-03,
     7      0.5068548633470890d-03,0.7803357702655141d-03,
     8      0.1004976753216044d-02,0.1108862945505090d-02/
         data arr1026/
     1      0.1068706461127721d-02,0.9141406044231898d-03,
     2      0.7032190666676518d-03,0.4919430678642623d-03,
     3      0.3159096839543919d-03,0.1877164103804725d-03,
     4      0.1039190153587131d-03,0.5391136171363319d-04,
     5      0.2634134667046322d-04,0.1217416099928033d-04,
     6      0.5341761854171703d-05,0.2232210234736721d-05,
     7      0.8907034779264575d-06,0.3401090273302052d-06,
     8      0.1244900924646765d-06,0.4373542736769978d-07/
         data arr1027/
     1      0.1476000401599806d-07,0.4790452995160126d-08,
     2      0.1508916559656939d-08,0.5555682440608426d-09,
     3      -.7842462449545250d-12,0.2761857771770846d-11,
     4      -.4657832520918793d-11,0.8437807812090308d-11,
     5      0.1889131630543470d-09,0.8546613319495470d-08,
     6      0.1545904015706136d-06,0.1473485261494225d-05,
     7      0.8580933398347187d-05,0.3381156255003498d-04,
     8      0.9696313144634463d-04,0.2136088901266447d-03/
         data arr1028/
     1      0.3766976836568847d-03,0.5491638731559458d-03,
     2      0.6790204671631075d-03,0.7270410082290615d-03,
     3      0.6857123138932066d-03,0.5778159037330539d-03,
     4      0.4402151541846411d-03,0.3062892199299673d-03,
     5      0.1962907192635935d-03,0.1167184018883991d-03,
     6      0.6479909382447758d-04,0.3376950146772747d-04,
     7      0.1659641640148984d-04,0.7722531360847188d-05,
     8      0.3413727234845582d-05,0.1437675525832963d-05/
         data arr1029/
     1      0.5782067046708814d-06,0.2224943598966717d-06,
     2      0.8203231696036786d-07,0.2900725326524277d-07,
     3      0.9849665942011918d-08,0.3243256121794391d-08,
     4      0.1254699723245169d-08,-.4153692038232940d-11,
     5      0.1304432976195186d-10,-.2064527688253637d-10,
     6      0.2438595814045997d-10,-.9481646527988840d-11,
     7      0.9650860930871230d-09,0.2286234224971018d-07,
     8      0.2794230081004810d-06,0.2015486289778978d-05/
         data arr1030/
     1      0.9582265324469458d-05,0.3247039468899731d-04,
     2      0.8309845448725105d-04,0.1678580879755364d-03,
     3      0.2770038447656046d-03,0.3838183703062857d-03,
     4      0.4565593801484057d-03,0.4747979039959424d-03,
     5      0.4382543558791513d-03,0.3636244037412964d-03,
     6      0.2741185206174068d-03,0.1894677053078392d-03,
     7      0.1210100766861632d-03,0.7189446390602559d-04,
     8      0.3996218762539010d-04,0.2088467143926141d-04/
         data arr1031/
     1      0.1030559491614173d-04,0.4819048215416079d-05,
     2      0.2142047810170379d-05,0.9073913273160921d-06,
     3      0.3670845989867961d-06,0.1420498639441926d-06,
     4      0.5264137688738608d-07,0.1871119373630029d-07,
     5      0.6448932901704348d-08,0.2633281927251787d-08,
     6      -.6208484536627671d-11,0.1639940241912286d-10,
     7      -.2480406604120909d-10,0.3414918591061272d-10,
     8      -.3887079709455437d-10,0.1367789938227297d-09/
         data arr1032/
     1      0.3111338695914632d-08,0.4922492467308248d-07,
     2      0.4395677955167212d-06,0.2521672887339497d-05,
     3      0.1009679189999652d-04,0.3001801825207863d-04,
     4      0.6945553834420428d-04,0.1297433032752686d-03,
     5      0.2014577511391678d-03,0.2662262874187027d-03,
     6      0.3052748043533559d-03,0.3086585537965068d-03,
     7      0.2789050400754057d-03,0.2278034854306177d-03,
     8      0.1698188757636068d-03,0.1164981569732264d-03/
         data arr1033/
     1      0.7406913071141975d-04,0.4391260117106639d-04,
     2      0.2440373472640117d-04,0.1277031231391683d-04,
     3      0.6316956384199900d-05,0.2963531537221371d-05,
     4      0.1322250109824910d-05,0.5623534022060857d-06,
     5      0.2283821900337699d-06,0.8868367210731163d-07,
     6      0.3298515442092469d-07,0.1189164153119567d-07,
     7      0.5113899920558829d-08,-.1344155571670271d-10,
     8      0.4209648537115358d-10,-.6965205732225051d-10/
         data arr1034/
     1      0.8496010541473032d-10,-.9115354817074244d-10,
     2      0.9322634261169898d-10,0.3347556493679190d-09,
     3      0.8139044846495038d-08,0.8944297109331609d-07,
     4      0.6193898914089527d-06,0.2930306454746380d-05,
     5      0.1012065550412694d-04,0.2682304801226073d-04,
     6      0.5671799706389430d-04,0.9869134096756701d-04,
     7      0.1448909728134933d-03,0.1831934442098293d-03,
     8      0.2028930608621375d-03,0.1996624744941437d-03/
         data arr1035/
     1      0.1766929137409658d-03,0.1420605700373424d-03,
     2      0.1046775001861149d-03,0.7122226159287768d-04,
     3      0.4503662805646983d-04,0.2661471481627949d-04,
     4      0.1476952628712216d-04,0.7728411432472672d-05,
     5      0.3826700653697415d-05,0.1798314215214928d-05,
     6      0.8040474804256862d-06,0.3426918096640603d-06,
     7      0.1394303410837695d-06,0.5426324940127779d-07,
     8      0.2046054328743485d-07,0.9271089390381929d-08/
         data arr1036/
     1      -.3008792642386418d-10,0.7254477292360646d-10,
     2      -.1066836951195285d-09,0.1319738096451244d-09,
     3      -.1532496561760879d-09,0.1488910870429651d-09,
     4      -.7429817104959562d-10,0.1341161640050187d-08,
     5      0.1700709163250932d-07,0.1426790258286241d-06,
     6      0.7972496867529334d-06,0.3198976312511749d-05,
     7      0.9711355162028318d-05,0.2324492321141983d-04,
     8      0.4532581746663527d-04,0.7392695535745760d-04/
         data arr1037/
     1      0.1030624017938836d-03,0.1250337974480712d-03,
     2      0.1340009056925719d-03,0.1284840424891099d-03,
     3      0.1114121463023747d-03,0.8817772631807532d-04,
     4      0.6420449526581452d-04,0.4330260032491532d-04,
     5      0.2721191612973193d-04,0.1601413329682603d-04,
     6      0.8864302053534926d-05,0.4632478257939521d-05,
     7      0.2292970944721166d-05,0.1077832327658406d-05,
     8      0.4821388619199807d-06,0.2055710349898747d-06/
         data arr1038/
     1      0.8373765271650905d-07,0.3305338136408779d-07,
     2      0.1581586302933431d-07,-.7894130038670417d-10,
     3      0.2201874808285738d-09,-.3234821181430885d-09,
     4      0.3539013748406667d-09,-.3518161447675221d-09,
     5      0.3042298673165418d-09,-.2354248831328062d-09,
     6      0.3625170752751971d-09,0.2930443514003820d-08,
     7      0.3102010443198254d-07,0.2040823389953780d-06,
     8      0.9517266050897041d-06,0.3309166784202325d-05/
         data arr1039/
     1      0.8966160195675444d-05,0.1959225265042673d-04,
     2      0.3550051867165365d-04,0.5457099681084289d-04,
     3      0.7252018961523903d-04,0.8464276515291445d-04,
     4      0.8793268938033950d-04,0.8223616420518792d-04,
     5      0.6990937359669457d-04,0.5447355850670163d-04,
     6      0.3918616111767759d-04,0.2618583229660654d-04,
     7      0.1634207208368081d-04,0.9568809609174026d-05,
     8      0.5277712855819373d-05,0.2751328664327979d-05/
         data arr1040/
     1      0.1359445036916014d-05,0.6380242754095523d-06,
     2      0.2848900795882360d-06,0.1213179933645295d-06,
     3      0.5001379481682624d-07,0.2514575828598570d-07,
     4      -.1070835753068769d-09,0.2386393692595381d-09,
     5      -.3385302893474688d-09,0.3793123015128211d-09,
     6      -.4435527823250862d-09,0.4165597200052950d-09,
     7      -.3500919945846893d-09,0.2919301113291866d-09,
     8      0.3208620863321754d-09,0.6506601392950952d-08/
         data arr1041/
     1      0.4923901229474636d-07,0.2675082210319277d-06,
     2      0.1064910413241390d-05,0.3266342585770392d-05,
     3      0.7998407299454084d-05,0.1610055039775051d-04,
     4      0.2728983124357939d-04,0.3972532973653047d-04,
     5      0.5049493175909091d-04,0.5683659106947312d-04,
     6      0.5732845536496513d-04,0.5234658910098996d-04,
     7      0.4364979349122916d-04,0.3349106125628742d-04,
     8      0.2379870966583215d-04,0.1575046381426730d-04/
         data arr1042/
     1      0.9755747727505179d-05,0.5679193268838472d-05,
     2      0.3118477777086724d-05,0.1620051990117610d-05,
     3      0.7980903326120389d-06,0.3735177757347198d-06,
     4      0.1665491959707033d-06,0.7195009545106736d-07,
     5      0.3831010659226197d-07,-.2307539905884681d-09,
     6      0.6009348476483385d-09,-.8375491595775223d-09,
     7      0.8795561545444459d-09,-.8709647278272967d-09,
     8      0.7469196853703078d-09,-.5953077539404314d-09/
         data arr1043/
     1      0.4485351230117459d-09,-.2534009271723126d-09,
     2      0.1505911983631567d-08,0.1109254225226638d-07,
     3      0.7138322724892806d-07,0.3245834896000106d-06,
     4      0.1127292702877136d-05,0.3093555350827215d-05,
     5      0.6917627589750316d-05,0.1292888480676303d-04,
     6      0.2061564368880256d-04,0.2853795924794001d-04,
     7      0.3480365301202947d-04,0.3786149504824281d-04,
     8      0.3713294983366808d-04,0.3313560837253410d-04/
         data arr1044/
     1      0.2711690226914070d-04,0.2049036914101473d-04,
     2      0.1438045148673186d-04,0.9421516712367568d-05,
     3      0.5787849556181899d-05,0.3346566167655330d-05,
     4      0.1826816329381059d-05,0.9435979725619224d-06,
     5      0.4619728908714027d-06,0.2149758004122511d-06,
     6      0.9674632406981997d-07,0.5387736879419471d-07,
     7      -.2579077021209933d-09,0.5162788016563138d-09,
     8      -.7168187856978107d-09,0.7383944966894854d-09/
         data arr1045/
     1      -.9227845338500399d-09,0.8613140248990047d-09,
     2      -.7505210380078861d-09,0.5664668617697050d-09,
     3      -.4219227948178328d-09,0.6211501922343690d-09,
     4      0.2157263356947231d-08,0.1829030053945150d-07,
     5      0.9387469232592202d-07,0.3696099374695862d-06,
     6      0.1136839584180164d-05,0.2823376354901761d-05,
     7      0.5819077711681658d-05,0.1016378903425851d-04,
     8      0.1532207093106294d-04,0.2024630318846126d-04/
         data arr1046/
     1      0.2375487224291312d-04,0.2502389369725558d-04,
     2      0.2389632681939102d-04,0.2085841123961082d-04,
     3      0.1676051871496114d-04,0.1247409352440455d-04,
     4      0.8645162359395147d-05,0.5605579944612912d-05,
     5      0.3414297462727013d-05,0.1959898101032504d-05,
     6      0.1062857105963848d-05,0.5456036086462004d-06,
     7      0.2660177837902251d-06,0.1256242919900182d-06,
     8      0.7433293389378802d-07,-.5185819770557840d-09/
         data arr1047/
     1      0.1258966173753753d-08,-.1656944936688904d-08,
     2      0.1662623483028019d-08,-.1653698881389619d-08,
     3      0.1417190739412564d-08,-.1147585723142414d-08,
     4      0.8539051220822858d-09,-.6505205123331732d-09,
     5      0.5845348917541549d-09,0.7972872142171154d-10,
     6      0.4756084618904617d-08,0.2570920716853336d-07,
     7      0.1154149256555796d-06,0.3980992212108445d-06,
     8      0.1097204755254634d-05,0.2494485980183471d-05/
         data arr1048/
     1      0.4772444084881863d-05,0.7834484225726731d-05,
     2      0.1121704921420373d-04,0.1419461385827428d-04,
     3      0.1606034930369824d-04,0.1641205941119467d-04,
     4      0.1527946007316641d-04,0.1305511472333155d-04,
     5      0.1030224847713013d-04,0.7550593525433581d-05,
     6      0.5164734372843988d-05,0.3310647848516840d-05,
     7      0.1995072211231098d-05,0.1132761708407270d-05,
     8      0.6069840655808405d-06,0.3079265444828083d-06/
         data arr1049/
     1      0.1508674680205868d-06,0.9275135100857730d-07,
     2      -.5068364578768875d-09,0.9016600843787262d-09,
     3      -.1210315803502842d-08,0.1088167279443457d-08,
     4      -.1497077942955383d-08,0.1380230268788150d-08,
     5      -.1259458778667888d-08,0.9393476678401142d-09,
     6      -.7485479539325445d-09,0.6927644824119839d-09,
     7      -.4205332983638394d-09,0.1502867159640870d-08,
     8      0.6531886013906119d-08,0.3440918648012121d-07/
         data arr1050/
     1      0.1333714552968383d-06,0.4066871224004137d-06,
     2      0.1020920397434998d-05,0.2139305993048924d-05,
     3      0.3823590708468163d-05,0.5932126430150651d-05,
     4      0.8096781204820291d-05,0.9839180605172170d-05,
     5      0.1075960225464968d-04,0.1068478528111849d-04,
     6      0.9708544593309551d-05,0.8124653725059730d-05,
     7      0.6299007579993131d-05,0.4548050465090103d-05,
     8      0.3071708566750936d-05,0.1947180405647765d-05/
         data arr1051/
     1      0.1161256955145163d-05,0.6528289422106900d-06,
     2      0.3473256084844876d-06,0.1788791301415007d-06,
     3      0.1172695561470800d-06,-.8704237877474764d-09,
     4      0.1934657579280623d-08,-.2352638314815947d-08,
     5      0.2223966736627311d-08,-.2280381893337744d-08,
     6      0.1993611808487660d-08,-.1675815455568036d-08,
     7      0.1254154383315612d-08,-.9752613288142241d-09,
     8      0.8279007580982804d-09,-.6337377464095012d-09/
         data arr1052/
     1      0.8653960568375555d-09,0.1360195977915756d-08,
     2      0.9805375631236533d-08,0.4306295974694011d-07,
     3      0.1437982781900801d-06,0.3998570683217367d-06,
     4      0.9175326824562259d-06,0.1784619453268181d-05,
     5      0.3000834835361279d-05,0.4417870887259505d-05,
     6      0.5765235870247049d-05,0.6745924031755522d-05,
     7      0.7144602604278996d-05,0.6901551618128386d-05,
     8      0.6121244653242104d-05,0.5015260127098280d-05/
         data arr1053/
     1      0.3816257573368404d-05,0.2708644855666704d-05,
     2      0.1798800884974261d-05,0.1119854755157549d-05,
     3      0.6545968159094783d-06,0.3605791821228873d-06,
     4      0.1914781343406959d-06,0.1292286371878787d-06,
     5      -.7401882917996443d-09,0.1073714774693845d-08,
     6      -.1369323366329880d-08,0.9271123483335082d-09,
     7      -.1703332946358866d-08,0.1578479669746501d-08,
     8      -.1580778354946474d-08,0.1170905672748694d-08/
         data arr1054/
     1      -.9938675912173301d-09,0.9277880228479051d-09,
     2      -.6825457368131067d-09,0.7230034434944639d-09,
     3      0.1612258345558140d-10,0.2674118073267477d-08,
     4      0.1376461569177682d-07,0.4829224683011004d-07,
     5      0.1503397542870704d-06,0.3774979173277197d-06,
     6      0.7979146521736066d-06,0.1454780607309289d-05,
     7      0.2310715495835425d-05,0.3237776914842321d-05,
     8      0.4053683275440813d-05,0.4580156826856260d-05/
         data arr1055/
     1      0.4705724032230611d-05,0.4426137930419439d-05,
     2      0.3836265826409205d-05,0.3081936278103236d-05,
     3      0.2305788718070245d-05,0.1611773493723006d-05,
     4      0.1054776053236053d-05,0.6474516044367712d-06,
     5      0.3745082773957222d-06,0.2094918563650642d-06,
     6      0.1513410395658558d-06,-.1130123498600399d-08,
     7      0.2212626782231139d-08,-.2342569446398460d-08,
     8      0.1961733913772239d-08,-.2180792428625734d-08/
         data arr1056/
     1      0.2009418610116825d-08,-.1822072957357188d-08,
     2      0.1387954112636337d-08,-.1113297221779654d-08,
     3      0.9677169299361551d-09,-.7636219780833994d-09,
     4      0.7761343225221119d-09,-.3323821517614556d-09,
     5      0.6794647255501137d-09,0.4580158488961283d-08,
     6      0.1512386379971432d-07,0.5447280981108289d-07,
     7      0.1493895179584550d-06,0.3420925866973638d-06,
     8      0.6770699505623033d-06,0.1160281358200820d-05/
         data arr1057/
     1      0.1744589404530554d-05,0.2336130518585314d-05,
     2      0.2814165559379642d-05,0.3071459167085841d-05,
     3      0.3057748897027912d-05,0.2795474866846939d-05,
     4      0.2361024909842759d-05,0.1850380737248231d-05,
     5      0.1349410874849873d-05,0.9170436038022372d-06,
     6      0.5816988530537779d-06,0.3459079801637740d-06,
     7      0.1978888531243877d-06,0.1455648431777993d-06,
     8      -.8961693252577063d-09,0.1023729725273716d-08/
         data arr1058/
     1      -.1210849801219522d-08,0.3028471502055673d-09,
     2      -.1409966424123177d-08,0.1274998019731074d-08,
     3      -.1497406825666224d-08,0.1090962351386750d-08,
     4      -.1021695524535853d-08,0.9768488893494433d-09,
     5      -.6867991678712730d-09,0.6996086330145490d-09,
     6      -.3855024512336161d-09,0.1385685212752659d-09,
     7      0.1963601819620220d-08,0.4091000749125792d-08,
     8      0.1921305694305863d-07,0.5729569544540213d-07/
         data arr1059/
     1      0.1406927869783238d-06,0.3029949358977038d-06,
     2      0.5609937411338277d-06,0.9046211224891793d-06,
     3      0.1295471420241994d-05,0.1665701514797686d-05,
     4      0.1934437234072907d-05,0.2042385124305050d-05,
     5      0.1975369039921688d-05,0.1762098263144590d-05,
     6      0.1456881623906291d-05,0.1119468857124544d-05,
     7      0.8006471109246808d-06,0.5339778595246636d-06,
     8      0.3339526625793205d-06,0.2017105310301682d-06/
         data arr1060/
     1      0.1594033655583004d-06,-.1141592835884674d-08,
     2      0.1885161145765195d-08,-.1514279933422454d-08,
     3      0.8743613821358012d-09,-.1266771221810772d-08,
     4      0.1341795948801288d-08,-.1421546050935368d-08,
     5      0.1125124232146891d-08,-.9467144597949646d-09,
     6      0.8555541303430882d-09,-.6763991040484895d-09,
     7      0.6941415402221531d-09,-.3817700695114990d-09,
     8      -.1612566146737978d-11,0.1012695519220240d-08/
         data arr1061/
     1      0.6681553396187439d-09,0.6691210670639177d-08,
     2      0.2138381119359281d-07,0.5538048883571902d-07,
     3      0.1305421972996356d-06,0.2609337620210540d-06,
     4      0.4501471466170607d-06,0.6883819657541914d-06,
     5      0.9423215691808122d-06,0.1159571536707007d-05,
     6      0.1291019044097313d-05,0.1311081520897221d-05,
     7      0.1222935953598402d-05,0.1052383361926519d-05,
     8      0.8373723949438822d-06,0.6166992705216062d-06/
         data arr1062/
     1      0.4211908915553138d-06,0.2682101812733835d-06,
     2      0.1639701535925303d-06,0.1302243702998073d-06,
     3      -.8587860194120809d-09,0.6922314930189972d-09,
     4      -.6794340009699837d-09,-.5886283885653937d-09,
     5      -.6380024594581837d-09,0.5287928131192041d-09,
     6      -.9734262629832905d-09,0.6862471196455773d-09,
     7      -.7786442902047892d-09,0.7739994101182526d-09,
     8      -.4974396272450552d-09,0.5340206266712146d-09/
         data arr1063/
     1      -.3040220456749424d-09,-.6246479946128383d-10,
     2      0.8693184321614191d-09,-.3287854648739592d-09,
     3      0.2388165404040881d-08,0.8130270887430153d-08,
     4      0.2077691837115628d-07,0.5420772970639480d-07,
     5      0.1178548702195727d-06,0.2170453241793985d-06,
     6      0.3542097858720134d-06,0.5182924570717732d-06,
     7      0.6794219896747501d-06,0.8023313280212902d-06,
     8      0.8620633301918425d-06,0.8498001435793005d-06/
         data arr1064/
     1      0.7724737476932138d-06,0.6486243675246327d-06,
     2      0.5035172007169225d-06,0.3621101979695089d-06,
     3      0.2429239153321542d-06,0.1571606379218231d-06,
     4      0.1345351577938198d-06,-.9049664684076518d-09,
     5      0.1155434714171654d-08,-.3522452447752255d-09,
     6      -.4197189634357531d-09,-.3749718428967767d-10,
     7      0.3414153902097915d-09,-.6723324203321341d-09,
     8      0.5888736462596663d-09,-.5512670857163596d-09/
         data arr1065/
     1      0.5382633572963820d-09,-.4253857234227399d-09,
     2      0.4522557480799923d-09,-.2500636822160658d-09,
     3      -.5437921764957332d-10,0.5238070972819727d-09,
     4      -.4424067295046731d-09,0.9052538991833907d-09,
     5      0.3063941544243743d-08,0.7320623812508379d-08,
     6      0.2166665355345703d-07,0.5085394554608122d-07,
     7      0.9922810790069596d-07,0.1721209879598989d-06,
     8      0.2668719735026290d-06,0.3681912947606810d-06/
         data arr1066/
     1      0.4547767053422329d-06,0.5085078505181599d-06,
     2      0.5192008322775942d-06,0.4861883143683380d-06,
     3      0.4182152183384927d-06,0.3306546022145153d-06,
     4      0.2409182891311273d-06,0.1628465761614065d-06,
     5      0.1055180383848671d-06,0.8969355791135958d-07,
     6      -.7009435483455834d-09,0.5031645814675024d-09,
     7      -.4596847895197513d-09,-.8317162337033310d-09,
     8      -.1141621465715186d-09,-.5479185124456431d-10/
         data arr1067/
     1      -.3981511816882097d-09,0.2418340100445351d-09,
     2      -.4260383177274671d-09,0.4422174351342696d-09,
     3      -.2312596959829287d-09,0.2817571524159365d-09,
     4      -.1552408549617852d-09,-.8111482373605958d-10,
     5      0.5383987722620030d-09,-.4173894579842605d-09,
     6      0.3639331597729241d-09,0.1431271244646976d-08,
     7      0.2371646655900839d-08,0.8337936280955704d-08,
     8      0.2189663629490535d-07,0.4494009038742836d-07/
         data arr1068/
     1      0.8252377307930749d-07,0.1372347841497513d-06,
     2      0.2022509067976447d-06,0.2650212390800235d-06,
     3      0.3134848476041440d-06,0.3384788394487875d-06,
     4      0.3353762625352334d-06,0.3049890284171636d-06,
     5      0.2546228404147380d-06,0.1956398947026674d-06,
     6      0.1395309487810881d-06,0.9587092602984322d-07,
     7      0.8805973806261123d-07,-.4965279239231919d-09,
     8      0.4557609854111092d-09,0.2623043172690375d-09/
         data arr1069/
     1      -.8298682706692558d-09,0.5060348698764537d-09,
     2      -.2071544633245126d-09,-.1177516859076529d-09,
     3      0.1574513232873722d-09,-.1907660184446100d-09,
     4      0.2161563580630309d-09,-.1711001117459174d-09,
     5      0.1939781082607844d-09,-.1052208831013203d-09,
     6      -.3949043430845531d-10,0.2407583442996175d-09,
     7      -.2389889459048542d-09,0.1625525388463917d-09,
     8      0.5603360311198952d-09,0.6646155307319604d-09/
         data arr1070/
     1      0.3026930828258076d-08,0.8476488835663926d-08,
     2      0.1804581486074378d-07,0.3488306513667090d-07,
     3      0.6069616212170874d-07,0.9275274073594605d-07,
     4      0.1252359235235544d-06,0.1519072059331660d-06,
     5      0.1674165789549198d-06,0.1683524747750548d-06,
     6      0.1545886951485976d-06,0.1296369841125211d-06,
     7      0.9963116083183191d-07,0.7073670518139947d-07,
     8      0.4809720451939822d-07,0.4327268419782305d-07/
         data arr1071/
     1      -.4232576069327335d-09,0.3208867598623246d-09,
     2      -.2822447790085875d-09,-.5818182382334611d-09,
     3      0.9438252417873044d-10,-.2391552326810629d-09,
     4      -.4937918443885730d-10,-.7245423858949571d-11,
     5      -.1471882191883172d-09,0.1635509388575949d-09,
     6      -.4939418301759745d-10,0.8857343288864954d-10,
     7      -.4609798965217305d-10,-.5567182457087507d-10,
     8      0.2475242190760824d-09,-.1689216686681483d-09/
         data arr1072/
     1      0.5348473026536852d-10,0.3810489584146008d-09,
     2      0.1414151689733298d-09,0.1051655905379271d-08,
     3      0.3619801793024427d-08,0.7830120115793159d-08,
     4      0.1563744927648141d-07,0.2936616503610315d-07,
     5      0.4819825470422281d-07,0.6906149496432306d-07,
     6      0.8856319189101691d-07,0.1032521297433364d-06,
     7      0.1100716676808825d-06,0.1070617868699216d-06,
     8      0.9497895430031679d-07,0.7708204237952833d-07/
         data arr1073/
     1      0.5782302501270130d-07,0.4176448736751584d-07,
     2      0.4068236599102967d-07,-.2217614489886338d-09,
     3      0.1779343557224626d-09,0.2148580905303952d-09,
     4      -.5194284723764838d-09,0.3993051295752752d-09,
     5      -.2476055068410944d-09,0.7194359820217039d-10,
     6      -.2132067800476509d-10,-.1549361918728395d-10,
     7      0.4003503279740047d-10,-.3038906196549134d-10,
     8      0.4126562535085163d-10,-.2313087290397146d-10/
         data arr1074/
     1      -.1800940774812806d-10,0.6296174094615629d-10,
     2      -.5324470869968616d-10,0.2199360940219897d-10,
     3      0.1125778807488775d-09,0.1535871070150640d-10,
     4      0.3050101582179142d-09,0.1045744057264243d-08,
     5      0.2283602277397439d-08,0.4763939421296350d-08,
     6      0.9172227640782111d-08,0.1530091901384509d-07,
     7      0.2221669290160711d-07,0.2878809180436854d-07,
     8      0.3381201701951840d-07,0.3613515374915267d-07/
         data arr1075/
     1      0.3512360517065218d-07,0.3102508083020065d-07,
     2      0.2501342732268818d-07,0.1857625515257162d-07,
     3      0.1322019422847737d-07,0.1258606408140591d-07,
     4      -.2060750336907641d-09,0.2778064648456636d-09,
     5      -.3414351457580253d-09,-.3194861625969305d-10,
     6      -.6858162737222075d-10,-.6849715044140068d-10,
     7      -.3409359299099400d-11,-.2655921371437798d-10,
     8      -.3556573294264490d-10,0.3445833309147226d-10/
         data arr1076/
     1      0.9414686691416803d-11,0.8503304255702741d-11,
     2      -.5257047106160668d-11,-.2079729554306291d-10,
     3      0.6592004708973431d-10,-.3212938183972754d-10,
     4      -.4034292511865367d-11,0.9167229614688503d-10,
     5      -.4339459249792763d-11,0.8611086289090642d-10,
     6      0.4706670508290057d-09,0.9880594509515111d-09,
     7      0.1998368793960775d-08,0.4192173222713636d-08,
     8      0.7584008599579947d-08,0.1168995452602579d-07/
         data arr1077/
     1      0.1598868278052790d-07,0.1984510529217834d-07,
     2      0.2252571766565196d-07,0.2322697959984700d-07,
     3      0.2174022603315108d-07,0.1852788244032433d-07,
     4      0.1455303751353130d-07,0.1101857681444652d-07,
     5      0.1136571901134584d-07,-.2711609927027492d-02,
     6      -.2712323091950082d-01,-.7339061333916577d-01,
     7      -.1136003758903926d+00,-.1251453965638457d+00,
     8      -.1084686821416411d+00,-.7831485274354880d-01/
         data arr1078/
     1      -.4886064192253051d-01,-.2702021411624898d-01,
     2      -.1349309427600355d-01,-.6171497435770150d-02,
     3      -.2614477245370996d-02,-.1035202738327146d-02,
     4      -.3859711438685201d-03,-.1363597510257083d-03,
     5      -.4588935467564056d-04,-.1477684708928139d-04,
     6      -.4570464808547835d-05,-.1362296514674097d-05,
     7      -.3924040410550408d-06,-.1094927275823319d-06,
     8      -.2965583953923092d-07,-.7810025065371958d-08/
         data arr1079/
     1      -.2002759743067309d-08,-.5006564912820381d-09,
     2      -.1221218915829114d-09,-.2908896724054467d-10,
     3      -.6767421756914585d-11,-.1534266621151976d-11,
     4      -.3371533918680217d-12,-.7286356154178161d-13,
     5      -.1751842141214357d-13,-.5864171320815727d-14,
     6      -.1058856286452599d-14,-.4374611517275874d-04,
     7      -.2284747311530816d-02,-.1496218129460452d-01,
     8      -.4213792260551370d-01,-.7267866430102235d-01/
         data arr1080/
     1      -.8989518073074194d-01,-.8699300464575518d-01,
     2      -.6954057315476886d-01,-.4763420019551657d-01,
     3      -.2870099092043499d-01,-.1551151774763515d-01,
     4      -.7633807173892552d-02,-.3462242368636874d-02,
     5      -.1461239485301366d-02,-.5785112527816086d-03,
     6      -.2162883079064588d-03,-.7679471726345495d-04,
     7      -.2601835534267584d-04,-.8445831378041930d-05,
     8      -.2635863187938659d-05,-.7932378847686118d-06/
         data arr1081/
     1      -.2307677343397671d-06,-.6503712024220194d-07,
     2      -.1778840288637437d-07,-.4728698349323936d-08,
     3      -.1223165777379592d-08,-.3081418800517591d-09,
     4      -.7565289765278745d-10,-.1811414142796687d-10,
     5      -.4233126456307603d-11,-.9631386890344807d-12,
     6      -.2092863396921992d-12,-.4143355434253463d-13,
     7      -.1039266977906406d-13,-.4325348692938826d-06,
     8      -.1178555147564489d-03,-.1867948777415273d-02/
         data arr1082/
     1      -.9571546329363261d-02,-.2584726703755950d-01,
     2      -.4562302630670340d-01,-.5917525806508260d-01,
     3      -.6060842482899767d-01,-.5142385172370911d-01,
     4      -.3738504103387923d-01,-.2387446614605071d-01,
     5      -.1364938672985106d-01,-.7090961952430670d-02,
     6      -.3387689476932748d-02,-.1502979496851185d-02,
     7      -.6242661257999290d-03,-.2443973799628541d-03,
     8      -.9070159940696478d-04,-.3206481998080582d-04/
         data arr1083/
     1      -.1084246149785100d-04,-.3519145391524696d-05,
     2      -.1099653007570193d-05,-.3316548036663271d-06,
     3      -.9675194366078868d-07,-.2734966005074519d-07,
     4      -.7502357238412673d-08,-.1999393204716254d-08,
     5      -.5181034704616833d-09,-.1306041917146712d-09,
     6      -.3203124927286334d-10,-.7646126291152897d-11,
     7      -.1781839170697529d-11,-.4100199195499088d-12,
     8      -.1036318521856137d-12,-.2707210979593753d-08/
         data arr1084/
     1      -.4439984537625458d-05,-.1703076316339255d-03,
     2      -.1587780514384536d-02,-.6713077867948075d-02,
     3      -.1690951433082162d-01,-.2939648160780466d-01,
     4      -.3857687932098671d-01,-.4054242220699397d-01,
     5      -.3556298413376112d-01,-.2683566786870182d-01,
     6      -.1782314974813713d-01,-.1060601427959432d-01,
     7      -.5735683189346105d-02,-.2851633219484844d-02,
     8      -.1315848410649195d-02,-.5680167072139197d-03/
         data arr1085/
     1      -.2309135479358036d-03,-.8890262163756281d-04,
     2      -.3257108887507068d-04,-.1140171938421902d-04,
     3      -.3826798440731662d-05,-.1235123912742531d-05,
     4      -.3843103060209034d-06,-.1155215623611164d-06,
     5      -.3360534161281115d-07,-.9473804908487244d-08,
     6      -.2591051171851284d-08,-.6880003771833015d-09,
     7      -.1774362841547083d-09,-.4444527939726906d-10,
     8      -.1080684649093011d-10,-.2558572075462158d-11/
         data arr1086/
     1      -.6799281526969709d-12,-.2795068239676394d-09,
     2      -.1321006422772321d-06,-.1227568554006683d-04,
     3      -.2082278273227558d-03,-.1378379334992654d-02,
     4      -.4954709385940638d-02,-.1154491011506433d-01,
     5      -.1941159386923384d-01,-.2526939184624345d-01,
     6      -.2674474977814123d-01,-.2384685746612606d-01,
     7      -.1839906619202260d-01,-.1254120504727949d-01,
     8      -.7677268395013505d-02,-.4277345022982573d-02/
         data arr1087/
     1      -.2192713848631269d-02,-.1043675966192676d-02,
     2      -.4647548082437311d-03,-.1948679153718482d-03,
     3      -.7735291326887708d-04,-.2920407742554358d-04,
     4      -.1052823392392323d-04,-.3636426444398857d-05,
     5      -.1206825039328358d-05,-.3857570345141292d-06,
     6      -.1190033700783004d-06,-.3548912445352178d-07,
     7      -.1024430362523707d-07,-.2865028414296031d-08,
     8      -.7767694685786353d-09,-.2042195601126527d-09/
         data arr1088/
     1      -.5208184723266471d-10,-.1294950532062311d-10,
     2      -.3622225166651623d-11,0.1931171313965612d-09,
     3      -.3350588856839235d-08,-.7326585572638172d-06,
     4      -.2261304560452855d-04,-.2343621130733131d-03,
     5      -.1202200318310385d-02,-.3754545369057184d-02,
     6      -.8088479684994859d-02,-.1304221894283912d-01,
     7      -.1665522410456208d-01,-.1754775257986677d-01,
     8      -.1572818853033776d-01,-.1227998760144745d-01/
         data arr1089/
     1      -.8509418653862094d-02,-.5312837095990347d-02,
     2      -.3025726419902595d-02,-.1587968393388861d-02,
     3      -.7745865787893103d-03,-.3537021575017483d-03,
     4      -.1521222256060616d-03,-.6194242940452141d-04,
     5      -.2398540523502492d-04,-.8865651832493898d-05,
     6      -.3138182563582371d-05,-.1066685394945832d-05,
     7      -.3489648705022651d-06,-.1100870834447394d-06,
     8      -.3353957954619333d-07,-.9879696957062217d-08/
         data arr1090/
     1      -.2816017383841874d-08,-.7769854393089498d-09,
     2      -.2075779920222987d-09,-.5395415860287659d-10,
     3      -.1581171122600247d-10,-.6569526593009323d-09,
     4      0.2543731422423040d-09,-.3750047844117592d-07,
     5      -.2096899328555180d-05,-.3402670218987613d-04,
     6      -.2490857437771979d-03,-.1042647636086589d-02,
     7      -.2877968292566885d-02,-.5748063889753329d-02,
     8      -.8856779364292905d-02,-.1102618442339610d-01/
         data arr1091/
     1      -.1148087621004762d-01,-.1026762483015714d-01,
     2      -.8053904243411097d-02,-.5634976635167153d-02,
     3      -.3565256323597848d-02,-.2063152967871418d-02,
     4      -.1102375232864663d-02,-.5482119298875612d-03,
     5      -.2554595071757703d-03,-.1121879935496440d-03,
     6      -.4666078051244147d-04,-.1845695037461519d-04,
     7      -.6968278493459933d-05,-.2518675547782060d-05,
     8      -.8738112782513576d-06,-.2916027065581702d-06/
         data arr1092/
     1      -.9376662222163994d-07,-.2909211469477480d-07,
     2      -.8717667906222732d-08,-.2524647313103477d-08,
     3      -.7070201108091538d-09,-.1925747833465716d-09,
     4      -.5954166221588706d-10,-.6658990029388345d-10,
     5      0.4871690372093039d-10,-.1700369310809866d-08,
     6      -.1697101282718221d-06,-.4312245625164793d-05,
     7      -.4504755348649534d-04,-.2527365870486390d-03,
     8      -.8938310851809393d-03,-.2211271308028732d-02/
         data arr1093/
     1      -.4111038225615272d-02,-.6047548305749191d-02,
     2      -.7315124234065233d-02,-.7493632637861097d-02,
     3      -.6653702464875554d-02,-.5216846804291508d-02,
     4      -.3666926493118579d-02,-.2339760192470788d-02,
     5      -.1369428213036417d-02,-.7416680990140364d-03,
     6      -.3744568790504499d-03,-.1773596698228506d-03,
     7      -.7923321558774117d-04,-.3353972971396047d-04,
     8      -.1350588779420254d-04,-.5191088688362818d-05/
         data arr1094/
     1      -.1909870170993583d-05,-.6742122093098021d-06,
     2      -.2288167129638086d-06,-.7477440263384813d-07,
     3      -.2355595620863956d-07,-.7159443226521009d-08,
     4      -.2100921517133419d-08,-.5989715395460877d-09,
     5      -.1946704410528790d-09,-.1206979030276752d-08,
     6      0.6404807120093680d-09,-.4168698154547754d-09,
     7      -.1200930349056428d-07,-.4850542025409186d-06,
     8      -.7229635661677403d-05,-.5436558878995080d-04/
         data arr1095/
     1      -.2463486408697410d-03,-.7548971022957547d-03,
     2      -.1693372430836683d-02,-.2943463950464781d-02,
     3      -.4136125038296271d-02,-.4853332964217691d-02,
     4      -.4878042417561474d-02,-.4285971993865523d-02,
     5      -.3346870670991237d-02,-.2354705227083249d-02,
     6      -.1509643411954701d-02,-.8904222373376368d-03,
     7      -.4870873349726659d-03,-.2488219246776568d-03,
     8      -.1193954692346611d-03,-.5408594828291323d-04/
         data arr1096/
     1      -.2322983147419261d-04,-.9494454439882693d-05,
     2      -.3704379645458111d-05,-.1383334655479712d-05,
     3      -.4955114561079796d-06,-.1705540930356566d-06,
     4      -.5648735752227028d-07,-.1802023602372193d-07,
     5      -.5542729450164675d-08,-.1655466337248048d-08,
     6      -.5677657683338710d-09,-.4423454310876263d-08,
     7      0.2313597170063995d-08,-.1243623639426318d-08,
     8      -.1562847100885095d-09,-.4933187361896839d-07/
         data arr1097/
     1      -.1042882482493577d-05,-.1051259227575080d-04,
     2      -.6103403838783809d-04,-.2316652546658115d-03,
     3      -.6270192115661632d-03,-.1287850626137205d-02,
     4      -.2102291858358733d-02,-.2825629214188408d-02,
     5      -.3214808917809856d-02,-.3165322541613491d-02,
     6      -.2746015937047799d-02,-.2130242985647751d-02,
     7      -.1496018203234157d-02,-.9609699151801221d-03,
     8      -.5695597056019020d-03,-.3137977439123312d-03/
         data arr1098/
     1      -.1617319450805198d-03,-.7840373058296243d-04,
     2      -.3591669513153543d-04,-.1561021838134506d-04,
     3      -.6458838911229454d-05,-.2551436646368619d-05,
     4      -.9645954398371556d-06,-.3496978486454090d-06,
     5      -.1217617713888165d-06,-.4076741860489084d-07,
     6      -.1314035436514229d-07,-.4109023046107236d-08,
     7      -.1483560159463271d-08,-.1015205507462482d-07,
     8      0.5331435278507137d-08,-.2878118033996680d-08/
         data arr1099/
     1      0.1426967503822930d-08,-.5216160038903573d-08,
     2      -.1363437428776631d-06,-.1846516925516459d-05,
     3      -.1373470069459587d-04,-.6457452067706054d-04,
     4      -.2108803728259428d-03,-.5117987778267048d-03,
     5      -.9705531653173115d-03,-.1494229244653035d-02,
     6      -.1924383966617137d-02,-.2123310890527238d-02,
     7      -.2046417071202126d-02,-.1750445984970808d-02,
     8      -.1346562003075545d-02,-.9419992545648464d-03/
         data arr1100/
     1      -.6049209827154712d-03,-.3594495690337831d-03,
     2      -.1989897703628691d-03,-.1032323877281554d-03,
     3      -.5043983507186680d-04,-.2331175702619262d-04,
     4      -.1022870410207765d-04,-.4274346957798244d-05,
     5      -.1705553464416464d-05,-.6512640748964802d-06,
     6      -.2384067736561865d-06,-.8378255969314962d-07,
     7      -.2830647332933391d-07,-.9273967905585455d-08,
     8      -.3534467318383987d-08,-.2273806022759731d-07/
         data arr1101/
     1      0.1193875594837872d-07,-.6443980602593892d-08,
     2      0.3296013896648498d-08,-.1977821872358118d-08,
     3      -.1566015306558064d-07,-.2974066011453674d-06,
     4      -.2831190706632447d-05,-.1648866900566220d-04,
     5      -.6497015577503657d-04,-.1863183497023526d-03,
     6      -.4104575510004124d-03,-.7238388688710804d-03,
     7      -.1055239152626369d-02,-.1304763536323472d-02,
     8      -.1397036811352523d-02,-.1317622149919385d-02/
         data arr1102/
     1      -.1110295146674609d-02,-.8458900738557034d-03,
     2      -.5885463103774554d-03,-.3771800661353937d-03,
     3      -.2242788408041283d-03,-.1245138882186182d-03,
     4      -.6488936677480339d-04,-.3189067427337886d-04,
     5      -.1483916056166767d-04,-.6559588390082684d-05,
     6      -.2762521997929937d-05,-.1111063259902756d-05,
     7      -.4275984193159749d-06,-.1577169238323471d-06,
     8      -.5584382830951400d-07,-.1916136234773375d-07/
         data arr1103/
     1      -.7699571775416770d-08,-.4987293898233078d-07,
     2      0.2619077343654059d-07,-.1413843322883340d-07,
     3      0.7236294929432319d-08,-.3536967244825127d-08,
     4      -.1799301877756042d-09,-.4484564668301579d-07,
     5      -.5381472166230061d-06,-.3884521647586779d-05,
     6      -.1846731146077366d-04,-.6257856174533159d-04,
     7      -.1601513133754177d-03,-.3235042313761750d-03,
     8      -.5338551380531396d-03,-.7397132948536105d-03/
         data arr1104/
     1      -.8799032525712180d-03,-.9150533887875982d-03,
     2      -.8446249718329796d-03,-.7007944764250495d-03,
     3      -.5282943927967359d-03,-.3651513410007397d-03,
     4      -.2332164868523652d-03,-.1385584277263053d-03,
     5      -.7701703296653860d-04,-.4025000914576040d-04,
     6      -.1986148557825897d-04,-.9287455631439675d-05,
     7      -.4128189650249632d-05,-.1748788599504807d-05,
     8      -.7075886143468761d-06,-.2739374176292514d-06/
         data arr1105/
     1      -.1016613782638076d-06,-.3654277974930091d-07,
     2      -.1549975957400259d-07,-.1011472327685816d-06,
     3      0.5309631842610815d-07,-.2864897817458761d-07,
     4      0.1465881411635948d-07,-.7105443964746190d-08,
     5      0.3128508370681100d-08,-.7595096300520438d-08,
     6      -.9436581805561371d-07,-.8496866957747128d-06,
     7      -.4872148073795294d-05,-.1950895980034823d-04,
     8      -.5800025012387313d-04,-.1342009106571800d-03/
         data arr1106/
     1      -.2506878198440915d-03,-.3892534009542788d-03,
     2      -.5143980551099827d-03,-.5898469019308259d-03,
     3      -.5963850700622089d-03,-.5388957168125510d-03,
     4      -.4401580723587763d-03,-.3281213236902507d-03,
     5      -.2250958890381360d-03,-.1431150614715699d-03,
     6      -.8484716536078500d-04,-.4715262623647865d-04,
     7      -.2467469253413004d-04,-.1220544817121622d-04,
     8      -.5725976424807697d-05,-.2554896076044072d-05/
         data arr1107/
     1      -.1086844397711726d-05,-.4416424189102700d-06,
     2      -.1717856157207130d-06,-.6469283055370152d-07,
     3      -.2897557257156379d-07,-.1863580730796395d-06,
     4      0.9786405964588922d-07,-.5283052767159633d-07,
     5      0.2704280894347684d-07,-.1311221158675481d-07,
     6      0.6102988287759417d-08,-.3588331311524611d-08,
     7      -.1437261410698415d-07,-.1738828461169405d-06,
     8      -.1199093646929378d-05,-.5674710696462564d-05/
         data arr1108/
     1      -.1959842843709082d-04,-.5194272224277246d-04,
     2      -.1098338194215465d-03,-.1911150387482496d-03,
     3      -.2805801630138074d-03,-.3547524705389207d-03,
     4      -.3929008769081915d-03,-.3866446917759582d-03,
     5      -.3421642087359028d-03,-.2750992568606773d-03,
     6      -.2027072270908798d-03,-.1379211392662058d-03,
     7      -.8721296598159944d-04,-.5153939184026088d-04,
     8      -.2860123118744952d-04,-.1496584022943429d-04/
         data arr1109/
     1      -.7410122586519848d-05,-.3482478069622230d-05,
     2      -.1557464572696914d-05,-.6642235450818107d-06,
     3      -.2707383319820079d-06,-.1067750647226931d-06,
     4      -.5045306474981917d-07,-.3319222323926017d-06,
     5      0.1742486153664683d-06,-.9402889063744968d-07,
     6      0.4812105464019999d-07,-.2332570503459721d-07,
     7      0.1089068096906770d-07,-.5089116935872606d-08,
     8      -.1298252899091885d-09,-.3420172291211836d-07/
         data arr1110/
     1      -.2762080221068107d-06,-.1547246854573530d-05,
     2      -.6206679423666735d-05,-.1884300519061043d-04,
     3      -.4510158083102890d-04,-.8794514153478220d-04,
     4      -.1434393707148934d-03,-.1999702279242480d-03,
     5      -.2426014714319684d-03,-.2599999065748979d-03,
     6      -.2492953944873185d-03,-.2161715639670672d-03,
     7      -.1710901410450662d-03,-.1245747234063554d-03,
     8      -.8401923407516811d-04,-.5279927106010487d-04/
         data arr1111/
     1      -.3107232591780052d-04,-.1719906153378299d-04,
     2      -.8987971755803623d-05,-.4449200703066358d-05,
     3      -.2092143434810510d-05,-.9366267282178277d-06,
     4      -.4002122612074152d-06,-.1654433782963092d-06,
     5      -.8270245681869600d-07,-.5404949386817111d-06,
     6      0.2838433739376453d-06,-.1532372667214148d-06,
     7      0.7844675659157463d-07,-.3804331426350195d-07,
     8      0.1776136087905478d-07,-.8164203970808234d-08/
         data arr1112/
     1      0.3376911782216167d-08,-.7705813266523267d-08,
     2      -.5924859916176566d-07,-.3972626305096781d-06,
     3      -.1849405120445861d-05,-.6432209436717871d-05,
     4      -.1742676306495153d-04,-.3808070585968054d-04,
     5      -.6900063587325220d-04,-.1060666154360235d-03,
     6      -.1409543418224589d-03,-.1645159170425877d-03,
     7      -.1709099848229018d-03,-.1598387536664852d-03,
     8      -.1358797607900135d-03,-.1058770827433676d-03/
         data arr1113/
     1      -.7616391744304563d-04,-.5089668483858517d-04,
     2      -.3176375092687829d-04,-.1859797579136709d-04,
     3      -.1025729883242526d-04,-.5347716146600910d-05,
     4      -.2643423186457391d-05,-.1241722047142635d-05,
     5      -.5557047605775616d-06,-.2403761158354971d-06,
     6      -.1265750090842084d-06,-.8778902977347178d-06,
     7      0.4608924216493389d-06,-.2487378994677339d-06,
     8      0.1273213943595130d-06,-.6173566106323634d-07/
         data arr1114/
     1      0.2884305396034216d-07,-.1323530648066488d-07,
     2      0.6019996208502053d-08,-.3847347478289142d-08,
     3      -.1096335763082571d-07,-.9681841632451569d-07,
     4      -.5200687658303519d-06,-.2073586188662866d-05,
     5      -.6357928737285999d-05,-.1557049407492818d-04,
     6      -.3134231083567303d-04,-.5312337268500491d-04,
     7      -.7733227916927363d-04,-.9829625469240963d-04,
     8      -.1106406307899661d-03,-.1115994287316582d-03/
         data arr1115/
     1      -.1019014579223558d-03,-.8497045123247324d-04,
     2      -.6519516756135549d-04,-.4632888326861511d-04,
     3      -.3066164348190015d-04,-.1899060450936345d-04,
     4      -.1105452746085309d-04,-.6070991631468622d-05,
     5      -.3155712626003725d-05,-.1556396377578889d-05,
     6      -.7303903999784664d-06,-.3313892903308666d-06,
     7      -.1850121869022882d-06,-.1258796487819939d-05,
     8      0.6611147645434858d-06,-.3569639120939086d-06/
         data arr1116/
     1      0.1827845331855765d-06,-.8867743001722850d-07,
     2      0.4141812924993907d-07,-.1903758815092797d-07,
     3      0.8693971296761453d-08,-.4256340629340913d-08,
     4      -.4644174069236193d-09,-.2306301503362969d-07,
     5      -.1381408388001838d-06,-.6335644141562229d-06,
     6      -.2196754885232566d-05,-.6030907554194127d-05,
     7      -.1348506399243127d-04,-.2520221552296239d-04,
     8      -.4018824519650434d-04,-.5563068112769282d-04/
         data arr1117/
     1      -.6784375598156818d-04,-.7380643274267907d-04,
     2      -.7238631198186941d-04,-.6459213895824822d-04,
     3      -.5285984181951066d-04,-.3994428388806024d-04,
     4      -.2803371998069619d-04,-.1836494399347589d-04,
     5      -.1128090296002612d-04,-.6523710635867934d-05,
     6      -.3563464558964844d-05,-.1842861363780058d-05,
     7      -.9047541347681578d-06,-.4287994484880558d-06,
     8      -.2514011619420061d-06,-.1876531397614282d-05/
         data arr1118/
     1      0.9852781533110760d-06,-.5318434181754412d-06,
     2      0.2723207793420354d-06,-.1321097847337772d-06,
     3      0.6176700460906766d-07,-.2836954256576862d-07,
     4      0.1302721095354619d-07,-.6125047665860337d-08,
     5      0.2481739893303261d-08,-.6317612247775613d-08,
     6      -.3420976027117674d-07,-.1844764901955599d-06,
     7      -.7202887966035015d-06,-.2219554272936287d-05,
     8      -.5510866597180154d-05,-.1135641139903574d-04/
         data arr1119/
     1      -.1983909358570656d-04,-.2990557871992294d-04,
     2      -.3951517005836469d-04,-.4636587942273667d-04,
     3      -.4884294323910523d-04,-.4663941226499198d-04,
     4      -.4071042910942344d-04,-.3271503476340970d-04,
     5      -.2434880917502244d-04,-.1687272472694246d-04,
     6      -.1093909313529399d-04,-.6664657863623044d-05,
     7      -.3829258525595353d-05,-.2079969505909613d-05,
     8      -.1071321542623795d-05,-.5330917885943384d-06/
         data arr1120/
     1      -.3322617368650115d-06,-.2376075864435343d-05,
     2      0.1248039050620699d-05,-.6739933491433993d-06,
     3      0.3452289086016847d-06,-.1675638524134915d-06,
     4      0.7830810218685444d-07,-.3604388998333343d-07,
     5      0.1646921609552258d-07,-.7799218706256036d-08,
     6      0.3578049583224271d-08,-.2949645701069066d-08,
     7      -.7333798841611094d-08,-.5186408473282225d-07,
     8      -.2241247740859438d-06,-.7787015613396062d-06/
         data arr1121/
     1      -.2144282339326519d-05,-.4872658765475272d-05,
     2      -.9327169714780927d-05,-.1530874655185957d-04,
     3      -.2191627179799383d-04,-.2773784094135117d-04,
     4      -.3138386913926746d-04,-.3206758433026727d-04,
     5      -.2985484225738032d-04,-.2551194117450329d-04,
     6      -.2013270953235081d-04,-.1475229762007626d-04,
     7      -.1008883578897639d-04,-.6468892951690331d-05,
     8      -.3902306102284821d-05,-.2219357203847938d-05/
         data arr1122/
     1      -.1193255902092892d-05,-.6183256068344892d-06,
     2      -.4026489838353844d-06,-.3301657093124708d-05,
     3      0.1733752516554959d-05,-.9360711110227968d-06,
     4      0.4794760862586727d-06,-.2327404708771025d-06,
     5      0.1089080672295146d-06,-.5007959748747236d-07,
     6      0.2303727747650768d-07,-.1081819190599009d-07,
     7      0.5197755938159800d-08,-.2916896296605232d-08,
     8      -.2816692289083354d-09,-.1501303144324173d-07/
         data arr1123/
     1      -.6534417784407662d-07,-.2619827928633803d-06,
     2      -.7959381999176501d-06,-.1994680976166821d-05,
     3      -.4186951668359188d-05,-.7479137307087931d-05,
     4      -.1160067736492299d-04,-.1583936520555853d-04,
     5      -.1924811604299162d-04,-.2104384038736047d-04,
     6      -.2089795931327691d-04,-.1899324021304572d-04,
     7      -.1589536549066606d-04,-.1231975893286084d-04,
     8      -.8893024675784344d-05,-.6009219718841643d-05/
         data arr1124/
     1      -.3815022053670511d-05,-.2280306609099241d-05,
     2      -.1287189596717124d-05,-.7011986992216541d-06,
     3      -.4869181743111229d-06,-.3665629207106191d-05,
     4      0.1925618121772208d-05,-.1040137549263864d-05,
     5      0.5329704104631262d-06,-.2588294545609371d-06,
     6      0.1210403891762046d-06,-.5580461831331782d-07,
     7      0.2549298543142855d-07,-.1215155664258616d-07,
     8      0.5670856145573500d-08,-.3139029113154963d-08/
         data arr1125/
     1      0.1359043269792314d-08,-.5228241730870030d-08,
     2      -.1705700231836390d-07,-.8550109146389450d-07,
     3      -.2821337254434996d-06,-.7803413328741354d-06,
     4      -.1799005420978066d-05,-.3494267730144967d-05,
     5      -.5872128491629499d-05,-.8651534944038182d-05,
     6      -.1129031607549456d-04,-.1320509325291842d-04,
     7      -.1398596073980722d-04,-.1351529789369770d-04,
     8      -.1198765641565474d-04,-.9816976326669273d-05/
         data arr1126/
     1      -.7467135996291210d-05,-.5302696996719513d-05,
     2      -.3527208091097397d-05,-.2200886068756354d-05,
     3      -.1291679043413168d-05,-.7290031687896965d-06,
     4      -.5247529294460071d-06,-.4776695059519156d-05,
     5      0.2508664192021987d-05,-.1354800958385746d-05,
     6      0.6942554515670074d-06,-.3372205463008100d-06,
     7      0.1579476981091999d-06,-.7272848056078336d-07,
     8      0.3351680811760458d-07,-.1579139469856407d-07/
         data arr1127/
     1      0.7648240050674359d-08,-.4040506682401983d-08,
     2      0.2415924430339336d-08,-.3270392263849835d-08,
     3      -.2421584896690909d-08,-.2848925109478346d-07,
     4      -.9533104590724717d-07,-.2912946397112212d-06,
     5      -.7430810981297082d-06,-.1563751702645679d-05,
     6      -.2846725694801386d-05,-.4530343543091670d-05,
     7      -.6347997889896976d-05,-.7940367370142896d-05,
     8      -.8972435087698147d-05,-.9225222486363092d-05/
         data arr1128/
     1      -.8678010724345549d-05,-.7515906546115064d-05,
     2      -.6035099555404582d-05,-.4519387463869073d-05,
     3      -.3166731422044518d-05,-.2078718296244563d-05,
     4      -.1282171259190747d-05,-.7619606013384190d-06,
     5      -.5868819408819557d-06,-.4585805300535934d-05,
     6      0.2409332216023947d-05,-.1301726659875187d-05,
     7      0.6672934340755815d-06,-.3242543459315997d-06,
     8      0.1517557933637186d-06,-.7008997651020881d-07/
         data arr1129/
     1      0.3201673798788732d-07,-.1537165147403470d-07,
     2      0.7150211875378153d-08,-.4000857322586939d-08,
     3      0.2276615725495742d-08,-.2586100352003724d-08,
     4      0.1314913240530879d-08,-.1043183509633937d-07,
     5      -.3044502434351743d-07,-.1036405257454955d-06,
     6      -.2961044276721998d-06,-.6712168530147288d-06,
     7      -.1323841090269919d-05,-.2277586735252459d-05,
     8      -.3424709018252609d-05,-.4578358441449560d-05/
         data arr1130/
     1      -.5516003541076544d-05,-.6026906704548738d-05,
     2      -.6000425005119612d-05,-.5479848416653614d-05,
     3      -.4624910228035670d-05,-.3628212872381848d-05,
     4      -.2652649954976594d-05,-.1808240093800389d-05,
     5      -.1152374648697775d-05,-.7043296617206014d-06,
     6      -.5566070337596116d-06,-.5630582883299365d-05,
     7      0.2957539764696089d-05,-.1597640942615835d-05,
     8      0.8190637428813283d-06,-.3981196340238843d-06/
         data arr1131/
     1      0.1866570646126445d-06,-.8606713049316836d-07,
     2      0.3973970431994880d-07,-.1878565218575604d-07,
     3      0.9150694341913593d-08,-.4876352425763516d-08,
     4      0.3066562277811411d-08,-.3020845812848482d-08,
     5      0.3012452573923849d-08,-.5584853944299226d-08,
     6      -.8844790341683009d-08,-.3385145492820166d-07,
     7      -.1162814484815282d-06,-.2763510949387076d-06,
     8      -.5899031466474197d-06,-.1103498444458155d-05/
         data arr1132/
     1      -.1779173758726222d-05,-.2538928897042879d-05,
     2      -.3265827180056824d-05,-.3800896001606117d-05,
     3      -.4013741509073051d-05,-.3875336502835992d-05,
     4      -.3453727365231597d-05,-.2860370168917196d-05,
     5      -.2206270196661248d-05,-.1584318152139427d-05,
     6      -.1062457520231184d-05,-.6849455375125705d-06,
     7      -.5811455048544001d-06,-.4547129063383058d-05,
     8      0.2389329938492353d-05,-.1291219435489608d-05/
         data arr1133/
     1      0.6621887341660337d-06,-.3219721205495327d-06,
     2      0.1507999727385531d-06,-.6978423341971929d-07,
     3      0.3186264233899314d-07,-.1542063921326771d-07,
     4      0.7135508063978151d-08,-.4091609444104407d-08,
     5      0.2327999541288445d-08,-.2460528340998198d-08,
     6      0.2594883709004516d-08,-.3424222525017898d-08,
     7      -.2072904935720935d-08,-.1000345220414892d-07,
     8      -.4503315266467263d-07,-.1091115913714827d-06/
         data arr1134/
     1      -.2524046812435544d-06,-.5144059530284441d-06,
     2      -.8873178938188493d-06,-.1348954580604929d-05,
     3      -.1847708533049273d-05,-.2280496341862371d-05,
     4      -.2539273163403898d-05,-.2572885304353953d-05,
     5      -.2396974980119100d-05,-.2066448597698386d-05,
     6      -.1650668945613849d-05,-.1220573425145668d-05,
     7      -.8380358830168594d-06,-.5501866309102126d-06,
     8      -.4727870575375184d-06,-.5278239209353247d-05/
         data arr1135/
     1      0.2772845298005512d-05,-.1498253719386940d-05,
     2      0.7684476960208141d-06,-.3737719080373659d-06,
     3      0.1754106118228137d-06,-.8099200313514722d-07,
     4      0.3746413047219497d-07,-.1776715406386159d-07,
     5      0.8701312208772485d-08,-.4681007000365395d-08,
     6      0.2984329203213591d-08,-.2869601119246099d-08,
     7      0.3154265779239327d-08,-.3311084028872186d-08,
     8      -.4450233701097550d-10,-.1172526885277498d-08/
         data arr1136/
     1      -.1949739751120446d-07,-.4099714837848856d-07,
     2      -.1021081851900477d-06,-.2338195546564037d-06,
     3      -.4299094563633309d-06,-.6928584480200584d-06,
     4      -.1015540674724185d-05,-.1339145276389719d-05,
     5      -.1581710129652909d-05,-.1692984757088692d-05,
     6      -.1666172757753086d-05,-.1519210639194255d-05,
     7      -.1283013791089618d-05,-.1001074828259046d-05,
     8      -.7242158757921478d-06,-.5023562808586804d-06/
         data arr1137/
     1      -.4649137804086901d-06,-.3460309330770040d-05,
     2      0.1818494032351297d-05,-.9829618576882549d-06,
     3      0.5043325295141497d-06,-.2453704968245053d-06,
     4      0.1150144912025374d-06,-.5333319138697927d-07,
     5      0.2433859318736570d-07,-.1187397285686268d-07,
     6      0.5470798218704822d-08,-.3206544231238780d-08,
     7      0.1820505305803410d-08,-.1919967643571991d-08,
     8      0.2044985481558551d-08,-.2150768123263482d-08/
         data arr1138/
     1      0.3639749502900490d-09,0.5541082127274584d-09,
     2      -.8305180758796872d-08,-.1462501265241108d-07,
     3      -.3958690733553574d-07,-.1014375557586778d-06,
     4      -.1975677339226186d-06,-.3362619699828557d-06,
     5      -.5226296706836330d-06,-.7264917297539805d-06,
     6      -.8973872677474034d-06,-.9989562778497943d-06,
     7      -.1018044918053480d-05,-.9564293566333029d-06,
     8      -.8274959312375552d-06,-.6576512591031417d-06/
         data arr1139/
     1      -.4819769038374788d-06,-.3368858263765815d-06,
     2      -.3117967746962960d-06,-.3787639644352174d-05,
     3      0.1990044373154979d-05,-.1075550020620203d-05,
     4      0.5518846929753053d-06,-.2686173268981509d-06,
     5      0.1261806554445938d-06,-.5834007441828094d-07,
     6      0.2703206693456611d-07,-.1286068716591432d-07,
     7      0.6329869530950889d-08,-.3437268744473370d-08,
     8      0.2215845905840061d-08,-.2111133636824269d-08/
         data arr1140/
     1      0.2293157784934335d-08,-.2217471308801862d-08,
     2      0.4182292057915062d-09,0.1712828497493018d-08,
     3      -.5307739012065974d-08,-.4703046060781358d-08,
     4      -.1327031138303330d-07,-.4462128945812370d-07,
     5      -.9070196748500500d-07,-.1600862375176222d-06,
     6      -.2679415298856989d-06,-.4007257699307003d-06,
     7      -.5249635212766911d-06,-.6161102135524641d-06,
     8      -.6634929623090088d-06,-.6608300241909591d-06/
         data arr1141/
     1      -.6059713788840694d-06,-.5089675833543779d-06,
     2      -.3934050917281045d-06,-.2908739491186931d-06,
     3      -.2905655887220032d-06,-.1819001019031330d-05,
     4      0.9560534437768233d-06,-.5168913931410070d-06,
     5      0.2653157685958856d-06,-.1291627874103768d-06,
     6      0.6058246446461841d-07,-.2815585475044045d-07,
     7      0.1283199308829075d-07,-.6318427272492240d-08,
     8      0.2888434049024940d-08,-.1737311076705434d-08/
         data arr1142/
     1      0.9756841886937602d-09,-.1038908177436360d-08,
     2      0.1080596815662690d-08,-.1088118831247443d-08,
     3      0.2583558872176279d-09,0.8680007855694685d-09,
     4      -.2297534285921179d-08,-.1394093270709603d-08,
     5      -.4381698577347136d-08,-.1744614472520568d-07,
     6      -.3679257632368644d-07,-.6754782283429101d-07,
     7      -.1184431835245251d-06,-.1839958391015865d-06,
     8      -.2483508057525930d-06,-.2988660415026305d-06/
         data arr1143/
     1      -.3285129206393286d-06,-.3321111051066585d-06,
     2      -.3074304549035471d-06,-.2594528980379698d-06,
     3      -.2006432598901283d-06,-.1476918325635052d-06,
     4      -.1454357784267513d-06,-.1881148663230559d-05,
     5      0.9884716145283591d-06,-.5343458221788691d-06,
     6      0.2742882481374619d-06,-.1335840324412581d-06,
     7      0.6280263956493337d-07,-.2907239637539434d-07,
     8      0.1349079627400110d-07,-.6436516081671678d-08/
         data arr1144/
     1      0.3181834501080612d-08,-.1741209862254281d-08,
     2      0.1133992220483969d-08,-.1071813653434817d-08,
     3      0.1147331225640591d-08,-.1071728783588132d-08,
     4      0.1882515581308261d-09,0.1046890868343999d-08,
     5      -.1976070030001860d-08,-.2429713284879912d-09,
     6      -.5325410953657701d-09,-.7886484691286515d-08,
     7      -.1648374537241623d-07,-.2967755619346170d-07,
     8      -.5687618269041151d-07,-.9634397859156009d-07/
         data arr1145/
     1      -.1377875668270660d-06,-.1741808456776901d-06,
     2      -.2023125017426502d-06,-.2174238808659669d-06,
     3      -.2138636379172495d-06,-.1910038499977908d-06,
     4      -.1558878857140688d-06,-.1214807833451558d-06,
     5      -.1293219418626250d-06,-.5769435654980186d-06,
     6      0.3032763301266353d-06,-.1640030308137725d-06,
     7      0.8422637085587174d-07,-.4103080764689527d-07,
     8      0.1925950677152595d-07,-.8976892268091890d-08/
         data arr1146/
     1      0.4082447549029140d-08,-.2031321253163413d-08,
     2      0.9233889597232857d-09,-.5659068959526621d-09,
     3      0.3207206987916143d-09,-.3370329120335534d-09,
     4      0.3465573177339087d-09,-.3350596714241058d-09,
     5      0.7198086657784479d-10,0.3167834730496978d-09,
     6      -.6031173863424395d-09,-.3302268595409259d-10,
     7      -.9725215626133978d-10,-.2314104104783684d-08,
     8      -.4905351241170489d-08,-.9051702939813750d-08/
         data arr1147/
     1      -.1781911377260169d-07,-.3072088763706512d-07,
     2      -.4454177433644952d-07,-.5696147071782662d-07,
     3      -.6668142143282460d-07,-.7187848326639097d-07,
     4      -.7065327802457798d-07,-.6290050597680366d-07,
     5      -.5105123025838277d-07,-.3942479217454290d-07,
     6      -.4123447466907156d-07,-.5561629545061783d-06,
     7      0.2922759692308045d-06,-.1580311665271245d-06,
     8      0.8115363274795083d-07,-.3954857912968180d-07/
         data arr1148/
     1      0.1860766129815192d-07,-.8627305434548786d-08,
     2      0.4005634083687698d-08,-.1920227896764099d-08,
     3      0.9503158538416063d-09,-.5273313902745035d-09,
     4      0.3444565881742434d-09,-.3245816454822036d-09,
     5      0.3407602301116400d-09,-.3104307709201338d-09,
     6      0.4100103897296246d-10,0.3307795962414442d-09,
     7      -.5430523225140783d-09,0.4292753528296965d-10,
     8      0.2847920520115474d-09,-.1146470980556561d-08/
         data arr1149/
     1      -.2236910008154399d-08,-.3608620148248964d-08,
     2      -.8000221942106281d-08,-.1537781809025485d-07,
     3      -.2356107204504808d-07,-.3144130073059697d-07,
     4      -.3883517368276346d-07,-.4459353270434252d-07,
     5      -.4665361790768437d-07,-.4396185761013418d-07,
     6      -.3763341668837063d-07,-.3075059155089801d-07,
     7      -.3475542109187410d-07,0.2188277347114944d-04,
     8      0.1142372712073358d-02,0.7481090844453642d-02/
         data arr1150/
     1      0.2106896125213815d-01,0.3633933216458125d-01,
     2      0.4494759036125308d-01,0.4349650232416082d-01,
     3      0.3477028657697133d-01,0.2381710009790857d-01,
     4      0.1435049546015013d-01,0.7755758873852107d-02,
     5      0.3816903586924673d-02,0.1731121184332154d-02,
     6      0.7306197426455702d-03,0.2892556263866984d-03,
     7      0.1081441539641223d-03,0.3839735862290162d-04,
     8      0.1300917767057107d-04,0.4222915697701990d-05/
         data arr1151/
     1      0.1317931589487721d-05,0.3966189367534029d-06,
     2      0.1153838727990982d-06,0.3251856453326935d-07,
     3      0.8894196664883432d-08,0.2364344709609526d-08,
     4      0.6115858610370208d-09,0.1540761062733106d-09,
     5      0.3782677477101323d-10,0.9052967193159834d-11,
     6      0.2113059521626162d-11,0.4818037326391668d-12,
     7      0.1074296344291878d-12,0.2309265948826547d-13,
     8      0.4571464250529516d-14,0.2535535339426909d-06/
         data arr1152/
     1      0.7454031037822249d-04,0.1181394134102467d-02,
     2      0.6053577529525922d-02,0.1634724699716177d-01,
     3      0.2885453538418031d-01,0.3742571932019052d-01,
     4      0.3833213357178637d-01,0.3252329950083307d-01,
     5      0.2364437601731572d-01,0.1509953818835245d-01,
     6      0.8632630146203985d-02,0.4484718114228139d-02,
     7      0.2142562950510137d-02,0.9505676973233857d-03,
     8      0.3948205647037258d-03,0.1545704749903879d-03/
         data arr1153/
     1      0.5736472830909057d-04,0.2027957276460064d-04,
     2      0.6857374765420754d-05,0.2225702980572203d-05,
     3      0.6954816163338701d-06,0.2097569085181849d-06,
     4      0.6119131209797348d-07,0.1729745123276909d-07,
     5      0.4744900656838430d-08,0.1264517854112773d-08,
     6      0.3276775916409459d-09,0.8260878300434245d-10,
     7      0.2026341389941030d-10,0.4833880471337764d-11,
     8      0.1120848871540468d-11,0.2545577953004644d-12/
         data arr1154/
     1      0.6673209870576503d-13,0.1946840233311200d-07,
     2      0.3137830647483063d-05,0.1204260414595578d-03,
     3      0.1122730275665015d-02,0.4746862909019789d-02,
     4      0.1195683224230744d-01,0.2078645149022367d-01,
     5      0.2727797296414338d-01,0.2866782166855844d-01,
     6      0.2514682724009791d-01,0.1897568272768726d-01,
     7      0.1260287004897389d-01,0.7499584618486487d-02,
     8      0.4055740477914685d-02,0.2016409186947598d-02/
         data arr1155/
     1      0.9304453342033550d-03,0.4016484654814123d-03,
     2      0.1632805356125095d-03,0.6286364664170576d-04,
     3      0.2303123780492873d-04,0.8062233083378765d-05,
     4      0.2705955139067185d-05,0.8733645018991257d-06,
     5      0.2717484136693479d-06,0.8168607184808071d-07,
     6      0.2376257085203524d-07,0.6699000686701819d-08,
     7      0.1832148901973271d-08,0.4864806489791349d-09,
     8      0.1254591087014780d-09,0.3142709977949908d-10/
         data arr1156/
     1      0.7645275414529638d-11,0.1811219838987529d-11,
     2      0.4741129903473334d-12,-.1062299233627962d-07,
     3      0.1008944815822609d-06,0.9279335643688636d-05,
     4      0.1574054938027457d-03,0.1041956824371988d-02,
     5      0.3745408247608840d-02,0.8727131734134752d-02,
     6      0.1467378569440025d-01,0.1910186474476082d-01,
     7      0.2021713051136003d-01,0.1802652983019745d-01,
     8      0.1390838671427911d-01,0.9480259913178713d-02/
         data arr1157/
     1      0.5803469406148385d-02,0.3233368914990130d-02,
     2      0.1657535868496424d-02,0.7889448731251916d-03,
     3      0.3513216123569494d-03,0.1473062978587772d-03,
     4      0.5847330620936138d-04,0.2207620748375263d-04,
     5      0.7958596756968027d-05,0.2748879995993702d-05,
     6      0.9122739945611833d-06,0.2916049195274043d-06,
     7      0.8995807632491236d-07,0.2682723322651323d-07,
     8      0.7743959115515774d-08,0.2165763887829642d-08/
         data arr1158/
     1      0.5871821048597618d-09,0.1543590415912077d-09,
     2      0.3934484395400508d-10,0.9765453709561458d-11,
     3      0.2710888450417146d-11,0.2336895324204687d-07,
     4      0.3718573045171557d-09,0.5796903627619102d-06,
     5      0.1787706227216781d-04,0.1852795511673091d-03,
     6      0.9504227933451360d-03,0.2968228738709811d-02,
     7      0.6394504652444193d-02,0.1031077940068216d-01,
     8      0.1316711077769815d-01,0.1387271649237143d-01/
         data arr1159/
     1      0.1243422480611635d-01,0.9708182614784334d-02,
     2      0.6727286127548757d-02,0.4200166515188770d-02,
     3      0.2392046765841721d-02,0.1255399243900080d-02,
     4      0.6123644584730981d-03,0.2796261077355449d-03,
     5      0.1202631789475145d-03,0.4896979017839246d-04,
     6      0.1896212774682159d-04,0.7008913188940015d-05,
     7      0.2480951187434993d-05,0.8432888400033411d-06,
     8      0.2758809099355398d-06,0.8703146054192035d-07/
         data arr1160/
     1      0.2651538070383299d-07,0.7810597630724870d-08,
     2      0.2226233871298765d-08,0.6142097317980106d-09,
     3      0.1640503838390606d-09,0.4260526325540007d-10,
     4      0.1239825378024900d-10,0.9232853565746684d-08,
     5      -.9725440001196561d-09,0.3075438698827126d-07,
     6      0.1712083665623212d-05,0.2778269129077095d-04,
     7      0.2033776575376133d-03,0.8513182297334159d-03,
     8      0.2349851271181645d-02,0.4693274512713276d-02/
         data arr1161/
     1      0.7231530069136972d-02,0.9002841882256933d-02,
     2      0.9374096171667023d-02,0.8383480567983260d-02,
     3      0.6575985277914513d-02,0.4600939156239878d-02,
     4      0.2911019598253090d-02,0.1684557344303081d-02,
     5      0.9000856085121568d-03,0.4476131662732011d-03,
     6      0.2085818142572783d-03,0.9160111320370980d-04,
     7      0.3809836763171576d-04,0.1507003682131499d-04,
     8      0.5689575651649785d-05,0.2056489990644920d-05/
         data arr1162/
     1      0.7134637787986515d-06,0.2380924547348334d-06,
     2      0.7656007264096471d-07,0.2375360576056213d-07,
     3      0.7117864034005917d-08,0.2061169436215798d-08,
     4      0.5770232001419355d-09,0.1569667902383705d-09,
     5      0.4810760997487102d-10,0.1932316404086075d-07,
     6      -.2101026557159527d-08,0.1915061151204534d-08,
     7      0.1418459379242229d-06,0.3607926820982254d-05,
     8      0.3768947490699812d-04,0.2114546026219869d-03/
         data arr1163/
     1      0.7478327391140041d-03,0.1850082310932439d-02,
     2      0.3439541351359749d-02,0.5059741925535858d-02,
     3      0.6120272036176349d-02,0.6269622881295817d-02,
     4      0.5566886880970629d-02,0.4364727185845471d-02,
     5      0.3067970816573402d-02,0.1957583825162914d-02,
     6      0.1145745845025732d-02,0.6205240508968486d-03,
     7      0.3132931027124384d-03,0.1483897463448220d-03,
     8      0.6629126373341472d-04,0.2806135089177300d-04/
         data arr1164/
     1      0.1129983688677223d-04,0.4343176609687978d-05,
     2      0.1597911536845691d-05,0.5640858709537700d-06,
     3      0.1914418110626213d-06,0.6256106268284597d-07,
     4      0.1970833960372228d-07,0.5989521966585310d-08,
     5      0.1756979027915712d-08,0.5003153030875505d-09,
     6      0.1613618977115289d-09,0.1773049576605676d-06,
     7      -.1789200704758958d-07,0.4057073696198005d-08,
     8      0.9273204974939146d-08,0.4139237916244525d-06/
         data arr1165/
     1      0.6165380444560015d-05,0.4636314846273485d-04,
     2      0.2100868234031158d-03,0.6437784115268293d-03,
     3      0.1444112862473797d-02,0.2510194489896653d-02,
     4      0.3527299285698181d-02,0.4138936257588451d-02,
     5      0.4160008551955676d-02,0.3655089197810714d-02,
     6      0.2854220896996205d-02,0.2008099366411296d-02,
     7      0.1287428227187884d-02,0.7593546338931045d-03,
     8      0.4153894762603607d-03,0.2121960510721137d-03/
         data arr1166/
     1      0.1018207964905556d-03,0.4612465102433850d-04,
     2      0.1981046830424582d-04,0.8096898320331875d-05,
     3      0.3159103699804990d-05,0.1179709945342444d-05,
     4      0.4225735141382937d-06,0.1454496417287086d-06,
     5      0.4817205765977189d-07,0.1536558961680171d-07,
     6      0.4724032047859031d-08,0.1409004404735464d-08,
     7      0.4791998809323902d-09,0.4538676017645030d-06,
     8      -.4617689058167320d-07,0.1046576950663960d-07/
         data arr1167/
     1      -.2307030338432857d-08,0.4339322496985242d-07,
     2      0.9029816323579661d-06,0.9104216051290022d-05,
     3      0.5285702059021253d-04,0.2006279938186682d-03,
     4      0.5430145694457174d-03,0.1115311354854117d-02,
     5      0.1820638158994882d-02,0.2447066678091232d-02,
     6      0.2784106192815258d-02,0.2741249732969754d-02,
     7      0.2378119557008685d-02,0.1844844545833526d-02,
     8      0.1295589767657498d-02,0.8322243548292964d-03/
         data arr1168/
     1      0.4932531774177989d-03,0.2717568197104422d-03,
     2      0.1400639683676899d-03,0.6789962084143732d-04,
     3      0.3110477434913748d-04,0.1351884685721358d-04,
     4      0.5593514098827019d-05,0.2209604871577420d-05,
     5      0.8353648127292117d-06,0.3028498344749631d-06,
     6      0.1054484579665897d-06,0.3530106259305560d-07,
     7      0.1137331473880682d-07,0.3551791528579099d-08,
     8      0.1271837311079511d-08,0.1109064674674093d-05/
         data arr1169/
     1      -.1129858581785100d-06,0.2565706706282696d-07,
     2      -.7307368173788444d-08,0.6250579115620476d-08,
     3      0.1191240358569979d-06,0.1619616047750712d-05,
     4      0.1204610988038363d-04,0.5663559740013006d-04,
     5      0.1849543306723473d-03,0.4488772134204990d-03,
     6      0.8512314454365092d-03,0.1310525734103914d-02,
     7      0.1687796394157483d-02,0.1862266846156866d-02,
     8      0.1794826493710532d-02,0.1535242698510070d-02/
         data arr1170/
     1      0.1181013001446524d-02,0.8261879900986807d-03,
     2      0.5305508072573484d-03,0.3152581320007984d-03,
     3      0.1745255620539387d-03,0.9054078891801304d-04,
     4      0.4423867139607476d-04,0.2044576615573618d-04,
     5      0.8971154714653801d-05,0.3748838134498888d-05,
     6      0.1495868754337921d-05,0.5712007812588610d-06,
     7      0.2090935513802786d-06,0.7346834748446955d-07,
     8      0.2480748853542643d-07,0.8114611870568302d-08/
         data arr1171/
     1      0.3064486665151108d-08,0.2599105013517954d-05,
     2      -.2645442119605506d-06,0.5998136348699703d-07,
     3      -.1713932518993752d-07,0.5691068501237301d-08,
     4      0.1280528217388374d-07,0.2638898890550581d-06,
     5      0.2509536184355843d-05,0.1461563347028192d-04,
     6      0.5758990806781846d-04,0.1651535437124750d-03,
     7      0.3638317529291070d-03,0.6416145629086906d-03,
     8      0.9353695453205191d-03,0.1156549267561860d-02/
         data arr1172/
     1      0.1238340755930124d-02,0.1167947228903021d-02,
     2      0.9841714544576536d-03,0.7498013864860166d-03,
     3      0.5216905653839997d-03,0.3343344068862142d-03,
     4      0.1988019163171286d-03,0.1103697547902499d-03,
     5      0.5751829972087406d-04,0.2826806963221609d-04,
     6      0.1315348337746012d-04,0.5814428227124526d-05,
     7      0.2448717279169198d-05,0.9848684040469210d-06,
     8      0.3790244094357387d-06,0.1397742092382140d-06/
         data arr1173/
     1      0.4946068077117031d-07,0.1694406478903208d-07,
     2      0.6747848852179074d-08,0.5628930662294357d-05,
     3      -.5729741522383921d-06,0.1299208824546646d-06,
     4      -.3712779094927992d-07,0.1162366987493047d-07,
     5      -.2136616976763809d-08,0.4067477961632745d-07,
     6      0.4812411554769559d-06,0.3474398387406249d-05,
     7      0.1651771135797212d-04,0.5597191997176651d-04,
     8      0.1432437345840783d-03,0.2893509412072259d-03/
         data arr1174/
     1      0.4774945726605829d-03,0.6616196953635619d-03,
     2      0.7870093457138731d-03,0.8184486844953431d-03,
     3      0.7554555310289410d-03,0.6268095818705050d-03,
     4      0.4725209134404249d-03,0.3266013134712496d-03,
     5      0.2085951059452207d-03,0.1239304023908125d-03,
     6      0.6888617850374079d-04,0.3600071650800143d-04,
     7      0.1776458972172566d-04,0.8306891531789318d-05,
     8      0.3692363934205206d-05,0.1564188214675238d-05/
         data arr1175/
     1      0.6328718957675422d-06,0.2449470211320420d-06,
     2      0.9083311513816689d-07,0.3258901048364720d-07,
     3      0.1368815983513747d-07,0.1132403187913526d-04,
     4      -.1152698436828095d-05,0.2614014804737276d-06,
     5      -.7472462148482313d-07,0.2335773587891085d-07,
     6      -.7415617514987160d-08,0.7969381230453016d-08,
     7      0.8487669020420228d-07,0.7658481645208907d-06,
     8      0.4391785978675973d-05,0.1758504331315518d-04/
         data arr1176/
     1      0.5228080876024621d-04,0.1209669863354825d-03,
     2      0.2259669894052906d-03,0.3508682953897384d-03,
     3      0.4636720438320107d-03,0.5316809169492804d-03,
     4      0.5375742170752479d-03,0.4857539291008603d-03,
     5      0.3967532123816723d-03,0.2957646145241958d-03,
     6      0.2028985706320244d-03,0.1290021291403946d-03,
     7      0.7648030420723781d-04,0.4250283569663833d-04,
     8      0.2224135025866203d-04,0.1100173287158011d-04/
         data arr1177/
     1      0.5161339847811267d-05,0.2303019418330063d-05,
     2      0.9796592435003387d-06,0.3979707914056638d-06,
     3      0.1546723014449168d-06,0.5813730535577967d-07,
     4      0.2578629162222018d-07,0.2095284103585029d-04,
     5      -.2133142677947996d-05,0.4838342047578293d-06,
     6      -.1383375660118858d-06,0.4324688363039060d-07,
     7      -.1402916857860400d-07,0.5327157601137972d-08,
     8      0.1270854391587885d-07,0.1577038529375105d-06/
         data arr1178/
     1      0.1088330795290738d-05,0.5149539426706724d-05,
     2      0.1778545179965385d-04,0.4713710433105753d-04,
     3      0.9967264611766241d-04,0.1734341109743520d-03,
     4      0.2546221686296396d-03,0.3219328158919116d-03,
     5      0.3565516977580118d-03,0.3508741440541589d-03,
     6      0.3105091227775205d-03,0.2496486003047171d-03,
     7      0.1839535832449616d-03,0.1251613105480219d-03,
     8      0.7914466284845913d-04,0.4677128572527347d-04/
         data arr1179/
     1      0.2595495835744558d-04,0.1358104958630885d-04,
     2      0.6724570402444334d-05,0.3160383122148390d-05,
     3      0.1413316472359085d-05,0.6025074095717551d-06,
     4      0.2453317189594610d-06,0.9653806834374498d-07,
     5      0.4513393491687259d-07,0.3701456783025366d-04,
     6      -.3767909559902330d-05,0.8545094169076661d-06,
     7      -.2442930925490009d-06,0.7636591669316652d-07,
     8      -.2480246145679428d-07,0.8240930378433471d-08/
         data arr1180/
     1      -.4463490711908786d-09,0.3104294256378158d-07,
     2      0.2524485852948087d-06,0.1412118812553224d-05,
     3      0.5666194526425016d-05,0.1720096707482229d-04,
     4      0.4117206305535042d-04,0.8028263136315879d-04,
     5      0.1309413127458223d-03,0.1825473536451410d-03,
     6      0.2214637607913078d-03,0.2373460094153378d-03,
     7      0.2275748095002307d-03,0.1973368998371126d-03,
     8      0.1561828133049600d-03,0.1137205011962913d-03/
         data arr1181/
     1      0.7669905601181866d-04,0.4819902311978105d-04,
     2      0.2836463131941304d-04,0.1570015774445635d-04,
     3      0.8204899466616590d-05,0.4061755948575692d-05,
     4      0.1909811062673865d-05,0.8546067405665659d-06,
     5      0.3647592437203940d-06,0.1504420054900215d-06,
     6      0.7440721148182175d-07,0.6021261434248624d-04,
     7      -.6129977162839684d-05,0.1390350475415898d-05,
     8      -.3975106269750062d-06,0.1242602570927261d-06/
         data arr1182/
     1      -.4035207305266307d-07,0.1327660150272378d-07,
     2      -.3985730472113595d-08,0.6765004972206233d-08,
     3      0.5487853239845650d-07,0.3640319569787860d-06,
     4      0.1697619477031565d-05,0.5902167024395180d-05,
     5      0.1599212800623656d-04,0.3494536128503763d-04,
     6      0.6331880652302535d-04,0.9733396899807980d-04,
     7      0.1293484579018418d-03,0.1509695941257857d-03,
     8      0.1568382365981720d-03,0.1466783620872048d-03/
         data arr1183/
     1      0.1246911567920562d-03,0.9715923905830222d-04,
     2      0.6989334418869811d-04,0.4670613423624631d-04,
     3      0.2914772090707356d-04,0.1706600239170793d-04,
     4      0.9412715340961007d-05,0.4907628442679219d-05,
     5      0.2425568843280828d-05,0.1138683656790175d-05,
     6      0.5088888222489542d-06,0.2195375559885180d-06,
     7      0.1142822466701658d-06,0.9524038920447310d-04,
     8      -.9695701672516495d-05,0.2199174517365203d-05/
         data arr1184/
     1      -.6288833184087113d-06,0.1966743852055419d-06,
     2      -.6393013399808568d-07,0.2104034260255047d-07,
     3      -.6819742201101794d-08,0.2997901274664878d-08,
     4      0.1093605335511980d-07,0.8842170412957735d-07,
     5      0.4802579543893040d-06,0.1911058201340665d-05,
     6      0.5862098378608363d-05,0.1435544865145081d-04,
     7      0.2889536644780780d-04,0.4897823254389020d-04,
     8      0.7129663881248329d-04,0.9062378242328586d-04/
         data arr1185/
     1      0.1020063897157582d-03,0.1028899940157751d-03,
     2      0.9394745290221314d-04,0.7833853718966791d-04,
     3      0.6010785772179340d-04,0.4271335990311466d-04,
     4      0.2826759734228592d-04,0.1750751515477143d-04,
     5      0.1019186108289144d-04,0.5597674393414166d-05,
     6      0.2909234610496756d-05,0.1433791404836390d-05,
     7      0.6718311551638272d-06,0.3039855525638664d-06,
     8      0.1677611911558725d-06,0.1366876774633702d-03/
         data arr1186/
     1      -.1391679538465377d-04,0.3157059810227756d-05,
     2      -.9029081402587417d-06,0.2823913223792323d-06,
     3      -.9177900683373025d-07,0.3021613015371220d-07,
     4      -.9829490484229205d-08,0.3122970664609744d-08,
     5      0.1628312768790430d-08,0.2013398920010579d-07,
     6      0.1290160265776439d-06,0.5855644868165509d-06,
     7      0.2034347002835634d-05,0.5583764726589630d-05,
     8      0.1248357009550352d-04,0.2333402215962373d-04/
         data arr1187/
     1      0.3720679373290845d-04,0.5150272793532304d-04,
     2      0.6281222357976814d-04,0.6833205326218490d-04,
     3      0.6701517874217501d-04,0.5980018866903744d-04,
     4      0.4893993845128215d-04,0.3698148167951263d-04,
     5      0.2595254728683851d-04,0.1700107484507930d-04,
     6      0.1044398250450576d-04,0.6040219163737138d-05,
     7      0.3298550234316231d-05,0.1704223576394603d-05,
     8      0.8351354668471286d-06,0.3945547825604771d-06/
         data arr1188/
     1      0.2284763566046581d-06,0.1958794724081883d-03,
     2      -.1994324008899863d-04,0.4524606324299562d-05,
     3      -.1294442387776003d-05,0.4051148009354676d-06,
     4      -.1318529339622587d-06,0.4346784891056446d-07,
     5      -.1424493504538138d-07,0.4332441010718371d-08,
     6      -.5010873319822855d-09,0.4085207428324506d-08,
     7      0.3342562021502763d-07,0.1699784136210542d-06,
     8      0.6701937529668474d-06,0.2062976767846006d-05/
         data arr1189/
     1      0.5119693039421950d-05,0.1055563433746916d-04,
     2      0.1843641155760944d-04,0.2779005569622462d-04,
     3      0.3672388172223395d-04,0.4308954750107055d-04,
     4      0.4538855035571909d-04,0.4334228551279658d-04,
     5      0.3783486855708464d-04,0.3040317016475323d-04,
     6      0.2262560994414095d-04,0.1567814448551020d-04,
     7      0.1016605262649232d-04,0.6194494118522421d-05,
     8      0.3558016747797509d-05,0.1930410091261627d-05/
         data arr1190/
     1      0.9922326770136752d-06,0.4921368568800620d-06,
     2      0.3029194433427339d-06,0.2490293336460876d-03,
     3      -.2535738694338191d-04,0.5753577898367130d-05,
     4      -.1646100963935856d-05,0.5151383036600656d-06,
     5      -.1675849775653780d-06,0.5526045967787960d-07,
     6      -.1803883213759742d-07,0.5491137336749861d-08,
     7      -.1041072676437767d-08,0.4469007655300159d-09,
     8      0.8917743621851266d-08,0.4649128941939682d-07/
         data arr1191/
     1      0.2100367185699615d-06,0.7265188891472235d-06,
     2      0.1997427854041201d-05,0.4546196584993496d-05,
     3      0.8697038365132900d-05,0.1427317358531058d-04,
     4      0.2043911381883274d-04,0.2586666724927786d-04,
     5      0.2926278529100152d-04,0.2990229505552167d-04,
     6      0.2784205132020108d-04,0.2379037698516653d-04,
     7      0.1877072563118776d-04,0.1375363839561941d-04,
     8      0.9407576273114031d-05,0.6032852178258008d-05/
         data arr1192/
     1      0.3637556500411982d-05,0.2065710194637865d-05,
     2      0.1107889090619327d-05,0.5719727462785465d-06,
     3      0.3675479447299422d-06,0.3270177084036840d-03,
     4      -.3329996123800801d-04,0.7557364985940980d-05,
     5      -.2163375950624689d-05,0.6777325529652223d-06,
     6      -.2209612367836627d-06,0.7301610257059752d-07,
     7      -.2407169171440623d-07,0.7342289564679704d-08,
     8      -.1625007190303243d-08,-.3767054345715285d-09/
         data arr1193/
     1      0.3062304154832460d-08,0.1153769870800147d-07,
     2      0.6256784603117508d-07,0.2454841675732012d-06,
     3      0.7417780047725168d-06,0.1869077624424015d-05,
     4      0.3915646039113220d-05,0.6993113103696334d-05,
     5      0.1085426501297776d-04,0.1481759259509461d-04,
     6      0.1800123147614210d-04,0.1968369507244170d-04,
     7      0.1955135913821982d-04,0.1776708686266321d-04,
     8      0.1486481647819420d-04,0.1152058826314995d-04/
         data arr1194/
     1      0.8318758970616697d-05,0.5622306979267341d-05,
     2      0.3567184273673121d-05,0.2128303959092626d-05,
     3      0.1198057220942499d-05,0.6501939004178264d-06,
     4      0.4454727398141790d-06,0.3661847654210357d-03,
     5      -.3729261413868244d-04,0.8464392263377120d-05,
     6      -.2423025663026154d-05,0.7589715538391861d-06,
     7      -.2472736232816206d-06,0.8173342736623082d-07,
     8      -.2679722280433735d-07,0.8232450141564372d-08/
         data arr1195/
     1      -.1740895194494703d-08,-.5958372350020748d-09,
     2      0.1837548597295042d-08,0.2068265657205839d-08,
     3      0.1760748516310732d-07,0.8067525512842883d-07,
     4      0.2615704167532200d-06,0.7356533362930117d-06,
     5      0.1686626253972495d-05,0.3274563914524802d-05,
     6      0.5511720834585645d-05,0.8117221675614964d-05,
     7      0.1058702035749685d-04,0.1238628003119487d-04,
     8      0.1312334806147428d-04,0.1267879666976694d-04/
         data arr1196/
     1      0.1124054117935168d-04,0.9204584337668271d-05,
     2      0.7004076985957900d-05,0.4974765879847598d-05,
     3      0.3306174681529260d-05,0.2058294385526600d-05,
     4      0.1204066454708310d-05,0.6766921903597712d-06,
     5      0.4802535267906312d-06,0.4439076792808837d-03,
     6      -.4521247217565901d-04,0.1026560714847746d-04,
     7      -.2941104455295173d-05,0.9226575645788852d-06,
     8      -.3015285156381352d-06,0.9996980420220203d-07/
         data arr1197/
     1      -.3322084497411875d-07,0.1024792449719239d-07,
     2      -.2440924642377336d-08,-.6123970659567028d-09,
     3      0.1636402596385451d-08,-.4340433625526930d-09,
     4      0.4374950486268766d-08,0.2723204474455071d-07,
     5      0.8598429537048660d-07,0.2784573759453284d-06,
     6      0.6974952375655843d-06,0.1466802020823011d-05,
     7      0.2681460846347129d-05,0.4262457767664337d-05,
     8      0.5965365131646950d-05,0.7467031592228873d-05/
         data arr1198/
     1      0.8443204575128315d-05,0.8677124271635495d-05,
     2      0.8156319562034860d-05,0.7064065357474660d-05,
     3      0.5676146584474325d-05,0.4251753091751497d-05,
     4      0.2975669581123544d-05,0.1947862589019044d-05,
     5      0.1197118257484161d-05,0.7084209579872503d-06,
     6      0.5379027158016754d-06,0.4326296228128246d-03,
     7      -.4406862939472819d-04,0.1000661449799216d-04,
     8      -.2866633749669121d-05,0.8990195478211911d-06/
         data arr1199/
     1      -.2934730788142853d-06,0.9731048444669938d-07,
     2      -.3208682505718847d-07,0.9981328850434882d-08,
     3      -.2225542641073533d-08,-.6200888643155828d-09,
     4      0.1608502916651113d-08,-.1025398506653062d-08,
     5      0.7701754715065729d-09,0.1026537215173089d-07,
     6      0.2509859744192396d-07,0.1020960292715343d-06,
     7      0.2778272785662460d-06,0.6289357243535279d-06,
     8      0.1252033291419730d-05,0.2148783005949023d-05/
         data arr1200/
     1      0.3223724540649508d-05,0.4315242387905867d-05,
     2      0.5204501584593052d-05,0.5682246077647065d-05,
     3      0.5651024253475520d-05,0.5160670304969183d-05,
     4      0.4359067680964444d-05,0.3420376725015639d-05,
     5      0.2496748522724407d-05,0.1696255619378117d-05,
     6      0.1076526037213779d-05,0.6548777765891056d-06,
     7      0.5098243694343719d-06,0.4873452562924254d-03,
     8      -.4964977251464982d-04,0.1127950343164937d-04/
         data arr1201/
     1      -.3234927598564007d-05,0.1016567009993046d-05,
     2      -.3331875559703389d-06,0.1109084010643632d-06,
     3      -.3721321060647857d-07,0.1163097569395711d-07,
     4      -.2978271078697635d-08,-.4855411049288657d-09,
     5      0.1528327726210573d-08,-.1134284837449405d-08,
     6      -.3696683026715629d-09,0.5579747554536387d-08,
     7      0.4401938730754543d-08,0.3703924303510419d-07,
     8      0.1080836660155957d-06,0.2568713291874218d-06/
         data arr1202/
     1      0.5620066980448430d-06,0.1044115532770895d-05,
     2      0.1675330923577608d-05,0.2397971219559074d-05,
     3      0.3090658701885602d-05,0.3591589897799949d-05,
     4      0.3785909143746529d-05,0.3656135090598036d-05,
     5      0.3263013816443414d-05,0.2703258496357639d-05,
     6      0.2080601742721093d-05,0.1487951785450419d-05,
     7      0.9933382495132579d-06,0.6375065539243429d-06,
     8      0.5328539293429532d-06,0.4026809619210520d-03/
         data arr1203/
     1      -.4102834105490441d-04,0.9321036531731983d-05,
     2      -.2672620861167321d-05,0.8394019056588927d-06,
     3      -.2746485104273268d-06,0.9141161101088354d-07,
     4      -.3034315202026043d-07,0.9576518533600487d-08,
     5      -.2256935016523916d-08,-.4387016130617805d-09,
     6      0.1365811690075901d-08,-.1014031833295163d-08,
     7      -.4688061810380912d-09,0.3507808181129915d-08,
     8      -.1334186119936186d-08,0.1364926777855123d-07/
         data arr1204/
     1      0.4120322595360608d-07,0.9976285880009211d-07,
     2      0.2427849737836851d-06,0.4882501774233348d-06,
     3      0.8352737083042473d-06,0.1276230270285843d-05,
     4      0.1753193180795189d-05,0.2158913442826144d-05,
     5      0.2397983024395494d-05,0.2430278423216599d-05,
     6      0.2267712839695680d-05,0.1955319176443206d-05,
     7      0.1557731348621247d-05,0.1146387714225441d-05,
     8      0.7831035117424386d-06,0.5115169858274929d-06/
         data arr1205/
     1      0.4326836180347619d-06,0.4237657089317794d-03,
     2      -.4318598594882215d-04,0.9817665409922381d-05,
     3      -.2819131154656398d-05,0.8876979251847346d-06,
     4      -.2919488401567306d-06,0.9763497567212516d-07,
     5      -.3312889781362241d-07,0.1050352190544214d-07,
     6      -.2901596509197561d-08,-.2251113666299915d-09,
     7      0.1139886207386911d-08,-.8729150429853802d-09,
     8      -.6711961394798197d-09,0.3228107903964810d-08/
         data arr1206/
     1      -.3309071868215560d-08,0.5625490679916235d-08,
     2      0.1669164912808522d-07,0.3529910257170894d-07,
     3      0.1010627355373634d-06,0.2228152225298193d-06,
     4      0.4026440992042130d-06,0.6565757900102256d-06,
     5      0.9675813795854837d-06,0.1270082026767223d-05,
     6      0.1494215450596580d-05,0.1600816828806540d-05,
     7      0.1579880835607627d-05,0.1440845269620180d-05,
     8      0.1212420509734025d-05,0.9406044178727763d-06/
         data arr1207/
     1      0.6768570482009462d-06,0.4673834576282528d-06,
     2      0.4258994378556773d-06,0.2854595434044112d-03,
     3      -.2909413407099420d-04,0.6614033865963259d-05,
     4      -.1898579313855081d-05,0.5973965398449984d-06,
     5      -.1960342916494010d-06,0.6555357045670765d-07,
     6      -.2193911276717836d-07,0.7045215457093454d-08,
     7      -.1766890321752104d-08,-.1865135938152325d-09,
     8      0.8633765202950796d-09,-.6375548911253316d-09/
         data arr1208/
     1      -.4353434221101059d-09,0.2118221647749897d-08,
     2      -.2626548319705312d-08,0.2510520772152025d-08,
     3      0.6716566810948010d-08,0.1144885009227990d-07,
     4      0.4043682296578269d-07,0.9708317958663186d-07,
     5      0.1841838466337749d-06,0.3189375932985286d-06,
     6      0.4992258634774965d-06,0.6897140580026689d-06,
     7      0.8477550997188651d-06,0.9446043085623228d-06,
     8      0.9654018231365803d-06,0.9068885249844103d-06/
         data arr1209/
     1      0.7813015634447931d-06,0.6169587185136247d-06,
     2      0.4494383321005169d-06,0.3124658472448209d-06,
     3      0.2844335804125920d-06,0.2815922062808440d-03,
     4      -.2870760333194899d-04,0.6531378313775248d-05,
     5      -.1878176425560566d-05,0.5928015509654046d-06,
     6      -.1957518241289282d-06,0.6580646669758594d-07,
     7      -.2262569355510539d-07,0.7279721332538205d-08,
     8      -.2176865200222581d-08,0.2259769044874150d-11/
         data arr1210/
     1      0.6097220280507675d-09,-.4675146348132746d-09,
     2      -.5229325656317167d-09,0.2038459804499299d-08,
     3      -.2556019722622233d-08,0.1449521034218714d-08,
     4      0.3675762422989642d-08,0.2170409186309423d-08,
     5      0.1555307587623487d-07,0.4296934125641287d-07,
     6      0.8279630093914693d-07,0.1520750093164550d-06,
     7      0.2578458766802668d-06,0.3809464117452000d-06,
     8      0.4951976382962693d-06,0.5827691170759639d-06/
         data arr1211/
     1      0.6308059398061319d-06,0.6282286883094331d-06,
     2      0.5728624579850910d-06,0.4776125729677028d-06,
     3      0.3670235811178905d-06,0.2702395727632298d-06,
     4      0.2657426652048589d-06,0.1399623914909191d-03,
     5      -.1427003826942732d-04,0.3246358001489759d-05,
     6      -.9330340352062502d-06,0.2941795685115208d-06,
     7      -.9683986149825600d-07,0.3254973586166245d-07,
     8      -.1098795182568025d-07,0.3594369240448110d-08/
         data arr1212/
     1      -.9551873198574163d-09,-.2294652251967724d-10,
     2      0.3680538440471922d-09,-.2647646455370974d-09,
     3      -.2420535626666468d-09,0.1014210306738293d-08,
     4      -.1334244713430116d-08,0.6983452178681660d-09,
     5      0.1532116107734576d-08,0.1630438850239263d-09,
     6      0.5620387021620110d-08,0.1688350698231838d-07,
     7      0.3326515635394287d-07,0.6413512202155176d-07,
     8      0.1141143856887837d-06,0.1748102750692903d-06/
         data arr1213/
     1      0.2339260688725532d-06,0.2822143442018644d-06,
     2      0.3116627646926105d-06,0.3149049605519396d-06,
     3      0.2897150461637263d-06,0.2425255782441890d-06,
     4      0.1862890907716661d-06,0.1363838133283379d-06,
     5      0.1319908193344305d-06,0.1302601113731758d-03,
     6      -.1328457953630800d-04,0.3024846953485725d-05,
     7      -.8711089245187139d-06,0.2756082495097639d-06,
     8      -.9138694530359713d-07,0.3088121758580806d-07/
         data arr1214/
     1      -.1076275454268362d-07,0.3507300974547817d-08,
     2      -.1129632886138581d-08,0.7129305445222790d-10,
     3      0.2092454051527041d-09,-.1628116329734697d-09,
     4      -.2742333902210291d-09,0.9294330718475617d-09,
     5      -.1145519573370609d-08,0.4612103532781069d-09,
     6      0.1168734858300143d-08,-.7969782839969157d-09,
     7      0.1918286574305685d-08,0.7678483612045179d-08,
     8      0.1405557694167173d-07,0.2825962762211265d-07/
         data arr1215/
     1      0.5558820062496920d-07,0.9159301493710216d-07,
     2      0.1292778929500030d-06,0.1644385031593109d-06,
     3      0.1926142742696815d-06,0.2068740374824179d-06,
     4      0.2018964955201876d-06,0.1787146076662885d-06,
     5      0.1449895593120366d-06,0.1125912550416523d-06,
     6      0.1179808913449811d-06,0.4075497141167066d-04,
     7      -.4157058533619782d-05,0.9465624093671917d-06,
     8      -.2724787617542572d-06,0.8613391898497674d-07/
         data arr1216/
     1      -.2846712426197753d-07,0.9631169300961564d-08,
     2      -.3286650416365295d-08,0.1098846014754706d-08,
     3      -.3122150431594222d-09,0.1867798669767961d-10,
     4      0.8588529306795263d-10,-.5905795440304295d-10,
     5      -.8084063637267941d-10,0.2913440360859435d-09,
     6      -.3727456306771370d-09,0.1564216530382879d-09,
     7      0.3530435038353023d-09,-.2945766083585059d-09,
     8      0.5371363286483603d-09,0.2250020488458199d-08/
         data arr1217/
     1      0.4132450174270085d-08,0.8581394269897677d-08,
     2      0.1733206258876324d-07,0.2903512385656705d-07,
     3      0.4152412712306423d-07,0.5338402869836669d-07,
     4      0.6293579383283160d-07,0.6773529423768032d-07,
     5      0.6599889657431755d-07,0.5816414762921597d-07,
     6      0.4685039071945267d-07,0.3597995071396603d-07,
     7      0.3693917104955824d-07,0.3583575336059003d-04,
     8      -.3656170663961393d-05,0.8332406117176010d-06/
         data arr1218/
     1      -.2403650249840292d-06,0.7625408809338516d-07,
     2      -.2541375054299995d-07,0.8629549849445792d-08,
     3      -.3062555312584672d-08,0.1005761285860611d-08,
     4      -.3537612409632824d-09,0.4033610696688247d-10,
     5      0.3250188755137456d-10,-.2813948565042985d-10,
     6      -.8626125549245244d-10,0.2524592876172026d-09,
     7      -.2952686169041637d-09,0.9573421529871963d-10,
     8      0.2996919868619537d-09,-.3128025613557141d-09/
         data arr1219/
     1      0.1313827710400354d-09,0.1115961475934961d-08,
     2      0.1668060470766822d-08,0.3456837007152207d-08,
     3      0.8014665884635610d-08,0.1457884937243284d-07,
     4      0.2189620125293721d-07,0.2957465051166153d-07,
     5      0.3701594614235210d-07,0.4245372338161827d-07,
     6      0.4396853408821035d-07,0.4102174407094378d-07,
     7      0.3492886671908282d-07,0.2848065438065715d-07,
     8      0.3170744868626362d-07,-.3043224561087037d-04/
         data arr1220/
     1      -.4823021163726444d-03,-.2471362663114176d-02,
     2      -.6673735646562508d-02,-.1177981474063247d-01,
     3      -.1527898593252927d-01,-.1564902800029282d-01,
     4      -.1327758142153859d-01,-.9652776088120029d-02,
     5      -.6164360652204815d-02,-.3524256499384426d-02,
     6      -.1830878503352507d-02,-.8746976617529375d-03,
     7      -.3880676374023179d-03,-.1611848205837571d-03,
     8      -.6310313216616908d-04,-.2341905226648653d-04/
         data arr1221/
     1      -.8279100915388847d-05,-.2799511521596582d-05,
     2      -.9086394356494009d-06,-.2839291840860071d-06,
     3      -.8563289971227735d-07,-.2498124557115193d-07,
     4      -.7061653857639786d-08,-.1937099572035415d-08,
     5      -.5162386254929894d-09,-.1337725112957871d-09,
     6      -.3372251048372150d-10,-.8271378582406282d-11,
     7      -.1973976559675200d-11,-.4586427294678751d-12,
     8      -.1041950176669538d-12,-.2552324872285908d-13/
         data arr1222/
     1      -.1678544568759184d-05,-.6437014651020282d-04,
     2      -.6001246479572392d-03,-.2537304932471429d-02,
     3      -.6391195674631763d-02,-.1111082567870934d-01,
     4      -.1458068986305256d-01,-.1532359524393317d-01,
     5      -.1344154455676883d-01,-.1014292906383795d-01,
     6      -.6736517401921406d-02,-.4008696597913347d-02,
     7      -.2167884474010704d-02,-.1077816047016156d-02,
     8      -.4973439510920957d-03,-.2146901354029014d-03/
         data arr1223/
     1      -.8727711745446979d-04,-.3360203253751454d-04,
     2      -.1231071444276367d-04,-.4309444856796930d-05,
     3      -.1446393855602145d-05,-.4668329600975930d-06,
     4      -.1452556423018387d-06,-.4366304486786711d-07,
     5      -.1270162432349297d-07,-.3580761937796717d-08,
     6      -.9793253606352292d-09,-.2600384678137770d-09,
     7      -.6706247988612762d-10,-.1679665668121555d-10,
     8      -.4082892282323912d-11,-.9652419889512169d-12/
         data arr1224/
     1      -.2518298280975832d-12,-.6078773342730446d-07,
     2      -.5682623524055032d-05,-.9639073164523613d-04,
     3      -.6380656528646271d-03,-.2293584767262643d-02,
     4      -.5344254917814939d-02,-.8985821886215273d-02,
     5      -.1169745544019274d-01,-.1238041345397477d-01,
     6      -.1103894997928303d-01,-.8517112648805837d-02,
     7      -.5805449854072100d-02,-.3553884695724626d-02,
     8      -.1980025997969751d-02,-.1015029277056272d-02/
         data arr1225/
     1      -.4831280935746550d-03,-.2151396714689552d-03,
     2      -.9020631642561547d-04,-.3580744093967765d-04,
     3      -.1351886093749391d-04,-.4873625289895792d-05,
     4      -.1683338345838121d-05,-.5586514377913818d-06,
     5      -.1785708048226171d-06,-.5508785054421565d-07,
     6      -.1642826577252448d-07,-.4742183348349317d-08,
     7      -.1326240483307785d-08,-.3595622402960982d-09,
     8      -.9452130946861483d-10,-.2409425894952451d-10/
         data arr1226/
     1      -.5977544693106534d-11,-.1639281803410717d-11,
     2      -.2255005979083946d-08,-.3860289788731249d-06,
     3      -.1191815219506268d-04,-.1235196704894684d-03,
     4      -.6336152041135033d-03,-.1978819156677887d-02,
     5      -.4263003102341468d-02,-.6873852933574509d-02,
     6      -.8778073851856260d-02,-.9248477661564303d-02,
     7      -.8289483204073540d-02,-.6472121743194707d-02,
     8      -.4484857418357997d-02,-.2800111010124062d-02/
         data arr1227/
     1      -.1594697843905780d-02,-.8369328292466547d-03,
     2      -.4082429723234328d-03,-.1864174051694172d-03,
     3      -.8017545261073582d-04,-.3264652678213967d-04,
     4      -.1264141851809933d-04,-.4672608789076465d-05,
     5      -.1653967434952048d-05,-.5621925565423292d-06,
     6      -.1839206220629160d-06,-.5802097635762010d-07,
     7      -.1767690067016790d-07,-.5207041141580319d-08,
     8      -.1484144426161143d-08,-.4094710023539813d-09/
         data arr1228/
     1      -.1093595367194893d-09,-.2837755630736481d-10,
     2      -.8173298176702613d-11,0.2561575771528845d-08,
     3      -.2222628142077942d-07,-.1210491155480230d-05,
     4      -.1964536969888993d-04,-.1438097081049461d-03,
     5      -.6019728974400186d-03,-.1661595767067870d-02,
     6      -.3318646234553203d-02,-.5113463949915368d-02,
     7      -.6365970545083954d-02,-.6628486970338100d-02,
     8      -.5928015959660860d-02,-.4649923782952984d-02/
         data arr1229/
     1      -.3253355277164594d-02,-.2058401698189466d-02,
     2      -.1191161921361303d-02,-.6364566374183513d-03,
     3      -.3165103053136838d-03,-.1474896152330305d-03,
     4      -.6477176823872445d-04,-.2693961417468199d-04,
     5      -.1065612527569684d-04,-.4023137442882206d-05,
     6      -.1454157938334279d-05,-.5044950975281097d-06,
     7      -.1683568308587564d-06,-.5413610088174243d-07,
     8      -.1679621066636022d-07,-.5032967821630321d-08/
         data arr1230/
     1      -.1457393641200199d-08,-.4079680529998774d-09,
     2      -.1108978680673343d-09,-.3364202831364143d-10,
     3      -.5332472147687907d-09,-.9129902387197039d-09,
     4      -.1049045811740120d-06,-.2664587048400128d-05,
     5      -.2783553483421257d-04,-.1561695703307565d-03,
     6      -.5523110818812277d-03,-.1366376340539836d-02,
     7      -.2540269639094358d-02,-.3736867065763296d-02,
     8      -.4520120460510315d-02,-.4630423370230499d-02/
         data arr1231/
     1      -.4111418437660492d-02,-.3223564661995927d-02,
     2      -.2265846612891252d-02,-.1445771470229495d-02,
     3      -.8461893860407595d-03,-.4582873840365058d-03,
     4      -.2313822905312970d-03,-.1095930904671137d-03,
     5      -.4895934324643826d-04,-.2072468130998439d-04,
     6      -.8345482287668089d-05,-.3207648229478668d-05,
     7      -.1180136053533776d-05,-.4166052730425524d-06,
     8      -.1413890266369659d-06,-.4620399055632553d-07/
         data arr1232/
     1      -.1455521846186418d-07,-.4423427643061444d-08,
     2      -.1297571119626182d-08,-.3692510567256157d-09,
     3      -.1178480304618160d-09,0.5087890617801639d-08,
     4      -.1377424844159857d-08,-.7527046449523963d-08,
     5      -.3160184585499108d-06,-.4708918668632371d-05,
     6      -.3541043285454876d-04,-.1604564619850984d-03,
     7      -.4916938847794165d-03,-.1102959416069809d-02,
     8      -.1917192711060766d-02,-.2694019328117784d-02/
         data arr1233/
     1      -.3161164783735023d-02,-.3177259013087027d-02,
     2      -.2791620486359885d-02,-.2179947219621765d-02,
     3      -.1533711223750466d-02,-.9832895504652754d-03,
     4      -.5799666827397496d-03,-.3172589520641410d-03,
     5      -.1620674101936403d-03,-.7776691897472363d-04,
     6      -.3522828463075659d-04,-.1513049385642606d-04,
     7      -.6184107363655445d-05,-.2412805907541960d-05,
     8      -.9010189983249178d-06,-.3227451572203079d-06/
         data arr1234/
     1      -.1110873939428064d-06,-.3679072761006968d-07,
     2      -.1173515144666617d-07,-.3607758522194039d-08,
     3      -.1075121767867356d-08,-.3614362089636461d-09,
     4      0.1784997724643046d-07,-.4716735587661548d-08,
     5      0.9328582590182883d-09,-.3381166443883150d-07,
     6      -.7084107502173812d-06,-.7141927356868268d-05,
     7      -.4146445489507928d-04,-.1573855517157925d-03,
     8      -.4259756704140234d-03,-.8749222131892288d-03/
         data arr1235/
     1      -.1428226073615812d-02,-.1919637039887873d-02,
     2      -.2184032584188793d-02,-.2150413211164475d-02,
     3      -.1865550468901986d-02,-.1447215125798524d-02,
     4      -.1016344231827435d-02,-.6528504994380626d-03,
     5      -.3869396247125420d-03,-.2131835864726868d-03,
     6      -.1098752195886459d-03,-.5326484626863549d-04,
     7      -.2440058926758160d-04,-.1060505378546250d-04,
     8      -.4387915338736038d-05,-.1733358781048272d-05/
         data arr1236/
     1      -.6553127025097352d-06,-.2375712108992244d-06,
     2      -.8271768415407003d-07,-.2769158196525819d-07,
     3      -.8921638131458477d-08,-.2783782611373205d-08,
     4      -.9853639749043577d-09,0.4132347679816851d-07,
     5      -.1093387923369250d-07,0.3383216459557230d-08,
     6      -.4344188238536625d-08,-.9567951180625606d-07,
     7      -.1298551489050587d-05,-.9658370953743351d-05,
     8      -.4540951053161432d-04,-.1482933624873812d-03/
         data arr1237/
     1      -.3599024535367675d-03,-.6825035118247331d-03,
     2      -.1050758212162838d-02,-.1353247678381551d-02,
     3      -.1493135247112045d-02,-.1439062681531693d-02,
     4      -.1230932602601213d-02,-.9469170041211833d-03,
     5      -.6624240934271220d-03,-.4253869967940423d-03,
     6      -.2527688335786052d-03,-.1399317629005216d-03,
     7      -.7259413489936641d-04,-.3546983830752791d-04,
     8      -.1639307616487839d-04,-.7192929839383730d-05/
         data arr1238/
     1      -.3005762131977673d-05,-.1199358743661205d-05,
     2      -.4579683553806476d-06,-.1676385318139640d-06,
     3      -.5890182415507279d-07,-.1988808519879740d-07,
     4      -.6498783087727365d-08,-.2423868052308027d-08,
     5      0.9545247207994172d-07,-.2526420787232962d-07,
     6      0.7894001672562134d-08,-.2999187432416603d-08,
     7      -.1087169055720522d-07,-.2153883864476792d-06,
     8      -.2049019269472172d-05,-.1193363890874639d-04/
         data arr1239/
     1      -.4702193909938138d-04,-.1348473252650594d-03,
     2      -.2970673628356153d-03,-.5238761123282847d-03,
     3      -.7637260287941484d-03,-.9443185150691789d-03,
     4      -.1011101013575986d-02,-.9536248993206444d-03,
     5      -.8035726269252304d-03,-.6122102893256166d-03,
     6      -.4259585479124019d-03,-.2729828854759850d-03,
     7      -.1623211035163220d-03,-.9011653693456722d-04,
     8      -.4696347492268925d-04,-.2308076786417806d-04/
         data arr1240/
     1      -.1073978584257418d-04,-.4747474739871944d-05,
     2      -.1999361449879155d-05,-.8041183874570769d-06,
     3      -.3094539119754265d-06,-.1141200700412153d-06,
     4      -.4038319770346589d-07,-.1382034080999456d-07,
     5      -.5434008790919133d-08,0.2162415325154692d-06,
     6      -.5719027172096448d-07,0.1785618381331024d-07,
     7      -.6177867927920916d-08,0.9148801065744654d-09,
     8      -.3357960080134318d-07,-.3989967190445450d-06/
         data arr1241/
     1      -.2880876618109052d-05,-.1369570868282339d-04,
     2      -.4640951307355741d-04,-.1187713871962365d-03,
     3      -.2399171609086312d-03,-.3959175687759046d-03,
     4      -.5485860545662949d-03,-.6525537213221445d-03,
     5      -.6786217552460203d-03,-.6263906345673004d-03,
     6      -.5197230953237890d-03,-.3917936103420891d-03,
     7      -.2708034714141069d-03,-.1729579658225330d-03,
     8      -.1027576811136992d-03,-.5711735622731430d-04/
         data arr1242/
     1      -.2985018411424325d-04,-.1472964237486654d-04,
     2      -.6887736297552587d-05,-.3061522626170929d-05,
     3      -.1296897907536536d-05,-.5247023492669278d-06,
     4      -.2030811342066251d-06,-.7530564023914892d-07,
     5      -.2698423830774701d-07,-.1117833081782730d-07,
     6      0.4474178047042317d-06,-.1184608044277818d-06,
     7      0.3703515787465031d-07,-.1278776047136220d-07,
     8      0.4563960495135802d-08,-.6428295525468078d-08/
         data arr1243/
     1      -.7124285001660659d-07,-.6435631981028229d-06,
     2      -.3689725774322988d-05,-.1477449134993522d-04,
     3      -.4392457667037970d-04,-.1016326678996866d-03,
     4      -.1898502129716764d-03,-.2947882992266709d-03,
     5      -.3895625276853704d-03,-.4467012300169808d-03,
     6      -.4516526808273020d-03,-.4081150242067705d-03,
     7      -.3333393043676442d-03,-.2484919160135459d-03,
     8      -.1704689804127462d-03,-.1083835080323514d-03/
         data arr1244/
     1      -.6425621763525798d-04,-.3570946274928964d-04,
     2      -.1868652559542314d-04,-.9243366329451317d-05,
     3      -.4336357113789093d-05,-.1934820570741017d-05,
     4      -.8230000378641184d-06,-.3343426086177933d-06,
     5      -.1299469765620148d-06,-.4878211804359981d-07,
     6      -.2133206260839754d-07,0.8378528189344792d-06,
     7      -.2217515158160193d-06,0.6930155715236160d-07,
     8      -.2391843813788248d-07,0.8787093939896850d-08/
         data arr1245/
     1      -.4019653827840906d-08,-.1067595035363243d-07,
     2      -.1342502169534169d-06,-.9246935274532335d-06,
     3      -.4376454221045151d-05,-.1511456232223932d-04,
     4      -.4005896877769893d-04,-.8470540153235689d-04,
     5      -.1473905914356867d-03,-.2163874046399181d-03,
     6      -.2735901173401275d-03,-.3030106747404676d-03,
     7      -.2981858586985241d-03,-.2638818842826075d-03,
     8      -.2121603939672853d-03,-.1563306417016287d-03/
         data arr1246/
     1      -.1063667358608678d-03,-.6725985602730786d-04,
     2      -.3974782491153473d-04,-.2205756108105646d-04,
     3      -.1154177110294569d-04,-.5714695350398314d-05,
     4      -.2685587487014991d-05,-.1200909991368767d-05,
     5      -.5119661087258005d-06,-.2084592553168072d-06,
     6      -.8190258866289273d-07,-.3771043291976697d-07,
     7      0.1516017689044676d-05,-.4016200285922329d-06,
     8      0.1256578816162863d-06,-.4342298582207356d-07/
         data arr1247/
     1      0.1599605575977547d-07,-.6293581067460425d-08,
     2      0.6565437426946645d-09,-.2707842631644764d-07,
     3      -.2163143452537496d-06,-.1212496767891665d-05,
     4      -.4863533476042888d-05,-.1476546631487731d-04,
     5      -.3534178665859606d-04,-.6891410783684541d-04,
     6      -.1123996828329133d-03,-.1566974465203083d-03,
     7      -.1901034008104582d-03,-.2037369570970269d-03,
     8      -.1953488622350037d-03,-.1693928113229274d-03/
         data arr1248/
     1      -.1340668428472608d-03,-.9761725323154238d-04,
     2      -.6583778604833460d-04,-.4137359954168647d-04,
     3      -.2434824595146792d-04,-.1347714856866987d-04,
     4      -.7042925731997556d-05,-.3486248939857315d-05,
     5      -.1639116504193596d-05,-.7335336030945121d-06,
     6      -.3131039795419754d-06,-.1289352419092899d-06,
     7      -.6277136004014867d-07,0.2507568865407901d-05,
     8      -.6639982560696367d-06,0.2076465479659298d-06/
         data arr1249/
     1      -.7171982567715611d-07,0.2641226512332941d-07,
     2      -.1027337462023964d-07,0.3929162604977681d-08,
     3      -.6576699844671060d-08,-.4688446692446759d-07,
     4      -.3158239621182399d-06,-.1469686173673191d-05,
     5      -.5111824458164963d-05,-.1384940741492645d-04,
     6      -.3026339392130573d-04,-.5483619731158463d-04,
     7      -.8429318990771819d-04,-.1120190497346226d-03,
     8      -.1307440168393297d-03,-.1358255115692459d-03/
         data arr1250/
     1      -.1270268389984897d-03,-.1079861777148086d-03,
     2      -.8414258523912762d-04,-.6052889439096862d-04,
     3      -.4044833904785131d-04,-.2524293737769772d-04,
     4      -.1477988459402225d-04,-.8151382787932184d-05,
     5      -.4249483090597351d-05,-.2100095144336807d-05,
     6      -.9859517784382633d-06,-.4406314459433673d-06,
     7      -.1897309759403134d-06,-.9710645880902449d-07,
     8      0.4120420762346771d-05,-.1092436088611097d-05/
         data arr1251/
     1      0.3421562154023150d-06,-.1183831770155231d-06,
     2      0.4367469022596221d-07,-.1700781820784623d-07,
     3      0.6948935387817652d-08,-.3873575838107247d-08,
     4      -.8475710957129988d-08,-.7810690019161916d-07,
     5      -.4183972849680381d-06,-.1668756361697868d-05,
     6      -.5116557545111337d-05,-.1253019054040547d-04,
     7      -.2522274375580183d-04,-.4275089803608760d-04,
     8      -.6223282400225575d-04,-.7910373780627138d-04/
         data arr1252/
     1      -.8903784661477390d-04,-.8980920769043318d-04,
     2      -.8200482233329656d-04,-.6837982146759137d-04,
     3      -.5246562720342191d-04,-.3728276018657457d-04,
     4      -.2467449500322466d-04,-.1528236901934388d-04,
     5      -.8895868702327058d-05,-.4885166239029180d-05,
     6      -.2538751937143191d-05,-.1251408206329796d-05,
     7      -.5864450641535952d-06,-.2648308293653010d-06,
     8      -.1436058461369073d-06,0.5983292268378047d-05/
         data arr1253/
     1      -.1585613053534989d-05,0.4963755593202555d-06,
     2      -.1716582277856973d-06,0.6330766818501079d-07,
     3      -.2464117879339389d-07,0.1011804748604728d-07,
     4      -.4563524390746297d-08,0.1296500584380536d-09,
     5      -.1903771708880417d-07,-.1122400096908329d-06,
     6      -.5156786332842046d-06,-.1787852146139897d-05,
     7      -.4908008124324523d-05,-.1097483162973873d-04,
     8      -.2051057798451766d-04,-.3270661889735326d-04/
         data arr1254/
     1      -.4527460831412395d-04,-.5521411372400640d-04,
     2      -.6006644004815639d-04,-.5891073213321322d-04,
     3      -.5256778178000270d-04,-.4301940100408313d-04,
     4      -.3250773462195458d-04,-.2281422514437398d-04,
     5      -.1494546871572504d-04,-.9180158268326283d-05,
     6      -.5308178952180062d-05,-.2898467655948806d-05,
     7      -.1497751395434845d-05,-.7339948203528350d-06,
     8      -.3459653291618658d-06,-.1966265987658821d-06/
         data arr1255/
     1      0.8984857128867325d-05,-.2384587329112026d-05,
     2      0.7478854705161646d-06,-.2591821268949574d-06,
     3      0.9579797627024757d-07,-.3737899706221791d-07,
     4      0.1539797750602850d-07,-.6777501902019170d-08,
     5      0.2825891294610014d-08,-.5628458128373509d-08,
     6      -.2783493957570379d-07,-.1517655919256533d-06,
     7      -.5922214823972429d-06,-.1824471144276174d-05,
     8      -.4530818337998353d-05,-.9336335754024062d-05/
         data arr1256/
     1      -.1630988069920788d-04,-.2458622074801973d-04,
     2      -.3248648447794562d-04,-.3811814337431808d-04,
     3      -.4015469058091995d-04,-.3834350412786878d-04,
     4      -.3346896003944119d-04,-.2689518887286564d-04,
     5      -.2001692570269638d-04,-.1387088198149415d-04,
     6      -.8992755657053252d-05,-.5478168332543587d-05,
     7      -.3146378645789465d-05,-.1707632459828661d-05,
     8      -.8779188314740374d-06,-.4343696300199359d-06/
         data arr1257/
     1      -.2621936720324461d-06,0.1151733812976335d-04,
     2      -.3054941910129309d-05,0.9575038331523444d-06,
     3      -.3316028833038932d-06,0.1224986268564660d-06,
     4      -.4776473213330793d-07,0.1967021204826081d-07,
     5      -.8630900315905455d-08,0.4001279498308908d-08,
     6      -.2968319992233818d-08,-.5702665330781960d-08,
     7      -.4315093188386383d-07,-.1860245853161270d-06,
     8      -.6457244324411787d-06,-.1779375165798975d-05/
         data arr1258/
     1      -.4042794380624119d-05,-.7738340983161821d-05,
     2      -.1270183416018287d-04,-.1818409029018861d-04,
     3      -.2301361907298971d-04,-.2603884118844927d-04,
     4      -.2660661398588483d-04,-.2477039233392881d-04,
     5      -.2116623983018576d-04,-.1670271566670834d-04,
     6      -.1223873168392526d-04,-.8369369092788011d-05,
     7      -.5365167118463246d-05,-.3234661431213208d-05,
     8      -.1837553550383685d-05,-.9856861090063640d-06/
         data arr1259/
     1      -.5074492802091461d-06,-.3194672362941000d-06,
     2      0.1605964335927185d-04,-.4267285331137246d-05,
     3      0.1340456479747695d-05,-.4653994861240039d-06,
     4      0.1723840331773675d-06,-.6741623026025052d-07,
     5      0.2785401323100524d-07,-.1225952444867898d-07,
     6      0.5810939144799151d-08,-.3247420068305980d-08,
     7      0.3082659406354748d-09,-.1276576479301851d-07,
     8      -.5475245614754150d-07,-.2187007515038502d-06/
         data arr1260/
     1      -.6662968080785087d-06,-.1668758104863288d-05,
     2      -.3502490972692785d-05,-.6257693788974102d-05,
     3      -.9705947497312484d-05,-.1325147259859039d-04,
     4      -.1610363024146587d-04,-.1760669520480045d-04,
     5      -.1748430353238434d-04,-.1588974818207529d-04,
     6      -.1329758250367187d-04,-.1030638480904037d-04,
     7      -.7439428646716249d-05,-.5025826020055320d-05,
     8      -.3188764955030913d-05,-.1903708873079215d-05/
         data arr1261/
     1      -.1072022020786272d-05,-.5800026519424186d-06,
     2      -.3888978326786485d-06,0.1805371760203315d-04,
     3      -.4793721510422790d-05,0.1504582663551942d-05,
     4      -.5219314204809974d-06,0.1931774741668123d-06,
     5      -.7547791804101127d-07,0.3116886830344586d-07,
     6      -.1370373347192411d-07,0.6499103723200892d-08,
     7      -.3469182816705785d-08,0.1793904910655262d-08,
     8      -.4606660838113319d-08,-.1446145484375983d-07/
         data arr1262/
     1      -.7152054451025971d-07,-.2382812930353741d-06,
     2      -.6577661103303229d-06,-.1516045349984776d-05,
     3      -.2946146753852217d-05,-.4950777244911858d-05,
     4      -.7293058287286182d-05,-.9517933891123236d-05,
     5      -.1113295609742175d-04,-.1179079220561972d-04,
     6      -.1139273958033583d-04,-.1010430623738598d-04,
     7      -.8274482613716247d-05,-.6293237592998562d-05,
     8      -.4467337331615492d-05,-.2968971914178635d-05/
         data arr1263/
     1      -.1849668914943093d-05,-.1082409957592683d-05,
     2      -.6062715589800032d-06,-.4208064294536591d-06,
     3      0.2350624114693745d-04,-.6254082177913630d-05,
     4      0.1967930957159291d-05,-.6846418370579072d-06,
     5      0.2541791946415368d-06,-.9965426893876710d-07,
     6      0.4130338718802033d-07,-.1823763024972191d-07,
     7      0.8718698196181612d-08,-.4654488050307399d-08,
     8      0.2885188139118898d-08,-.3106983194628300d-08/
         data arr1264/
     1      -.2153666507334288d-08,-.2348442165169332d-07,
     2      -.8149312876371586d-07,-.2471199783647323d-06,
     3      -.6300911283721584d-06,-.1327941130068281d-05,
     4      -.2417020188051619d-05,-.3845275750289144d-05,
     5      -.5388783999003636d-05,-.6741595786748970d-05,
     6      -.7617297978812538d-05,-.7830586516002953d-05,
     7      -.7365608198040726d-05,-.6379463736711293d-05,
     8      -.5122271592586790d-05,-.3834206518752448d-05/
         data arr1265/
     1      -.2684033882600595d-05,-.1758922579423186d-05,
     2      -.1081604350992504d-05,-.6375999105594711d-06,
     3      -.4728086719106192d-06,0.2287398774300330d-04,
     4      -.6080517420857523d-05,0.1911342645366681d-05,
     5      -.6642238044255594d-06,0.2463492786928479d-06,
     6      -.9646812910083622d-07,0.3995186097646243d-07,
     7      -.1761232208754869d-07,0.8411996253762658d-08,
     8      -.4470821840804686d-08,0.2826521635840187d-08/
         data arr1266/
     1      -.2478630476058308d-08,0.1051510472337872d-08,
     2      -.8215087658958780d-08,-.2657070045329838d-07,
     3      -.8838487671545235d-07,-.2522455658151963d-06,
     4      -.5738677467017894d-06,-.1131383822945039d-05,
     5      -.1945201738176233d-05,-.2925698316476118d-05,
     6      -.3912355468662862d-05,-.4712938805690569d-05,
     7      -.5148014311266999d-05,-.5124804928130533d-05,
     8      -.4680233491444945d-05,-.3949463315749052d-05/
         data arr1267/
     1      -.3096408789233614d-05,-.2260990978494771d-05,
     2      -.1538118061320850d-05,-.9768195521505433d-06,
     3      -.5918905082627286d-06,-.4499536556615579d-06,
     4      0.2794247970627768d-04,-.7444232640483210d-05,
     5      0.2346512610007714d-05,-.8180290582357626d-06,
     6      0.3044099399294073d-06,-.1196525377464885d-06,
     7      0.4974404731096002d-07,-.2204118345777139d-07,
     8      0.1060081992287938d-07,-.5696524751332391d-08/
         data arr1268/
     1      0.3666660710225506d-08,-.3024464701545063d-08,
     2      0.2495918256401841d-08,-.3979933890672119d-08,
     3      -.8287060423751372d-08,-.2884831489131178d-07,
     4      -.9907186760889233d-07,-.2379616569950409d-06,
     5      -.5072367281103746d-06,-.9474461676379707d-06,
     6      -.1528689736191870d-05,-.2182769705612223d-05,
     7      -.2806968700036132d-05,-.3265416475377430d-05,
     8      -.3447956726838011d-05,-.3329495669310114d-05/
         data arr1269/
     1      -.2967024308815473d-05,-.2455518782582186d-05,
     2      -.1891239164726818d-05,-.1355066092655116d-05,
     3      -.9053227111946860d-06,-.5782385981714304d-06,
     4      -.4710571685077042d-06,0.2291364362307867d-04,
     5      -.6097936881552033d-05,0.1919690833300384d-05,
     6      -.6683111966921779d-06,0.2483699058294525d-06,
     7      -.9747294879755503d-07,0.4048316526768352d-07,
     8      -.1789139382071847d-07,0.8603859004520390d-08/
         data arr1270/
     1      -.4590151394845125d-08,0.2959169202138826d-08,
     2      -.2406862582490756d-08,0.2202825305579569d-08,
     3      -.2271622529147956d-08,-.2366278658996133d-08,
     4      -.8445203193559930d-08,-.3818985231271187d-07,
     5      -.9465393264040164d-07,-.2183171765867611d-06,
     6      -.4436865161494840d-06,-.7663471152679573d-06,
     7      -.1166197522907190d-05,-.1596675467730724d-05,
     8      -.1969373129673534d-05,-.2192558862625768d-05/
         data arr1271/
     1      -.2221873012771308d-05,-.2069583115483012d-05,
     2      -.1782552648019274d-05,-.1421453276857442d-05,
     3      -.1048438086505215d-05,-.7169633079461129d-06,
     4      -.4662028635532723d-06,-.3845757169151797d-06,
     5      0.2634762660073976d-04,-.7028303235235419d-05,
     6      0.2219122953279422d-05,-.7751465087716858d-06,
     7      0.2890967129082073d-06,-.1139108965790562d-06,
     8      0.4749355209891360d-07,-.2111405615048162d-07/
         data arr1272/
     1      0.1021080992200423d-07,-.5526900390101839d-08,
     2      0.3595385874329941d-08,-.2925559963426601d-08,
     3      0.2669310868879352d-08,-.2113847353487061d-08,
     4      -.7014833043095359d-09,-.7622121150230428d-09,
     5      -.1614532408651364d-07,-.3603045594132867d-07,
     6      -.8883362297130548d-07,-.2021169774201438d-06,
     7      -.3729289739883386d-06,-.6022644461107522d-06,
     8      -.8819887798663769d-06,-.1161795683364772d-05/
         data arr1273/
     1      -.1372184913103013d-05,-.1469302678319337d-05,
     2      -.1445907432729980d-05,-.1316860114461593d-05,
     3      -.1109823671799604d-05,-.8635037885263152d-06,
     4      -.6219536175665911d-06,-.4269407720013549d-06,
     5      -.3784663131535034d-06,0.1758327590751542d-04,
     6      -.4684737494749135d-05,0.1477040369263580d-05,
     7      -.5151371131449781d-06,0.1918360088976601d-06,
     8      -.7545799795229855d-07,0.3142380232450035d-07/
         data arr1274/
     1      -.1392811654498719d-07,0.6738223649324546d-08,
     2      -.3612662600705070d-08,0.2358013845901357d-08,
     3      -.1903014469479470d-08,0.1775806853479427d-08,
     4      -.1360168195292155d-08,-.1372348864901566d-09,
     5      0.6572162822207390d-09,-.6716357593275908d-08,
     6      -.1304569706375132d-07,-.3465406586544358d-07,
     7      -.8785356330051251d-07,-.1720573577800704d-06,
     8      -.2937436068389525d-06,-.4559759515971560d-06/
         data arr1275/
     1      -.6329793320268511d-06,-.7818907482815461d-06,
     2      -.8707988801180545d-06,-.8873132664556975d-06,
     3      -.8325683170519919d-06,-.7187780495450078d-06,
     4      -.5695885840599551d-06,-.4155982976590048d-06,
     5      -.2874905075260032d-06,-.2549864251053477d-06,
     6      0.1897502577137805d-04,-.5067849155428431d-05,
     7      0.1602702052138903d-05,-.5608893428320181d-06,
     8      0.2096321887525184d-06,-.8279802994919290d-07/
         data arr1276/
     1      0.3460823586018969d-07,-.1544306437253118d-07,
     2      0.7496784039945508d-08,-.4093940772050624d-08,
     3      0.2679301432832983d-08,-.2183039422972701d-08,
     4      0.1967845485605605d-08,-.1401058568116458d-08,
     5      -.1205817869700729d-09,0.1696501705140987d-08,
     6      -.4107221651555881d-08,-.4434468915415613d-08,
     7      -.1170694106136744d-07,-.3840619646960476d-07,
     8      -.7915966758871451d-07,-.1406070054806496d-06/
         data arr1277/
     1      -.2347277518628810d-06,-.3502465870381522d-06,
     2      -.4589715881262765d-06,-.5392051420158159d-06,
     3      -.5806717308341622d-06,-.5773728633594919d-06,
     4      -.5280058253238183d-06,-.4420060118838945d-06,
     5      -.3399722515038959d-06,-.2485204617703721d-06,
     6      -.2373209841312230d-06,0.9300358503838675d-05,
     7      -.2480491016055514d-05,0.7831493641045038d-06,
     8      -.2735819341838118d-06,0.1020712492008854d-06/
         data arr1278/
     1      -.4023149898846910d-07,0.1679606409528069d-07,
     2      -.7462088686838950d-08,0.3631516035157373d-08,
     3      -.1953219398596929d-08,0.1290388569836102d-08,
     4      -.1035442429008699d-08,0.9581737149663808d-09,
     5      -.6874891609058704d-09,-.1836617686350399d-10,
     6      0.8645473412148297d-09,-.1753014903316796d-08,
     7      -.1381105553071853d-08,-.3901629992394647d-08,
     8      -.1500454528057592d-07,-.3220455037887066d-07/
         data arr1279/
     1      -.5959978561738489d-07,-.1041834879036502d-06,
     2      -.1614454152344658d-06,-.2180176301218685d-06,
     3      -.2626522225380673d-06,-.2887022172533851d-06,
     4      -.2913994144962863d-06,-.2690488891270065d-06,
     5      -.2263307856783086d-06,-.1742041246452744d-06,
     6      -.1268241812441422d-06,-.1195095923168763d-06,
     7      0.9441060803858500d-05,-.2524238693193530d-05,
     8      0.7994160788887915d-06,-.2802327110839247d-06/
         data arr1280/
     1      0.1049315639283587d-06,-.4153187278046175d-07,
     2      0.1739732123725937d-07,-.7788354718842260d-08,
     3      0.3793114391804425d-08,-.2086905299403143d-08,
     4      0.1372735387965879d-08,-.1120172530114843d-08,
     5      0.9946578353579379d-09,-.6784767637617279d-09,
     6      -.7956138402608411d-10,0.1024756049328961d-08,
     7      -.1483981224950483d-08,-.3746114200198622d-09,
     8      -.4997927346836860d-09,-.6619289463504533d-08/
         data arr1281/
     1      -.1440065126351084d-07,-.2635631454646161d-07,
     2      -.5017257291938395d-07,-.8462560183944778d-07,
     3      -.1211695689321339d-06,-.1534951985141194d-06,
     4      -.1783231616907428d-06,-.1912094801477258d-06,
     5      -.1874515019718294d-06,-.1667889580399415d-06,
     6      -.1354038902320124d-06,-.1042443252128512d-06,
     7      -.1059130915147198d-06,0.2971288033167417d-05,
     8      -.7933588354606080d-06,0.2508561432586358d-06/
         data arr1282/
     1      -.8779091254768409d-07,0.3281807171026039d-07,
     2      -.1296867976198433d-07,0.5423805751541437d-08,
     3      -.2421285644817263d-08,0.1180989129919709d-08,
     4      -.6414026691577129d-09,0.4260933647612577d-09,
     5      -.3421826645291214d-09,0.3116248734473122d-09,
     6      -.2138381545969637d-09,-.1764382398186836d-10,
     7      0.3160272403893941d-09,-.4545119044583113d-09,
     8      -.8015229216204260d-10,-.9698905245571898d-10/
         data arr1283/
     1      -.1945089960757835d-08,-.4303533991507249d-08,
     2      -.8082948014021807d-08,-.1580241096888788d-07,
     3      -.2713757189606078d-07,-.3940965462359747d-07,
     4      -.5051098006917893d-07,-.5915026603036839d-07,
     5      -.6364378563768641d-07,-.6238014285531570d-07,
     6      -.5535028917813485d-07,-.4470634625743323d-07,
     7      -.3413069685087765d-07,-.3411817673049645d-07,
     8      0.2795341636918517d-05,-.7482020449783405d-06/
         data arr1284/
     1      0.2372909893684489d-06,-.8332271797045881d-07,
     2      0.3125582389430304d-07,-.1240209499831949d-07,
     3      0.5200187862309231d-08,-.2342977052523425d-08,
     4      0.1137066269637598d-08,-.6372394135855751d-09,
     5      0.4152597858205320d-09,-.3447216413180667d-09,
     6      0.2973575496597607d-09,-.1973220827114323d-09,
     7      -.3681892216274853d-10,0.3234732932278154d-09,
     8      -.4098479601405018d-09,-.9960489717099832d-11/
         data arr1285/
     1      0.2476821219879657d-09,-.9192113555151674d-09,
     2      -.1946599381868167d-08,-.3252742906307598d-08,
     3      -.7099629349134839d-08,-.1355258106668521d-07,
     4      -.2082449621962887d-07,-.2789745662254821d-07,
     5      -.3448187669223996d-07,-.3948459270351350d-07,
     6      -.4115249203000472d-07,-.3862405992446067d-07,
     7      -.3288192838412001d-07,-.2652974846447435d-07,
     8      -.2857924786182008d-07,0.2282057538687168d-04/
         data arr1286/
     1      0.2121660558844916d-03,0.8970748135498205d-03,
     2      0.2259628411544634d-02,0.3928270223173865d-02,
     3      0.5155052298101874d-02,0.5417709068416749d-02,
     4      0.4752303647310689d-02,0.3586066963743176d-02,
     5      0.2381718566665364d-02,0.1417288275079586d-02,
     6      0.7664629056435717d-03,0.3810655178647407d-03,
     7      0.1758376407060913d-03,0.7590442464286012d-04,
     8      0.3085712104724918d-04,0.1188011289711755d-04/
         data arr1287/
     1      0.4352494363566680d-05,0.1523618760795909d-05,
     2      0.5113778884177107d-06,0.1650503653593544d-06,
     3      0.5135524617988839d-07,0.1543718474593458d-07,
     4      0.4491019266223424d-08,0.1266138201775052d-08,
     5      0.3460504471183644d-09,0.9169305951828233d-10,
     6      0.2368590985900703d-10,0.6109299497955020d-11,
     7      0.1617534614770349d-11,0.3816925650077501d-12,
     8      -.7157622399483552d-13,0.2681789351757746d-05/
         data arr1288/
     1      0.4543855076954262d-04,0.3007871303388798d-03,
     2      0.1081206204823056d-02,0.2519305934901394d-02,
     3      0.4235957058204419d-02,0.5514233376956493d-02,
     4      0.5836182871182695d-02,0.5203810925158783d-02,
     5      0.4015005406652820d-02,0.2736715306488730d-02,
     6      0.1675317311905225d-02,0.9333932067297259d-03,
     7      0.4784893899627443d-03,0.2277487673998655d-03,
     8      0.1014178137474299d-03,0.4252366538160666d-04/
         data arr1289/
     1      0.1687978951334792d-04,0.6372852162108210d-05,
     2      0.2297449014689420d-05,0.7935333018338686d-06,
     3      0.2633507961127290d-06,0.8417908673105214d-07,
     4      0.2596867634252621d-07,0.7744361494448712d-08,
     5      0.2235475036164693d-08,0.6251853737096133d-09,
     6      0.1694999172122801d-09,0.4456497248911194d-10,
     7      0.1136280585880890d-10,0.2814943575770120d-11,
     8      0.7582453056028772d-12,0.2116806229265674d-06/
         data arr1290/
     1      0.6527781850952824d-05,0.6765452513550318d-04,
     2      0.3470453359755484d-03,0.1083843890435636d-02,
     3      0.2334942961580114d-02,0.3764964308761756d-02,
     4      0.4807949060098575d-02,0.5065599837816620d-02,
     5      0.4540336940941727d-02,0.3544927073658018d-02,
     6      0.2456457575235633d-02,0.1533683963765506d-02,
     7      0.8734519815007148d-03,0.4584069897102211d-03,
     8      0.2236038848790923d-03,0.1021050179119116d-03/
         data arr1291/
     1      0.4391390396736267d-04,0.1788123914575051d-04,
     2      0.6923990065554612d-05,0.2559293236238696d-05,
     3      0.9059152882953709d-06,0.3079255454461875d-06,
     4      0.1007374585972754d-06,0.3177938948932398d-07,
     5      0.9682044363469571d-08,0.2852022909356581d-08,
     6      0.8128964171392055d-09,0.2242618873880055d-09,
     7      0.5988156044979339d-10,0.1552806981986703d-10,
     8      0.4447443108538534d-11,0.1314202263508925d-07/
         data arr1292/
     1      0.7300130554958756d-06,0.1184658842387491d-04,
     2      0.8672052112324895d-04,0.3630033141442121d-03,
     3      0.1001979948188471d-02,0.2001218976535118d-02,
     4      0.3083534782081354d-02,0.3838824677116299d-02,
     5      0.3997128037942441d-02,0.3574728125314708d-02,
     6      0.2804009543979487d-02,0.1961847048039127d-02,
     7      0.1241262927353074d-02,0.7182976650830560d-03,
     8      0.3837977930365190d-03,0.1908628954021525d-03/
         data arr1293/
     1      0.8893958442821308d-04,0.3905884590550847d-04,
     2      0.1624519854237454d-04,0.6425885284321148d-05,
     3      0.2426043197397892d-05,0.8768902624351920d-06,
     4      0.3042219517214621d-06,0.1015229275150411d-06,
     5      0.3264528076059021d-07,0.1012851822070106d-07,
     6      0.3034998536914536d-08,0.8787970185378136d-09,
     7      0.2459339918402140d-09,0.6677955940863540d-10,
     8      0.2011001134192921d-10,0.1071736391115459d-08/
         data arr1294/
     1      0.6753313368729591d-07,0.1720046766641527d-05,
     2      0.1796773906525996d-04,0.1008070313499759d-03,
     3      0.3565152679831059d-03,0.8819921360142678d-03,
     4      0.1639737000988707d-02,0.2412137318788712d-02,
     5      0.2917725211138794d-02,0.2988925433062971d-02,
     6      0.2653909189738534d-02,0.2080802041990684d-02,
     7      0.1462597699268774d-02,0.9332414712609022d-03,
     8      0.5462129000262756d-03,0.2958232341314278d-03/
         data arr1295/
     1      0.1493566264216864d-03,0.7074203588112856d-04,
     2      0.3160311998171523d-04,0.1337772411329828d-04,
     3      0.5386985839770290d-05,0.2070528179204958d-05,
     4      0.7617743811686314d-06,0.2689173086532319d-06,
     5      0.9126621727678752d-07,0.2982471575444185d-07,
     6      0.9395429832562662d-08,0.2855158527475065d-08,
     7      0.8372741625274885d-09,0.2380045967879750d-09,
     8      0.7543782440406037d-10,0.2040466213358636d-08/
         data arr1296/
     1      0.4610937580307944d-08,0.2148704762160107d-06,
     2      0.3199020800362063d-05,0.2405667106320553d-04,
     3      0.1090086943069350d-03,0.3340402176831158d-03,
     4      0.7493133697018189d-03,0.1302475965763132d-02,
     5      0.1830225729316675d-02,0.2147588571062568d-02,
     6      0.2158522447376267d-02,0.1896532659186065d-02,
     7      0.1480982502700538d-02,0.1041951598077927d-02,
     8      0.6680137056194944d-03,0.3940097724342901d-03/
         data arr1297/
     1      0.2155350157047435d-03,0.1101031244928209d-03,
     2      0.5283221705605603d-04,0.2393290613035026d-04,
     3      0.1027914714317959d-04,0.4201274077104057d-05,
     4      0.1639178114736947d-05,0.6121209996106455d-06,
     5      0.2192621368402679d-06,0.7546953041489604d-07,
     6      0.2499447042061883d-07,0.7971755294583863d-08,
     7      0.2449817226163612d-08,0.7291625953798100d-09,
     8      0.2433626764912863d-09,0.5803081401138575d-08/
         data arr1298/
     1      -.1906623225128945d-08,0.2436223568906358d-07,
     2      0.5007691627983953d-06,0.5050154358840183d-05,
     3      0.2931978250938903d-04,0.1112883945545372d-03,
     4      0.3012102850352111d-03,0.6186634289687421d-03,
     5      0.1009908343065642d-02,0.1357388367131666d-02,
     6      0.1544344251053783d-02,0.1520571764871807d-02,
     7      0.1319143385076473d-02,0.1023335631212475d-02,
     8      0.7186638985253631d-03,0.4616350129306696d-03/
         data arr1299/
     1      0.2736076340241971d-03,0.1507435612055680d-03,
     2      0.7769351070592768d-04,0.3766393274073092d-04,
     3      0.1725382418866423d-04,0.7498906733083936d-05,
     4      0.3102722815299484d-05,0.1225667477375091d-05,
     5      0.4633762231451490d-06,0.1679899216853149d-06,
     6      0.5849080537916389d-07,0.1957919108164677d-07,
     7      0.6305454140454879d-08,0.1965036605019658d-08,
     8      0.6904290979449063d-09,0.1513208111387807d-07/
         data arr1300/
     1      -.5944341484871513d-08,0.4431046717803610d-08,
     2      0.6944903377403404d-07,0.9484658038435109d-06,
     3      0.7053434562873346d-05,0.3316242876491750d-04,
     4      0.1082981585924082d-03,0.2628355874545436d-03,
     5      0.4984300953102072d-03,0.7673652973948355d-03,
     6      0.9882723734613045d-03,0.1090431810861416d-02,
     7      0.1050942784125694d-02,0.8989460759249371d-03,
     8      0.6915304050235740d-03,0.4837661519103902d-03/
         data arr1301/
     1      0.3106587421776855d-03,0.1845962603398253d-03,
     2      0.1021917050916130d-03,0.5301525669871383d-04,
     3      0.2590351266164104d-04,0.1197181353773062d-04,
     4      0.5252967983498695d-05,0.2195091559856092d-05,
     5      0.8758873562171834d-06,0.3344565480714350d-06,
     6      0.1224266767669684d-06,0.4301049038798838d-07,
     7      0.1451513896976433d-07,0.4736188358696791d-08,
     8      0.1752347711385837d-08,0.3730960950987785d-07/
         data arr1302/
     1      -.1469812361120016d-07,0.5417533787940321d-08,
     2      0.7084208881555709d-08,0.1618879736538930d-06,
     3      0.1536658020363986d-05,0.8950257282661063d-05,
     4      0.3526645149734298d-04,0.1011354882952553d-03,
     5      0.2228005303749187d-03,0.3929070767857507d-03,
     6      0.5727945240697623d-03,0.7082388926193542d-03,
     7      0.7583257459632349d-03,0.7152186869452829d-03,
     8      0.6026794719098204d-03,0.4591577013475791d-03/
         data arr1303/
     1      0.3194689203842918d-03,0.2047371750282102d-03,
     2      0.1217408135164630d-03,0.6758739383322282d-04,
     3      0.3522261969835420d-04,0.1731058492954168d-04,
     4      0.8054827082035302d-05,0.3560590511525266d-05,
     5      0.1499521752205127d-05,0.6031001760183440d-06,
     6      0.2320945491695950d-06,0.8557884557164814d-07,
     7      0.3026671294938398d-07,0.1034255704334308d-07,
     8      0.4033992076894410d-08,0.8379343725776818d-07/
         data arr1304/
     1      -.3300988650814230d-07,0.1171912381960509d-07,
     2      -.3055349083754346d-08,0.2651439251198421d-07,
     3      0.3057848539342067d-06,0.2209591192453638d-05,
     4      0.1050412407629754d-04,0.3559445805734073d-04,
     5      0.9109351459084917d-04,0.1840080454230515d-03,
     6      0.3036549196581170d-03,0.4207463111335615d-03,
     7      0.5004858257393295d-03,0.5204791552255812d-03,
     8      0.4804196894803351d-03,0.3986093830893665d-03/
         data arr1305/
     1      0.3004920035984963d-03,0.2076968054849470d-03,
     2      0.1326526722698561d-03,0.7881152409039587d-04,
     3      0.4380704237113860d-04,0.2289406474403400d-04,
     4      0.1129709015840766d-04,0.5282615257302399d-05,
     5      0.2348078965620242d-05,0.9946964913607747d-06,
     6      0.4024325061832418d-06,0.1557261297002513d-06,
     7      0.5770647880548354d-07,0.2064216249784105d-07,
     8      0.8477769065125535d-08,0.1738439960749252d-06/
         data arr1306/
     1      -.6850084396011097d-07,0.2429519759447491d-07,
     2      -.8382810476538384d-08,0.6575897756170686d-08,
     3      0.5522305488509012d-07,0.5032161580833368d-06,
     4      0.2884383080715218d-05,0.1154972215243054d-04,
     5      0.3433746096659398d-04,0.7944987518244907d-04,
     6      0.1484127511283597d-03,0.2304466424491797d-03,
     7      0.3045349706681130d-03,0.3492024736643951d-03,
     8      0.3530731484897900d-03,0.3190381180482710d-03/
         data arr1307/
     1      0.2605833662388429d-03,0.1942551159403058d-03,
     2      0.1332616656731195d-03,0.8472724593198436d-04,
     3      0.5023145922271145d-04,0.2791541153427506d-04,
     4      0.1460787061406435d-04,0.7225800034081546d-05,
     5      0.3389889872774907d-05,0.1512570641236566d-05,
     6      0.6433855311821156d-06,0.2613135566893293d-06,
     7      0.1014873687858754d-06,0.3802984274722199d-07,
     8      0.1648592250173502d-07,0.3302586903801718d-06/
         data arr1308/
     1      -.1301372533364797d-06,0.4615453069159587d-07,
     2      -.1612556274984448d-07,0.6138796900342819d-08,
     3      0.7591841432888635d-08,0.1069178904047879d-06,
     4      0.7348561146469941d-06,0.3477997450522586d-05,
     5      0.1201191179712216d-04,0.3183557139974076d-04,
     6      0.6731705121406155d-04,0.1171342186312423d-03,
     7      0.1719671459308685d-03,0.2174274898196718d-03,
     8      0.2408084785338656d-03,0.2369739535074628d-03/
         data arr1309/
     1      0.2097121424346108d-03,0.1686080781614409d-03,
     2      0.1242388690337612d-03,0.8453163313140961d-04,
     3      0.5345283143073892d-04,0.3158844033259748d-04,
     4      0.1752945271845541d-04,0.9172321089808663d-05,
     5      0.4541571094707966d-05,0.2134369498377845d-05,
     6      0.9543992292691519d-06,0.4067473106687714d-06,
     7      0.1654652369946790d-06,0.6487585653618447d-07,
     8      0.2959338078706070d-07,0.5987032641005721d-06/
         data arr1310/
     1      -.2359228786929118d-06,0.8367757643672348d-07,
     2      -.2925745992858176d-07,0.1032425119206569d-07,
     3      -.2109157577694223d-08,0.2222543748704724d-07,
     4      0.1743791263427045d-06,0.9774407168408067d-06,
     5      0.3921247227229622d-05,0.1190417230265357d-04,
     6      0.2849350509277358d-04,0.5556042704257263d-04,
     7      0.9061929279666786d-04,0.1263337259925574d-03,
     8      0.1532662818164417d-03,0.1642577360146158d-03/
         data arr1311/
     1      0.1574954468118446d-03,0.1365690204421220d-03,
     2      0.1080879120698864d-03,0.7870140946036007d-04,
     3      0.5308034069752865d-04,0.3335659969014188d-04,
     4      0.1962997669942160d-04,0.1086537318766610d-04,
     5      0.5678198784560971d-05,0.2810878831791943d-05,
     6      0.1321548585672584d-05,0.5911981941821604d-06,
     7      0.2520912898828373d-06,0.1035862613237336d-06,
     8      0.4995827650576888d-07,0.9938487470251209d-06/
         data arr1312/
     1      -.3916204336074245d-06,0.1388909472130355d-06,
     2      -.4855866730536464d-07,0.1703957798309981d-07,
     3      -.5804272548237951d-08,0.6011105007960576d-08,
     4      0.3825437007201647d-07,0.2576897485183290d-06,
     5      0.1200229729883276d-05,0.4173573462521326d-05,
     6      0.1130807156498505d-04,0.2471011823448493d-04,
     7      0.4477318719103557d-04,0.6882544507525309d-04,
     8      0.9146320352770923d-04,0.1067516272671756d-03/
         data arr1313/
     1      0.1109013317550474d-03,0.1037172606155532d-03,
     2      0.8816995599138321d-04,0.6870190517074555d-04,
     3      0.4942199557657419d-04,0.3302614182645838d-04,
     4      0.2061040117124595d-04,0.1206727112731772d-04,
     5      0.6655547014303641d-05,0.3469922344856719d-05,
     6      0.1714740510246796d-05,0.8046378578139192d-06,
     7      0.3591521449094489d-06,0.1542650137909724d-06,
     8      0.7816677354317232d-07,0.1601173565685784d-05/
         data arr1314/
     1      -.6310511154550153d-06,0.2238808320717215d-06,
     2      -.7831266181730083d-07,0.2749160605638524d-07,
     3      -.9715225036640649d-08,0.4143060220929792d-08,
     4      0.7001460558035431d-08,0.6418374895715209d-07,
     5      0.3458774367072937d-06,0.1377574709062703d-05,
     6      0.4224993593273522d-05,0.1034671663881263d-04,
     7      0.2082638095948205d-04,0.3530095648009825d-04,
     8      0.5138710287930949d-04,0.6531709229887731d-04/
         data arr1315/
     1      0.7352102388467439d-04,0.7415795816795146d-04,
     2      0.6771261882681564d-04,0.5646242603037919d-04,
     3      0.4332266641669708d-04,0.3078557917274671d-04,
     4      0.2037371876177701d-04,0.1261832125660640d-04,
     5      0.7345549211371323d-05,0.4034246838500121d-05,
     6      0.2096408302087206d-05,0.1032757346998357d-05,
     7      0.4833039734932601d-06,0.2176946910744289d-06,
     8      0.1168630696164673d-06,0.2334066210348605d-05/
         data arr1316/
     1      -.9198837984535623d-06,0.3263370241827217d-06,
     2      -.1141431506432284d-06,0.4006365253098869d-07,
     3      -.1419873788415807d-07,0.5164515488165628d-08,
     4      -.9729349633974446d-10,0.1541851926535818d-07,
     5      0.9419547842525049d-07,0.4295833982173445d-06,
     6      0.1491371872692684d-05,0.4093929011063047d-05,
     7      0.9152744587113928d-05,0.1710783068812866d-04,
     8      0.2727926287296177d-04,0.3776065670532693d-04/
         data arr1317/
     1      0.4605240079921914d-04,0.5009952230423073d-04,
     2      0.4913401501667433d-04,0.4384403882290912d-04,
     3      0.3588151864111767d-04,0.2711379690615730d-04,
     4      0.1902746944578895d-04,0.1246429226667971d-04,
     5      0.7656693101468586d-05,0.4427834842308752d-05,
     6      0.2417466941805148d-05,0.1248223646138910d-05,
     7      0.6106754201650143d-06,0.2869981843140284d-06,
     8      0.1613719886635102d-06,0.3391252332976828d-05/
         data arr1318/
     1      -.1336883588047194d-05,0.4744890638584857d-06,
     2      -.1660798352296267d-06,0.5835629145904104d-07,
     3      -.2072106827095290d-07,0.7413571412524620d-08,
     4      -.2228103946468926d-08,0.4002069812017475d-08,
     5      0.2432069044604441d-07,0.1269365086449011d-06,
     6      0.4987493277016920d-06,0.1536037127390932d-05,
     7      0.3811942699684223d-05,0.7858929756427706d-05,
     8      0.1372685669270166d-04,0.2069096761051327d-04/
         data arr1319/
     1      0.2734243035997809d-04,0.3208211963212147d-04,
     2      0.3379382684702725d-04,0.3227014674982648d-04,
     3      0.2816962721349354d-04,0.2263638460285693d-04,
     4      0.1684547460069923d-04,0.1167262296529983d-04,
     5      0.7568583183191492d-05,0.4611483263408200d-05,
     6      0.2648198428903510d-05,0.1435899025178172d-05,
     7      0.7368182224763621d-06,0.3634641445448152d-06,
     8      0.2170604185740322d-06,0.4368338170496577d-05/
         data arr1320/
     1      -.1721959215564114d-05,0.6110844290415152d-06,
     2      -.2138485609378478d-06,0.7511715825933608d-07,
     3      -.2666193928412156d-07,0.9509566401868943d-08,
     4      -.3197567778189016d-08,0.1563660335415493d-08,
     5      0.5991333440219828d-08,0.3558740984668617d-07,
     6      0.1582643767975913d-06,0.5485797498029700d-06,
     7      0.1508158088677543d-05,0.3432018127910589d-05,
     8      0.6566260187875832d-05,0.1077603068723363d-04/
         data arr1321/
     1      0.1543097670163138d-04,0.1952888876686008d-04,
     2      0.2209289713122922d-04,0.2257551497562528d-04,
     3      0.2102000895408281d-04,0.1796097151079090d-04,
     4      0.1417092067819505d-04,0.1038280109897670d-04,
     5      0.7101423663443979d-05,0.4553333060556730d-05,
     6      0.2744478071569763d-05,0.1557169284239652d-05,
     7      0.8333826604250507d-06,0.4275772204847259d-06,
     8      0.2661354904128209d-06,0.5789931702621004d-05/
         data arr1322/
     1      -.2283242450121825d-05,0.8108263043161589d-06,
     2      -.2840463513984373d-06,0.9993424537586654d-07,
     3      -.3555573297620502d-07,0.1273585878777339d-07,
     4      -.4385782611268825d-08,0.1347962527869751d-08,
     5      0.1380605727856974d-08,0.9467996334060664d-08,
     6      0.4743014366575473d-07,0.1877934984102545d-06,
     7      0.5673334242463621d-06,0.1428725318669579d-05,
     8      0.2994099112308784d-05,0.5346964187226232d-05/
         data arr1323/
     1      0.8298903769814711d-05,0.1132954646435657d-04,
     2      0.1376375562363692d-04,0.1504992606944649d-04,
     3      0.1494874550031696d-04,0.1358448394834433d-04,
     4      0.1136512923584958d-04,0.8807875380015922d-05,
     5      0.6359684536893583d-05,0.4297810541326492d-05,
     6      0.2725938849256686d-05,0.1624968659235515d-05,
     7      0.9127440669555021d-06,0.4921426757881191d-06,
     8      0.3263181858181951d-06,0.6556900324822101d-05/
         data arr1324/
     1      -.2585448045714463d-05,0.9179772085822927d-06,
     2      -.3214905151664362d-06,0.1130565151159331d-06,
     3      -.4019928004735038d-07,0.1437848421330571d-07,
     4      -.4950922782677428d-08,0.1372517799082371d-08,
     5      0.3115824463256120d-09,0.2328981836682006d-08,
     6      0.1315615815836990d-07,0.6250559785657441d-07,
     7      0.2025235373582772d-06,0.5685946150706041d-06,
     8      0.1304802568885899d-05,0.2532885379724349d-05/
         data arr1325/
     1      0.4262951255498138d-05,0.6278585583247084d-05,
     2      0.8188954122597045d-05,0.9580366775903878d-05,
     3      0.1015039707169324d-04,0.9806409067986984d-05,
     4      0.8693489726986809d-05,0.7118236803617229d-05,
     5      0.5415891089236098d-05,0.3845877746113476d-05,
     6      0.2554560611669500d-05,0.1588450906941834d-05,
     7      0.9267505652645510d-06,0.5170609801589296d-06,
     8      0.3546129263443017d-06,0.7989587314238220d-05/
         data arr1326/
     1      -.3152127225226186d-05,0.1120251299632021d-05,
     2      -.3929047014479934d-06,0.1384759566816361d-06,
     3      -.4940144055972407d-07,0.1777874647203030d-07,
     4      -.6197337787162471d-08,0.1768700546915573d-08,
     5      -.3360504654395950d-10,0.5460034278869598d-09,
     6      0.2858007334663469d-08,0.2141722089777627d-07,
     7      0.6744790969181715d-07,0.2171657595898819d-06,
     8      0.5455183515550182d-06,0.1146681102634854d-05/
         data arr1327/
     1      0.2095806824899201d-05,0.3332108147382710d-05,
     2      0.4663324459317982d-05,0.5836899759409603d-05,
     3      0.6600020434218926d-05,0.6782889053083660d-05,
     4      0.6375388249118394d-05,0.5521198757765866d-05,
     5      0.4436127293164236d-05,0.3322409816693292d-05,
     6      0.2324134916509323d-05,0.1519557783677314d-05,
     7      0.9313517005042019d-06,0.5469741108703601d-06,
     8      0.4009649054514532d-06,0.7870758350431468d-05/
         data arr1328/
     1      -.3104742794878559d-05,0.1103081921932599d-05,
     2      -.3867039273246153d-06,0.1361925127734773d-06,
     3      -.4853758701207489d-07,0.1743074353095707d-07,
     4      -.6056183065818055d-08,0.1698794249575084d-08,
     5      -.5430916234733154d-10,0.6152276588652774d-10,
     6      0.5636710904212202d-10,0.8227844787313831d-08,
     7      0.2005277092699894d-07,0.8008394774935524d-07,
     8      0.2195677913854972d-06,0.4965253990685865d-06/
         data arr1329/
     1      0.9879701166013183d-06,0.1696224506465173d-05,
     2      0.2544785039296145d-05,0.3406076646436170d-05,
     3      0.4107968085617221d-05,0.4484967197072927d-05,
     4      0.4459822660777032d-05,0.4072216200389735d-05,
     5      0.3439126471725896d-05,0.2697705783975327d-05,
     6      0.1967784771515512d-05,0.1334805592470998d-05,
     7      0.8444231833570330d-06,0.5094471804105288d-06,
     8      0.3824728804581593d-06,0.8877341462750931d-05/
         data arr1330/
     1      -.3504374996208675d-05,0.1246628010392766d-05,
     2      -.4378622485541014d-06,0.1546533508095742d-06,
     3      -.5535480940723394d-07,0.2003568453231247d-07,
     4      -.7068411543668720d-08,0.2095444391950701d-08,
     5      -.2207086747338978d-09,0.7012888875723543d-10,
     6      -.9144583476373543d-09,0.4584038512293192d-08,
     7      0.3757195623121817d-08,0.2893688486645141d-07,
     8      0.8638118572332079d-07,0.2046405081848972d-06/
         data arr1331/
     1      0.4472381711640519d-06,0.8316770172549514d-06,
     2      0.1334455683467695d-05,0.1909713524589033d-05,
     3      0.2461503943244848d-05,0.2860550609779380d-05,
     4      0.3014951074556975d-05,0.2911250658737331d-05,
     5      0.2598060697847418d-05,0.2151986660098977d-05,
     6      0.1655238306788733d-05,0.1181932717868540d-05,
     7      0.7864540971207363d-06,0.5003794268111673d-06,
     8      0.4029402073477989d-06,0.7415084011774076d-05/
         data arr1332/
     1      -.2926382661130044d-05,0.1040532784675376d-05,
     2      -.3652124560419858d-06,0.1288518297745599d-06,
     3      -.4604694605526772d-07,0.1661487457949811d-07,
     4      -.5830821608028931d-08,0.1693342944936984d-08,
     5      -.1400631544665015d-09,-.4260433572686315d-12,
     6      -.8911474608186187d-09,0.2934168639515398d-08,
     7      -.8486993261451595d-09,0.1048672930434678d-07,
     8      0.3332961803517568d-07,0.8017189718026982d-07/
         data arr1333/
     1      0.1946510369363882d-06,0.3921532251759249d-06,
     2      0.6708922977430337d-06,0.1024758706278964d-05,
     3      0.1407802942108772d-05,0.1733593488182407d-05,
     4      0.1925189255196118d-05,0.1950681348614196d-05,
     5      0.1819857573062573d-05,0.1568565696097809d-05,
     6      0.1248454372835980d-05,0.9170271887385509d-06,
     7      0.6240980846123478d-06,0.4039203936883697d-06,
     8      0.3289183711988453d-06,0.7782678793911460d-05/
         data arr1334/
     1      -.3074354141966630d-05,0.1094902063720880d-05,
     2      -.3852333598942118d-06,0.1364126041865199d-06,
     3      -.4901502845310279d-07,0.1786002738543340d-07,
     4      -.6387587267701081d-08,0.1978372526022613d-08,
     5      -.3132755943554976d-09,0.1354618767667937d-09,
     6      -.1081398269508463d-08,0.2732086473843593d-08,
     7      -.2466813557577835d-08,0.4064305685445634d-08,
     8      0.1376040426860656d-07,0.2859656597506384d-07/
         data arr1335/
     1      0.8144190746533815d-07,0.1803587031229051d-06,
     2      0.3259062963044936d-06,0.5311587166698614d-06,
     3      0.7829707382878052d-06,0.1027899431625552d-05,
     4      0.1209027689145562d-05,0.1295090997496955d-05,
     5      0.1278166444238676d-05,0.1165500092227860d-05,
     6      0.9799432230811817d-06,0.7588179865952967d-06,
     7      0.5439610081206561d-06,0.3720178932606708d-06,
     8      0.3260303800752508d-06,0.5305525374772541d-05/
         data arr1336/
     1      -.2095104580464768d-05,0.7457023086545481d-06,
     2      -.2621273793938197d-06,0.9268936827043443d-07,
     3      -.3323686308411988d-07,0.1206404344291571d-07,
     4      -.4284889815028971d-08,0.1297080201758390d-08,
     5      -.1692966817823052d-09,0.5616646178641956d-10,
     6      -.7179639775010777d-09,0.1812528196905905d-08,
     7      -.1987947979710644d-08,0.1712319257242647d-08,
     8      0.5643416864397327d-08,0.9358929436043452d-08/
         data arr1337/
     1      0.3271848119832895d-07,0.7915180839521087d-07,
     2      0.1501700024518452d-06,0.2598332262907195d-06,
     3      0.4068318548838202d-06,0.5621416024651293d-06,
     4      0.6907651813564986d-06,0.7694973454274585d-06,
     5      0.7863696424909411d-06,0.7384638306360165d-06,
     6      0.6355441173687244d-06,0.5007816315074799d-06,
     7      0.3633175677315275d-06,0.2501003454555367d-06,
     8      0.2188868840219468d-06,0.5200972194910263d-05/
         data arr1338/
     1      -.2056191013333540d-05,0.7332863532290301d-06,
     2      -.2585294860877220d-06,0.9182242374558163d-07,
     3      -.3314323975995222d-07,0.1217072096158508d-07,
     4      -.4420524588286640d-08,0.1435065376534422d-08,
     5      -.3025873806171303d-09,0.1700666725861763d-09,
     6      -.7841280873942423d-09,0.1752196575740733d-08,
     7      -.1965942305085763d-08,0.8706077304169042d-09,
     8      0.3182283769221565d-08,0.1789176956305114d-08/
         data arr1339/
     1      0.1252886993300329d-07,0.3527479820951419d-07,
     2      0.6794496276346474d-07,0.1246294499904560d-06,
     3      0.2115379113551368d-06,0.3126789383385642d-06,
     4      0.4063149940462279d-06,0.4781335089653619d-06,
     5      0.5176820847181899d-06,0.5155781053583729d-06,
     6      0.4697408221433984d-06,0.3908057845510766d-06,
     7      0.2990531438628935d-06,0.2179211007371990d-06,
     8      0.2058358982874622d-06,0.2619153501032773d-05/
         data arr1340/
     1      -.1034968627661234d-05,0.3687786125734120d-06,
     2      -.1298476952985316d-06,0.4602727758421823d-07,
     3      -.1656601467016474d-07,0.6051456375748582d-08,
     4      -.2176905300120179d-08,0.6868424092602513d-09,
     5      -.1209387951169733d-09,0.6091303622354045d-10,
     6      -.3765878161168240d-09,0.8806274157002577d-09,
     7      -.1030407562832178d-08,0.4156454560166004d-09,
     8      0.1347403500732704d-08,0.1434042319849845d-09/
         data arr1341/
     1      0.4522127081475861d-08,0.1395025891723466d-07,
     2      0.2748180549977175d-07,0.5289318808547825d-07,
     3      0.9420768088684402d-07,0.1443794272468511d-06,
     4      0.1931379838806346d-06,0.2329626574117499d-06,
     5      0.2573011935089427d-06,0.2599204021355943d-06,
     6      0.2388629395802377d-06,0.1994815291674275d-06,
     7      0.1525509403759261d-06,0.1105128182494683d-06,
     8      0.1027200262878391d-06,0.2415621564940773d-05/
         data arr1342/
     1      -.9558238829057821d-06,0.3413513716481327d-06,
     2      -.1206034542143282d-06,0.4296894512416650d-07,
     3      -.1558180727171330d-07,0.5767155924881245d-08,
     4      -.2127244747863559d-08,0.7210492820964394d-09,
     5      -.1862975734223971d-09,0.1175614607706342d-09,
     6      -.3902634198245680d-09,0.8092128750984498d-09,
     7      -.8959831692044676d-09,0.2394795871269988d-09,
     8      0.1047304933802513d-08,-.6635634599127530d-09/
         data arr1343/
     1      0.1486987825274601d-08,0.6385535992878252d-08,
     2      0.1166849245137738d-07,0.2339558232418865d-07,
     3      0.4617156296586198d-07,0.7616408786570374d-07,
     4      0.1074421499022696d-06,0.1366814169736293d-06,
     5      0.1602110430744399d-06,0.1721221010843723d-06,
     6      0.1678333557419123d-06,0.1482127467636376d-06,
     7      0.1196946719414768d-06,0.9192970314226195d-07,
     8      0.9243084133913326d-07,0.7698604549692063d-06/
         data arr1344/
     1      -.3044805009649109d-06,0.1086493608304328d-06,
     2      -.3833879921713432d-07,0.1363380837663579d-07,
     3      -.4930207526264832d-08,0.1816346260100821d-08,
     4      -.6631866108277115d-09,0.2204390838080270d-09,
     5      -.4967657580631921d-10,0.3118338361916406d-10,
     6      -.1185115515364658d-09,0.2583581930652793d-09,
     7      -.2938578795625007d-09,0.8584065874998866d-10,
     8      0.3204058323420960d-09,-.2472319949992439d-09/
         data arr1345/
     1      0.4151440532613987d-09,0.1888016733258343d-08,
     2      0.3460432230416782d-08,0.7162716654180549d-08,
     3      0.1451388990932873d-07,0.2434549602892506d-07,
     4      0.3480831153807432d-07,0.4475787530602973d-07,
     5      0.5280757689121167d-07,0.5685308927433855d-07,
     6      0.5535104270831215d-07,0.4867137970414368d-07,
     7      0.3903468946477771d-07,0.2965715612310042d-07,
     8      0.2923090976958020d-07,0.6694920080771490d-06/
         data arr1346/
     1      -.2651780735784303d-06,0.9486270868739521d-07,
     2      -.3360144583604888d-07,0.1201612623701390d-07,
     3      -.4381399839502994d-08,0.1636835399218355d-08,
     4      -.6141563072492326d-09,0.2183896891254933d-09,
     5      -.6669285426553920d-10,0.4599134257420337d-10,
     6      -.1166980164328528d-09,0.2239232584125745d-09,
     7      -.2357081046683402d-09,0.4267472555609210d-10,
     8      0.2742008584571227d-09,-.2668468260633055d-09/
         data arr1347/
     1      0.8145648553090458d-10,0.9428807914641700d-09,
     2      0.1399372045560153d-08,0.2885150168192927d-08,
     3      0.6753260072360699d-08,0.1231628440646005d-07,
     4      0.1848336638702748d-07,0.2498231738987867d-07,
     5      0.3131784071171514d-07,0.3595405089287906d-07,
     6      0.3721571179088733d-07,0.3464173349557480d-07,
     7      0.2935991524755917d-07,0.2366998387444488d-07,
     8      0.2527176511180986d-07,-.8473405728944735d-06/
         data arr1348/
     1      -.1436908427616205d-04,-.9511720739894789d-04,
     2      -.3419074316096066d-03,-.7966744852081367d-03,
     3      -.1339527238243308d-02,-.1743753701813494d-02,
     4      -.1845563071531617d-02,-.1645589503582259d-02,
     5      -.1269656190322891d-02,-.8654253675741760d-03,
     6      -.5297818509240142d-03,-.2951648485787830d-03,
     7      -.1513116308410620d-03,-.7202048394004801d-04,
     8      -.3207112867035688d-04,-.1344716370011440d-04/
         data arr1349/
     1      -.5337858137068617d-05,-.2015272803010310d-05,
     2      -.7265171616958149d-06,-.2509372639348574d-06,
     3      -.8327884011865679d-07,-.2661976435074342d-07,
     4      -.8212010984828983d-08,-.2448980069440270d-08,
     5      -.7069226224274266d-09,-.1977044683902223d-09,
     6      -.5360030413799112d-10,-.1408942465578879d-10,
     7      -.3590237298033980d-11,-.8891722872070704d-12,
     8      -.2403227402866517d-12,-.9053563636689920d-07/
         data arr1350/
     1      -.2783401176879323d-05,-.2884799806381880d-04,
     2      -.1479806256357910d-03,-.4621525885178660d-03,
     3      -.9956230238540584d-03,-.1605386175462932d-02,
     4      -.2050116367582475d-02,-.2159979028412296d-02,
     5      -.1936006176591673d-02,-.1511561983076523d-02,
     6      -.1047437029468633d-02,-.6539650394736071d-03,
     7      -.3724411763258027d-03,-.1954653971666801d-03,
     8      -.9534501687432872d-04,-.4353772593262646d-04/
         data arr1351/
     1      -.1872495155981680d-04,-.7624585986719258d-05,
     2      -.2952399292248163d-05,-.1091286304222929d-05,
     3      -.3862835690619142d-06,-.1312998909749161d-06,
     4      -.4295460244057550d-07,-.1355078124537802d-07,
     5      -.4128433988186340d-08,-.1216099910430566d-08,
     6      -.3466169893023497d-09,-.9562656777766770d-10,
     7      -.2553484400632926d-10,-.6618138054012505d-11,
     8      -.1878168428517328d-11,-.6353505234212167d-08/
         data arr1352/
     1      -.3650447991462682d-06,-.5923287070791251d-05,
     2      -.4336026208451776d-04,-.1815016567045828d-03,
     3      -.5009899741864911d-03,-.1000609488248013d-02,
     4      -.1541767391036221d-02,-.1919412338567805d-02,
     5      -.1998564018957676d-02,-.1787364062666468d-02,
     6      -.1402004771987072d-02,-.9809235240078053d-03,
     7      -.6206314636962926d-03,-.3591488325262327d-03,
     8      -.1918988965108591d-03,-.9543144772269792d-04/
         data arr1353/
     1      -.4446979220560106d-04,-.1952942293315618d-04,
     2      -.8122599284609009d-05,-.3212942657929109d-05,
     3      -.1213021583135793d-05,-.4384451102716067d-06,
     4      -.1521109801221569d-06,-.5076147934007309d-07,
     5      -.1632263753161395d-07,-.5064234168270840d-08,
     6      -.1517471853051799d-08,-.4393833872512397d-09,
     7      -.1229594202672083d-09,-.3337205373557400d-10,
     8      -.9966372784627936d-11,-.1243832244256515d-08/
         data arr1354/
     1      -.3736691596644343d-07,-.9541191506522536d-06,
     2      -.9966709418497052d-05,-.5591767899190477d-04,
     3      -.1977590895835068d-03,-.4892412107655173d-03,
     4      -.9095624362219071d-03,-.1338013044093492d-02,
     5      -.1618462747092579d-02,-.1657957524270526d-02,
     6      -.1472123948306675d-02,-.1154221300932595d-02,
     7      -.8113032308993066d-03,-.5176692271498036d-03,
     8      -.3029844027856324d-03,-.1640932061496621d-03/
         data arr1355/
     1      -.8284814993108315d-04,-.3924062107497846d-04,
     2      -.1753025694423110d-04,-.7420626281068663d-05,
     3      -.2988162007503627d-05,-.1148522280196770d-05,
     4      -.4225564501718574d-06,-.1491685915569281d-06,
     5      -.5062538219415742d-07,-.1654365349871221d-07,
     6      -.5211529925113199d-08,-.1583719978267092d-08,
     7      -.4644427440834349d-09,-.1319702516911737d-09,
     8      -.4145955823822196d-10,-.4329076225652831d-08/
         data arr1356/
     1      -.2221859229995818d-08,-.1284959407506659d-06,
     2      -.1911767628712967d-05,-.1437661249578984d-04,
     3      -.6514515467093741d-04,-.1996272127377414d-03,
     4      -.4478003880513822d-03,-.7783782689947951d-03,
     5      -.1093769076240210d-02,-.1283429650892882d-02,
     6      -.1289963891404495d-02,-.1133395046167758d-02,
     7      -.8850563290595001d-03,-.6226851793752796d-03,
     8      -.3992145461026569d-03,-.2354658766957435d-03/
         data arr1357/
     1      -.1288068082623395d-03,-.6579920179760013d-04,
     2      -.3157328905954336d-04,-.1430264734860759d-04,
     3      -.6142964951219472d-05,-.2510741108194115d-05,
     4      -.9795965178706824d-06,-.3658126224856401d-06,
     5      -.1310340644396872d-06,-.4510114150777292d-07,
     6      -.1493659795694324d-07,-.4763896742340276d-08,
     7      -.1464046974964856d-08,-.4355173835517961d-09,
     8      -.1439365761900970d-09,-.1312390967084819d-07/
         data arr1358/
     1      0.2874288030710098d-08,-.1569185078757883d-07,
     2      -.3166666769248094d-06,-.3194006340375027d-05,
     3      -.1854345640553176d-04,-.7038496218683267d-04,
     4      -.1905021098173855d-03,-.3912771093331098d-03,
     5      -.6387221172717289d-03,-.8584877828108809d-03,
     6      -.9767290646505325d-03,-.9616940238775539d-03,
     7      -.8342995328888737d-03,-.6472142798693765d-03,
     8      -.4545229580467229d-03,-.2919636192298461d-03/
         data arr1359/
     1      -.1730446609177194d-03,-.9533859805827588d-04,
     2      -.4913769183842491d-04,-.2382076350816577d-04,
     3      -.1091227534127911d-04,-.4742723961870903d-05,
     4      -.1962334948387097d-05,-.7751813420792809d-06,
     5      -.2930646358900854d-06,-.1062447476232204d-06,
     6      -.3699163142896974d-07,-.1238267870799581d-07,
     7      -.3988024817538334d-08,-.1242144311916279d-08,
     8      -.4321190912386030d-09,-.3397807942381770d-07/
         data arr1360/
     1      0.8012474078171359d-08,-.3574365599818137d-08,
     2      -.4584639462914471d-07,-.6273605085372802d-06,
     3      -.4665407050820286d-05,-.2193488678831648d-04,
     4      -.7163249611771678d-04,-.1738494029260678d-03,
     5      -.3296805166179457d-03,-.5075644376933387d-03,
     6      -.6536807312771995d-03,-.7212528463591805d-03,
     7      -.6951333162222498d-03,-.5945969365027644d-03,
     8      -.4574043680752516d-03,-.3199812368943182d-03/
         data arr1361/
     1      -.2054814414540782d-03,-.1220989461501168d-03,
     2      -.6759346261911785d-04,-.3506629880839147d-04,
     3      -.1713355979027846d-04,-.7918607084678038d-05,
     4      -.3474513501680136d-05,-.1451919676597260d-05,
     5      -.5793442351421161d-06,-.2212179162135181d-06,
     6      -.8097376224083711d-07,-.2844746822143062d-07,
     7      -.9600802355418197d-08,-.3130642465279481d-08,
     8      -.1146119313233829d-08,-.8642409499257511d-07/
         data arr1362/
     1      0.2038216596611796d-07,-.5322639188805304d-08,
     2      -.4641742841730507d-08,-.1110746729049756d-06,
     3      -.1054136212798685d-05,-.6139830616477183d-05,
     4      -.2419257940600665d-04,-.6937838015155395d-04,
     5      -.1528398953852212d-03,-.2695320370115598d-03,
     6      -.3929338000924790d-03,-.4858478671068531d-03,
     7      -.5202071804132160d-03,-.4906359630770334d-03,
     8      -.4134347047751558d-03,-.3149795955665348d-03/
         data arr1363/
     1      -.2191538657178336d-03,-.1404485348744163d-03,
     2      -.8351351750597667d-04,-.4636457637977571d-04,
     3      -.2416250914009903d-04,-.1187495522315266d-04,
     4      -.5525571031206478d-05,-.2442553638097583d-05,
     5      -.1028662173325988d-05,-.4137132209516933d-06,
     6      -.1592068045787686d-06,-.5870457613165979d-07,
     7      -.2076385446354054d-07,-.7090681610201000d-08,
     8      -.2735373835315516d-08,-.2039215926778249d-06/
         data arr1364/
     1      0.4813067249850124d-07,-.1225722056398307d-07,
     2      0.2740199530181576d-08,-.1882046976914966d-07,
     3      -.2162077802835484d-06,-.1562431473711527d-05,
     4      -.7427520093726340d-05,-.2516910090456188d-04,
     5      -.6441282388924424d-04,-.1301133508767551d-03,
     6      -.2147164484980590d-03,-.2975125583296794d-03,
     7      -.3538969453157052d-03,-.3680343202898725d-03,
     8      -.3397080155964256d-03,-.2818594232523398d-03/
         data arr1365/
     1      -.2124799200087988d-03,-.1468638001150688d-03,
     2      -.9379962375366204d-04,-.5572817823682959d-04,
     3      -.3097623629980515d-04,-.1618852957598881d-04,
     4      -.7988260648892252d-05,-.3735391983265630d-05,
     5      -.1660337968447331d-05,-.7033316216430179d-06,
     6      -.2845410311524116d-06,-.1101089470492928d-06,
     7      -.4080578120576087d-07,-.1458526711674204d-07,
     8      -.5920198131863297d-08,-.4392944867016877d-06/
         data arr1366/
     1      0.1037892483864962d-06,-.2644759983550844d-07,
     2      0.7431236630701586d-08,-.4963676626030767d-08,
     3      -.4001685209497467d-07,-.3651085087531791d-06,
     4      -.2092512102055114d-05,-.8379089434411144d-05,
     5      -.2491097338117962d-04,-.5763902834108796d-04,
     6      -.1076699165150183d-03,-.1671835420580373d-03,
     7      -.2209329398000733d-03,-.2533380585331416d-03,
     8      -.2561461744971585d-03,-.2314546316227771d-03/
         data arr1367/
     1      -.1890470143893856d-03,-.1409274321171339d-03,
     2      -.9667821577696352d-04,-.6146763671644004d-04,
     3      -.3644168757639536d-04,-.2025192950505573d-04,
     4      -.1059769015969504d-04,-.5242188973056977d-05,
     5      -.2459277840789062d-05,-.1097284969015961d-05,
     6      -.4667195914582099d-06,-.1895686459022390d-06,
     7      -.7363318290344777d-07,-.2756974383057904d-07,
     8      -.1180582048116442d-07,-.8461300763895324d-06/
         data arr1368/
     1      0.1999729650095564d-06,-.5097354416142325d-07,
     2      0.1447548354618395d-07,-.4896289303610582d-08,
     3      -.5550502243467103d-08,-.7936077986974043d-07,
     4      -.5449086857657687d-06,-.2579429451559532d-05,
     5      -.8908196543876147d-05,-.2360995122947249d-04,
     6      -.4992364269375602d-04,-.8686901469123161d-04,
     7      -.1275343484002678d-03,-.1612484593616409d-03,
     8      -.1785883290180663d-03,-.1757446927606796d-03/
         data arr1369/
     1      -.1555266309880982d-03,-.1250430173918611d-03,
     2      -.9213809337988700d-04,-.6269039922376517d-04,
     3      -.3964159623516768d-04,-.2342653796647882d-04,
     4      -.1300024065469016d-04,-.6802456140031650d-05,
     5      -.3368102919258563d-05,-.1582791031557409d-05,
     6      -.7077165171028724d-06,-.3016321673245106d-06,
     7      -.1227218980842072d-06,-.4807230172528317d-07,
     8      -.2164599611705722d-07,-.1576111324890711d-05/
         data arr1370/
     1      0.3728589598780794d-06,-.9518344932135207d-07,
     2      0.2709682691427152d-07,-.8561604744949387d-08,
     3      0.1790601516016451d-08,-.1694914918641171d-07,
     4      -.1316689609985468d-06,-.7390253836200983d-06,
     5      -.2964040507243746d-05,-.8998821958676354d-05,
     6      -.2153902865226681d-04,-.4199964952657206d-04,
     7      -.6850193223666471d-04,-.9549916436777760d-04,
     8      -.1158583874000957d-03,-.1241673730669756d-03/
         data arr1371/
     1      -.1190552598269723d-03,-.1032363288553089d-03,
     2      -.8170693659637104d-04,-.5949278794652073d-04,
     3      -.4012480851704936d-04,-.2521508214184002d-04,
     4      -.1483896911658912d-04,-.8213606173711870d-05,
     5      -.4292290718051348d-05,-.2124649390810438d-05,
     6      -.9988530273700893d-06,-.4468815864597605d-06,
     7      -.1905932259630505d-06,-.7823754330398200d-07,
     8      -.3722044842735530d-07,-.2664255853016774d-05/
         data arr1372/
     1      0.6304949046246513d-06,-.1610142079006569d-06,
     2      0.4585817516612510d-07,-.1442372764156800d-07,
     3      0.4813271613330604d-08,-.4879739648675801d-08,
     4      -.2914912993675960d-07,-.1983427013929149d-06,
     5      -.9223788505976216d-06,-.3208444466371237d-05,
     6      -.8692520482514399d-05,-.1899467464240036d-04,
     7      -.3441773708299840d-04,-.5290627540923154d-04,
     8      -.7030827147197480d-04,-.8206095951664887d-04/
         data arr1373/
     1      -.8525034874721555d-04,-.7972784465130793d-04,
     2      -.6777704810586741d-04,-.5281176710135347d-04,
     3      -.3799072297155004d-04,-.2538716719046282d-04,
     4      -.1584351585512243d-04,-.9276451177748430d-05,
     5      -.5116120144714595d-05,-.2667056325187426d-05,
     6      -.1317892719893925d-05,-.6184984245564439d-06,
     7      -.2761391508900198d-06,-.1184787376957914d-06,
     8      -.5918106968503044d-07,-.4426735710941623d-05/
         data arr1374/
     1      0.1049474795161339d-05,-.2687193884621059d-06,
     2      0.7679146953273476d-07,-.2424255828407399d-07,
     3      0.8398880009332297d-08,-.3761316798090452d-08,
     4      -.4992763789739314d-08,-.5052048092864059d-07,
     5      -.2694316569825519d-06,-.1075099135668717d-05,
     6      -.3296182307661967d-05,-.8072168622074957d-05,
     7      -.1624904236918261d-04,-.2754099004482532d-04,
     8      -.4009160334100539d-04,-.5096025366715733d-04/
         data arr1375/
     1      -.5736001860168084d-04,-.5785686059971164d-04,
     2      -.5282911671377708d-04,-.4405169982214373d-04,
     3      -.3379944334983930d-04,-.2401821807926164d-04,
     4      -.1589566240879554d-04,-.9845120361825417d-05,
     5      -.5730851914324662d-05,-.3147000666204138d-05,
     6      -.1635223131609953d-05,-.8057162725757644d-06,
     7      -.3771777905089322d-06,-.1696786138416039d-06,
     8      -.8970585062895899d-07,-.6535580627939803d-05/
         data arr1376/
     1      0.1549903450938212d-05,-.3969856824860077d-06,
     2      0.1134870559929352d-06,-.3583729676295780d-07,
     3      0.1245572354607022d-07,-.4873576805127436d-08,
     4      0.7779055930693776d-09,-.1284973753962407d-07,
     5      -.7384652909987776d-07,-.3401045016862294d-06,
     6      -.1178863077864595d-05,-.3236193482612883d-05,
     7      -.7236647437770534d-05,-.1352426671589157d-04,
     8      -.2156604156891784d-04,-.2985322468941066d-04/
         data arr1377/
     1      -.3640715516952262d-04,-.3960656012412089d-04,
     2      -.3884450857061908d-04,-.3466221396598253d-04,
     3      -.2836617816981093d-04,-.2143481410996849d-04,
     4      -.1504301152149174d-04,-.9854578637827268d-05,
     5      -.6053096466338489d-05,-.3499866461781322d-05,
     6      -.1910693013672105d-05,-.9868339901485453d-06,
     7      -.4830075652341109d-06,-.2267077048545391d-06,
     8      -.1254853265380675d-06,-.9792969740644318d-05/
         data arr1378/
     1      0.2328035357611826d-05,-.5983837797686244d-06,
     2      0.1718195553096838d-06,-.5454270509365405d-07,
     3      0.1906970308359398d-07,-.7389616433198734d-08,
     4      0.2952799179073476d-08,-.4251610590189576d-08,
     5      -.1849206792736969d-07,-.1023086531354440d-06,
     6      -.3987211814797047d-06,-.1228341110113435d-05,
     7      -.3050696459137309d-05,-.6286136895356633d-05,
     8      -.1098135533263729d-04,-.1655396623721189d-04/
         data arr1379/
     1      -.2187322434544921d-04,-.2566484285816250d-04,
     2      -.2703606111150346d-04,-.2581676638788050d-04,
     3      -.2253470405603164d-04,-.1810834017364101d-04,
     4      -.1347709194456203d-04,-.9339077566508170d-05,
     5      -.6054720439611875d-05,-.3688180510577795d-05,
     6      -.2117822937403482d-05,-.1148744883063851d-05,
     7      -.5897666309734327d-06,-.2904652746387430d-06,
     8      -.1705334701807257d-06,-.1275475552399868d-04/
         data arr1380/
     1      0.3032542043503140d-05,-.7795330542730771d-06,
     2      0.2238456503659809d-06,-.7105313965297325d-07,
     3      0.2484407856542128d-07,-.9606013600922385d-08,
     4      0.4122468730970763d-08,-.2637261686116298d-08,
     5      -.3581812734595098d-08,-.2976842603335666d-07,
     6      -.1276063169314008d-06,-.4429487364198753d-06,
     7      -.1220998200071940d-05,-.2773838535835123d-05,
     8      -.5309360297391556d-05,-.8715132911884580d-05/
         data arr1381/
     1      -.1247666008152579d-04,-.1579009880607929d-04,
     2      -.1786580069756919d-04,-.1825559351874239d-04,
     3      -.1699567524665803d-04,-.1452246298727484d-04,
     4      -.1145978224115761d-04,-.8397082337505078d-05,
     5      -.5742318474508485d-05,-.3680839031296787d-05,
     6      -.2218568810668524d-05,-.1259495452814622d-05,
     7      -.6745768581852692d-06,-.3455971837273006d-06,
     8      -.2114587097363223d-06,-.1751515857490037d-04/
         data arr1382/
     1      0.4177701095957373d-05,-.1078802799078333d-05,
     2      0.3115501094939192d-06,-.9955145664656151d-07,
     3      0.3505855068182225d-07,-.1366610929660924d-07,
     4      0.5968997337419151d-08,-.3122606488894362d-08,
     5      0.6816718357472408d-09,-.9152165250354045d-08,
     6      -.3816766266054849d-07,-.1525126787937403d-06,
     7      -.4652499539704239d-06,-.1164706050684576d-05,
     8      -.2444519552203818d-05,-.4367875272300527d-05/
         data arr1383/
     1      -.6774676930172362d-05,-.9249086810907174d-05,
     2      -.1123988643508368d-04,-.1228929627169379d-04,
     3      -.1220379909766255d-04,-.1109042341338932d-04,
     4      -.9280967552767745d-05,-.7193371938624623d-05,
     5      -.5192424449353657d-05,-.3507478826271219d-05,
     6      -.2224624381726676d-05,-.1327047811907951d-05,
     7      -.7459740422489079d-06,-.4014154597918551d-06,
     8      -.2611591718254615d-06,-.2002648224063680d-04/
         data arr1384/
     1      0.4776231291240607d-05,-.1233052093513469d-05,
     2      0.3559640051015064d-06,-.1136801845187281d-06,
     3      0.4001487229106440d-07,-.1558043497452625d-07,
     4      0.6814797322816854d-08,-.3442593959747569d-08,
     5      0.1816031094789545d-08,-.3543538796910768d-08,
     6      -.1019327801441036d-07,-.5055031166534305d-07,
     7      -.1691448437115518d-06,-.4662704952652814d-06,
     8      -.1074664199825488d-05,-.2088871391585287d-05/
         data arr1385/
     1      -.3510077424821243d-05,-.5170365183024778d-05,
     2      -.6747807403901929d-05,-.7893159382697431d-05,
     3      -.8359493282879788d-05,-.8076869667588977d-05,
     4      -.7163261944600033d-05,-.5866249670897445d-05,
     5      -.4461789595127535d-05,-.3166976253597258d-05,
     6      -.2103978997156900d-05,-.1309689167183929d-05,
     7      -.7650376933424597d-06,-.4261424652343614d-06,
     8      -.2869062278983401d-06,-.2537371091306507d-04/
         data arr1386/
     1      0.6075423118074860d-05,-.1577191857179931d-05,
     2      0.4584503664563608d-06,-.1475726603277221d-06,
     3      0.5238477597897799d-07,-.2059327950642169d-07,
     4      0.9092592184400902d-08,-.4632527230754390d-08,
     5      0.2782306055296703d-08,-.2613389680259790d-08,
     6      -.1464218883175290d-08,-.1669025838792850d-07,
     7      -.5890592052600964d-07,-.1776129278030799d-06,
     8      -.4529415959980318d-06,-.9552386969254665d-06/
         data arr1387/
     1      -.1738421093875123d-05,-.2765198152316873d-05,
     2      -.3875383696459379d-05,-.4848719172621823d-05,
     3      -.5478396430722893d-05,-.5631252754731259d-05,
     4      -.5296646967149916d-05,-.4587718466003341d-05,
     5      -.3683732786723512d-05,-.2756952620320051d-05,
     6      -.1928907223135437d-05,-.1262703460642581d-05,
     7      -.7747781565356895d-06,-.4538535263227877d-06,
     8      -.3257916617201835d-06,-.2520249641727986d-04/
         data arr1388/
     1      0.6031838015920674d-05,-.1564755537611375d-05,
     2      0.4544065816525382d-06,-.1460950281113119d-06,
     3      0.5179927456890112d-07,-.2032547730773800d-07,
     4      0.8970545105635104d-08,-.4550407557501016d-08,
     5      0.2778793907198171d-08,-.2188776152888032d-08,
     6      0.8584936928483552d-09,-.5791639955436622d-08,
     7      -.1964988331731377d-07,-.6428772788743252d-07,
     8      -.1836147975363826d-06,-.4183699405667055d-06/
         data arr1389/
     1      -.8245583125605372d-06,-.1417227709381141d-05,
     2      -.2131861035095120d-05,-.2851270954615073d-05,
     3      -.3434626810459675d-05,-.3751276747109714d-05,
     4      -.3734325728150595d-05,-.3410811879589587d-05,
     5      -.2878600784026414d-05,-.2256685106391285d-05,
     6      -.1647108367368727d-05,-.1119434538095958d-05,
     7      -.7094996008746243d-06,-.4272929876610719d-06,
     8      -.3145422744035096d-06,-.2965307176786974d-04/
         data arr1390/
     1      0.7129732293080877d-05,-.1861473884985964d-05,
     2      0.5448323581860980d-06,-.1767356535275060d-06,
     3      0.6325417267981313d-07,-.2508138137565913d-07,
     4      0.1118053692523900d-07,-.5756081705251732d-08,
     5      0.3570805602927839d-08,-.2706995937174743d-08,
     6      0.1957930666770738d-08,-.2699910447485371d-08,
     7      -.6491205661072824d-08,-.2110801473060822d-07,
     8      -.7283796250397680d-07,-.1757762276031964d-06/
         data arr1391/
     1      -.3742483286267253d-06,-.6984982540777402d-06,
     2      -.1127402955339052d-05,-.1610300959973402d-05,
     3      -.2070561213252375d-05,-.2408159128922646d-05,
     4      -.2542653602053936d-05,-.2455649269018629d-05,
     5      -.2188497244075619d-05,-.1810761950366509d-05,
     6      -.1393617078211361d-05,-.9971592982222347d-06,
     7      -.6644949052780850d-06,-.4213907560919087d-06,
     8      -.3316022303397509d-06,-.2495275433229942d-04/
         data arr1392/
     1      0.5994133873565772d-05,-.1562824543981423d-05,
     2      0.4566243643510221d-06,-.1478129277976558d-06,
     3      0.5279150939781913d-07,-.2087383115769283d-07,
     4      0.9291970709633872d-08,-.4760943111148936d-08,
     5      0.2952460373658446d-08,-.2208686324867842d-08,
     6      0.1751271708980698d-08,-.1503602424976427d-08,
     7      -.2073752188602527d-08,-.6147815350302252d-08,
     8      -.2830538342175282d-07,-.7080661061514611d-07/
         data arr1393/
     1      -.1629182230191833d-06,-.3307015907402649d-06,
     2      -.5715655471442668d-06,-.8702309991533294d-06,
     3      -.1191337106951873d-05,-.1469096706612379d-05,
     4      -.1635705148458473d-05,-.1658139948572149d-05,
     5      -.1544949298938788d-05,-.1330676806064823d-05,
     6      -.1060618984524465d-05,-.7814850722009714d-06,
     7      -.5332590544957878d-06,-.3444578007896491d-06,
     8      -.2747293853010180d-06,-.2738597953388517d-04/
         data arr1394/
     1      0.6612933904479037d-05,-.1736597933277803d-05,
     2      0.5118259192238322d-06,-.1673038595283739d-06,
     3      0.6036108188215843d-07,-.2413350699179351d-07,
     4      0.1085530175517512d-07,-.5647547364814260d-08,
     5      0.3545286892362956d-08,-.2674352310266853d-08,
     6      0.2135669902649425d-08,-.1373350295322002d-08,
     7      -.9076182130027015d-09,-.3833389735309050d-09,
     8      -.1196010357329356d-07,-.2741557617973373d-07/
         data arr1395/
     1      -.6702494602518485d-07,-.1520179374062820d-06,
     2      -.2809688031154874d-06,-.4542113290857216d-06,
     3      -.6649006845336754d-06,-.8753608853671672d-06,
     4      -.1033888444257958d-05,-.1107476142782810d-05,
     5      -.1090061150834774d-05,-.9924363348024219d-06,
     6      -.8355951724698662d-06,-.6490735143105294d-06,
     7      -.4661417710683290d-06,-.3174478592497636d-06,
     8      -.2713193998538441d-06,-.1886045750382931d-04/
         data arr1396/
     1      0.4548675689975884d-05,-.1192344552542288d-05,
     2      0.3506290105224649d-06,-.1143109879281463d-06,
     3      0.4113325190286282d-07,-.1639047238794509d-07,
     4      0.7358932199257883d-08,-.3808263216441215d-08,
     5      0.2387767388815905d-08,-.1789502698104618d-08,
     6      0.1449011808345569d-08,-.8939456404560304d-09,
     7      -.3564587456309653d-09,0.6431922876251260d-09,
     8      -.4990056698029270d-08,-.1009480073122987d-07/
         data arr1397/
     1      -.2639754509877185d-07,-.6667849480562654d-07,
     2      -.1309435581793001d-06,-.2238586414616081d-06,
     3      -.3473860833503522d-06,-.4820744052961692d-06,
     4      -.5956918688349496d-06,-.6639496393459187d-06,
     5      -.6769761147787944d-06,-.6353364316234008d-06,
     6      -.5483015134212677d-06,-.4340774797623965d-06,
     7      -.3160437255654370d-06,-.2171034619956147d-06,
     8      -.1859559421316842d-06,-.1928466333458196d-04/
         data arr1398/
     1      0.4677198628455926d-05,-.1235516319415823d-05,
     2      0.3666873498373492d-06,-.1207719032567793d-06,
     3      0.4391525073390603d-07,-.1769883918888617d-07,
     4      0.8028526057566101d-08,-.4218143186085965d-08,
     5      0.2674772975446897d-08,-.2026172630232148d-08,
     6      0.1612054803659658d-08,-.9196638396452643d-09,
     7      -.3792840802466879d-09,0.1462096623196068d-08,
     8      -.3015829861457647d-08,-.3603274192908866d-08/
         data arr1399/
     1      -.9016524025527933d-08,-.2926499539487411d-07,
     2      -.6073469946116909d-07,-.1081773784471978d-06,
     3      -.1803614479109496d-06,-.2688408213815498d-06,
     4      -.3523929010562970d-06,-.4143478807689323d-06,
     5      -.4464109597038460d-06,-.4437106677221415d-06,
     6      -.4053168396655516d-06,-.3386928398331418d-06,
     7      -.2596941028825459d-06,-.1882177785727482d-06,
     8      -.1730395076883203d-06,-.9822960793833448d-05/
         data arr1400/
     1      0.2378011904755710d-05,-.6265090358552670d-06,
     2      0.1853444492254764d-06,-.6082210128497469d-07,
     3      0.2203560102644447d-07,-.8841627718869066d-08,
     4      0.3999914534285815d-08,-.2087866928134103d-08,
     5      0.1321318565843484d-08,-.9937611738176258d-09,
     6      0.7997155766656189d-09,-.4607278061392008d-09,
     7      -.1543876774046070d-09,0.7569430214890030d-09,
     8      -.1301910041503601d-08,-.1162673287362139d-08/
         data arr1401/
     1      -.3021133254866028d-08,-.1153108943369935d-07,
     2      -.2496673108209119d-07,-.4634287365253852d-07,
     3      -.8093464378407808d-07,-.1253554162153219d-06,
     4      -.1694181720500031d-06,-.2043861945368194d-06,
     5      -.2248852744314461d-06,-.2270701900085552d-06,
     6      -.2095848394221133d-06,-.1761371462139774d-06,
     7      -.1352691652100099d-06,-.9775158439558714d-07,
     8      -.8884827950826673d-07,-.9396165874270583d-05/
         data arr1402/
     1      0.2288188965974675d-05,-.6077174506156410d-06,
     2      0.1815072632178357d-06,-.6018793476606764d-07,
     3      0.2203765478424063d-07,-.8943818400218737d-08,
     4      0.4086662881093849d-08,-.2165056916227646d-08,
     5      0.1384332091342284d-08,-.1052694142965250d-08,
     6      0.8312358560693410d-09,-.4531046481000243d-09,
     7      -.2103661134149893d-09,0.8877590724886829d-09,
     8      -.1094506745291008d-08,-.3953980781989939d-09/
         data arr1403/
     1      -.3942552579256041d-09,-.5055601669901786d-08,
     2      -.1122596937684969d-07,-.2067602575297526d-07,
     3      -.3922630684083553d-07,-.6604233096360872d-07,
     4      -.9464042160356127d-07,-.1200764808538178d-06,
     5      -.1396025741334557d-06,-.1496268838360675d-06,
     6      -.1464951696629572d-06,-.1300934386729579d-06,
     7      -.1052609962780559d-06,-.8029911832909443d-07,
     8      -.7844159619079688d-07,-.3093914319869149d-05/
         data arr1404/
     1      0.7523606065662477d-06,-.1993965109329225d-06,
     2      0.5940073527645549d-07,-.1963912389997645d-07,
     3      0.7170214044414045d-08,-.2899104774066573d-08,
     4      0.1322676345923179d-08,-.6967957734455511d-09,
     5      0.4455470707891453d-09,-.3359981619742415d-09,
     6      0.2685037517963235d-09,-.1473752068641082d-09,
     7      -.6111732598015554d-10,0.2831501237344904d-09,
     8      -.3451059878999193d-09,-.9432086403689211d-10/
         data arr1405/
     1      -.6917125904541921d-10,-.1508838554451254d-08,
     2      -.3411593772358030d-08,-.6438704927240383d-08,
     3      -.1256129946741006d-07,-.2156652341373572d-07,
     4      -.3137473101038802d-07,-.4030864790678952d-07,
     5      -.4728352850786862d-07,-.5092080381004581d-07,
     6      -.4991295361426870d-07,-.4425977850293785d-07,
     7      -.3567762045314914d-07,-.2703345227652477d-07,
     8      -.2604578539415378d-07,-.2732181246599116d-05/
         data arr1406/
     1      0.6683426927277822d-06,-.1785542959765063d-06,
     2      0.5369369258573145d-07,-.1793395122901431d-07,
     3      0.6614376746288141d-08,-.2704117607017357d-08,
     4      0.1244527070323499d-08,-.6651791124545637d-09,
     5      0.4285891368176682d-09,-.3271746491814821d-09,
     6      0.2564169266863170d-09,-.1341615851487248d-09,
     7      -.7475638953395580d-10,0.2873019346266504d-09,
     8      -.3090785419271514d-09,-.3969003393677817d-10/
         data arr1407/
     1      0.1998265252882425d-09,-.6985486718302966d-09,
     2      -.1545632923662901d-08,-.2611312454946732d-08,
     3      -.5656679574877432d-08,-.1077499901083198d-07,
     4      -.1659065794828998d-07,-.2228534403134823d-07,
     5      -.2758230283770576d-07,-.3158022309483093d-07,
     6      -.3287715445522670d-07,-.3080434775488421d-07,
     7      -.2614127498360312d-07,-.2089485807112660d-07,
     8      -.2162675247794035d-07,0.8067918836678069d-06/
         data arr1408/
     1      0.8327190008744560d-05,0.4271842179563085d-04,
     2      0.1334119402550063d-03,0.2874116154545584d-03,
     3      0.4634350688574082d-03,0.5918176188155877d-03,
     4      0.6235322365624027d-03,0.5588768436987082d-03,
     5      0.4363503588560081d-03,0.3023690254955672d-03,
     6      0.1887834457827607d-03,0.1075145066864824d-03,
     7      0.5642599986706692d-04,0.2752373556248789d-04,
     8      0.1256825888105225d-04,0.5405427935740489d-05/
         data arr1409/
     1      0.2201028385762136d-05,0.8522842425265790d-06,
     2      0.3150272248929098d-06,0.1115104797440991d-06,
     3      0.3790301282031062d-07,0.1239990967090921d-07,
     4      0.3911768150320632d-08,0.1191787331663717d-08,
     5      0.3510696765763608d-09,0.1000596075216157d-09,
     6      0.2759539931005942d-10,0.7362060975755847d-11,
     7      0.1908006762552525d-11,0.5472591077309984d-12,
     8      0.1434928395116652d-06,0.2323257744391283d-05/
         data arr1410/
     1      0.1700730219160109d-04,0.7119080527499098d-04,
     2      0.1965044353011584d-03,0.3924713311559119d-03,
     3      0.6047309240473166d-03,0.7528554591440433d-03,
     4      0.7839013024547207d-03,0.7010618641067988d-03,
     5      0.5499115146555796d-03,0.3847498607936798d-03,
     6      0.2434316880034958d-03,0.1408697619540728d-03,
     7      0.7526893984552752d-04,0.3743129338778762d-04,
     8      0.1744248755840384d-04,0.7660069902247134d-05/
         data arr1411/
     1      0.3185945552586375d-05,0.1260219786050648d-05,
     2      0.4757862150905557d-06,0.1719723284126433d-06,
     3      0.5966283080251996d-07,0.1991028028435589d-07,
     4      0.6402262512334867d-08,0.1986361755338629d-08,
     5      0.5952058210612358d-09,0.1723361321406706d-09,
     6      0.4821697644235058d-10,0.1307419453324729d-10,
     7      0.3879087655962155d-11,0.1727615341266593d-07,
     8      0.4417004393909896d-06,0.4613677426407782d-05/
         data arr1412/
     1      0.2588486029938594d-04,0.9154466826535858d-04,
     2      0.2264746739568315d-03,0.4210455924551555d-03,
     3      0.6193796851076931d-03,0.7492026709407707d-03,
     4      0.7674852003041556d-03,0.6814609703189532d-03,
     5      0.5343006400309201d-03,0.3755604190586097d-03,
     6      0.2396342877674698d-03,0.1402545250464780d-03,
     7      0.7596039419992118d-04,0.3835124121481400d-04,
     8      0.1816487791217570d-04,0.8114932096781085d-05/
         data arr1413/
     1      0.3435082432810149d-05,0.1383250248544032d-05,
     2      0.5316625561653914d-06,0.1956056121003925d-06,
     3      0.6905158317602506d-07,0.2343498026617072d-07,
     4      0.7658259190668875d-08,0.2412504102774268d-08,
     5      0.7331066384807917d-09,0.2149358416068016d-09,
     6      0.6100845132446071d-10,0.1903641015839699d-10,
     7      0.9121810883738135d-09,0.6651480132461060d-07,
     8      0.9871713406841011d-06,0.7424072515303649d-05/
         data arr1414/
     1      0.3364080543872625d-04,0.1030870522777082d-03,
     2      0.2312431249147538d-03,0.4019528101901292d-03,
     3      0.5648199220366485d-03,0.6627602219836051d-03,
     4      0.6661344890350300d-03,0.5852826852744830d-03,
     5      0.4570411229207628d-03,0.3215532439855177d-03,
     6      0.2061535052868656d-03,0.1215940556834535d-03,
     7      0.6651554978124666d-04,0.3397856190416277d-04,
     8      0.1630437626041511d-04,0.7385855145461435d-05/
         data arr1415/
     1      0.3172213574230535d-05,0.1296541315366748d-05,
     2      0.5058613753529371d-06,0.1889045879618722d-06,
     3      0.6766562986734073d-07,0.2329025868332455d-07,
     4      0.7713328967532211d-08,0.2459971071118151d-08,
     5      0.7557641467592691d-09,0.2245584072444544d-09,
     6      0.7368883918823374d-10,-.2248197777963279d-08,
     7      0.9252036130378323d-08,0.1768345128691569d-06,
     8      0.1785571064120871d-05,0.1036608309439500d-04/
         data arr1416/
     1      0.3934639901542409d-04,0.1064939133313919d-03,
     2      0.2187305550932692d-03,0.3570565175841113d-03,
     3      0.4799092604349816d-03,0.5460081456843555d-03,
     4      0.5376033031919919d-03,0.4663876168503693d-03,
     5      0.3618037815592279d-03,0.2540860583171976d-03,
     6      0.1632126242765681d-03,0.9673490627566720d-04,
     7      0.5329589719041112d-04,0.2746880447570153d-04,
     8      0.1331621101884174d-04,0.6100147735806496d-05/
         data arr1417/
     1      0.2651263903315608d-05,0.1096978317770659d-05,
     2      0.4333388073945344d-06,0.1638279258357973d-06,
     3      0.5939309379587695d-07,0.2067935000371425d-07,
     4      0.6921882171771910d-08,0.2228546374633781d-08,
     5      0.6932752633404338d-09,0.2394108789398104d-09,
     6      -.6909095432876667d-08,0.3598222007673688d-08,
     7      0.2666715607462230d-07,0.3729113345454216d-06,
     8      0.2771591563684094d-05,0.1303129189903031d-04/
         data arr1418/
     1      0.4255603326979102d-04,0.1032819400072616d-03,
     2      0.1958594100435195d-03,0.3015382097396097d-03,
     3      0.3883442208540351d-03,0.4284880415984761d-03,
     4      0.4129707257865657d-03,0.3532432176970809d-03,
     5      0.2717386880844999d-03,0.1900971794813927d-03,
     6      0.1220741666587094d-03,0.7253758491526130d-04,
     7      0.4015649963527013d-04,0.2083248389076066d-04,
     8      0.1017885230937723d-04,0.4704355417887435d-05/
         data arr1419/
     1      0.2064167768092217d-05,0.8625664445429974d-06,
     2      0.3441809527586730d-06,0.1314242105519105d-06,
     3      0.4810658726644376d-07,0.1689939516423380d-07,
     4      0.5701057605920993d-08,0.1856381675146982d-08,
     5      0.6742693760936884d-09,-.1874829129352841d-07,
     6      0.7371643980040452d-08,0.1335453943656622d-08,
     7      0.6982362846647342d-07,0.6571695558066089d-06,
     8      0.3828931645416616d-05,0.1508669461495703d-04/
         data arr1420/
     1      0.4326503369756700d-04,0.9531241501350418d-04,
     2      0.1680827594722020d-03,0.2450372728868300d-03,
     3      0.3029793805681121d-03,0.3244061697054928d-03,
     4      0.3059652799735599d-03,0.2578218398647613d-03,
     5      0.1964242834038031d-03,0.1366664468845775d-03,
     6      0.8758505509994595d-04,0.5207982571370981d-04,
     7      0.2891338824148523d-04,0.1506797474994846d-04,
     8      0.7405340721812403d-05,0.3445796865287156d-05/
         data arr1421/
     1      0.1523193727137186d-05,0.6414819198265072d-06,
     2      0.2579993664726030d-06,0.9928623860697958d-07,
     3      0.3660684535290817d-07,0.1294187216048692d-07,
     4      0.4412922702360259d-08,0.1688802206146027d-08,
     5      -.4511372991276146d-07,0.1752986625848957d-07,
     6      -.5477206439106328d-08,0.1353375028524386d-07,
     7      0.1398194929601455d-06,0.1014016290330180d-05,
     8      0.4819542100008802d-05,0.1633189822061313d-04/
         data arr1422/
     1      0.4179654623943919d-04,0.8442869832857080d-04,
     2      0.1393264225178638d-03,0.1930516490007311d-03,
     3      0.2296386531654320d-03,0.2388122037819824d-03,
     4      0.2204316768696452d-03,0.1828945328063640d-03,
     5      0.1378751788582796d-03,0.9529783033626357d-04,
     6      0.6086522672193202d-04,0.3616120507519747d-04,
     7      0.2010004327900322d-04,0.1050451664771102d-04,
     8      0.5183462173842194d-05,0.2423826923142941d-05/
         data arr1423/
     1      0.1077364491742055d-05,0.4563895301387715d-06,
     2      0.1846408143676028d-06,0.7144179363930569d-07,
     3      0.2646085522449087d-07,0.9441797001905193d-08,
     4      0.3799947712062029d-08,-.9907871800237158d-07,
     5      0.3849351220742347d-07,-.1302464411381009d-07,
     6      0.6203618166446555d-08,0.2581207931028681d-07,
     7      0.2453064503979834d-06,0.1403549347447729d-05,
     8      0.5620926621108352d-05,0.1671076085105129d-04/
         data arr1424/
     1      0.3866545183335070d-04,0.7222716038516686d-04,
     2      0.1121501488825301d-03,0.1482063028600797d-03,
     3      0.1699443406429423d-03,0.1718280961514146d-03,
     4      0.1552644605808532d-03,0.1268165940264058d-03,
     5      0.9453702360722847d-04,0.6485370459547941d-04,
     6      0.4123371824803084d-04,0.2444584323874668d-04,
     7      0.1358543344663887d-04,0.7109135083762118d-05,
     8      0.3516535434923073d-05,0.1649725625945950d-05/
         data arr1425/
     1      0.7361014594678050d-06,0.3131021348806931d-06,
     2      0.1271559939019757d-06,0.4935946968362385d-07,
     3      0.1844809688682123d-07,0.7831921418972008d-08,
     4      -.1977705971185998d-06,0.7682836339427239d-07,
     5      -.2609643044726971d-07,0.9132198981454660d-08,
     6      0.1764878032818334d-08,0.5553290761071189d-07,
     7      0.3757217773067587d-06,0.1780100600345637d-05,
     8      0.6147183399779480d-05,0.1629244655646545d-04/
         data arr1426/
     1      0.3445055567882450d-04,0.5994535416365161d-04,
     2      0.8800702406941001d-04,0.1112720174585813d-03,
     3      0.1232376924614029d-03,0.1212753068491466d-03,
     4      0.1073235745410593d-03,0.8628793601066669d-04,
     5      0.6358129642933031d-04,0.4326043287306272d-04,
     6      0.2735533129402710d-04,0.1616589714598977d-04,
     7      0.8970991601426523d-05,0.4694071774551424d-05,
     8      0.2324188783773545d-05,0.1092262053697587d-05/
         data arr1427/
     1      0.4883959807518946d-06,0.2081158870107027d-06,
     2      0.8460772734014952d-07,0.3307383234711020d-07,
     3      0.1475555867442510d-07,-.3748187727605391d-06,
     4      0.1456251602824737d-06,-.4948067462657113d-07,
     5      0.1688165528156406d-07,-.5149520530183533d-08,
     6      0.1342804357179203d-07,0.9254040558472012d-07,
     7      0.5228030650471974d-06,0.2095789258450969d-05,
     8      0.6363187208223130d-05,0.1523033647865320d-04/
         data arr1428/
     1      0.2969831031347335d-04,0.4843810881645133d-04,
     2      0.6752812615919952d-04,0.8192432072648440d-04,
     3      0.8779949037654214d-04,0.8418478926541478d-04,
     4      0.7299921476107284d-04,0.5777547336278762d-04,
     5      0.4206765590012022d-04,0.2837258692661828d-04,
     6      0.1782985407475127d-04,0.1049268963032015d-04,
     7      0.5807775342762866d-05,0.3035078380052201d-05,
     8      0.1502431873771221d-05,0.7063597590703376d-06/
         data arr1429/
     1      0.3159514730393525d-06,0.1346357247610122d-06,
     2      0.5514858488760212d-07,0.2599462245027407d-07,
     3      -.6459390507247993d-06,0.2509335388502898d-06,
     4      -.8525576448059388d-07,0.2903290291978252d-07,
     5      -.1015078786150039d-07,0.6003854925157226d-08,
     6      0.2008766596290037d-07,0.1436656658813632d-06,
     7      0.6660707529504206d-06,0.2317608713867054d-05,
     8      0.6278642046286626d-05,0.1372026674380568d-04/
         data arr1430/
     1      0.2486032741949722d-04,0.3821503714719602d-04,
     2      0.5078484589128249d-04,0.5927369731787247d-04,
     3      0.6157763016869641d-04,0.5758881020972704d-04,
     4      0.4895628877503704d-04,0.3814656796657556d-04,
     5      0.2744137829552508d-04,0.1833769514798456d-04,
     6      0.1144391653389915d-04,0.6700291559773499d-05,
     7      0.3695373948315126d-05,0.1926556572874056d-05,
     8      0.9520065185835352d-06,0.4466413331016674d-06/
         data arr1431/
     1      0.1991950649626281d-06,0.8525244709256349d-07,
     2      0.4216357165029317d-07,-.1075099333664725d-05,
     3      0.4177522381187324d-06,-.1419743337634929d-06,
     4      0.4836031105230579d-07,-.1710971980358680d-07,
     5      0.6817540129078873d-08,0.2101447555411592d-08,
     6      0.3782684471596395d-07,0.1980145508260188d-06,
     7      0.7914089003652298d-06,0.2425770822213599d-05,
     8      0.5941162265455206d-05,0.1195876000472251d-04/
         data arr1432/
     1      0.2026968681351356d-04,0.2950681140958155d-04,
     2      0.3750543778857276d-04,0.4221586428435429d-04,
     3      0.4258179874776523d-04,0.3888100763709611d-04,
     4      0.3242089817150905d-04,0.2487590631624531d-04,
     5      0.1767720791016089d-04,0.1169874877122395d-04,
     6      0.7245465292967740d-05,0.4217717933661439d-05,
     7      0.2316358943712255d-05,0.1203671784035491d-05,
     8      0.5928656077841787d-06,0.2772097882730999d-06/
         data arr1433/
     1      0.1243904424039279d-06,0.6512249012697571d-07,
     2      -.1613610372188212d-05,0.6269382999575281d-06,
     3      -.2130510864892374d-06,0.7256408555617666d-07,
     4      -.2569769336002837d-07,0.9712922831075148d-08,
     5      -.2936790261693206d-08,0.1058014427190095d-07,
     6      0.5484145051102110d-07,0.2547450121363597d-06,
     7      0.8819510957884376d-06,0.2422055793816867d-05,
     8      0.5415093197207452d-05,0.1012073677657212d-04/
         data arr1434/
     1      0.1613883149069740d-04,0.2233966726333008d-04,
     2      0.2724467265587102d-04,0.2963928710300500d-04,
     3      0.2906830903649812d-04,0.2593840797069342d-04,
     4      0.2122757610586244d-04,0.1604073409132740d-04,
     5      0.1125689716212192d-04,0.7373901972135206d-05,
     6      0.4529520829561990d-05,0.2619292980508130d-05,
     7      0.1429975205683278d-05,0.7381621004362221d-06,
     8      0.3607553345854819d-06,0.1688204782478821d-06/
         data arr1435/
     1      0.9245750086091142d-07,-.2404161229773303d-05,
     2      0.9343701109371074d-06,-.3176447616356940d-06,
     3      0.1082426230686719d-06,-.3835800226533416d-07,
     4      0.1442401380747389d-07,-.5642175118127026d-08,
     5      0.4605131481748527d-08,0.1346028840155835d-07,
     6      0.7802684784356443d-07,0.3025318172488464d-06,
     7      0.9334464289000913d-06,0.2316683619194002d-05,
     8      0.4774844901928383d-05,0.8341340493610219d-05/
         data arr1436/
     1      0.1257297389390922d-04,0.1661401400864408d-04,
     2      0.1949451537888313d-04,0.2053495511762908d-04,
     3      0.1960864174596817d-04,0.1711678801907752d-04,
     4      0.1375488271898748d-04,0.1023624179374599d-04,
     5      0.7092764933724809d-05,0.4598752092859439d-05,
     6      0.2801906807481105d-05,0.1608999504664984d-05,
     7      0.8722386144589596d-06,0.4470952098046018d-06,
     8      0.2195509890968392d-06,0.1275913041664763d-06/
         data arr1437/
     1      -.3172887811760443d-05,0.1232962824054832d-05,
     2      -.4191008480765157d-06,0.1427931575173832d-06,
     3      -.5059675510057190d-07,0.1900689574906665d-07,
     4      -.7650665408162530d-08,0.3840568349211881d-08,
     5      0.1988604877254048d-08,0.2333175036869667d-07,
     6      0.9781286069328127d-07,0.3415809101751684d-06,
     7      0.9392817429761247d-06,0.2135543677092959d-05,
     8      0.4087674889379063d-05,0.6708033834942821d-05/
         data arr1438/
     1      0.9604682467187704d-05,0.1215609943913971d-04,
     2      0.1375255071621632d-04,0.1405235756864722d-04,
     3      0.1308383942990036d-04,0.1118012823458651d-04,
     4      0.8821164921529040d-05,0.6462878323206628d-05,
     5      0.4420021469704542d-05,0.2833920385019061d-05,
     6      0.1708044179648776d-05,0.9688292425034232d-06,
     7      0.5178392094331877d-06,0.2643618922727136d-06,
     8      0.1599504574240174d-06,-.4285173709182306d-05/
         data arr1439/
     1      0.1665864807109025d-05,-.5665523159707768d-06,
     2      0.1931699304396145d-06,-.6850395732423738d-07,
     3      0.2576787478474986d-07,-.1042709641549773d-07,
     4      0.4728653420524547d-08,-.1469161303438541d-08,
     5      0.7617811288052549d-08,0.2923119344844181d-07,
     6      0.1196259182858665d-06,0.3616208253951925d-06,
     7      0.9079277730555648d-06,0.1905416214061178d-05,
     8      0.3402212154156291d-05,0.5279052747643478d-05/
         data arr1440/
     1      0.7207999898501661d-05,0.8757257429111005d-05,
     2      0.9574711329116959d-05,0.9509994934500286d-05,
     3      0.8642655520947803d-05,0.7231004480913290d-05,
     4      0.5603673456681284d-05,0.4045747293342443d-05,
     5      0.2734025919124835d-05,0.1734136637851513d-05,
     6      0.1033493802921102d-05,0.5797378816547129d-06,
     7      0.3109374005521868d-06,0.2002083685178349d-06,
     8      -.4953872827826441d-05,0.1925484760425825d-05/
         data arr1441/
     1      -.6547372793750295d-06,0.2231892982406131d-06,
     2      -.7913619102296554d-07,0.2975212974487372d-07,
     3      -.1204532378918704d-07,0.5364489732153187d-08,
     4      -.2514450474841586d-08,0.3352225831597751d-08,
     5      0.7442484384006945d-08,0.4073618991282795d-07,
     6      0.1322204627454127d-06,0.3678037976903732d-06,
     7      0.8474232963998112d-06,0.1644299238909667d-05,
     8      0.2765684201968330d-05,0.4074753815542279d-05/
         data arr1442/
     1      0.5315248989884421d-05,0.6217313023644628d-05,
     2      0.6586859456135208d-05,0.6364338255302228d-05,
     3      0.5642450675998242d-05,0.4619694449094540d-05,
     4      0.3514457706758797d-05,0.2495581655783543d-05,
     5      0.1657676213714701d-05,0.1030439178952874d-05,
     6      0.6002658066557193d-06,0.3329949661007274d-06,
     7      0.2215820451935550d-06,-.6118709437496316d-05,
     8      0.2379516754278417d-05,-.8097108246678424d-06/
         data arr1443/
     1      0.2762858152077130d-06,-.9807532001684639d-07,
     2      0.3694200140290862d-07,-.1498556964890680d-07,
     3      0.6689668046406691d-08,-.3369467685442148d-08,
     4      0.2635105131591697d-08,0.5419149693150687d-09,
     5      0.1437184906938235d-07,0.4554147767473171d-07,
     6      0.1420402995692356d-06,0.3613097211779526d-06,
     7      0.7584385612534674d-06,0.1383986145477262d-05,
     8      0.2202239152904920d-05,0.3082875495694261d-05/
         data arr1444/
     1      0.3857315446710020d-05,0.4361190908262352d-05,
     2      0.4482967020418654d-05,0.4214154995409350d-05,
     3      0.3649125673085416d-05,0.2931546568603427d-05,
     4      0.2195648523643018d-05,0.1536153433921631d-05,
     5      0.1004143134219231d-05,0.6144747546667936d-06,
     6      0.3586886771427194d-06,0.2548501714527459d-06,
     7      -.6143717506932663d-05,0.2388670525268374d-05,
     8      -.8126224792025748d-06,0.2771897860963818d-06/
         data arr1445/
     1      -.9836715382094957d-07,0.3702515202010051d-07,
     2      -.1501741049760349d-07,0.6684757969088008d-08,
     3      -.3403407653423282d-08,0.2321092584068332d-08,
     4      -.1322344833714620d-08,0.5744917595155577d-08,
     5      0.1444539436677894d-07,0.5232357871157849d-07,
     6      0.1483351796241228d-06,0.3342815095271382d-06,
     7      0.6628080364961118d-06,0.1139966861366817d-05,
     8      0.1711080666249379d-05,0.2288731280387679d-05/
         data arr1446/
     1      0.2759983283779549d-05,0.3014316476230963d-05,
     2      0.2997986489571347d-05,0.2737064491173026d-05,
     3      0.2311181554444230d-05,0.1813077786214760d-05,
     4      0.1322779101472524d-05,0.8970814691569586d-06,
     5      0.5665460996955630d-06,0.3396408968344543d-06,
     6      0.2470298154547500d-06,-.6991757668309641d-05,
     7      0.2720263804898382d-05,-.9262965011256968d-06,
     8      0.3163623671289227d-06,-.1124368176910790d-06/
         data arr1447/
     1      0.4242364565724634d-07,-.1724912135041565d-07,
     2      0.7729090301681426d-08,-.3968558407730031d-08,
     3      0.2642856353592415d-08,-.2161602556156396d-08,
     4      0.3382540773464215d-08,0.3660526708432493d-08,
     5      0.1805664209361274d-07,0.5984749299874063d-07,
     6      0.1403355432705745d-06,0.3039325082952240d-06,
     7      0.5676643973341628d-06,0.9117374610068111d-06,
     8      0.1302984645532783d-05,0.1679065917170699d-05/
         data arr1448/
     1      0.1952515509364591d-05,0.2058538988927847d-05,
     2      0.1987293674359867d-05,0.1773156769467669d-05,
     3      0.1469037934031235d-05,0.1130416673841918d-05,
     4      0.8071157945356231d-06,0.5361100204190427d-06,
     5      0.3388037857452742d-06,0.2640268598418765d-06,
     6      -.5946776163371662d-05,0.2312920446454343d-05,
     7      -.7872944586863049d-06,0.2687568360437280d-06,
     8      -.9547075145053555d-07,0.3598405412322475d-07/
         data arr1449/
     1      -.1462511607423146d-07,0.6530647852527567d-08,
     2      -.3352751403214217d-08,0.2201886321891368d-08,
     3      -.1934869494110900d-08,0.2244099002680727d-08,
     4      0.3443273958069307d-09,0.5814694840232555d-08,
     5      0.2383322647133920d-07,0.5607476089913120d-07,
     6      0.1336483319422466d-06,0.2715392556230240d-06,
     7      0.4653243547098786d-06,0.7091766743723318d-06,
     8      0.9739766299261320d-06,0.1200548509212138d-05/
         data arr1450/
     1      0.1333838688829915d-05,0.1351185395135215d-05,
     2      0.1260347812012811d-05,0.1086660928148578d-05,
     3      0.8653474697756059d-06,0.6355885625439855d-06,
     4      0.4317673113224685d-06,0.2775166032836143d-06,
     5      0.2186494077727221d-06,-.6272073478160558d-05,
     6      0.2441575350917131d-05,-.8320792855244327d-06,
     7      0.2845005523358596d-06,-.1012573498019957d-06,
     8      0.3828225502252608d-07,-.1560756969373768d-07/
         data arr1451/
     1      0.7027794681349318d-08,-.3636360651383907d-08,
     2      0.2418377062219778d-08,-.2135912740868126d-08,
     3      0.2151495219923290d-08,-.7555848492372281d-09,
     4      0.1339367496373448d-08,0.1046414505981133d-07,
     5      0.2065686426588839d-07,0.5597648165312518d-07,
     6      0.1266105866681136d-06,0.2295471226361812d-06,
     7      0.3723257241790195d-06,0.5485794026250846d-06,
     8      0.7214710724129344d-06,0.8491985898751516d-06/
         data arr1452/
     1      0.9092574767148709d-06,0.8971810757943720d-06,
     2      0.8185811571727333d-06,0.6888690518321919d-06,
     3      0.5335080822075751d-06,0.3817273996117006d-06,
     4      0.2591539484795855d-06,0.2195152188742554d-06,
     5      -.4360526354707002d-05,0.1696737765138386d-05,
     6      -.5779658508944883d-06,0.1974919228450549d-06,
     7      -.7024509212096098d-07,0.2652182023298960d-07,
     8      -.1080739579120096d-07,0.4844933288586547d-08/
         data arr1453/
     1      -.2505449430836396d-08,0.1649763149956302d-08,
     2      -.1479188626377171d-08,0.1449634773528583d-08,
     3      -.7385059257240221d-09,0.1599562638445978d-09,
     4      0.4574625485019063d-08,0.7057493761832850d-08,
     5      0.2243205830472640d-07,0.5629037853747069d-07,
     6      0.1073322236851088d-06,0.1844210932906599d-06,
     7      0.2886445364053979d-06,0.3998441835522944d-06,
     8      0.4918257021626149d-06,0.5476997266870444d-06/
         data arr1454/
     1      0.5596846514243876d-06,0.5260393081053732d-06,
     2      0.4532439993633479d-06,0.3572651430907683d-06,
     3      0.2587467689924526d-06,0.1768428830415114d-06,
     4      0.1496461416920232d-06,-.4279018636068275d-05,
     5      0.1666812599801791d-05,-.5686023803356954d-06,
     6      0.1946735641343164d-06,-.6940492838495691d-07,
     7      0.2630267457227654d-07,-.1075797030454290d-07,
     8      0.4871835854043721d-08,-.2542393779674800d-08/
         data arr1455/
     1      0.1703249594976855d-08,-.1502947953399576d-08,
     2      0.1427545553874336d-08,-.7583287385795216d-09,
     3      -.4004085485443878d-09,0.2849184207967030d-08,
     4      0.1679877285559029d-08,0.8216875001395166d-08,
     5      0.2543155003898818d-07,0.4946303284887890d-07,
     6      0.8937536499112716d-07,0.1516206219208926d-06,
     7      0.2251188667565671d-06,0.2929536173936376d-06,
     8      0.3444763195384201d-06,0.3729358294863904d-06/
         data arr1456/
     1      0.3719088323723629d-06,0.3394091715830989d-06,
     2      0.2825452940644962d-06,0.2158149909470384d-06,
     3      0.1560621383534850d-06,0.1423702355586518d-06,
     4      -.2198588119192492d-05,0.8559214007618052d-06,
     5      -.2917827859952403d-06,0.9980873765502036d-07,
     6      -.3554989421785693d-07,0.1344727500677798d-07,
     7      -.5494963031763633d-08,0.2473766154817699d-08,
     8      -.1288959026925209d-08,0.8528565490264427d-09/
         data arr1457/
     1      -.7636542568847382d-09,0.7248327902670332d-09,
     2      -.4146191853681281d-09,-.2284655387445983d-09,
     3      0.1268836178161962d-08,0.3047574053352638d-09,
     4      0.2880358116914430d-08,0.1018554717033912d-07,
     5      0.2031802725877290d-07,0.3838844266117083d-07,
     6      0.6835950721142976d-07,0.1053262537817176d-06,
     7      0.1411407244860009d-06,0.1701415332745652d-06,
     8      0.1879300172279436d-06,0.1901178883750788d-06/
         data arr1458/
     1      0.1750196141508607d-06,0.1462601792589565d-06,
     2      0.1116514256837839d-06,0.8027539920162711d-07,
     3      0.7208801965235933d-07,-.2025036753276376d-05,
     4      0.7893578698762770d-06,-.2695519527182435d-06,
     5      0.9241563821899728d-07,-.3300630237473236d-07,
     6      0.1253956082052532d-07,-.5145771343873910d-08,
     7      0.2343783898866648d-08,-.1233821714740632d-08,
     8      0.8327673453914685d-09,-.7310309864665592d-09/
         data arr1459/
     1      0.6785032468818338d-09,-.3540392824347324d-09,
     2      -.3067002474181926d-09,0.1040021464873160d-08,
     3      -.3076766330861042d-09,0.7212300294286617d-09,
     4      0.4741483393989707d-08,0.8876290049929415d-08,
     5      0.1710222788056396d-07,0.3376427597055820d-07,
     6      0.5622291736857728d-07,0.7950024915573357d-07,
     7      0.1009986335447741d-06,0.1183906667262391d-06,
     8      0.1274655640939936d-06,0.1245907721106020d-06/
         data arr1460/
     1      0.1101269852363475d-06,0.8876676178990478d-07,
     2      0.6762524238027785d-07,0.6561935417710986d-07,
     3      -.6672688892921118d-06,0.2599458132699275d-06,
     4      -.8870898482137088d-07,0.3038796139012567d-07,
     5      -.1084394711608921d-07,0.4112134542319437d-08,
     6      -.1686845177113378d-08,0.7633304013585087d-09,
     7      -.4021120678411456d-09,0.2672922318235613d-09,
     8      -.2389568060648520d-09,0.2209399559400616d-09/
         data arr1461/
     1      -.1217396618735873d-09,-.9623425046697720d-10,
     2      0.3305588949550352d-09,-.1284321049616067d-09,
     3      0.1851839386694801d-09,0.1428958944029086d-08,
     4      0.2686846073942320d-08,0.5326871292715687d-08,
     5      0.1081552359810385d-07,0.1833672139460867d-07,
     6      0.2629604350303037d-07,0.3379042444680393d-07,
     7      0.3990021573164511d-07,0.4308165224308491d-07,
     8      0.4207595054888004d-07,0.3706138669296346d-07/
         data arr1462/
     1      0.2969083389413461d-07,0.2239977369007622d-07,
     2      0.2134160535528618d-07,-.5773939287128150d-06,
     3      0.2252641520957126d-06,-.7702175277359351d-07,
     4      0.2645219723317103d-07,-.9467838847305967d-08,
     5      0.3607921368655329d-08,-.1486515265556656d-08,
     6      0.6816536105827746d-09,-.3628545546096390d-09,
     7      0.2468508998889569d-09,-.2155364952864928d-09,
     8      0.1952773998072489d-09,-.9430070473864206d-10/
         data arr1463/
     1      -.1046040509557612d-09,0.2868353987850884d-09,
     2      -.1536867599756835d-09,-.4488142851086098d-10,
     3      0.7310318539433216d-09,0.1142258437153764d-08,
     4      0.2148779261797629d-08,0.5058688943780441d-08,
     5      0.9393918066726746d-08,0.1414897174739040d-07,
     6      0.1908475249325271d-07,0.2394087959804550d-07,
     7      0.2758701230523220d-07,0.2866358238723190d-07,
     8      0.2672749962298851d-07,0.2261714566612444d-07/
         data arr1464/
     1      0.1808929530644873d-07,0.1863995718982312d-07,
     2      -.6303303853711037d-06,-.4543177175554635d-05,
     3      -.1902710113880835d-04,-.5251786530046186d-04,
     4      -.1048924226865138d-03,-.1616211213342616d-03,
     5      -.2012090916822844d-03,-.2095064323199136d-03,
     6      -.1873666664318235d-03,-.1469700331293466d-03,
     7      -.1028287261215963d-03,-.6505985552595424d-04,
     8      -.3764902672881362d-04,-.2011647102902911d-04/
         data arr1465/
     1      -.1000393397837242d-04,-.4661700296422940d-05,
     2      -.2047240114745307d-05,-.8514801278112134d-06,
     3      -.3368075516801745d-06,-.1271589447289305d-06,
     4      -.4596181533296692d-07,-.1594583945535520d-07,
     5      -.5321108862868800d-08,-.1710787028142074d-08,
     6      -.5308197349581825d-09,-.1592645644308282d-09,
     7      -.4625556285368915d-10,-.1292150949360263d-10,
     8      -.3383999023838631d-11,-.8588227452925185d-12/
         data arr1466/
     1      -.1628252953527297d-06,-.1684316950385586d-05,
     2      -.9451904597805223d-05,-.3342736187981269d-04,
     3      -.8269686593761707d-04,-.1537441098859065d-03,
     4      -.2261654845150212d-03,-.2735701348240728d-03,
     5      -.2802459714810306d-03,-.2488343634813671d-03,
     6      -.1950990087581986d-03,-.1371352755364468d-03,
     7      -.8750206984538438d-04,-.5121371153762617d-04,
     8      -.2773681427158040d-04,-.1400389318851640d-04/
         data arr1467/
     1      -.6632875624387263d-05,-.2963154304262203d-05,
     2      -.1254314717342361d-05,-.5050915261901614d-06,
     3      -.1941357429230335d-06,-.7142511609881357d-07,
     4      -.2521406766761487d-07,-.8557204723571796d-08,
     5      -.2796378685589501d-08,-.8809341138178598d-09,
     6      -.2677154198486379d-09,-.7848927830899920d-10,
     7      -.2225516344697606d-10,-.6873007924476824d-11,
     8      -.2886125107274289d-07,-.4274536397731680d-06/
         data arr1468/
     1      -.3214715999841063d-05,-.1456689731333781d-04,
     2      -.4463800241902710d-04,-.1001312105925200d-03,
     3      -.1740506722492732d-03,-.2445742005808453d-03,
     4      -.2869835943924991d-03,-.2884446949608235d-03,
     5      -.2534348368646512d-03,-.1979046115680361d-03,
     6      -.1392366389677246d-03,-.8926708627124474d-04,
     7      -.5265177066207403d-04,-.2880207793045437d-04,
     8      -.1471314881112285d-04,-.7060002049516025d-05/
         data arr1469/
     1      -.3198169171436150d-05,-.1373608731106430d-05,
     2      -.5614187724584466d-06,-.2190444117778907d-06,
     3      -.8179816303434267d-07,-.2930009622502824d-07,
     4      -.1008490677664446d-07,-.3339880377709782d-08,
     5      -.1065157250760215d-08,-.3272542239751699d-09,
     6      -.9720822000746625d-10,-.3165387301514847d-10,
     7      -.4092710542049658d-08,-.8590470131042136d-07,
     8      -.8660875420328188d-06,-.5028303151552509d-05/
         data arr1470/
     1      -.1908580176008799d-04,-.5165713769232823d-04,
     2      -.1060999029273662d-03,-.1731978517371684d-03,
     3      -.2327901846333103d-03,-.2648528539949311d-03,
     4      -.2607759060850774d-03,-.2262312245110070d-03,
     5      -.1755006126041348d-03,-.1232498416818840d-03,
     6      -.7916975196033645d-04,-.4692332195693919d-04,
     7      -.2585230714298660d-04,-.1332432741607012d-04,
     8      -.6459311437104537d-05,-.2959006167983404d-05/
         data arr1471/
     1      -.1286051568611578d-05,-.5321126673306872d-06,
     2      -.2102004974938255d-06,-.7946832636325523d-07,
     3      -.2880964890506597d-07,-.1003063673890066d-07,
     4      -.3357451515644683d-08,-.1081002970051451d-08,
     5      -.3361936856016079d-09,-.1151866711895815d-09,
     6      -.5849102754499269d-09,-.1447632482310962d-07,
     7      -.1964038331226215d-06,-.1460804227231195d-05,
     8      -.6868076647395629d-05,-.2242900564739174d-04/
         data arr1472/
     1      -.5443435903982248d-04,-.1032269742109373d-03,
     2      -.1589245898716073d-03,-.2046753764266402d-03,
     3      -.2258330261514815d-03,-.2176546839987904d-03,
     4      -.1861755227144071d-03,-.1432188629350728d-03,
     5      -.1001900115417503d-03,-.6433873521330794d-04,
     6      -.3823066295798626d-04,-.2116433387777330d-04,
     7      -.1097968411467294d-04,-.5364725854623306d-05,
     8      -.2479411918865666d-05,-.1087911977670344d-05/
         data arr1473/
     1      -.4546134181180259d-06,-.1813996777776375d-06,
     2      -.6926588590307160d-07,-.2535332135597615d-07,
     3      -.8906227285057862d-08,-.3004710301697060d-08,
     4      -.9781125409936517d-09,-.3523560328752926d-09,
     5      -.3441535478603360d-09,-.1971575732857245d-08,
     6      -.3883858495525544d-07,-.3694341235496417d-06,
     7      -.2151623960213742d-05,-.8478010014292115d-05,
     8      -.2431284167502032d-04,-.5356095733626814d-04/
         data arr1474/
     1      -.9445435417195667d-04,-.1376990620018456d-03,
     2      -.1702597111589647d-03,-.1823005311726617d-03,
     3      -.1719376441551934d-03,-.1448833638286729d-03,
     4      -.1103809207229422d-03,-.7679991354786486d-04,
     5      -.4921854878161179d-04,-.2926633631081904d-04,
     6      -.1624792452760293d-04,-.8467469729613318d-05,
     7      -.4161439098931843d-05,-.1936370870826033d-05,
     8      -.8559638748894141d-06,-.3604828268465954d-06/
         data arr1475/
     1      -.1449809466492773d-06,-.5579100620609368d-07,
     2      -.2056983878485345d-07,-.7272786458933381d-08,
     3      -.2479115801597734d-08,-.9405034031145727d-09,
     4      -.7668123977303044d-09,0.1580767380033969d-09,
     5      -.7001458105244183d-08,-.8306228867903859d-07,
     6      -.5997749331790013d-06,-.2851328520325405d-05,
     7      -.9662060481838022d-05,-.2472718014549821d-04,
     8      -.4994868551567152d-04,-.8242662847456581d-04/
         data arr1476/
     1      -.1142108901124334d-03,-.1358560637789158d-03,
     2      -.1412832052584450d-03,-.1304091326480637d-03,
     3      -.1082018713790778d-03,-.8156805697845638d-04,
     4      -.5637894883317820d-04,-.3600835590997252d-04,
     5      -.2139326497305117d-04,-.1189134318856576d-04,
     6      -.6214548155965512d-05,-.3066578372571389d-05,
     7      -.1433962857111188d-05,-.6373804266163744d-06,
     8      -.2699985278202339d-06,-.1092277981838328d-06/
         data arr1477/
     1      -.4226244487887877d-07,-.1565508618347397d-07,
     2      -.5584330944468946d-08,-.2227119532917490d-08,
     3      -.1764651978990396d-08,0.9852437747934726d-09,
     4      -.1530763610482468d-08,-.1671685405829816d-07,
     5      -.1511210198868249d-06,-.8664007880826989d-06,
     6      -.3469264053460122d-05,-.1031412786787346d-04,
     7      -.2386482148352784d-04,-.4457958318431434d-04,
     8      -.6922056176069837d-04,-.9147492634505215d-04/
         data arr1478/
     1      -.1048919243946169d-03,-.1060545897109737d-03,
     2      -.9583132072887228d-04,-.7827290349619421d-04,
     3      -.5834949967510159d-04,-.4002858070770581d-04,
     4      -.2545002053425392d-04,-.1508829532076112d-04,
     5      -.8385093811673502d-05,-.4387855167412621d-05,
     6      -.2170469572666413d-05,-.1018238856991600d-05,
     7      -.4543190636379209d-06,-.1932337432042763d-06,
     8      -.7847480082690039d-07,-.3046631162753944d-07/
         data arr1479/
     1      -.1138247786879394d-07,-.4785449497466499d-08,
     2      -.3628189402391159d-08,0.2091795076664730d-08,
     3      -.1083663037693037d-08,-.2754652671646975d-08,
     4      -.3492816926713307d-07,-.2405429814997947d-06,
     5      -.1138458552888700d-05,-.3931798010305294d-05,
     6      -.1042065593487700d-04,-.2203467426572706d-04,
     7      -.3834115060507477d-04,-.5628950310486982d-04,
     8      -.7116982176312697d-04,-.7882306459894516d-04/
         data arr1480/
     1      -.7756797837570268d-04,-.6864439379935390d-04,
     2      -.5518991190875956d-04,-.4066674484380642d-04,
     3      -.2766950164696954d-04,-.1749651541012573d-04,
     4      -.1033970702545263d-04,-.5737871271215233d-05,
     5      -.3002376198518250d-05,-.1486572584104762d-05,
     6      -.6985914941867695d-06,-.3123486560113941d-06,
     7      -.1331006358276888d-06,-.5412184650199976d-07,
     8      -.2114991197561802d-07,-.9342203098618384d-08/
         data arr1481/
     1      -.7106864839447046d-08,0.4118155756004175d-08,
     2      -.1850886133593810d-08,0.2287570949426479d-09,
     3      -.7705613681544339d-08,-.6146601208538692d-07,
     4      -.3445377850823612d-06,-.1382011024322147d-05,
     5      -.4195708390394727d-05,-.1004263378682593d-04,
     6      -.1958243378994375d-04,-.3193918579697224d-04,
     7      -.4452672652187244d-04,-.5401924293747344d-04,
     8      -.5789333175119389d-04,-.5550981388177147d-04/
         data arr1482/
     1      -.4813418369465857d-04,-.3809604189463293d-04,
     2      -.2773865972711697d-04,-.1870830106669648d-04,
     3      -.1175658635304969d-04,-.6918683979574269d-05,
     4      -.3829602757798077d-05,-.2001295585827530d-05,
     5      -.9906229969343793d-06,-.4656923111252831d-06,
     6      -.2083045063685743d-06,-.8878301924503635d-07,
     7      -.3635022454946287d-07,-.1694823780974026d-07,
     8      -.1260895539872292d-07,0.7314873532696987d-08/
         data arr1483/
     1      -.3256250044263132d-08,0.1279629161145243d-08,
     2      -.2038270052669657d-08,-.1438682786461568d-07,
     3      -.9693092479993716d-07,-.4510873691444914d-06,
     4      -.1568935981945839d-05,-.4250743821073884d-05,
     5      -.9288572678262740d-05,-.1683059741870873d-04,
     6      -.2587169921304127d-04,-.3438140788019618d-04,
     7      -.4012859351433686d-04,-.4168826530444428d-04,
     8      -.3898768031433317d-04,-.3314360686535957d-04/
         data arr1484/
     1      -.2582547199139417d-04,-.1857785355947258d-04,
     2      -.1241456143266928d-04,-.7747599987888689d-05,
     3      -.4536261250357536d-05,-.2501847926371253d-05,
     4      -.1304224957538198d-05,-.6444265115789480d-06,
     5      -.3023630244646426d-06,-.1348983773521156d-06,
     6      -.5771778492440909d-07,-.2823585269997419d-07,
     7      -.2168668031750941d-07,0.1265266794992690d-07,
     8      -.5667870214846825d-08,0.2385194365684458d-08/
         data arr1485/
     1      -.1303310098769109d-08,-.2778040269865447d-08,
     2      -.2565496056065482d-07,-.1374438624204682d-06,
     3      -.5481536655395057d-06,-.1680759277975398d-05,
     4      -.4116002595099172d-05,-.8285405538116215d-05,
     5      -.1404323764535166d-04,-.2044276089573644d-04,
     6      -.2598472081127211d-04,-.2924802219372257d-04,
     7      -.2950131715035961d-04,-.2693763050461974d-04,
     8      -.2246206109399936d-04,-.1723443897615486d-04/
         data arr1486/
     1      -.1224691861236108d-04,-.8105170362039276d-05,
     2      -.5020017877959520d-05,-.2922190146824538d-05,
     3      -.1604666301853594d-05,-.8337342578610743d-06,
     4      -.4106801472914743d-06,-.1920892363513830d-06,
     5      -.8614661219620579d-07,-.4455209699264036d-07,
     6      -.3328969057965283d-07,0.1944094342342663d-07,
     7      -.8716516850876411d-08,0.3689912728159234d-08,
     8      -.1642354342388913d-08,0.5774418016793623d-10/
         data arr1487/
     1      -.6640019419829451d-08,-.3916715565970185d-07,
     2      -.1799042569435496d-06,-.6238405449003168d-06,
     3      -.1712415114576569d-05,-.3829255317097745d-05,
     4      -.7156419035506778d-05,-.1141163802067724d-04,
     5      -.1579682483359771d-04,-.1926491131595257d-04,
     6      -.2095780904232554d-04,-.2055452513608621d-04,
     7      -.1834154448871171d-04,-.1501003577706663d-04,
     8      -.1134222913052949d-04,-.7959953726333718d-05/
         data arr1488/
     1      -.5214550084478699d-05,-.3203074360120921d-05,
     2      -.1852019791013664d-05,-.1010998483525025d-05,
     3      -.5220021715550900d-06,-.2552745349797302d-06,
     4      -.1194336050717045d-06,-.6463724041336862d-07,
     5      -.5106529232588754d-07,0.3004233090874692d-07,
     6      -.1359091650075033d-07,0.5815710570563775d-08,
     7      -.2551256669867912d-08,0.1056698937015397d-08,
     8      -.2075460416227512d-08,-.1025394801925505d-07/
         data arr1489/
     1      -.5586184204387041d-07,-.2181451777528236d-06,
     2      -.6718016284457162d-06,-.1668527592110794d-05,
     3      -.3438223385029721d-05,-.6006102685339306d-05,
     4      -.9054031599728471d-05,-.1196346126608381d-04,
     5      -.1403715245966923d-04,-.1478706562433675d-04,
     6      -.1412030035838847d-04,-.1232525423154184d-04,
     7      -.9904171429982186d-05,-.7371061267808169d-05,
     8      -.5107881150418296d-05,-.3311633804180869d-05/
         data arr1490/
     1      -.2017247202658498d-05,-.1158189402126148d-05,
     2      -.6279646037213356d-06,-.3220557340668890d-06,
     3      -.1580365504116148d-06,-.9058658754196781d-07,
     4      -.6876632173788213d-07,0.4048327519398858d-07,
     5      -.1832455974012426d-07,0.7846025922329447d-08,
     6      -.3434663510156675d-08,0.1582884909960991d-08,
     7      -.1158077961724035d-08,-.2202190837272585d-08,
     8      -.1664949789795813d-07,-.7198749052421051d-07/
         data arr1491/
     1      -.2495361572581747d-06,-.6879228029442588d-06,
     2      -.1562975172156684d-05,-.2991409772911592d-05,
     3      -.4910392496846478d-05,-.7029908023463862d-05,
     4      -.8896687738944362d-05,-.1006613521293581d-04,
     5      -.1028592214973677d-04,-.9576126068625817d-05,
     6      -.8182507754675162d-05,-.6456811781548403d-05,
     7      -.4731316543297445d-05,-.3235708659991860d-05,
     8      -.2074194380157616d-05,-.1250093204708309d-05/
         data arr1492/
     1      -.7094423666478155d-06,-.3796029806611576d-06,
     2      -.1937798548920082d-06,-.1157511119372024d-06,
     3      -.9574594617052881d-07,0.5690848322019054d-07,
     4      -.2605375313986113d-07,0.1129907366820631d-07,
     5      -.5014443976287265d-08,0.2381025469771552d-08,
     6      -.1335260284605791d-08,0.1362117947140868d-09,
     7      -.5124874405424516d-08,-.2221421398869057d-07,
     8      -.8821165381719283d-07,-.2692352048867025d-06/
         data arr1493/
     1      -.6742214010803867d-06,-.1414708867289087d-05,
     2      -.2527962263365462d-05,-.3921123720936029d-05,
     3      -.5353055799224387d-05,-.6505171019155061d-05,
     4      -.7112747065563825d-05,-.7063351136135107d-05,
     5      -.6418761302497022d-05,-.5371365347207996d-05,
     6      -.4163269476916843d-05,-.3005376177384310d-05,
     7      -.2030143042678872d-05,-.1287384178017623d-05,
     8      -.7675472962134385d-06,-.4309060000114459d-06/
         data arr1494/
     1      -.2308967418741106d-06,-.1463843459252241d-06,
     2      -.1128326178488314d-06,0.6706867777964499d-07,
     3      -.3070003493093432d-07,0.1331073851909487d-07,
     4      -.5904594868725025d-08,0.2807480167541025d-08,
     5      -.1505046151023130d-08,0.7825821373661880d-09,
     6      -.1908968911842130d-08,-.6186540658228541d-08,
     7      -.2991639844652206d-07,-.1002740639423773d-06,
     8      -.2766666164291489d-06,-.6372263421249249d-06/
         data arr1495/
     1      -.1238797785836800d-05,-.2081857430610493d-05,
     2      -.3066315114733030d-05,-.4001735103236797d-05,
     3      -.4681261727210346d-05,-.4957981113002833d-05,
     4      -.4790229659440948d-05,-.4248356647505752d-05,
     5      -.3479425678577392d-05,-.2646829855239304d-05,
     6      -.1878967327309357d-05,-.1248247193868127d-05,
     7      -.7767432596147555d-06,-.4532527648208401d-06,
     8      -.2514779690054155d-06,-.1650507436626447d-06/
         data arr1496/
     1      -.1437952680394398d-06,0.8647840973873465d-07,
     2      -.4012497528327920d-07,0.1765771669593809d-07,
     3      -.7958182449849458d-08,0.3850921467150047d-08,
     4      -.2091947753017609d-08,0.1304315628910694d-08,
     5      -.1335379773651251d-08,-.1068955482095112d-08,
     6      -.1002842372890538d-07,-.3568198869933004d-07,
     7      -.1078739565123463d-06,-.2745168016072395d-06,
     8      -.5792357903411595d-06,-.1054399582490690d-05/
         data arr1497/
     1      -.1676795519765955d-05,-.2349908671241598d-05,
     2      -.2940450269022959d-05,-.3322418095025067d-05,
     3      -.3414852407976083d-05,-.3211785828485900d-05,
     4      -.2782111820338062d-05,-.2234221871456466d-05,
     5      -.1672182493951181d-05,-.1169665940384055d-05,
     6      -.7651802270416614d-06,-.4687955779460364d-06,
     7      -.2732991663609949d-06,-.1908252392434258d-06,
     8      -.1471697151754211d-06,0.8843561710556880d-07/
         data arr1498/
     1      -.4098489352742317d-07,0.1801237883874997d-07,
     2      -.8105174028394399d-08,0.3916696692504513d-08,
     3      -.2120192697616852d-08,0.1348025442981055d-08,
     4      -.1118186139731272d-08,0.3559269021361698d-09,
     5      -.3499787478254763d-08,-.1212841108200790d-07,
     6      -.3994617827437040d-07,-.1135012320513410d-06,
     7      -.2589089403618182d-06,-.5105218635886110d-06,
     8      -.8771088696172604d-06,-.1319315133738687d-05/
         data arr1499/
     1      -.1764906993008429d-05,-.2126190444598549d-05,
     2      -.2322106799644151d-05,-.2311689103127047d-05,
     3      -.2111930083179676d-05,-.1783068785640552d-05,
     4      -.1398309768690412d-05,-.1020718784032403d-05,
     5      -.6935626601773040d-06,-.4391555434627528d-06,
     6      -.2633853710364981d-06,-.1887888168295062d-06,
     7      -.1729200038315712d-06,0.1053351241145054d-06,
     8      -.4957480052250387d-07,0.2214838584824662d-07/
         data arr1500/
     1      -.1013813607184044d-07,0.4987942594392108d-08,
     2      -.2757913128370614d-08,0.1798951976120998d-08,
     3      -.1419920000795327d-08,0.1024229314422435d-08,
     4      -.1584544668844080d-08,-.4068259492558335d-08,
     5      -.1348598191601206d-07,-.4575848045338455d-07,
     6      -.1108291747817032d-06,-.2362256996761676d-06,
     7      -.4404277211320151d-06,-.7108099932832352d-06,
     8      -.1015683553814290d-05,-.1306090671800295d-05/
         data arr1501/
     1      -.1518755255960670d-05,-.1603470246814612d-05,
     2      -.1548927329438847d-05,-.1380850944585825d-05,
     3      -.1142670397121290d-05,-.8792216654837334d-06,
     4      -.6286474022788429d-06,-.4182364297792450d-06,
     5      -.2638345542929522d-06,-.2016349560719474d-06,
     6      -.1500145685486620d-06,0.9117683687004159d-07,
     7      -.4279331363355533d-07,0.1906267339758891d-07,
     8      -.8697281603714204d-08,0.4266340772879880d-08/
         data arr1502/
     1      -.2348370815930879d-08,0.1527733136412909d-08,
     2      -.1191332847509881d-08,0.9539607810175004d-09,
     3      -.8758104373704158d-09,-.1315747884715416d-08,
     4      -.4080440656515382d-08,-.1803042791346462d-07,
     5      -.4542298654830872d-07,-.1047071768921053d-06,
     6      -.2121695890333984d-06,-.3666723415272550d-06,
     7      -.5586590494852854d-06,-.7649848339586152d-06,
     8      -.9432828678320151d-06,-.1050420475048297d-05/
         data arr1503/
     1      -.1065422935921299d-05,-.9934514092294334d-06,
     2      -.8562340070597075d-06,-.6827061839213534d-06,
     3      -.5030114445487630d-06,-.3429419987560436d-06,
     4      -.2205621368259884d-06,-.1711008905001234d-06,
     5      -.1633962626705163d-06,0.1008551288473998d-06,
     6      -.4814859199916341d-07,0.2183031208887251d-07,
     7      -.1014020648790589d-07,0.5065428375048377d-08,
     8      -.2847940607576325d-08,0.1890247530406174d-08/
         data arr1504/
     1      -.1484226290150032d-08,0.1200380600419066d-08,
     2      -.7774413293498812d-09,-.5886859527236819d-09,
     3      -.3899467329969362d-09,-.7640066874490058d-08,
     4      -.1787192537990802d-07,-.4387361980132115d-07,
     5      -.9904678426002377d-07,-.1830665634634030d-06,
     6      -.2963279027423814d-06,-.4338499793918229d-06,
     7      -.5709314392588081d-06,-.6742945678605439d-06,
     8      -.7226483543271447d-06,-.7117313948761670d-06/
         data arr1505/
     1      -.6481922821209126d-06,-.5456483274277972d-06,
     2      -.4235426511526455d-06,-.3036499672680685d-06,
     3      -.2056177654713729d-06,-.1704367193886464d-06,
     4      -.1164568654419236d-06,0.7165355053292720d-07,
     5      -.3408116766467191d-07,0.1539360897365967d-07,
     6      -.7120850611291766d-08,0.3544388711201643d-08,
     7      -.1982267523953172d-08,0.1310656267675938d-08,
     8      -.1025545310355322d-08,0.8376526828132556d-09/
         data arr1506/
     1      -.5222508353361040d-09,-.2408757003243796d-09,
     2      0.3442027948496970d-09,-.3213821534728546d-08,
     3      -.6685777099119481d-08,-.1757701426770844d-07,
     4      -.4411708295064025d-07,-.8664953384522200d-07,
     5      -.1484148824387817d-06,-.2304533234553342d-06,
     6      -.3198124924001618d-06,-.3953802435943709d-06,
     7      -.4412041048509655d-06,-.4505091901682332d-06,
     8      -.4233277989519905d-06,-.3656399038683034d-06/
         data arr1507/
     1      -.2895770358340543d-06,-.2107223941223503d-06,
     2      -.1441306081595082d-06,-.1199915743822780d-06,
     3      -.1175173905794033d-06,0.7352620721724589d-07,
     4      -.3560723477282848d-07,0.1637747847080816d-07,
     5      -.7713873024910620d-08,0.3907697990552064d-08,
     6      -.2230220098607349d-08,0.1501647481027952d-08,
     7      -.1185761383199967d-08,0.9514322195212525d-09,
     8      -.5293387149377087d-09,-.2682328775962591d-09/
         data arr1508/
     1      0.9019165360800353d-09,-.1919978132973247d-08,
     2      -.2427967554618314d-08,-.6150570691329751d-08,
     3      -.1958647724611809d-07,-.4068909385478819d-07,
     4      -.7272705631720479d-07,-.1212902208463563d-06,
     5      -.1806511713489389d-06,-.2368264389019274d-06,
     6      -.2787619260769497d-06,-.3006950797391417d-06,
     7      -.2990882895268936d-06,-.2732268650628870d-06,
     8      -.2282029146448687d-06,-.1747003025858385d-06/
         data arr1509/
     1      -.1258805066457094d-06,-.1121367287225125d-06,
     2      -.6207231700494598d-07,0.3863125415379050d-07,
     3      -.1859896593521032d-07,0.8504859858016225d-08,
     4      -.3981496244908425d-08,0.2006394451342505d-08,
     5      -.1136815040659057d-08,0.7613449108133078d-09,
     6      -.5987292962064050d-09,0.4838110656713233d-09,
     7      -.2760632495584624d-09,-.1154961228920964d-09,
     8      0.4823759669043559d-09,-.8444864863723147d-09/
         data arr1510/
     1      -.7994341612530868d-09,-.2099342196200139d-08,
     2      -.7838364401951128d-08,-.1699141282110540d-07,
     3      -.3167208666881073d-07,-.5537466430836854d-07,
     4      -.8577382558832968d-07,-.1160270921889749d-06,
     5      -.1402396962301610d-06,-.1546327856898026d-06,
     6      -.1564056143696260d-06,-.1445242348526241d-06,
     7      -.1215276119204285d-06,-.9328515998346489d-07,
     8      -.6710285709735413d-07,-.5921916525301090d-07/
         data arr1511/
     1      -.5835470298576280d-07,0.3696639268946250d-07,
     2      -.1813240623545430d-07,0.8444944809399054d-08,
     3      -.4024841291822185d-08,0.2062726287162465d-08,
     4      -.1191601553246017d-08,0.8114109511357513d-09,
     5      -.6438479680961138d-09,0.5109856419013227d-09,
     6      -.2668876666881701d-09,-.1585810734444372d-09,
     7      0.5811094810145213d-09,-.7064338163115277d-09,
     8      -.2826106003559274d-09,-.3106920985689624d-09/
         data arr1512/
     1      -.3454459639127357d-08,-.7705355959770060d-08,
     2      -.1430148127374600d-07,-.2713872826011620d-07,
     3      -.4562953901529354d-07,-.6541557759703002d-07,
     4      -.8314669784297278d-07,-.9684605494535542d-07,
     5      -.1039109765448992d-06,-.1017605963504666d-06,
     6      -.9033371494197588d-07,-.7297579177307100d-07,
     7      -.5532872424756985d-07,-.5231684708971351d-07,
     8      -.2023529001886160d-07,0.1276580051463663d-07/
         data arr1513/
     1      -.6233452469754457d-08,0.2890626572228661d-08,
     2      -.1371120452527032d-08,0.7003321607529513d-09,
     3      -.4022998302335724d-09,0.2729651388029434d-09,
     4      -.2157615253052833d-09,0.1720548630462598d-09,
     5      -.9205085236093316d-10,-.5000071550485584d-10,
     6      0.1941610728550475d-09,-.2333950493056313d-09,
     7      -.7135372409824557d-10,-.5547743758129583d-10,
     8      -.1057636733492349d-08,-.2401439692286996d-08/
         data arr1514/
     1      -.4562661895801428d-08,-.8920728699058065d-08,
     2      -.1532923947495154d-07,-.2234103195788158d-07,
     3      -.2879121551542692d-07,-.3388587588077908d-07,
     4      -.3659532161429023d-07,-.3594373090734084d-07,
     5      -.3191525741996726d-07,-.2573000018510803d-07,
     6      -.1941242987666083d-07,-.1815552444167047d-07,
     7      -.1750007275304115d-07,0.1124013882178772d-07,
     8      -.5590736426623158d-08,0.2638591830324600d-08/
         data arr1515/
     1      -.1273086667971550d-08,0.6601238891922787d-09,
     2      -.3860237122683992d-09,0.2657156659158600d-09,
     3      -.2120392073176514d-09,0.1661846582553880d-09,
     4      -.8204923543830620d-10,-.6010289995873023d-10,
     5      0.1999123526191941d-09,-.2086443599742898d-09,
     6      -.3336490605442265d-10,0.1359282666607408d-09,
     7      -.4882472782520902d-09,-.1093075600614813d-08,
     8      -.1866958756207331d-08,-.4046429030856302d-08/
         data arr1516/
     1      -.7700207798781880d-08,-.1187172442377659d-07,
     2      -.1599369181058382d-07,-.1985637482265301d-07,
     3      -.2278339534373913d-07,-.2374685717003585d-07,
     4      -.2226094446526760d-07,-.1887434558891925d-07,
     5      -.1500096665406373d-07,-.1503070971921953d-07,
     6      0.4057743538238368d-07,0.4211249746718895d-06,
     7      0.2362962403521371d-05,0.8356844645103774d-05,
     8      0.2067421512112453d-04,0.3843602796049177d-04/
         data arr1517/
     1      0.5654137091936707d-04,0.6839253380721998d-04,
     2      0.7006149280469190d-04,0.6220859090559263d-04,
     3      0.4877475217342349d-04,0.3428381887027928d-04,
     4      0.2187551748518861d-04,0.1280342786266927d-04,
     5      0.6934203562060734d-05,0.3500973313769912d-05,
     6      0.1658218897631823d-05,0.7407885616864937d-06,
     7      0.3135786855478941d-06,0.1262728898444684d-06,
     8      0.4853392901364727d-07,0.1785626822147968d-07/
         data arr1518/
     1      0.6303516191142224d-08,0.2139307302509689d-08,
     2      0.6990973177716115d-09,0.2202290520764573d-09,
     3      0.6692095524469467d-10,0.1961598914148888d-10,
     4      0.5559446914789132d-11,0.1707998383597509d-11,
     5      0.9929624601553576d-08,0.1466016943523625d-06,
     6      0.1102643540357666d-05,0.4996402727569135d-05,
     7      0.1531070921042344d-04,0.3434472160542186d-04,
     8      0.5969888819770418d-04,0.8388825865327081d-04/
         data arr1519/
     1      0.9843456084035738d-04,0.9893571411936136d-04,
     2      0.8692743192108851d-04,0.6788072174570118d-04,
     3      0.4775777314772752d-04,0.3061835802396875d-04,
     4      0.1805940832701215d-04,0.9879031209967285d-05,
     5      0.5046568440854594d-05,0.2421560726463088d-05,
     6      0.1096962941356174d-05,0.4711439095509096d-06,
     7      0.1925650817847754d-06,0.7513161479862605d-07,
     8      0.2805650545947171d-07,0.1004982892794066d-07/
         data arr1520/
     1      0.3459106768884672d-08,0.1145590946064464d-08,
     2      0.3653451011475580d-09,0.1122175725219668d-09,
     3      0.3329415335851344d-10,0.1076252621032048d-10,
     4      0.1870854846409120d-08,0.3498582203669501d-07,
     5      0.3536084742624829d-06,0.2052785781730879d-05,
     6      0.7791749759830476d-05,0.2108893661594830d-04,
     7      0.4331510467868524d-04,0.7070772651131736d-04,
     8      0.9503619514905317d-04,0.1081257246865173d-03/
         data arr1521/
     1      0.1064613179703885d-03,0.9235851062606889d-04,
     2      0.7164782497484531d-04,0.5031653732557495d-04,
     3      0.3232091580590847d-04,0.1915636587829148d-04,
     4      0.1055416034432328d-04,0.5439633903919277d-05,
     5      0.2637002693701224d-05,0.1208009210908699d-05,
     6      0.5250285014400437d-06,0.2172341054973121d-06,
     7      0.8581385259352357d-07,0.3244271661083442d-07,
     8      0.1176155322808579d-07,0.4095102197393533d-08/
         data arr1522/
     1      0.1370687816537516d-08,0.4411979758993970d-09,
     2      0.1370416773458028d-09,0.4659863704619545d-10,
     3      0.9979792300893733d-09,0.6333657365408536d-08,
     4      0.9022466162422362d-07,0.6702250381510459d-06,
     5      0.3151303670591471d-05,0.1029112795475930d-04,
     6      0.2497619940436573d-04,0.4736378272160366d-04,
     7      0.7291960371641354d-04,0.9391150271247464d-04,
     8      0.1036192992952501d-03,0.9986681802505391d-04/
         data arr1523/
     1      0.8542318798530907d-04,0.6571332169064239d-04,
     2      0.4597032973583726d-04,0.2952063595850781d-04,
     3      0.1754143175527204d-04,0.9710862449524745d-05,
     4      0.5037823991896249d-05,0.2461505031426912d-05,
     5      0.1137632753862885d-05,0.4991683178407692d-06,
     6      0.2085904000149274d-06,0.8323150119229829d-07,
     7      0.3178155976731371d-07,0.1163328121739066d-07,
     8      0.4086481550718467d-08,0.1378185614637904d-08/
         data arr1524/
     1      0.4479930551279237d-09,0.1600906255956909d-09,
     2      0.2482324309345289d-08,0.8133491769555406d-11,
     3      0.1976279198296158d-07,0.1845969438374243d-06,
     4      0.1075856237722161d-05,0.4238987183627774d-05,
     5      0.1215642888294476d-04,0.2678047433885620d-04,
     6      0.4722717986109563d-04,0.6884952889414699d-04,
     7      0.8512985696253241d-04,0.9115026526214727d-04,
     8      0.8596882094773469d-04,0.7244168379824183d-04/
         data arr1525/
     1      0.5519045935151627d-04,0.3839995567210483d-04,
     2      0.2460927614277545d-04,0.1463316835793189d-04,
     3      0.8123960419036150d-05,0.4233734876839163d-05,
     4      0.2080721292975373d-05,0.9681856853153450d-06,
     5      0.4279803090789588d-06,0.1802403532834964d-06,
     6      0.7249123804085569d-07,0.2789685707242250d-07,
     7      0.1028514404158343d-07,0.3635059687195048d-08,
     8      0.1237204663988267d-08,0.4655201023507235d-09/
         data arr1526/
     1      0.6672600896396540d-08,-.2728441506033616d-08,
     2      0.4669835970620262d-08,0.4407489571144771d-07,
     3      0.3207123877864049d-06,0.1524051342433548d-05,
     4      0.5164610212689054d-05,0.1321722220550873d-04,
     5      0.2669870291534700d-04,0.4405888060224702d-04,
     6      0.6104829241368763d-04,0.7261811979930840d-04,
     7      0.7551904685310728d-04,0.6970661855383202d-04,
     8      0.5783633034865777d-04,0.4359995754577436d-04/
         data arr1527/
     1      0.3013582048272999d-04,0.1924727635468500d-04,
     2      0.1143517621639027d-04,0.6356190352750619d-05,
     3      0.3321820296295847d-05,0.1639155570696863d-05,
     4      0.7664808130242854d-06,0.3406910740474263d-06,
     5      0.1443219846722231d-06,0.5838790620023362d-07,
     6      0.2259037582437821d-07,0.8364032193183398d-08,
     7      0.2978355336306552d-08,0.1177546594576443d-08,
     8      0.1605542098601151d-07,-.6920331169713332d-08/
         data arr1528/
     1      0.3096758945287022d-08,0.8649830047143758d-08,
     2      0.8553058412325065d-07,0.4886007583870496d-06,
     3      0.1956980751762828d-05,0.5817925001934319d-05,
     4      0.1346159262377496d-04,0.2514626285004697d-04,
     5      0.3904567173840859d-04,0.5159881518110352d-04,
     6      0.5916701797470755d-04,0.5982286874942354d-04,
     7      0.5405614860974963d-04,0.4415186533202610d-04,
     8      0.3291356808083357d-04,0.2257916577097225d-04/
         data arr1529/
     1      0.1435573586975447d-04,0.8510946756589487d-05,
     2      0.4729842085331763d-05,0.2475085588331170d-05,
     3      0.1224299515374966d-05,0.5743576866830110d-06,
     4      0.2562758251110576d-06,0.1090074809592851d-06,
     5      0.4426729919886587d-07,0.1717684849563104d-07,
     6      0.6405681348269693d-08,0.2669511729369032d-08,
     7      0.3481359549536660d-07,-.1502707298840407d-07,
     8      0.5476417409852651d-08,-.6346022014211620d-10/
         data arr1530/
     1      0.2122060721292295d-07,0.1416153974591599d-06,
     2      0.6715387409160571d-06,0.2318788090418691d-05,
     3      0.6145806277844053d-05,0.1299531297499251d-04,
     4      0.2261239657405918d-04,0.3319773312658979d-04,
     5      0.4197365593963551d-04,0.4648733360315587d-04,
     6      0.4574708359762025d-04,0.4048424014502533d-04,
     7      0.3254925897038110d-04,0.2398394000933698d-04,
     8      0.1631855614591292d-04,0.1031888240101590d-04/
         data arr1531/
     1      0.6098050381942646d-05,0.3384013942952008d-05,
     2      0.1770680623468392d-05,0.8767164151912691d-06,
     3      0.4120155442893148d-06,0.1842294801632154d-06,
     4      0.7849867242225379d-07,0.3189812354397294d-07,
     5      0.1243892736223392d-07,0.5443063954164812d-08,
     6      0.7044967360630081d-07,-.3044894378201353d-07,
     7      0.1092892135224391d-07,-.3557799952581638d-08,
     8      0.5974768627738508d-08,0.3713643019430635d-07/
         data arr1532/
     1      0.2112119882094278d-06,0.8461847263062428d-06,
     2      0.2569413465920189d-05,0.6149773718297952d-05,
     3      0.1199178204906050d-04,0.1955866667725163d-04,
     4      0.2726691021590195d-04,0.3307994791466338d-04,
     5      0.3545225090975896d-04,0.3399265094406548d-04,
     6      0.2947609718884693d-04,0.2332896977629227d-04,
     7      0.1698633897832991d-04,0.1145645059097280d-04,
     8      0.7199459200711733d-05,0.4236817343775255d-05/
         data arr1533/
     1      0.2345097726153430d-05,0.1225511457555064d-05,
     2      0.6066555478046287d-06,0.2852178881621625d-06,
     3      0.1275677064124597d-06,0.5433228451490746d-07,
     4      0.2219645794910164d-07,0.1025265017372765d-07,
     5      0.1290806486298207d-06,-.5573285383137690d-07,
     6      0.1997074320447825d-07,-.7053595031633249d-08,
     7      0.3583443238127211d-08,0.8180607284362559d-08,
     8      0.6171821027600756d-07,0.2850734276906203d-06/
         data arr1534/
     1      0.9924235340323986d-06,0.2688300724095777d-05,
     2      0.5874681529438222d-05,0.1064458577737847d-04,
     3      0.1636264601413229d-04,0.2174480758678387d-04,
     4      0.2537949691645269d-04,0.2636592210660917d-04,
     5      0.2465806539854060d-04,0.2096186397652785d-04,
     6      0.1633336829693308d-04,0.1174967058131531d-04,
     7      0.7851745937602644d-05,0.4900017856001378d-05,
     8      0.2868893051516716d-05,0.1582248839623602d-05/
         data arr1535/
     1      0.8248978186202183d-06,0.4076305642632198d-06,
     2      0.1912299514457059d-06,0.8523762590114697d-07,
     3      0.3637693198724063d-07,0.1761791785465823d-07,
     4      0.2251158978846875d-06,-.9733528178206403d-07,
     5      0.3491209023114649d-07,-.1243114067819329d-07,
     6      0.4838375385227904d-08,0.2111508806651283d-09,
     7      0.1740211444548145d-07,0.8902046431542975d-07,
     8      0.3567845959883100d-06,0.1093056432208110d-05/
         data arr1536/
     1      0.2677352725912500d-05,0.5389153045514589d-05,
     2      0.9134245269971695d-05,0.1329702809449625d-04,
     3      0.1690149883359530d-04,0.1902410308381121d-04,
     4      0.1918910276305297d-04,0.1752141711267382d-04,
     5      0.1461014189037228d-04,0.1121004576176370d-04,
     6      0.7966089588925652d-05,0.5271973114783274d-05,
     7      0.3265096997613925d-05,0.1900644730054149d-05,
     8      0.1043836980941909d-05,0.5424350296710993d-06/
         data arr1537/
     1      0.2671547720616569d-06,0.1248353176958464d-06,
     2      0.5584157990621635d-07,0.2859845095986165d-07,
     3      0.3545541610110151d-06,-.1531469402164874d-06,
     4      0.5490025192417511d-07,-.1955098995328103d-07,
     5      0.7362902750509422d-08,-.2540926158599097d-08,
     6      0.5549692959084280d-08,0.2551930646952288d-07,
     7      0.1203160029029185d-06,0.4156090617848664d-06,
     8      0.1141807677508471d-05,0.2552780570078999d-05/
         data arr1538/
     1      0.4770808506468803d-05,0.7608016998689060d-05,
     2      0.1053106394798912d-04,0.1284314047099197d-04,
     3      0.1397212258545555d-04,0.1370302597211478d-04,
     4      0.1222743973326722d-04,0.1000670988114025d-04,
     5      0.7561724476584812d-05,0.5306640708005215d-05,
     6      0.3476114119190662d-05,0.2135224526660279d-05,
     7      0.1234772507500622d-05,0.6741552337658258d-06,
     8      0.3479871638817567d-06,0.1699566166871028d-06/
         data arr1539/
     1      0.7927346304854745d-07,0.4244771206818257d-07,
     2      0.5467852562375596d-06,-.2365673647231474d-06,
     3      0.8491274112255460d-07,-.3027943919766335d-07,
     4      0.1136807892666899d-07,-.4558175408594436d-08,
     5      0.3125082737930538d-08,0.6085653371969664d-08,
     6      0.3863385029824326d-07,0.1482078730154993d-06,
     7      0.4580571580272931d-06,0.1136811504191490d-05,
     8      0.2342554546991316d-05,0.4092858178490700d-05/
         data arr1540/
     1      0.6169037261467478d-05,0.8151531002462343d-05,
     2      0.9565091559401485d-05,0.1007568691938630d-04,
     3      0.9620973385214341d-05,0.8398299161563240d-05,
     4      0.6748944671986844d-05,0.5022566109077129d-05,
     5      0.3480102484040805d-05,0.2256349756744272d-05,
     6      0.1374784221496671d-05,0.7895370654724136d-06,
     7      0.4279821560016061d-06,0.2192070344442793d-06,
     8      0.1072516700015799d-06,0.6086533160635815d-07/
         data arr1541/
     1      0.7515863997047147d-06,-.3248009863702267d-06,
     2      0.1165055943890752d-06,-.4152066732078326d-07,
     3      0.1558273777896671d-07,-.6350285380714168d-08,
     4      0.3149336733921279d-08,0.3021686823181895d-09,
     5      0.1235107111983436d-07,0.4942957033756579d-07,
     6      0.1737955533142260d-06,0.4778413961464192d-06,
     7      0.1085700429601458d-05,0.2078989643225594d-05,
     8      0.3411446762499709d-05,0.4884179096363911d-05/
         data arr1542/
     1      0.6182020188359915d-05,0.6994031295465482d-05,
     2      0.7146208326757143d-05,0.6653635964334033d-05,
     3      0.5685776138135011d-05,0.4486237306372772d-05,
     4      0.3286822375605264d-05,0.2247884114744780d-05,
     5      0.1441383068225763d-05,0.8689062530147614d-06,
     6      0.4928850243348162d-06,0.2632665379258286d-06,
     7      0.1339124311399992d-06,0.7910949040507634d-07,
     8      0.1040210933048100d-05,-.4504464724013069d-06/
         data arr1543/
     1      0.1618411030791594d-06,-.5777472684817344d-07,
     2      0.2170466753030308d-07,-.8890228106122636d-08,
     3      0.4134134539503114d-08,-.1762866591100448d-08,
     4      0.4668310865561418d-08,0.1491090469998613d-07,
     5      0.6294257138999656d-07,0.1901653319408036d-06,
     6      0.4764083577217110d-06,0.1001064334855459d-05,
     7      0.1787051377124584d-05,0.2772326689337048d-05,
     8      0.3785909452404384d-05,0.4599810595811263d-05/
         data arr1544/
     1      0.5028747036738381d-05,0.4994694356447687d-05,
     2      0.4539500734208111d-05,0.3798188973557554d-05,
     3      0.2943290199936624d-05,0.2124945241837240d-05,
     4      0.1436146309107445d-05,0.9111108415576684d-06,
     5      0.5430060192297888d-06,0.3043352081426862d-06,
     6      0.1625525990095762d-06,0.1020466590309530d-06,
     7      0.1246430501602937d-05,-.5390060712577191d-06,
     8      0.1934996484365224d-06,-.6902397965980093d-07/
         data arr1545/
     1      0.2592970147951040d-07,-.1060822265508201d-07,
     2      0.4893472211224773d-08,-.2541208240575420d-08,
     3      0.2622839495447480d-08,0.3502039410587801d-08,
     4      0.2217486658352448d-07,0.7179022791995780d-07,
     5      0.1983685452516713d-06,0.4586504543756227d-06,
     6      0.8894005122206157d-06,0.1495269827308815d-05,
     7      0.2203774280930485d-05,0.2874878088228043d-05,
     8      0.3362244810381472d-05,0.3562068671746439d-05/
         data arr1546/
     1      0.3442220438686253d-05,0.3052045293447295d-05,
     2      0.2498793731991206d-05,0.1901051474032741d-05,
     3      0.1350268312628143d-05,0.8972949740805947d-06,
     4      0.5579162615423794d-06,0.3247932704868485d-06,
     5      0.1794667817713022d-06,0.1164603300929240d-06,
     6      0.1564829501764403d-05,-.6784189744123587d-06,
     7      0.2440657794624210d-06,-.8725223483352608d-07,
     8      0.3282501343787248d-07,-.1347550896730611d-07/
         data arr1547/
     1      0.6205548939483406d-08,-.3371089731924628d-08,
     2      0.2470596535085574d-08,-.3713898164465863d-09,
     3      0.8151715592324665d-08,0.2564121621627578d-07,
     4      0.7819271259344329d-07,0.2011137504368285d-06,
     5      0.4214148618390295d-06,0.7681039610917927d-06,
     6      0.1223251296077678d-05,0.1712643449407813d-05,
     7      0.2142143581373547d-05,0.2421924286054390d-05,
     8      0.2490135222660744d-05,0.2341063555407407d-05/
         data arr1548/
     1      0.2027014070069105d-05,0.1628405721337146d-05,
     2      0.1219982108409975d-05,0.8539448077676274d-06,
     3      0.5583110313757505d-06,0.3413426551707019d-06,
     4      0.1983389943454729d-06,0.1372040441251516d-06,
     5      0.1626670669996357d-05,-.7040298029605780d-06,
     6      0.2530071972196910d-06,-.9035780438359769d-07,
     7      0.3398793190413655d-07,-.1392672255985594d-07,
     8      0.6424040942690393d-08,-.3490180618308813d-08/
         data arr1549/
     1      0.2386944722354895d-08,-.1443171797837513d-08,
     2      0.3464244439497547d-08,0.8589365068233833d-08,
     3      0.2906281880008003d-07,0.8489317979888861d-07,
     4      0.1904273426258497d-06,0.3766249483869065d-06,
     5      0.6489130443639649d-06,0.9742382653588279d-06,
     6      0.1302360856936464d-05,0.1570571693476385d-05,
     7      0.1716060237819650d-05,0.1707177095673857d-05,
     8      0.1558631255784139d-05,0.1316375275712299d-05/
         data arr1550/
     1      0.1033341529727871d-05,0.7546118458563568d-06,
     2      0.5121191801106857d-06,0.3232971569299254d-06,
     3      0.1930387853795127d-06,0.1368290489051103d-06,
     4      0.1867315695553864d-05,-.8107564417635476d-06,
     5      0.2921454460467115d-06,-.1046252564158402d-06,
     6      0.3942890294854784d-07,-.1622492233631668d-07,
     7      0.7485142593108260d-08,-.4114770055983928d-08,
     8      0.2746110772293955d-08,-.2073058969202425d-08/
         data arr1551/
     1      0.2173925389454462d-08,0.2539555252461673d-08,
     2      0.9667440140061885d-08,0.3536724444896038d-07,
     3      0.8187489206370126d-07,0.1761977489077215d-06,
     4      0.3305282026976403d-06,0.5311082158261480d-06,
     5      0.7580520438372372d-06,0.9768776400634740d-06,
     6      0.1136782746617998d-05,0.1198832855309400d-05,
     7      0.1157179524626699d-05,0.1032600061974329d-05,
     8      0.8560954664405501d-06,0.6594125245505390d-06/
         data arr1552/
     1      0.4710893853400944d-06,0.3126654057385819d-06,
     2      0.1966363640879488d-06,0.1490537032312345d-06,
     3      0.1643983449669493d-05,-.7122171456355016d-06,
     4      0.2562602585807392d-06,-.9164457436913327d-07,
     5      0.3452334663487786d-07,-.1417078445983395d-07,
     6      0.6550490216958011d-08,-.3575070903160287d-08,
     7      0.2395860173979535d-08,-.1856972047153451d-08,
     8      0.1537750336017327d-08,0.5737380491473008d-09/
         data arr1553/
     1      0.2726631006109819d-08,0.1465377856029260d-07,
     2      0.3349937603401650d-07,0.7881344863225798d-07,
     3      0.1615113371764024d-06,0.2769542064770291d-06,
     4      0.4212174146725186d-06,0.5786373473162124d-06,
     5      0.7141265177299695d-06,0.7938628415881144d-06,
     6      0.8042572467749681d-06,0.7505707512478544d-06,
     7      0.6479765669368038d-06,0.5168752379458291d-06,
     8      0.3801173971338237d-06,0.2581933455100251d-06/
         data arr1554/
     1      0.1652793065504134d-06,0.1268293032080570d-06,
     2      0.1736920752514500d-05,-.7554700026834954d-06,
     3      0.2727429098482448d-06,-.9788035659386395d-07,
     4      0.3696137151440317d-07,-.1525172330009648d-07,
     5      0.7052816262548081d-08,-.3899060940757503d-08,
     6      0.2595406295775362d-08,-.2066085641081403d-08,
     7      0.1497580960584877d-08,-.8378400554859513d-10,
     8      0.1810750973260717d-10,0.6848330418447791d-08/
         data arr1555/
     1      0.1268788219036672d-07,0.3325102856249444d-07,
     2      0.7683870846930164d-07,0.1394853709594270d-06,
     3      0.2252437226630999d-06,0.3319893842914109d-06,
     4      0.4374888484022442d-06,0.5152497653283692d-06,
     5      0.5515470370150307d-06,0.5444189387640275d-06,
     6      0.4974312488444683d-06,0.4193468167438830d-06,
     7      0.3251198508184629d-06,0.2324803128978273d-06,
     8      0.1570299846227355d-06,0.1292775581760467d-06/
         data arr1556/
     1      0.1256305076807704d-05,-.5449399484483631d-06,
     2      0.1963754967038676d-06,-.7035016722840608d-07,
     3      0.2655159250699112d-07,-.1092260605415935d-07,
     4      0.5062795436792227d-08,-.2773825838999027d-08,
     5      0.1862941198293381d-08,-.1465668455128584d-08,
     6      0.1061139280706186d-08,-.1785495046402485d-09,
     7      -.4655499052249889d-09,0.3215081048422992d-08,
     8      0.4481431107777891d-08,0.1337014221401694d-07/
         data arr1557/
     1      0.3487358660783727d-07,0.6658029216678177d-07,
     2      0.1136507136009071d-06,0.1780850040390141d-06,
     3      0.2474826496306751d-06,0.3047938532772478d-06,
     4      0.3395190206377689d-06,0.3473707113929993d-06,
     5      0.3273144713006547d-06,0.2828560371995592d-06,
     6      0.2234629948341621d-06,0.1619387828209187d-06,
     7      0.1102783500022964d-06,0.9091092835707024d-07,
     8      0.1225271162376647d-05,-.5341030684359997d-06/
         data arr1558/
     1      0.1932745498077868d-06,-.6953722006182647d-07,
     2      0.2632144764007274d-07,-.1089789170804238d-07,
     3      0.5053017022833415d-08,-.2811994756288644d-08,
     4      0.1875140424891513d-08,-.1503297211502750d-08,
     5      0.1037873229618180d-08,-.2195653916829058d-09,
     6      -.8217105293118541d-09,0.2160363338190988d-08,
     7      0.1166354393823852d-08,0.4680813763923872d-08,
     8      0.1607606853154870d-07,0.3135257704701674d-07/
         data arr1559/
     1      0.5586641421948307d-07,0.9495136427187842d-07,
     2      0.1416909686390602d-06,0.1846095261584139d-06,
     3      0.2169822831596846d-06,0.2351330875930300d-06,
     4      0.2351193635900541d-06,0.2152135539322417d-06,
     5      0.1794919490064359d-06,0.1370740271269120d-06,
     6      0.9862978417655555d-07,0.8743315862597899d-07,
     7      0.6569505769955730d-06,-.2853347657120091d-06,
     8      0.1029909279067411d-06,-.3696304312008968d-07/
         data arr1560/
     1      0.1397822142030210d-07,-.5763520408694513d-08,
     2      0.2679028674599447d-08,-.1473603017624734d-08,
     3      0.9930510980623926d-09,-.7826915954255682d-09,
     4      0.5550067553169263d-09,-.1222859160308617d-09,
     5      -.4443299658939143d-09,0.1023554038888882d-08,
     6      0.2568031981841705d-09,0.1590217132746702d-08,
     7      0.6592049605941892d-08,0.1317082749712428d-07,
     8      0.2444905843612088d-07,0.4368588207572047d-07/
         data arr1561/
     1      0.6775696755782134d-07,0.9097645989351906d-07,
     2      0.1096995045892058d-06,0.1213984631587295d-06,
     3      0.1232709307259228d-06,0.1139409916357695d-06,
     4      0.9549511348648573d-07,0.7296292609204835d-07,
     5      0.5226729901709240d-07,0.4570737540518807d-07,
     6      0.5976098899405749d-06,-.2611107778362578d-06,
     7      0.9471797820071067d-07,-.3416782302896868d-07,
     8      0.1296490006402840d-07,-.5386650882425301d-08/
         data arr1562/
     1      0.2504115116598422d-08,-.1403106259154452d-08,
     2      0.9372840939584001d-09,-.7548566773700770d-09,
     3      0.5112802266961793d-09,-.1084604752787805d-09,
     4      -.4825663582836398d-09,0.8620379607652786d-09,
     5      -.1503274995326842d-09,0.2303668455739862d-09,
     6      0.3140447469935567d-08,0.5913853624529865d-08,
     7      0.1098213958238638d-07,0.2181770278208944d-07,
     8      0.3671512794077899d-07,0.5201007101077679d-07/
         data arr1563/
     1      0.6601009356775746d-07,0.7749873417799885d-07,
     2      0.8377687720567636d-07,0.8221816910126494d-07,
     3      0.7284439158873020d-07,0.5870888068790839d-07,
     4      0.4449266177826747d-07,0.4192513242519277d-07,
     5      0.2112390650873502d-06,-.9191875620037960d-07,
     6      0.3325404648488933d-07,-.1196533976244204d-07,
     7      0.4537443527692154d-08,-.1876928887606820d-08,
     8      0.8758673540301620d-09,-.4844252181388812d-09/
         data arr1564/
     1      0.3279764513931976d-09,-.2589444364089758d-09,
     2      0.1810295166664821d-09,-.3720730290912556d-10,
     3      -.1631432334279202d-09,0.2950522152503101d-09,
     4      -.6943429345260963d-10,0.3911547025772840d-10,
     5      0.9877420626625774d-09,0.1855680116976233d-08,
     6      0.3524243851254859d-08,0.7231984950139945d-08,
     7      0.1242893071357265d-07,0.1788392753556460d-07,
     8      0.2299552624112236d-07,0.2725427713297455d-07/
         data arr1565/
     1      0.2961648887511162d-07,0.2911399894506571d-07,
     2      0.2576698572994910d-07,0.2069206549763912d-07,
     3      0.1557442325143810d-07,0.1447298597378025d-07,
     4      0.1781000896448834d-06,-.7807523402737633d-07,
     5      0.2841466953532976d-07,-.1028577478056452d-07,
     6      0.3914671612633163d-08,-.1634071721069320d-08,
     7      0.7617118136436022d-09,-.4308922115382062d-09,
     8      0.2880571575196655d-09,-.2337690277719966d-09/
         data arr1566/
     1      0.1546972770862416d-09,-.2969739146596481d-10,
     2      -.1585625183036238d-09,0.2532871965594924d-09,
     3      -.9247561520791855d-10,-.1050502400593903d-09,
     4      0.5171892696006622d-09,0.8195850348596477d-09,
     5      0.1414123222614749d-08,0.3397125494867926d-08,
     6      0.6441416309357977d-08,0.9727870130756500d-08,
     7      0.1309935276498183d-07,0.1648106840426538d-07,
     8      0.1911395730180877d-07,0.1997794575376335d-07/
         data arr1567/
     1      0.1869350085709802d-07,0.1582880346914184d-07,
     2      0.1260014012813615d-07,0.1261378777041580d-07,
     3      0.1559136583902051d-13,-.3519631876496678d-07,
     4      -.2597394540856718d-06,-.1177703147805440d-05,
     5      -.3608757606587746d-05,-.8095132073515035d-05,
     6      -.1407116154377769d-04,-.1977265279831596d-04,
     7      -.2320124812768044d-04,-.2331937167625389d-04,
     8      -.2048899206916373d-04,-.1599963953473781d-04/
         data arr1568/
     1      -.1125661520685791d-04,-.7216816043827746d-05,
     2      -.4256643391441222d-05,-.2328510087840292d-05,
     3      -.1189487492655941d-05,-.5707672794395904d-06,
     4      -.2585567363889312d-06,-.1110497188036095d-06,
     5      -.4538794092370827d-07,-.1770863931974401d-07,
     6      -.6613032108483659d-08,-.2368831698064812d-08,
     7      -.8153114491774605d-09,-.2699558558261132d-09,
     8      -.8606414467792268d-10,-.2644930239094030d-10/
         data arr1569/
     1      -.7878034581802699d-11,-.2557042159103033d-11,
     2      0.1100983989872829d-14,-.1152345537922914d-07,
     3      -.1146818358947289d-06,-.6660234655020488d-06,
     4      -.2527973902412161d-05,-.6842155748061231d-05,
     5      -.1405327518654194d-04,-.2294061599990663d-04,
     6      -.3083381312443317d-04,-.3508061754181229d-04,
     7      -.3454061253195617d-04,-.2996505769744224d-04,
     8      -.2324562403611024d-04,-.1632484030041551d-04/
         data arr1570/
     1      -.1048628981753784d-04,-.6215145848384646d-05,
     2      -.3424221714681474d-05,-.1764850260501178d-05,
     3      -.8555567171306841d-06,-.3919299563681838d-06,
     4      -.1703416753762177d-06,-.7048002296688231d-07,
     5      -.2784173782600037d-07,-.1052585361157183d-07,
     6      -.3815935581374696d-08,-.1328570616098927d-08,
     7      -.4446690575452939d-09,-.1431384026905584d-09,
     8      -.4446540891303384d-10,-.1503529448243490d-10/
         data arr1571/
     1      0.3190687692607682d-13,-.2584523635318726d-08,
     2      -.3490345434280451d-07,-.2595901361319999d-06,
     3      -.1220489991414529d-05,-.3985738575632911d-05,
     4      -.9673239577674253d-05,-.1834391462863104d-04,
     5      -.2824164076626602d-04,-.3637176883295062d-04,
     6      -.4013158189053831d-04,-.3867825232438653d-04,
     7      -.3308425858491011d-04,-.2545065982265536d-04,
     8      -.1780423224333307d-04,-.1143329329148079d-04/
         data arr1572/
     1      -.6793767099960055d-05,-.3761000792517248d-05,
     2      -.1951141056862990d-05,-.9533368319372083d-06,
     3      -.4406030613720144d-06,-.1933269810088502d-06,
     4      -.8078688331175460d-07,-.3223557692069359d-07,
     5      -.1230888897422069d-07,-.4505365582554319d-08,
     6      -.1582556155951463d-08,-.5337526341571026d-09,
     7      -.1734996802540271d-09,-.6161519973264479d-10,
     8      0.1845716200621684d-13,-.3958540318350987d-09/
         data arr1573/
     1      -.8498993430506613d-08,-.8060702564738602d-07,
     2      -.4695267352112793d-06,-.1850051942255792d-05,
     3      -.5305497645363863d-05,-.1168795880909298d-04,
     4      -.2061163004932390d-04,-.3004839869286244d-04,
     5      -.3715371502383231d-04,-.3978123725784480d-04,
     6      -.3751986995945883d-04,-.3161614202444269d-04,
     7      -.2408709156064362d-04,-.1675911514176018d-04,
     8      -.1074036793200667d-04,-.6386438066143435d-05/
         data arr1574/
     1      -.3545587769668143d-05,-.1847753489641138d-05,
     2      -.9081004875822507d-06,-.4225506159089015d-06,
     3      -.1867865042535495d-06,-.7866384864213605d-07,
     4      -.3163752952418748d-07,-.1217450420069222d-07,
     5      -.4488326634546448d-08,-.1586399971561832d-08,
     6      -.5399216575241659d-09,-.2018062588195583d-09,
     7      0.2226476576536584d-12,0.1488187657015294d-09,
     8      -.1855221079278874d-08,-.2113631384130364d-07/
         data arr1575/
     1      -.1528482074914206d-06,-.7265813128926056d-06,
     2      -.2462122803566236d-05,-.6301068047631107d-05,
     3      -.1272810408114936d-04,-.2100424951859963d-04,
     4      -.2910362984361092d-04,-.3461933052812373d-04,
     5      -.3600229435173639d-04,-.3323132419070328d-04,
     6      -.2757238967387935d-04,-.2078546566118524d-04,
     7      -.1436668661155136d-04,-.9175778431752183d-05,
     8      -.5451508573938474d-05,-.3030195140479422d-05/
         data arr1576/
     1      -.1583613587961567d-05,-.7814361061688030d-06,
     2      -.3654072338633957d-06,-.1624197447329375d-06,
     3      -.6880230703322964d-07,-.2783359463988953d-07,
     4      -.1076839684500960d-07,-.3987413419241211d-08,
     5      -.1419934254550833d-08,-.5575549029458170d-09,
     6      0.1088526383169154d-12,0.5260054660259454d-09,
     7      -.6070519384822490d-09,-.4745484157073048d-08,
     8      -.4356580526959870d-07,-.2496029981290873d-06/
         data arr1577/
     1      -.9995134739210282d-06,-.2971540085008026d-05,
     2      -.6875553197129841d-05,-.1284355844101234d-04,
     3      -.1994272569250373d-04,-.2635429787504203d-04,
     4      -.3021978988088317d-04,-.3055475872834321d-04,
     5      -.2760939253128965d-04,-.2255074201399100d-04,
     6      -.1681072847225696d-04,-.1153239611530005d-04,
     7      -.7332254113577729d-05,-.4347000051880108d-05,
     8      -.2415779826524481d-05,-.1264157843020254d-05/
         data arr1578/
     1      -.6253202599656652d-06,-.2933592123679345d-06,
     2      -.1308919778839309d-06,-.5567087233687931d-07,
     3      -.2260621092645466d-07,-.8772740243223008d-08,
     4      -.3271502821684894d-08,-.1353235565231091d-08,
     5      0.1065720307098252d-11,0.1239814363176064d-08,
     6      -.7313329939261072d-09,-.7137575934815206d-09,
     7      -.1118757327824582d-07,-.7659107186786638d-07,
     8      -.3626215599728327d-06,-.1252316083418553d-05/
         data arr1579/
     1      -.3319096246194427d-05,-.7018284992744136d-05,
     2      -.1221208018684788d-04,-.1792882674818795d-04,
     3      -.2266837306288955d-04,-.2510601590248471d-04,
     4      -.2470625516799096d-04,-.2186399704806220d-04,
     5      -.1757859645503010d-04,-.1295280504934032d-04,
     6      -.8813040795443223d-05,-.5572835079634975d-05,
     7      -.3293311416739512d-05,-.1827573224046867d-05,
     8      -.9562885392261132d-06,-.4734914763068242d-06/
         data arr1580/
     1      -.2225117024811736d-06,-.9948602068549974d-07,
     2      -.4238859552090889d-07,-.1722822242775393d-07,
     3      -.6719104932284892d-08,-.2918168431536433d-08,
     4      0.4772702080235645d-12,0.2444212792820061d-08,
     5      -.1366055125058249d-08,0.3906488855697910d-09,
     6      -.2789579743935191d-08,-.2124562945202299d-07,
     7      -.1193708140735161d-06,-.4787334728286357d-06,
     8      -.1453440868913179d-05,-.3478867290635251d-05/
         data arr1581/
     1      -.6783555937687099d-05,-.1106405716165159d-04,
     2      -.1542451073017784d-04,-.1871281577837631d-04,
     3      -.2005483578945695d-04,-.1922916507304828d-04,
     4      -.1667417210722463d-04,-.1319685262097291d-04,
     5      -.9608952470949529d-05,-.6480749590720553d-05,
     6      -.4072602059308326d-05,-.2396697662468957d-05,
     7      -.1326609800784310d-05,-.6932719043497895d-06,
     8      -.3431663883409533d-06,-.1613186954211272d-06/
         data arr1582/
     1      -.7214685183361812d-07,-.3073372860424696d-07,
     2      -.1255564414278844d-07,-.5751075200549063d-08,
     3      0.4055778297154206d-11,0.4666784911803679d-08,
     4      -.2585253179274317d-08,0.1064825005205732d-08,
     5      -.9845390518507063d-09,-.5264617690947518d-08,
     6      -.3610446312705475d-07,-.1678336007100362d-06,
     7      -.5838163419503710d-06,-.1581713290610200d-05,
     8      -.3456320015683132d-05,-.6262733164325703d-05/
         data arr1583/
     1      -.9626967900814965d-05,-.1279346816304580d-04,
     2      -.1493201307772479d-04,-.1551238112711632d-04,
     3      -.1450748288101006d-04,-.1233286913466937d-04,
     4      -.9609764883584522d-05,-.6912905960818104d-05,
     5      -.4619514874322321d-05,-.2882909473943313d-05,
     6      -.1687960782311040d-05,-.9309602991648492d-06,
     7      -.4853240915492041d-06,-.2397987177238804d-06,
     8      -.1124959138433626d-06,-.5016216879708738d-07/
         data arr1584/
     1      -.2141366379221644d-07,-.1028633062918703d-07,
     2      0.2061235947519902d-11,0.7569709634688406d-08,
     3      -.4266817074786681d-08,0.1832298358350385d-08,
     4      -.8615538532530839d-09,-.9648433906546007d-09,
     5      -.1021126183761655d-07,-.5438048905073103d-07,
     6      -.2169988457022340d-06,-.6653155456225294d-06,
     7      -.1629314071328506d-05,-.3279752004086940d-05,
     8      -.5558980212020842d-05,-.8092216198995616d-05/
         data arr1585/
     1      -.1028597585802860d-04,-.1157775862747250d-04,
     2      -.1167802448353024d-04,-.1066317950786151d-04,
     3      -.8891545468142405d-05,-.6822221481861122d-05,
     4      -.4847914986757205d-05,-.3208396696861260d-05,
     5      -.1987152922820788d-05,-.1156755100040798d-05,
     6      -.6352231549323085d-06,-.3300311816309570d-06,
     7      -.1625330678415554d-06,-.7597186249383714d-07,
     8      -.3398434355318413d-07,-.1724034421727014d-07/
         data arr1586/
     1      0.1260445704448943d-10,0.1234459631748657d-07,
     2      -.6925729858070952d-08,0.2978086536592800d-08,
     3      -.1241414005317121d-08,0.2429660672223355d-09,
     4      -.2862917104616558d-08,-.1632206943805451d-07,
     5      -.7519461271785738d-07,-.2606597076186805d-06,
     6      -.7155489544633216d-06,-.1600067449663318d-05,
     7      -.2990349054302067d-05,-.4768418474759917d-05,
     8      -.6600775273694447d-05,-.8049955438233352d-05/
         data arr1587/
     1      -.8757342564595901d-05,-.8588803077226375d-05,
     2      -.7664111704356663d-05,-.6272052681730598d-05,
     3      -.4739430260448002d-05,-.3326106251763992d-05,
     4      -.2178940722834965d-05,-.1338476297332575d-05,
     5      -.7739458331655586d-06,-.4224889864274169d-06,
     6      -.2181030636243788d-06,-.1065912696612433d-06,
     7      -.4974205720830391d-07,-.2639753510016923d-07,
     8      0.7239833540907215d-11,0.1675742722323210d-07/
         data arr1588/
     1      -.9652704452704305d-08,0.4244797144296883d-08,
     2      -.1787726578566233d-08,0.7251975845202167d-09,
     3      -.1017437861016665d-08,-.4444083843455057d-08,
     4      -.2451000601348971d-07,-.9560030402840696d-07,
     5      -.2944684159294010d-06,-.7313277681812027d-06,
     6      -.1507022865215406d-05,-.2632555276697955d-05,
     7      -.3968481035355033d-05,-.5243754644802459d-05,
     8      -.6152675306344883d-05,-.6481334326514116d-05/
         data arr1589/
     1      -.6189106522217316d-05,-.5402354384129820d-05,
     2      -.4341139126304486d-05,-.3230804318360898d-05,
     3      -.2238843185843027d-05,-.1451582271880228d-05,
     4      -.8842542519025529d-06,-.5076693253655800d-06,
     5      -.2751835095016947d-06,-.1410172430118276d-06,
     6      -.6899634869096086d-07,-.3873496645335223d-07,
     7      0.3206552789103878d-10,0.2384740054669281d-07,
     8      -.1365097257512530d-07,0.5991750557389715d-08/
         data arr1590/
     1      -.2511088089189201d-08,0.1097808460999684d-08,
     2      -.6784552555258649d-09,-.9315156935527986d-09,
     3      -.7647729663702535d-08,-.3289947656423418d-07,
     4      -.1141422563291284d-06,-.3146257560590312d-06,
     5      -.7148744040528539d-06,-.1368210007036977d-05,
     6      -.2245881864608778d-05,-.3215348258631905d-05,
     7      -.4069170956848452d-05,-.4604002937585151d-05,
     8      -.4704566359702540d-05,-.4379989124359058d-05/
         data arr1591/
     1      -.3742568218071159d-05,-.2953243535733516d-05,
     2      -.2164093623111378d-05,-.1480140828604027d-05,
     3      -.9489339549195765d-06,-.5719464429610517d-06,
     4      -.3245409564946796d-06,-.1735419606404125d-06,
     5      -.8834525843732234d-07,-.5168625835521219d-07,
     6      0.2016519081361111d-10,0.2655928100995202d-07,
     7      -.1591512939226599d-07,0.7255471359038435d-08,
     8      -.3160513522613071d-08,0.1438910087515885d-08/
         data arr1592/
     1      -.7584387857119303d-09,0.1213278340081059d-09,
     2      -.2459621153000932d-08,-.1054173415987675d-07,
     3      -.4192466259934004d-07,-.1279223151462677d-06,
     4      -.3203988934599379d-06,-.6722523388691067d-06,
     5      -.1201235231924435d-05,-.1863314868671096d-05,
     6      -.2543735585680655d-05,-.3091146254016713d-05,
     7      -.3379915233790569d-05,-.3356516664939442d-05,
     8      -.3050172685234503d-05,-.2552400079760059d-05/
         data arr1593/
     1      -.1978381332660924d-05,-.1428285060514621d-05,
     2      -.9649099073666760d-06,-.6118738667841317d-06,
     3      -.3646999693438849d-06,-.2045666835896669d-06,
     4      -.1092617415297175d-06,-.6775218368924798d-07,
     5      0.6506607461219318d-10,0.3357273272530974d-07,
     6      -.1988010704900125d-07,0.9014310740511674d-08,
     7      -.3900047369793384d-08,0.1785561903951849d-08,
     8      -.8946726902420900d-09,0.4674690967444712d-09/
         data arr1594/
     1      -.9661435273356071d-09,-.3015808093694956d-08,
     2      -.1471905253722919d-07,-.4929775647218432d-07,
     3      -.1360927958487215d-06,-.3134250296449365d-06,
     4      -.6092855698619594d-06,-.1024033887946920d-05,
     5      -.1508243726458073d-05,-.1968278946074958d-05,
     6      -.2302593554628215d-05,-.2438825170868021d-05,
     7      -.2356319579809203d-05,-.2089782367922499d-05,
     8      -.1711702922176128d-05,-.1302387581702010d-05/
         data arr1595/
     1      -.9248006814038999d-06,-.6144800068594214d-06,
     2      -.3823505593428111d-06,-.2229804989828538d-06,
     3      -.1233547752104903d-06,-.7920502738234992d-07,
     4      0.4300906825325886d-10,0.2886489861651432d-07,
     5      -.1874483713957600d-07,0.9125540303584924d-08,
     6      -.4216036408754509d-08,0.2033788340063107d-08,
     7      -.1085303911033980d-08,0.6682275970359448d-09,
     8      -.6673422225071955d-09,-.5517915110198311d-09/
         data arr1596/
     1      -.5080765325064101d-08,-.1808947522113583d-07,
     2      -.5478130269383161d-07,-.1392961021910178d-06,
     3      -.2939383931786523d-06,-.5351844731434137d-06,
     4      -.8510101322223434d-06,-.1192546956161160d-05,
     5      -.1492356812369524d-05,-.1686320533499109d-05,
     6      -.1733180253600450d-05,-.1630064959384459d-05,
     7      -.1412123496989999d-05,-.1134275717270265d-05,
     8      -.8491254104920790d-06,-.5939826380275384d-06/
         data arr1597/
     1      -.3884770035715938d-06,-.2377946093931133d-06,
     2      -.1381496425850030d-06,-.9422679461015581d-07,
     3      0.1053425664337519d-09,0.3319659661402838d-07,
     4      -.2095944984516442d-07,0.1005410242697178d-07,
     5      -.4577042693748720d-08,0.2209213013702986d-08,
     6      -.1152779589779280d-08,0.7397390890848423d-09,
     7      -.5746009603897252d-09,0.1950571396057547d-09,
     8      -.1813221174096041d-08,-.6305775087220712d-08/
         data arr1598/
     1      -.2087924174301486d-07,-.5924721643565676d-07,
     2      -.1351655006420256d-06,-.2666574827423268d-06,
     3      -.4580690751534951d-06,-.6889353960024516d-06,
     4      -.9217632109120047d-06,-.1110620480301889d-05,
     5      -.1213000117224885d-05,-.1207642661151982d-05,
     6      -.1103594086446079d-05,-.9322174327462938d-06,
     7      -.7314847634829887d-06,-.5342146784637364d-06,
     8      -.3630754443786791d-06,-.2298213630453099d-06/
         data arr1599/
     1      -.1374470056656238d-06,-.9631298547813399d-07,
     2      0.7167137299596112d-10,0.1745436703592847d-07,
     3      -.1433485992967228d-07,0.8087872503942376d-08,
     4      -.4168352886701412d-08,0.2199446432749926d-08,
     5      -.1265434122051069d-08,0.8557833765096880d-09,
     6      -.6799398069229260d-09,0.4935775852044226d-09,
     7      -.8100147874429186d-09,-.2163677510767662d-08,
     8      -.7283472469677709d-08,-.2447169833707517d-07/
         data arr1600/
     1      -.5938744456385982d-07,-.1267154211103539d-06,
     2      -.2360966327916640d-06,-.3809749264327002d-06,
     3      -.5445571203206878d-06,-.7003727808426174d-06,
     4      -.8143485692515053d-06,-.8597695793757966d-06,
     5      -.8307613783052187d-06,-.7409863445452698d-06,
     6      -.6134798450819226d-06,-.4721728058291166d-06,
     7      -.3375957035546647d-06,-.2244528588027073d-06,
     8      -.1411035726367291d-06,-.1052556150082281d-06/
         data arr1601/
     1      0.1309956564817650d-09,0.2072298299883895d-07,
     2      -.1511958598890137d-07,0.8060612602602763d-08,
     3      -.3984616216124894d-08,0.2072967460863275d-08,
     4      -.1148773316878205d-08,0.7885357212102670d-09,
     5      -.5906006387104136d-09,0.5014842292761089d-09,
     6      -.4426431690781888d-09,-.6975697033664258d-09,
     7      -.2267389003907981d-08,-.9853095618109428d-08,
     8      -.2490886513397537d-07,-.5755458027325394d-07/
         data arr1602/
     1      -.1165206711559398d-06,-.2013253017931392d-06,
     2      -.3069158878362962d-06,-.4204367753684702d-06,
     3      -.5184847964041993d-06,-.5775117048838071d-06,
     4      -.5861389817016801d-06,-.5470850953142797d-06,
     5      -.4720115435314675d-06,-.3766750042804268d-06,
     6      -.2776862492067341d-06,-.1893102750473335d-06,
     7      -.1214133481370452d-06,-.9199855181363391d-07,
     8      0.8949206249626920d-10,-.2350442815573638d-08/
         data arr1603/
     1      -.4510863383014630d-08,0.4428771459969270d-08,
     2      -.2915240432797512d-08,0.1786188600727920d-08,
     3      -.1139397517862424d-08,0.8344900814974986d-09,
     4      -.6829698121516725d-09,0.5743031605399442d-09,
     5      -.3687570370039182d-09,-.3208981552392295d-09,
     6      -.2842909186445513d-09,-.4205499680076864d-08,
     7      -.1002550445685330d-07,-.2471759308166327d-07,
     8      -.5558624918626459d-07,-.1027263909344193d-06/
         data arr1604/
     1      -.1664847677231195d-06,-.2438343611736182d-06,
     2      -.3208176364660827d-06,-.3789481830352223d-06,
     3      -.4064111887944623d-06,-.4006730918860891d-06,
     4      -.3652423112632505d-06,-.3076537984916449d-06,
     5      -.2388787287414196d-06,-.1711976545103277d-06,
     6      -.1155340472284037d-06,-.9339925449062287d-07,
     7      0.1244875182334243d-09,0.3641866270508979d-08,
     8      -.5766091905570631d-08,0.4144343881062262d-08/
         data arr1605/
     1      -.2424080867789133d-08,0.1426524773338219d-08,
     2      -.8585726473312471d-09,0.6361169826381750d-09,
     3      -.4915042459449468d-09,0.4365595673804008d-09,
     4      -.2490369537919463d-09,-.1226814094919346d-09,
     5      0.1731544458462880d-09,-.1788365360664349d-08,
     6      -.3813960886173260d-08,-.1011750719431751d-07,
     7      -.2528799079903096d-07,-.4966553138675683d-07,
     8      -.8522572378652022d-07,-.1324682197366057d-06/
         data arr1606/
     1      -.1839045320710329d-06,-.2275255898790193d-06,
     2      -.2542578929701439d-06,-.2601134248921443d-06,
     3      -.2448833058769569d-06,-.2118563653052901d-06,
     4      -.1680009670960152d-06,-.1223288907735624d-06,
     5      -.8347545228182690d-07,-.6786862652304951d-07,
     6      0.8560178335085511d-10,-.1726783225232161d-07,
     7      0.4246721768899923d-08,0.5100656926235155d-09,
     8      -.1239219206451290d-08,0.1036831740024941d-08/
         data arr1607/
     1      -.7688841233866279d-09,0.6184143508137667d-09,
     2      -.5286472920038917d-09,0.4495445168739198d-09,
     3      -.2371329153467697d-09,-.1565944986050997d-09,
     4      0.4728542607440647d-09,-.1041853017221278d-08,
     5      -.1424389583982056d-08,-.3654109634075562d-08,
     6      -.1141162359035235d-07,-.2374144036086807d-07,
     7      -.4259388727092421d-07,-.7108150027443408d-07,
     8      -.1058432518284095d-06,-.1388443089208493d-06/
         data arr1608/
     1      -.1636945883110180d-06,-.1769170300312080d-06,
     2      -.1762857982478946d-06,-.1612701863870551d-06,
     3      -.1348440738430042d-06,-.1032727902638974d-06,
     4      -.7420197819642529d-07,-.6446803255325439d-07,
     5      0.7931201959377800d-10,-.4668380364084909d-08,
     6      0.1094497943112177d-09,0.1077355121483304d-08,
     7      -.9309057858506839d-09,0.6601109820574799d-09,
     8      -.4379611435643223d-09,0.3504386633126925d-09/
         data arr1609/
     1      -.2790785896308166d-09,0.2502328413104070d-09,
     2      -.1263037950776881d-09,-.6213404406639367d-10,
     3      0.2713870051132976d-09,-.4644035639828611d-09,
     4      -.4703057771278870d-09,-.1272502929355905d-08,
     5      -.4659402563429753d-08,-.1011745168955312d-07,
     6      -.1895021228469363d-07,-.3318972094160971d-07,
     7      -.5144002478172189d-07,-.6967537849003227d-07,
     8      -.8440781413447901d-07,-.9332506100083506d-07/
         data arr1610/
     1      -.9463073207634811d-07,-.8761893680599422d-07,
     2      -.7379382801843736d-07,-.5668955981608643d-07,
     3      -.4067783821897079d-07,-.3502448102630528d-07,
     4      0.5365876143001852d-10,-.1618338200125048d-07,
     5      0.5772425786473687d-08,-.1057104181698471d-08,
     6      -.1943326756161862d-09,0.3926735390349257d-09,
     7      -.3563397400019012d-09,0.3155974441452282d-09,
     8      -.2805297091608987d-09,0.2394267373643257d-09/
         data arr1611/
     1      -.1142978201430912d-09,-.9886957818621282d-10,
     2      0.3212018706408883d-09,-.3783002480076816d-09,
     3      -.1797954480826160d-09,-.2185914561265626d-09,
     4      -.2068347296915439d-08,-.4652341428037142d-08,
     5      -.8716827390704289d-08,-.1654864932129574d-07,
     6      -.2780800931517864d-07,-.3992223839650387d-07,
     7      -.5088401024785532d-07,-.5943889217703943d-07,
     8      -.6393365474008819d-07,-.6273297283277912d-07/
         data arr1612/
     1      -.5577861884644273d-07,-.4509757790319375d-07,
     2      -.3409780557030902d-07,-.3142610328327838d-07,
     3      0.3288176066854025d-10,-.4452347181243272d-08,
     4      0.1444267669414056d-08,-.1465953657056547d-09,
     5      -.1459167933928511d-09,0.1732455680628754d-09,
     6      -.1351555873007868d-09,0.1208407495404784d-09,
     7      -.9927373311914150d-10,0.9030501279058838d-10,
     8      -.4033334880527315d-10,-.3008208860602691d-10/
         data arr1613/
     1      0.1169215722002541d-09,-.1302297997365982d-09,
     2      -.4434660600754803d-10,-.3861590605354313d-10,
     3      -.6527411706079877d-09,-.1495069681129395d-08,
     4      -.2867336216200470d-08,-.5624548754526840d-08,
     5      -.9684418164545380d-08,-.1415572337452224d-07,
     6      -.1831568061843258d-07,-.2165398459281962d-07,
     7      -.2348275723121385d-07,-.2314644248299959d-07,
     8      -.2061493958475069d-07,-.1665505043770193d-07/
         data arr1614/
     1      -.1254833165001305d-07,-.1145800654550975d-07,
     2      0.2289597867465768d-10,-.7903875455048588d-08,
     3      0.3191128577043663d-08,-.8346938570854196d-09,
     4      0.1056334873321434d-09,0.7189199936452052d-10,
     5      -.9854195094027776d-10,0.9958842692908738d-10,
     6      -.9240500769601620d-10,0.7941621858559253d-10,
     7      -.3366914331403982d-10,-.4101879747027278d-10,
     8      0.1183571878752291d-09,-.1153312023649402d-09/
         data arr1615/
     1      -.2633441196794400d-10,0.7992173078883492d-10,
     2      -.2999647741515039d-09,-.6901022429733210d-09,
     3      -.1196209914787004d-08,-.2592592314014441d-08,
     4      -.4938434612223794d-08,-.7641089566110196d-08,
     5      -.1034430213670255d-07,-.1290441199186410d-07,
     6      -.1487368527896368d-07,-.1556418628493391d-07,
     7      -.1464254799218368d-07,-.1244753502001868d-07,
     8      -.9880916089660857d-08,-.9665003535176488d-08/
         data arr1616/
     1      0.7908979261105867d-12,0.2657216114566555d-07,
     2      0.1486542135714720d-06,0.5653524619883939d-06,
     3      0.1529927150116982d-05,0.3142416915594948d-05,
     4      0.5129673816553268d-05,0.6894652229049947d-05,
     5      0.7844263334464630d-05,0.7723516369578876d-05,
     6      0.6700390578335330d-05,0.5197879057669875d-05,
     7      0.3650345835714767d-05,0.2344805513156269d-05,
     8      0.1389748524896548d-05,0.7656795666962888d-06/
         data arr1617/
     1      0.3946326420989898d-06,0.1913080093694770d-06,
     2      0.8763811660636491d-07,0.3808976997337727d-07,
     3      0.1575991682152611d-07,0.6225463092760599d-08,
     4      0.2353500108595606d-08,0.8532827713466263d-09,
     5      0.2971990545389587d-09,0.9951596944473318d-10,
     6      0.3199107357641421d-10,0.9860007980704508d-11,
     7      0.3247781888011957d-11,0.2372598158960822d-12,
     8      0.1106094471404788d-07,0.8002522032994111d-07/
         data arr1618/
     1      0.3766770470376073d-06,0.1230017367581524d-05,
     2      0.2985229569764688d-05,0.5661053628074405d-05,
     3      0.8715560282646028d-05,0.1122457109926226d-04,
     4      0.1238487528850528d-04,0.1193636780724169d-04,
     5      0.1021002365227842d-04,0.7854244395807231d-05,
     6      0.5494505280059127d-05,0.3528390752257780d-05,
     7      0.2096602209226413d-05,0.1160670109812866d-05,
     8      0.6021350429774255d-06,0.2942060927383878d-06/
         data arr1619/
     1      0.1359731932294694d-06,0.5966206229505106d-07,
     2      0.2493127554532157d-07,0.9948017988363981d-08,
     3      0.3798631119707079d-08,0.1390482776162444d-08,
     4      0.4884403464848272d-09,0.1646798397201119d-09,
     5      0.5343601415096109d-10,0.1881126078372104d-10,
     6      0.9193742731128175d-13,0.3200309319551880d-08,
     7      0.2974403270888155d-07,0.1733923328905698d-06,
     8      0.6831736932725072d-06,0.1959186342211649d-05/
         data arr1620/
     1      0.4316063996002077d-05,0.7611349375259303d-05,
     2      0.1109610617362625d-04,0.1371991877669671d-04,
     3      0.1469019542256437d-04,0.1385512991539855d-04,
     4      0.1167503455923707d-04,0.8894747910250572d-05,
     5      0.6188713133421092d-05,0.3966144015501378d-05,
     6      0.2358348667826939d-05,0.1309294713490554d-05,
     7      0.6823281232420309d-06,0.3353386481527218d-06,
     8      0.1560372783361333d-06,0.6897522929658222d-07/
         data arr1621/
     1      0.2904832099778409d-07,0.1168303199112619d-07,
     2      0.4496006223038814d-08,0.1657546960385979d-08,
     3      0.5856606888228984d-09,0.1990170082253035d-09,
     4      0.7377901732222615d-10,0.2687437273347166d-13,
     5      0.7825062332395150d-09,0.8798799192907453d-08,
     6      0.6375211015774933d-07,0.3029998848520928d-06,
     7      0.1026779278262656d-05,0.2627725100884587d-05,
     8      0.5307987761815242d-05,0.8759376464143967d-05/
         data arr1622/
     1      0.1213705335266999d-04,0.1443725886454507d-04,
     2      0.1501399379911873d-04,0.1385842133124760d-04,
     3      0.1149848097096785d-04,0.8668137563780370d-05,
     4      0.5991323456052099d-05,0.3826564494847106d-05,
     5      0.2273435178774362d-05,0.1263678531922742d-05,
     6      0.6604135482701206d-06,0.3258817771509286d-06,
     7      0.1523845371795689d-06,0.6773300849100775d-07,
     8      0.2869289643731061d-07,0.1160830085341634d-07/
         data arr1623/
     1      0.4491125191558236d-08,0.1662357564081563d-08,
     2      0.5909833560492458d-09,0.2301155423788661d-09,
     3      0.2985396683080158d-12,0.2787128177168699d-09,
     4      0.2128350291701558d-08,0.1991128722017682d-07,
     5      0.1139127023817735d-06,0.4562218543768356d-06,
     6      0.1356310864240733d-05,0.3138250242712953d-05,
     7      0.5862252423230222d-05,0.9102569192360080d-05,
     8      0.1202903618107294d-04,0.1379338148370604d-04/
         data arr1624/
     1      0.1394627866860411d-04,0.1260190475195781d-04,
     2      0.1029295606487601d-04,0.7673015376622231d-05,
     3      0.5263795544619463d-05,0.3346697793942943d-05,
     4      0.1984124429250904d-05,0.1102650476204706d-05,
     5      0.5770075385034184d-06,0.2854160251573311d-06,
     6      0.1338975856934295d-06,0.5974480207799103d-07,
     7      0.2541274150168106d-07,0.1031944220692559d-07,
     8      0.4002801786783519d-08,0.1489981406227945d-08/
         data arr1625/
     1      0.6109792700939694d-09,0.5934590343149045d-13,
     2      0.3593626088148304d-09,0.2574429431184108d-09,
     3      0.5545733859776760d-08,0.3748512018334676d-07,
     4      0.1776685533607195d-06,0.6134939088121764d-06,
     5      0.1626028261889914d-05,0.3438235836279514d-05,
     6      0.5982677917272363d-05,0.8783295529433826d-05,
     7      0.1110518380635939d-04,0.1229939362248199d-04,
     8      0.1210354097791341d-04,0.1071112164908055d-04/
         data arr1626/
     1      0.8611725143040447d-05,0.6345555086960637d-05,
     2      0.4317483266764585d-05,0.2730119206595931d-05,
     3      0.1613393730494770d-05,0.8953270851597984d-06,
     4      0.4684781616556540d-06,0.2319577437345743d-06,
     5      0.1090107003006396d-06,0.4874438046406383d-07,
     6      0.2076895272812197d-07,0.8436641664122118d-08,
     7      0.3283689606246200d-08,0.1413331579798132d-08,
     8      0.1429460453163540d-11,0.7495106587197395d-09/
         data arr1627/
     1      -.4234817910572910d-09,0.1597536126318395d-08,
     2      0.1093948284593951d-07,0.6198583407873496d-07,
     3      0.2483725029824553d-06,0.7541751998629157d-06,
     4      0.1805078225634922d-05,0.3519825121939322d-05,
     5      0.5740857089595705d-05,0.8003372860505376d-05,
     6      0.9709620893505880d-05,0.1040593670200346d-04,
     7      0.9977511111155265d-05,0.8651818250416699d-05,
     8      0.6847515665797125d-05,0.4985823900142329d-05/
         data arr1628/
     1      0.3362693132178358d-05,0.2113185651772679d-05,
     2      0.1243591220190933d-05,0.6883313946532613d-06,
     3      0.3597109561109094d-06,0.1780670906837596d-06,
     4      0.8371925971576820d-07,0.3744225077625763d-07,
     5      0.1593990099284136d-07,0.6497644583945748d-08,
     6      0.2948878555408326d-08,0.2427478978008402d-12,
     7      0.1502146723594259d-08,-.1027472266163505d-08,
     8      0.8394226637355451d-09,0.2696829985747931d-08/
         data arr1629/
     1      0.1974839451251824d-07,0.9129747529500936d-07,
     2      0.3178334684240418d-06,0.8609415578742094d-06,
     3      0.1881404466184357d-05,0.3408999974679649d-05,
     4      0.5240232746476261d-05,0.6963917526753768d-05,
     5      0.8127945490523494d-05,0.8443845985306087d-05,
     6      0.7896904234934227d-05,0.6713174018887296d-05,
     7      0.5230860570558313d-05,0.3762904797935837d-05,
     8      0.2514578578868713d-05,0.1569269694077074d-05/
         data arr1630/
     1      0.9187854145054277d-06,0.5067318237734502d-06,
     2      0.2641921612216144d-06,0.1305614283263912d-06,
     3      0.6125026319736163d-07,0.2729167029992406d-07,
     4      0.1162278645345603d-07,0.5530700927678807d-08,
     5      0.5446684002473199d-11,0.2793982913882995d-08,
     6      -.1950220528726845d-08,0.1080786657383210d-08,
     7      0.2205177788156940d-09,0.5970322670877986d-08,
     8      0.3071697772951609d-07,0.1231085303633342d-06/
         data arr1631/
     1      0.3771332142082940d-06,0.9237752843702498d-06,
     2      0.1859442238954436d-05,0.3151599064997266d-05,
     3      0.4587920984971755d-05,0.5831573870070389d-05,
     4      0.6563925965365943d-05,0.6620875101371336d-05,
     5      0.6045471786650969d-05,0.5040969791125938d-05,
     6      0.3867828176848942d-05,0.2748571451393550d-05,
     7      0.1819011873236148d-05,0.1126564051190355d-05,
     8      0.6557850640574634d-06,0.3601692255196743d-06/
         data arr1632/
     1      0.1871720705040233d-06,0.9217849101641342d-07,
     2      0.4304975279341194d-07,0.1920795367700574d-07,
     3      0.9651520320785707d-08,0.1076485515702665d-11,
     4      0.4733919629755518d-08,-.3300330409363213d-08,
     5      0.1735760339728204d-08,-.6927131819581300d-09,
     6      0.1988776917643140d-08,0.9394918992144911d-08,
     7      0.4429530143853134d-07,0.1529568194406170d-06,
     8      0.4202557690980095d-06,0.9395892688706555d-06/
         data arr1633/
     1      0.1755917274090987d-05,0.2800223592402832d-05,
     2      0.3876065530138192d-05,0.4727020791324656d-05,
     3      0.5142586958983710d-05,0.5043548751952402d-05,
     4      0.4500417737006359d-05,0.3683065776946945d-05,
     5      0.2783196598747229d-05,0.1953196968488628d-05,
     6      0.1279445509613395d-05,0.7859295008954801d-06,
     7      0.4545351194901727d-06,0.2482027516980731d-06,
     8      0.1281296629000210d-06,0.6255742303137640d-07/
         data arr1634/
     1      0.2911177635179182d-07,0.1529907569345220d-07,
     2      0.1692402507327611d-10,0.7633506619102003d-08,
     3      -.5352327912554564d-08,0.2805845805303940d-08,
     4      -.1368902424822723d-08,0.1124073508063735d-08,
     5      0.2375418962902543d-08,0.1506598209751828d-07,
     6      0.5770958748404618d-07,0.1784239239256171d-06,
     7      0.4428298545337015d-06,0.9124248632511066d-06,
     8      0.1594270571498923d-05,0.2402957459541188d-05/
         data arr1635/
     1      0.3175129431391088d-05,0.3725789862161841d-05,
     2      0.3924684083986792d-05,0.3747518372325146d-05,
     3      0.3271274528621150d-05,0.2628864834384608d-05,
     4      0.1956409559471343d-05,0.1355567740476676d-05,
     5      0.8789023316688255d-06,0.5355514098465009d-06,
     6      0.3075992371302491d-06,0.1667332422235963d-06,
     7      0.8534499145619804d-07,0.4163448461639088d-07,
     8      0.2314884345511673d-07,0.3905556106830404d-11/
         data arr1636/
     1      0.1116216960212585d-07,-.7803473006657584d-08,
     2      0.4085982113281476d-08,-.2032859693464177d-08,
     3      0.1166209768018252d-08,0.1264524472700357d-09,
     4      0.5088699062279105d-08,0.2021398856261973d-07,
     5      0.7118682652238902d-07,0.1957383060567111d-06,
     6      0.4446011002957045d-06,0.8515241239861526d-06,
     7      0.1397213567163534d-05,0.2000324832707375d-05,
     8      0.2531956318798745d-05,0.2864540089307730d-05/
         data arr1637/
     1      0.2926801882196598d-05,0.2725093212840948d-05,
     2      0.2328784423300313d-05,0.1837528222022950d-05,
     3      0.1346288804003403d-05,0.9208241236211612d-06,
     4      0.5905910709735155d-06,0.3561567391849022d-06,
     5      0.2020949673353945d-06,0.1079301634698457d-06,
     6      0.5477464480085896d-07,0.3173811489822284d-07,
     7      0.4272522553166496d-10,0.1589996428944590d-07,
     8      -.1119472401710112d-07,0.5882655966574149d-08/
         data arr1638/
     1      -.2954135724860238d-08,0.1576343193850565d-08,
     2      -.7467593924519401d-09,0.2037661688198090d-08,
     3      0.6342875539222424d-08,0.2696617283706318d-07,
     4      0.8149901729674317d-07,0.2039704362066939d-06,
     5      0.4288509373987937d-06,0.7654651968675799d-06,
     6      0.1187393585415897d-05,0.1621659906754331d-05,
     7      0.1970296968011112d-05,0.2153923262798520d-05,
     8      0.2139362759005756d-05,0.1944491665410738d-05/
         data arr1639/
     1      0.1626974884065275d-05,0.1260752237021176d-05,
     2      0.9102599464786124d-06,0.6153153117481612d-06,
     3      0.3904646811715536d-06,0.2327264475473100d-06,
     4      0.1303508038695056d-06,0.6939954435474171d-07,
     5      0.4263437157436798d-07,0.1087765855344814d-10,
     6      0.2013927984482469d-07,-.1412688598819947d-07,
     7      0.7416920352857623d-08,-.3712011171284914d-08,
     8      0.1965388841369433d-08,-.1133718018950250d-08/
         data arr1640/
     1      0.1228646491922146d-08,0.1502697233371490d-08,
     2      0.9902875652509297d-08,0.3207271327365575d-07,
     3      0.8834512541560098d-07,0.2046204586897628d-06,
     4      0.3966390610292466d-06,0.6666994831739821d-06,
     5      0.9828125197259557d-06,0.1282112901728560d-05,
     6      0.1499333388624118d-05,0.1588517569111223d-05,
     7      0.1535270883960818d-05,0.1361365594320921d-05,
     8      0.1114676295383272d-05,0.8482420814219957d-06/
         data arr1641/
     1      0.6028100028601336d-06,0.4008898924509757d-06,
     2      0.2494393577371504d-06,0.1452336407461748d-06,
     3      0.8007461724668560d-07,0.5093825507259342d-07,
     4      0.8663999912423753d-10,0.2568660996803808d-07,
     5      -.1818197221424922d-07,0.9592026160029163d-08,
     6      -.4838105653346659d-08,0.2554860370679819d-08,
     7      -.1549500847916826d-08,0.1207603834669072d-08,
     8      -.2471943705377043d-09,0.3781089051158960d-08/
         data arr1642/
     1      0.1193274748948404d-07,0.3601242978844557d-07,
     2      0.9312248143519002d-07,0.1949262698104461d-06,
     3      0.3551088865695746d-06,0.5658140911342292d-06,
     4      0.7921858386451086d-06,0.9906597327678319d-06,
     5      0.1120110345545151d-05,0.1151848653564660d-05,
     6      0.1082940941444469d-05,0.9376440922622000d-06,
     7      0.7533677091212793d-06,0.5646542153964466d-06,
     8      0.3954517345406711d-06,0.2586175512519082d-06/
         data arr1643/
     1      0.1580191130503245d-06,0.9149964688575607d-07,
     2      0.6187476934026764d-07,0.2241491919546433d-10,
     3      0.2822440866210260d-07,-.1988363721499269d-07,
     4      0.1047612869310489d-07,-.5259608763199167d-08,
     5      0.2786920745441901d-08,-.1683477306454589d-08,
     6      0.1235159530023926d-08,-.7820700424025433d-09,
     7      0.1681939587576099d-08,0.4188952109713651d-08,
     8      0.1372362412522421d-07,0.4072351196063564d-07/
         data arr1644/
     1      0.9106480917376147d-07,0.1799075018412134d-06,
     2      0.3103374484347988d-06,0.4659156814764973d-06,
     3      0.6226266913218434d-06,0.7510094028646315d-06,
     4      0.8209300177552206d-06,0.8168965678570829d-06,
     5      0.7460088156570728d-06,0.6304687152917319d-06,
     6      0.4955158887195577d-06,0.3624268290790564d-06,
     7      0.2463299862004276d-06,0.1556387529032809d-06,
     8      0.9278062570082501d-07,0.6448496849227424d-07/
         data arr1645/
     1      0.1401994654204098d-09,0.3249056476208290d-07,
     2      -.2315332926399441d-07,0.1227413097972792d-07,
     3      -.6221565963037866d-08,0.3294214333262670d-08,
     4      -.2025271027387756d-08,0.1442886411478127d-08,
     5      -.1126091203639977d-08,0.1088418365946608d-08,
     6      0.1345166556054481d-08,0.4562102004321699d-08,
     7      0.1757541233703688d-07,0.4037407813945001d-07,
     8      0.8664605625664026d-07,0.1629773838743072d-06/
         data arr1646/
     1      0.2618614106116771d-06,0.3734770739805436d-06,
     2      0.4814095006161218d-06,0.5605062428056738d-06,
     3      0.5911790022329493d-06,0.5706364509555934d-06,
     4      0.5094131041621385d-06,0.4227422689737281d-06,
     5      0.3259857824179690d-06,0.2330558881927996d-06,
     6      0.1546289640453875d-06,0.9691202992460865d-07,
     7      0.7177288184070390d-07,0.3351094240319818d-10,
     8      0.3028381168098371d-07,-.2143769446642241d-07/
         data arr1647/
     1      0.1133921906401644d-07,-.5712413467222096d-08,
     2      0.3036412942329545d-08,-.1843738048037818d-08,
     3      0.1327845880844021d-08,-.1050696365396017d-08,
     4      0.8136375685527980d-09,0.3796986666543337d-09,
     5      0.1187679947057447d-08,0.7585564273487377d-08,
     6      0.1699561238777040d-07,0.3976037135153388d-07,
     7      0.8196283257532416d-07,0.1405101897581326d-06,
     8      0.2134393270139033d-06,0.2934286580582655d-06/
         data arr1648/
     1      0.3625731771639937d-06,0.4033080521400484d-06,
     2      0.4088227409291249d-06,0.3820466421073747d-06,
     3      0.3305726832061922d-06,0.2643901324770503d-06,
     4      0.1949013706851926d-06,0.1325870760984133d-06,
     5      0.8477233726249829d-07,0.6378504651807351d-07,
     6      0.1749545589578324d-09,0.3169457468134036d-07,
     7      -.2276571348054510d-07,0.1213645883703735d-07,
     8      -.6186827860635986d-08,0.3286719379947007d-08/
         data arr1649/
     1      -.2035690820609752d-08,0.1445083414644139d-08,
     2      -.1186464058474105d-08,0.7991141481918033d-09,
     3      0.4797262470230907d-10,-.1994369057591848d-09,
     4      0.3713928601224336d-08,0.6616755749401174d-08,
     5      0.1709254137712729d-07,0.4004819041081409d-07,
     6      0.7265252704797067d-07,0.1170076950460890d-06,
     7      0.1726267769916351d-06,0.2278227239660051d-06,
     8      0.2683952201363884d-06,0.2873076902720943d-06/
         data arr1650/
     1      0.2838526867287724d-06,0.2598263783646148d-06,
     2      0.2194642033959822d-06,0.1703652207400704d-06,
     3      0.1218116810629003d-06,0.8199199477333357d-07,
     4      0.6591062199896910d-07,0.3762092959234435d-10,
     5      0.2453822232258480d-07,-.1747897781995040d-07,
     6      0.9291658905807554d-08,-.4701210367974915d-08,
     7      0.2509019187452495d-08,-.1530752672213512d-08,
     8      0.1104968477774450d-08,-.8864498915454477d-09/
         data arr1651/
     1      0.6040014208271458d-09,-.2335712096995891d-10,
     2      -.4198142431514172d-09,0.1862037923053361d-08,
     3      0.2396072110748203d-08,0.6960740096781265d-08,
     4      0.1869392269170458d-07,0.3562163439130116d-07,
     5      0.6054902869640234d-07,0.9512707320111176d-07,
     6      0.1326297039204324d-06,0.1635759756541864d-06,
     7      0.1824431299937307d-06,0.1871808291612858d-06,
     8      0.1771198458475838d-06,0.1537621532345141d-06/
         data arr1652/
     1      0.1219615216472266d-06,0.8863539608832703d-07,
     2      0.6035900728239882d-07,0.4884781473113942d-07,
     3      0.1679573818992328d-09,0.2333589994246810d-07,
     4      -.1693076001394770d-07,0.9087835610639272d-08,
     5      -.4665737910925776d-08,0.2487773202678961d-08,
     6      -.1554873595094604d-08,0.1103432498520234d-08,
     7      -.9148585328802075d-09,0.5858366928479999d-09,
     8      -.5308099221701449d-10,-.6150889744388629d-09/
         data arr1653/
     1      0.1303308816366319d-08,0.6434771951919906d-09,
     2      0.2388703262511144d-08,0.8840564446223679d-08,
     3      0.1717930406030193d-07,0.3034027424193747d-07,
     4      0.5174952817105953d-07,0.7752881118589346d-07,
     5      0.1010732453171275d-06,0.1188100663256003d-06,
     6      0.1289984280270204d-06,0.1294277839162595d-06,
     7      0.1188622338923236d-06,0.9935315634608024d-07,
     8      0.7591686892648059d-07,0.5445812754659249d-07/
         data arr1654/
     1      0.4714669993084357d-07,0.2700357649866433d-10,
     2      0.1349602412583900d-07,-.9673769640537426d-08,
     3      0.5168105833032866d-08,-.2626066736526951d-08,
     4      0.1407044717184781d-08,-.8623435307050694d-09,
     5      0.6244970365724007d-09,-.5019722551025278d-09,
     6      0.3355312249979056d-09,-.2865227368481575d-10,
     7      -.3489516518051361d-09,0.6618165349939445d-09,
     8      0.1448246738488915d-09,0.7895163793355581d-09/
         data arr1655/
     1      0.3747450476442096d-08,0.7431869349350135d-08,
     2      0.1362879074308941d-07,0.2451537556424259d-07,
     3      0.3827566869080706d-07,0.5149901822402076d-07,
     4      0.6220104116784903d-07,0.6911467560073940d-07,
     5      0.7059628333072611d-07,0.6563891026378225d-07,
     6      0.5527709075517864d-07,0.4237219010174579d-07,
     7      0.3035600674626262d-07,0.2605071942252567d-07,
     8      0.1080638649697136d-09,0.1180353164256254d-07/
         data arr1656/
     1      -.8653943593981880d-08,0.4677528657260778d-08,
     2      -.2418827935825074d-08,0.1294263836621039d-08,
     3      -.8162936655037857d-09,0.5790566114399035d-09,
     4      -.4837135938378337d-09,0.3032362054007155d-09,
     5      -.2835625145442892d-10,-.3654630300613670d-09,
     6      0.5600635528217208d-09,-.8424264153196154d-10,
     7      0.4189098009376916d-10,0.1833550741546691d-08,
     8      0.3415878049979010d-08,0.6189200183685435d-08/
         data arr1657/
     1      0.1241980218530759d-07,0.2107357459475521d-07,
     2      0.2987062785147324d-07,0.3790472714151664d-07,
     3      0.4463344513914634d-07,0.4848340287747073d-07,
     4      0.4778584934590405d-07,0.4244913508156774d-07,
     5      0.3423286756585348d-07,0.2585754652567249d-07,
     6      0.2377726047410805d-07,0.1333658326070790d-10,
     7      0.4709156470408788d-08,-.3407438738734399d-08,
     8      0.1833838190927294d-08,-.9376880301593799d-09/
         data arr1658/
     1      0.5052810714527712d-09,-.3117641952896930d-09,
     2      0.2267456738346197d-09,-.1826252396976738d-09,
     3      0.1204433032538502d-09,-.8461093325925600d-11,
     4      -.1374132226264173d-09,0.2139538115697451d-09,
     5      -.4339703825001889d-10,-.1793488843045417d-10,
     6      0.6157655813335041d-09,0.1130531681593862d-08,
     7      0.2074559156617854d-08,0.4337859547229497d-08,
     8      0.7562504965330479d-08,0.1091905202492912d-07/
         data arr1659/
     1      0.1407844975337566d-07,0.1680350716281062d-07,
     2      0.1843764796980891d-07,0.1829075677751717d-07,
     3      0.1630625284160089d-07,0.1316389843276540d-07,
     4      0.9927779079306253d-08,0.9072599658646471d-08,
     5      0.4638467269821126d-10,0.3702975049078013d-08,
     6      -.2757070034234724d-08,0.1504375403589603d-08,
     7      -.7862346202930568d-09,0.4221214865320808d-09,
     8      -.2700254464255454d-09,0.1907373558556983d-09/
         data arr1660/
     1      -.1615130349240563d-09,0.9823648437440725d-10,
     2      -.8038833231430140d-11,-.1279835194737698d-09,
     3      0.1779899609159081d-09,-.5713220012977892d-10,
     4      -.9623113440129244d-10,0.3288681579304843d-09,
     5      0.5092982956777784d-09,0.8234339621331733d-09,
     6      0.2039971752036837d-08,0.3936495021930674d-08,
     7      0.5948449469109196d-08,0.8006373401798789d-08,
     8      0.1012526075283826d-07,0.1183452068627777d-07/
         data arr1661/
     1      0.1244978085155799d-07,0.1169695301405663d-07,
     2      0.9921116909482593d-08,0.7878310413829718d-08,
     3      0.7703211241628358d-08,-.5469474304815631d-11,
     4      -.1808551124991823d-07,-.7995777210242800d-07,
     5      -.2623608389805897d-06,-.6364069802067137d-06,
     6      -.1206961930377001d-05,-.1858151549248252d-05,
     7      -.2393094365011867d-05,-.2640460309732620d-05,
     8      -.2544841669122476d-05,-.2176788755386712d-05/
         data arr1662/
     1      -.1674525571974516d-05,-.1171433508179784d-05,
     2      -.7522589866229139d-06,-.4469940145228813d-06,
     3      -.2474538785919591d-06,-.1283787848516162d-06,
     4      -.6272623559963282d-07,-.2898689178081204d-07,
     5      -.1271833301366121d-07,-.5317122438049626d-08,
     6      -.2123172863260791d-08,-.8097257620176646d-09,
     7      -.2944700733307879d-09,-.1025973540204807d-09,
     8      -.3522743817795195d-10,-.1268647503704559d-10/
         data arr1663/
     1      -.5536436876996144d-11,-.2190498344354428d-11,
     2      -.9181015037862703d-08,-.5099032888057081d-07,
     3      -.2015052242959880d-06,-.5777139656014610d-06,
     4      -.1272746432544548d-05,-.2244459547244720d-05,
     5      -.3272066373909661d-05,-.4045781699408477d-05,
     6      -.4331902094121536d-05,-.4085656738688659d-05,
     7      -.3442777809187933d-05,-.2622918500709801d-05,
     8      -.1824953429472552d-05,-.1169550771809902d-05/
         data arr1664/
     1      -.6954383170104505d-06,-.3860912882560628d-06,
     2      -.2012081320086195d-06,-.9888482691632663d-07,
     3      -.4601217633108321d-07,-.2034044075137840d-07,
     4      -.8566847893533528d-08,-.3445073391983955d-08,
     5      -.1324941621279925d-08,-.4881121852289519d-09,
     6      -.1727370805931565d-09,-.5920941833709666d-10,
     7      -.2226781885030873d-10,-.6698037954650624d-12,
     8      -.3231983365470774d-08,-.2249762523788913d-07/
         data arr1665/
     1      -.1071415541064934d-06,-.3630153251689837d-06,
     2      -.9290440211231231d-06,-.1876655311581719d-05,
     3      -.3096908433137718d-05,-.4291095731442476d-05,
     4      -.5104341733909121d-05,-.5308249185809884d-05,
     5      -.4899690949435198d-05,-.4065327131581963d-05,
     6      -.3064650116531174d-05,-.2118252097872275d-05,
     7      -.1352894481953025d-05,-.8037813976192742d-06,
     8      -.4467781049200510d-06,-.2334908441568979d-06/
         data arr1666/
     1      -.1152162452513781d-06,-.5387650585938847d-07,
     2      -.2394778611000058d-07,-.1014444249195523d-07,
     3      -.4103669943879897d-08,-.1587459048726189d-08,
     4      -.5877124130320228d-09,-.2091272284930159d-09,
     5      -.8112406300342009d-10,-.3255903604493324d-12,
     6      -.9034496413857197d-09,-.7944170684800104d-08,
     7      -.4557355285177104d-07,-.1824846973464053d-06,
     8      -.5425267231237643d-06,-.1255298445702537d-05/
         data arr1667/
     1      -.2344902249364844d-05,-.3641026953569288d-05,
     2      -.4811614377114746d-05,-.5517353633052249d-05,
     3      -.5578510213796183d-05,-.5040762219634331d-05,
     4      -.4117183483818527d-05,-.3069205159902857d-05,
     5      -.2105517649662764d-05,-.1338680280969733d-05,
     6      -.7936502187276072d-06,-.4410591153741079d-06,
     7      -.2308023890941219d-06,-.1141672107634506d-06,
     8      -.5356001548331721d-07,-.2389781263350160d-07/
         data arr1668/
     1      -.1016413293519101d-07,-.4126974621886673d-08,
     2      -.1600989950726225d-08,-.5961314695448262d-09,
     3      -.2431202095517964d-09,-.5935372372283203d-12,
     4      -.1915037446153384d-09,-.2398093312153417d-08,
     5      -.1645391181578502d-07,-.7790460761968165d-07,
     6      -.2690399730344253d-06,-.7130567837178278d-06,
     7      -.1507769098608548d-05,-.2623576059278425d-05,
     8      -.3851729629950798d-05,-.4869947753172142d-05/
         data arr1669/
     1      -.5393637779491259d-05,-.5307754609654138d-05,
     2      -.4697140169281305d-05,-.3776488770532226d-05,
     3      -.2782708550360138d-05,-.1893344601343812d-05,
     4      -.1197237597060244d-05,-.7075172504037842d-06,
     5      -.3926254022258126d-06,-.2054434586896893d-06,
     6      -.1017228741772906d-06,-.4780425385496873d-07,
     7      -.2137353873984697d-07,-.9105911538960604d-08,
     8      -.3699523450718839d-08,-.1440425682750797d-08/
         data arr1670/
     1      -.6164132497497881d-09,-.1133568458316691d-11,
     2      0.1818175062696608d-10,-.6730885332087876d-09,
     3      -.5194516840029382d-08,-.2920065892812042d-07,
     4      -.1170963619809026d-06,-.3555125706234192d-06,
     5      -.8509292646524386d-06,-.1659257247204392d-05,
     6      -.2706265564504610d-05,-.3772832158851637d-05,
     7      -.4577151707561465d-05,-.4905407689508769d-05,
     8      -.4703450087292412d-05,-.4078500116945962d-05/
         data arr1671/
     1      -.3227946579735570d-05,-.2350347088328125d-05,
     2      -.1585191267999753d-05,-.9961585870560870d-06,
     3      -.5862308558804179d-06,-.3244876189419451d-06,
     4      -.1695753190348590d-06,-.8394075033335981d-07,
     5      -.3945959762852272d-07,-.1764557914073570d-07,
     6      -.7513465157855222d-08,-.3063879782212679d-08,
     7      -.1381848181185533d-08,-.2599825338253439d-11,
     8      0.1257933049046632d-09,-.2477055004961180d-09/
         data arr1672/
     1      -.1428916137583100d-08,-.9831661072632289d-08,
     2      -.4567508291379481d-07,-.1588972799816634d-06,
     3      -.4304859440467804d-06,-.9406929875880363d-06,
     4      -.1704499006795380d-05,-.2620128854866511d-05,
     5      -.3481942721285110d-05,-.4063977109966090d-05,
     6      -.4221935960324923d-05,-.3948438950341354d-05,
     7      -.3356580167774676d-05,-.2615445518029130d-05,
     8      -.1881457823550127d-05,-.1257275644656715d-05/
         data arr1673/
     1      -.7846281843136533d-06,-.4594049831993365d-06,
     2      -.2533802736980809d-06,-.1320962680821925d-06,
     3      -.6527022682719164d-07,-.3061714509499299d-07,
     4      -.1364641968674457d-07,-.5814819057220550d-08,
     5      -.2749495991578582d-08,-.4047268573409526d-11,
     6      0.2447082781833720d-09,-.2167250440296791d-09,
     7      -.2815946523243798d-09,-.3049174546922218d-08,
     8      -.1618725853674850d-07,-.6462101387230983d-07/
         data arr1674/
     1      -.1981110360041246d-06,-.4851720630731479d-06,
     2      -.9766260058940125d-06,-.1655325568478133d-05,
     3      -.2409662475589264d-05,-.3062902484792947d-05,
     4      -.3447568294157712d-05,-.3477427610969942d-05,
     5      -.3175224794563917d-05,-.2647677489678110d-05,
     6      -.2031492349535650d-05,-.1443592194684998d-05,
     7      -.9553778640795442d-06,-.5917229761310050d-06,
     8      -.3444600863725980d-06,-.1891661533470737d-06/
         data arr1675/
     1      -.9828305351586733d-07,-.4839600926951931d-07,
     2      -.2261007810738142d-07,-.1009368130975082d-07,
     3      -.5036437726488415d-08,-.7897925858716784d-11,
     4      0.4250877414939821d-09,-.3259572139643535d-09,
     5      0.8567889431219191d-10,-.9350053344694477d-09,
     6      -.5240334954209843d-08,-.2419241872224937d-07,
     7      -.8383170485302615d-07,-.2301501666172917d-06,
     8      -.5146322852662337d-06,-.9617979345984702d-06/
         data arr1676/
     1      -.1533689355592956d-05,-.2123025524520623d-05,
     2      -.2589139798889733d-05,-.2816663989231394d-05,
     3      -.2762443605634555d-05,-.2465034059943181d-05,
     4      -.2017315483138321d-05,-.1524372284545647d-05,
     5      -.1069790051720336d-05,-.7008269410320205d-06,
     6      -.4305224053855673d-06,-.2489606291990443d-06,
     7      -.1359123259324855d-06,-.7015589988301509d-07,
     8      -.3427027749204374d-07,-.1596006575890680d-07/
         data arr1677/
     1      -.8327871654434080d-08,-.9564006621200377d-11,
     2      0.6434877785362454d-09,-.4902933766080038d-09,
     3      0.2535118959071582d-09,-.3665611605647159d-09,
     4      -.1516276419439371d-08,-.8438212264125065d-08,
     5      -.3287159882588088d-07,-.1012802431335865d-06,
     6      -.2515109146283974d-06,-.5182940729564122d-06,
     7      -.9053893261652996d-06,-.1364821447683950d-05,
     8      -.1803425871060497d-05,-.2116025424575109d-05/
         data arr1678/
     1      -.2229037441268541d-05,-.2128539599528635d-05,
     2      -.1857983234183232d-05,-.1493009553869717d-05,
     3      -.1111128772855575d-05,-.7699815038377956d-06,
     4      -.4992558520738395d-06,-.3041582507980600d-06,
     5      -.1746324692173111d-06,-.9464775689087688d-07,
     6      -.4847589736646164d-07,-.2366588755653822d-07,
     7      -.1305368176613502d-07,-.1646090087180663d-10,
     8      0.9463142095250881d-09,-.7193142562456643d-09/
         data arr1679/
     1      0.3998149564477414d-09,-.2705143079828674d-09,
     2      -.3240146450316636d-09,-.2802925649723855d-08,
     3      -.1199179684855010d-07,-.4164797166022741d-07,
     4      -.1147614727388938d-06,-.2607753059563063d-06,
     5      -.4991055619933188d-06,-.8192381822372874d-06,
     6      -.1172902065265705d-05,-.1484368211955265d-05,
     7      -.1679436701494833d-05,-.1716129504754026d-05,
     8      -.1597767654161933d-05,-.1365253941231357d-05/
         data arr1680/
     1      -.1077310250767098d-05,-.7894644678198598d-06,
     2      -.5400230293991504d-06,-.3462814642713653d-06,
     3      -.2087487807633550d-06,-.1184533001148987d-06,
     4      -.6331851053169736d-07,-.3216977744271636d-07,
     5      -.1849348414202814d-07,-.1443312288163220d-10,
     6      0.1185733720694317d-08,-.9183724847708292d-09,
     7      0.5253638793609119d-09,-.3040135703472050d-09,
     8      0.5842754576337066d-10,-.9546643370485732d-09/
         data arr1681/
     1      -.4043718580820155d-08,-.1612488944578311d-07,
     2      -.4915586708209962d-07,-.1231534196508379d-06,
     3      -.2583905454754055d-06,-.4616787642194678d-06,
     4      -.7161827927432961d-06,-.9777100290674751d-06,
     5      -.1188071135146580d-05,-.1299075084473678d-05,
     6      -.1290127803302247d-05,-.1172381131267820d-05,
     7      -.9810360933031810d-06,-.7604357735628753d-06,
     8      -.5490742738335527d-06,-.3710197601051593d-06/
         data arr1682/
     1      -.2353128485819720d-06,-.1402529012987220d-06,
     2      -.7863846359140247d-07,-.4191177649976568d-07,
     3      -.2551723642318462d-07,-.2381363047933683d-10,
     4      0.1514847497853415d-08,-.1171194135760628d-08,
     5      0.6732953701482783d-09,-.3749451181218537d-09,
     6      0.1999005362041460d-09,-.4020857907825965d-09,
     7      -.1206382630077399d-08,-.5943386337499112d-08,
     8      -.1984193233945674d-07,-.5482228763482070d-07/
         data arr1683/
     1      -.1262449879911151d-06,-.2453679469100410d-06,
     2      -.4124496467120602d-06,-.6074754797029404d-06,
     3      -.7927112900922049d-06,-.9273826475543070d-06,
     4      -.9823217867509143d-06,-.9491089112027931d-06,
     5      -.8417528853286481d-06,-.6895380885686082d-06,
     6      -.5247948538440564d-06,-.3727911638133470d-06,
     7      -.2477870815316820d-06,-.1542086848681559d-06,
     8      -.8991373359684715d-07,-.4964336796121051d-07/
         data arr1684/
     1      -.3129579485442552d-07,-.1085759736445620d-10,
     2      0.1533307574507340d-08,-.1229154562352661d-08,
     3      0.7340395101240822d-09,-.4282339883470131d-09,
     4      0.2702654257946347d-09,-.2755828853421807d-09,
     5      -.2336476042442646d-09,-.2142908699226133d-08,
     6      -.7582319890657050d-08,-.2303151621693823d-07,
     7      -.5851887903853245d-07,-.1234523489494386d-06,
     8      -.2248478972141567d-06,-.3575169512350277d-06/
         data arr1685/
     1      -.5009379327971080d-06,-.6269181211977585d-06,
     2      -.7084734365122101d-06,-.7281609972710350d-06,
     3      -.6848264718294007d-06,-.5933415691309558d-06,
     4      -.4767590713071901d-06,-.3570653334115653d-06,
     5      -.2498733782748870d-06,-.1634552242447195d-06,
     6      -.1000393343074395d-06,-.5800347364617251d-07,
     7      -.3882010985358579d-07,-.2156957889539892d-10,
     8      0.1712478886549386d-08,-.1366631749936076d-08/
         data arr1686/
     1      0.8185267300697543d-09,-.4737170559034688d-09,
     2      0.3081931185864934d-09,-.2492853013137107d-09,
     3      0.8131636220899516d-10,-.8034619874775753d-09,
     4      -.2736766715615154d-08,-.9133800021993685d-08,
     5      -.2586460873357912d-07,-.5896363396488946d-07,
     6      -.1164073798588361d-06,-.1999485658703360d-06,
     7      -.3006565943179935d-06,-.4023229735377334d-06,
     8      -.4848624147749423d-06,-.5296013732973438d-06/
         data arr1687/
     1      -.5273088048495700d-06,-.4820421976078127d-06,
     2      -.4074591294988226d-06,-.3199986339287403d-06,
     3      -.2338997711687433d-06,-.1590812901729800d-06,
     4      -.1007370938881754d-06,-.6016338563871789d-07,
     5      -.4139478187819395d-07,0.6576032453600714d-11,
     6      0.1269250620885301d-08,-.1104146682813999d-08,
     7      0.7195519264805153d-09,-.4590017269424837d-09,
     8      0.3259487622914082d-09,-.2696536079643398d-09/
         data arr1688/
     1      0.1970927555979126d-09,-.3618261713462810d-09,
     2      -.9603243941599940d-09,-.3325067371736593d-08,
     3      -.1104589981464186d-07,-.2681267096483915d-07,
     4      -.5730135012996114d-07,-.1067060553429235d-06,
     5      -.1721237560611039d-06,-.2461064223417084d-06,
     6      -.3166169015731796d-06,-.3681505587281307d-06,
     7      -.3887087423104957d-06,-.3757510193254658d-06,
     8      -.3354182972082108d-06,-.2779766258203024d-06/
         data arr1689/
     1      -.2141550798972619d-06,-.1532444887766944d-06,
     2      -.1019466388450998d-06,-.6400741929933012d-07,
     3      -.4686145572411148d-07,-.8465902141729364d-11,
     4      0.1302724304773745d-08,-.1105767480980966d-08,
     5      0.7115380573372399d-09,-.4421624524141460d-09,
     6      0.3128820673959215d-09,-.2487377421301557d-09,
     7      0.2100511229966117d-09,-.2077260583759127d-09,
     8      -.3121941844005035d-09,-.1089983392685101d-08/
         data arr1690/
     1      -.4591151554978660d-08,-.1159863542338464d-07,
     2      -.2688849565638750d-07,-.5438532255106881d-07,
     3      -.9390900715496743d-07,-.1432451941117498d-06,
     4      -.1963425443619644d-06,-.2421770302555411d-06,
     5      -.2698218593261741d-06,-.2740675129221674d-06,
     6      -.2561341076520678d-06,-.2213139132592307d-06,
     7      -.1768596301295192d-06,-.1305376574145602d-06,
     8      -.8907078232542790d-07,-.5706217838996136d-07/
         data arr1691/
     1      -.4243393957963485d-07,0.3034712421853717d-10,
     2      0.4467414207247654d-09,-.5429172092970288d-09,
     3      0.4524348039086388d-09,-.3483477441919813d-09,
     4      0.2868360088313879d-09,-.2550636097002929d-09,
     5      0.2233101220390629d-09,-.1556782083171967d-09,
     6      -.1414427891455225d-09,-.1812319140347433d-09,
     7      -.1989301475870738d-08,-.4803888462523451d-08,
     8      -.1192213447553808d-07,-.2670688847008746d-07/
         data arr1692/
     1      -.4932072071611256d-07,-.8002969831506063d-07,
     2      -.1172901477730044d-06,-.1543308682229104d-06,
     3      -.1823524191865634d-06,-.1957672552633397d-06,
     4      -.1933139098711823d-06,-.1765355378410879d-06,
     5      -.1489586118200999d-06,-.1158432195920304d-06,
     6      -.8313809537070471d-07,-.5606960886766965d-07,
     7      -.4448505490336744d-07,0.8520033591549941d-11,
     8      0.4811527637225249d-09,-.5070737036259050d-09/
         data arr1693/
     1      0.3957298720225177d-09,-.2855705518647160d-09,
     2      0.2313551133048885d-09,-.1973753129349357d-09,
     3      0.1777948776407755d-09,-.1124077109449409d-09,
     4      -.5460768020610178d-10,0.5350449226263684d-10,
     5      -.8679196607018082d-09,-.1873399068405188d-08,
     6      -.5028634086184986d-08,-.1250055456331814d-07,
     7      -.2452268537761790d-07,-.4216086736804448d-07,
     8      -.6562826602774322d-07,-.9117245221406075d-07/
         data arr1694/
     1      -.1129071358541819d-06,-.1264090922934776d-06,
     2      -.1296576618335749d-06,-.1224159017783731d-06,
     3      -.1061981876469484d-06,-.8443061757270383d-07,
     4      -.6161841156402265d-07,-.4205738035624500d-07,
     5      -.3359482276978435d-07,0.4293400132228523d-10,
     6      -.4115880244749204d-09,0.1009135642310058d-09,
     7      0.9895065303997044d-10,-.1627180450633543d-09,
     8      0.1813849429574534d-09,-.1831903172991138d-09/
         data arr1695/
     1      0.1660350953376420d-09,-.8921117506432809d-10,
     2      -.7557012480920336d-10,0.2000331269363665d-09,
     3      -.4910743768856734d-09,-.7231487316624476d-09,
     4      -.1888367716378808d-08,-.5771028411757752d-08,
     5      -.1200933380965738d-07,-.2162609603628490d-07,
     6      -.3613916123751988d-07,-.5383918959942625d-07,
     7      -.7071211950144847d-07,-.8356506499614525d-07,
     8      -.9060358865276602d-07,-.9058897398991414d-07/
         data arr1696/
     1      -.8315413890313700d-07,-.6975441424488897d-07,
     2      -.5359028707482818d-07,-.3854046972232873d-07,
     3      -.3290627136448276d-07,0.1281171588970118d-10,
     4      -.4907668793702087d-10,-.6613393946476540d-10,
     5      0.1184815100519948d-09,-.1169884647063499d-09,
     6      0.1147384243142956d-09,-.1063164846978535d-09,
     7      0.9830783102165679d-10,-.5332010592919539d-10,
     8      -.3102863545899626d-10,0.1186119068220785d-09/
         data arr1697/
     1      -.2261074583511394d-09,-.2431293172767388d-09,
     2      -.6819320918188466d-09,-.2422224466093624d-08,
     3      -.5254497402942630d-08,-.9891133095596420d-08,
     4      -.1736589496581986d-07,-.2693922091846813d-07,
     5      -.3654872650812876d-07,-.4440598443533473d-07,
     6      -.4927605638225519d-07,-.5014878123960874d-07,
     7      -.4658762106236168d-07,-.3935408476600188d-07,
     8      -.3031142187930112d-07,-.2175546654268107d-07/
         data arr1698/
     1      -.1838842420669256d-07,0.3282435442971280d-10,
     2      -.5922273534900613d-09,0.3108962776697022d-09,
     3      -.7172377281813603d-10,-.3339615916625410d-10,
     4      0.7596031763599646d-10,-.9012517018348827d-10,
     5      0.8388864277985723d-10,-.3723261845481666d-10,
     6      -.5323680854619840d-10,0.1465807316057919d-09,
     7      -.1750223300326239d-09,-.1020583501556268d-09,
     8      -.1377819922430850d-09,-.1089285181640874d-08/
         data arr1699/
     1      -.2467336270111176d-08,-.4666392378165075d-08,
     2      -.8871832957427705d-08,-.1491968968705620d-07,
     3      -.2147105303767653d-07,-.2747227450870756d-07,
     4      -.3224001852948253d-07,-.3483828033116409d-07,
     5      -.3433612278972367d-07,-.3065609300137500d-07,
     6      -.2488356608050478d-07,-.1883955002808770d-07,
     7      -.1705767084736332d-07,0.8610857884894962d-11,
     8      -.1869734819363381d-09,0.9239387989681119d-10/
         data arr1700/
     1      -.1241748631474831d-10,-.1889345846743551d-10,
     2      0.3334584353820548d-10,-.3582513250243756d-10,
     3      0.3451865655275745d-10,-.1495898074266845d-10,
     4      -.1838245656080168d-10,0.5686751381386510d-10,
     5      -.6509634640606916d-10,-.2682637316838203d-10,
     6      -.2693652355804726d-10,-.3595285501028417d-09,
     7      -.8281712192108803d-09,-.1601625245106084d-08,
     8      -.3156631182734746d-08,-.5453888170169418d-08/
         data arr1701/
     1      -.8005726367877790d-08,-.1041664303010695d-07,
     2      -.1239640656832647d-07,-.1353457055210066d-07,
     3      -.1342674047009390d-07,-.1202983627119585d-07,
     4      -.9772763002749762d-08,-.7385307840398063d-08,
     5      -.6640010260128109d-08,0.1430422914920699d-10,
     6      -.3705459627004745d-09,0.2224715787017610d-09,
     7      -.8072226441737574d-10,0.1278124146374934d-10,
     8      0.1671905524769084d-10,-.2739911544838061d-10/
         data arr1702/
     1      0.2659137373546701d-10,-.8313761392174485d-11,
     2      -.2571354624934245d-10,0.5985282418771363d-10,
     3      -.5539672007838188d-10,-.2036184701114487d-10,
     4      0.4006742112735487d-10,-.1648603755638178d-09,
     5      -.3922349610276699d-09,-.6883946845251094d-09,
     6      -.1492858469145080d-08,-.2857098236831069d-08,
     7      -.4446859592494959d-08,-.6060767961245062d-08,
     8      -.7620265695782899d-08,-.8854082392742788d-08/
         data arr1703/
     1      -.9339520719059678d-08,-.8851293151839796d-08,
     2      -.7577916779061882d-08,-.6040335286021017d-08,
     3      -.5821331965733685d-08,0.1018030987643397d-08,
     4      0.1091227994640899d-07,0.4091023739872377d-07,
     5      0.1180207695861545d-06,0.2597529702856443d-06,
     6      0.4581736667314813d-06,0.6678919960986611d-06,
     7      0.8258503157502909d-06,0.8842448451531324d-06,
     8      0.8339752639580121d-06,0.7027622971107764d-06/
         data arr1704/
     1      0.5353973447398502d-06,0.3725134121404256d-06,
     2      0.2387388692870958d-06,0.1419562096540168d-06,
     3      0.7880609784033632d-07,0.4107171020593579d-07,
     4      0.2018839798507118d-07,0.9392516734213697d-08,
     5      0.4149140876945950d-08,0.1747249990932270d-08,
     6      0.7046931744713828d-09,0.2725858284548758d-09,
     7      0.1001788970709032d-09,0.3414441141140244d-10,
     8      0.1060320938784505d-10,0.3868978196608607d-11/
         data arr1705/
     1      0.4983395609279139d-09,0.6608242219082786d-08,
     2      0.3019626475348002d-07,0.1027227255916950d-06,
     3      0.2627512104736236d-06,0.5308106547269901d-06,
     4      0.8759302520777828d-06,0.1213709370930809d-05,
     5      0.1443725407654221d-05,0.1501396643241245d-05,
     6      0.1385845962581383d-05,0.1149846360482156d-05,
     7      0.8668121032108392d-06,0.5991348266913122d-06,
     8      0.3826566108531834d-06,0.2273414616816757d-06/
         data arr1706/
     1      0.1263680367621419d-06,0.6604302847211106d-07,
     2      0.3258828033232065d-07,0.1523714526061339d-07,
     3      0.6772696149043478d-08,0.2870030314630408d-08,
     4      0.1161820458737401d-08,0.4493216159181156d-09,
     5      0.1656661062383598d-09,0.5834315879353417d-10,
     6      0.2242144083055032d-10,0.1717942554567388d-09,
     7      0.2778766785927864d-08,0.1544471945294717d-07,
     8      0.6200272039236291d-07,0.1842794491981242d-06/
         data arr1707/
     1      0.4264081500740996d-06,0.7965208161581968d-06,
     2      0.1236796918168829d-05,0.1634424087016390d-05,
     3      0.1874150496662200d-05,0.1894927445332695d-05,
     4      0.1712261149464811d-05,0.1398536708006249d-05,
     5      0.1042558336293709d-05,0.7152090949866443d-06,
     6      0.4547259693273061d-06,0.2695894458575951d-06,
     7      0.1498212978068739d-06,0.7839996347307816d-07,
     8      0.3877994580037811d-07,0.1819287348293902d-07/
         data arr1708/
     1      0.8117998314697841d-08,0.3453292558851817d-08,
     2      0.1402187517128242d-08,0.5435332994808865d-09,
     3      0.2018458910140103d-09,0.8158576883553838d-10,
     4      0.5466375323948341d-10,0.9365358038910089d-09,
     5      0.6325566853536952d-08,0.2998981387927548d-07,
     6      0.1035507433552292d-06,0.2744577736056435d-06,
     7      0.5803390268141863d-06,0.1009815728902303d-05,
     8      0.1482531742626838d-05,0.1874442328332608d-05/
         data arr1709/
     1      0.2076013752654183d-05,0.2042955435202323d-05,
     2      0.1807928720505696d-05,0.1453572407793922d-05,
     3      0.1071065804642166d-05,0.7287473021479221d-06,
     4      0.4608164458531708d-06,0.2723248896031273d-06,
     5      0.1511224404714517d-06,0.7907439613792329d-07,
     6      0.3915222113322196d-07,0.1840032738654861d-07,
     7      0.8228087173221011d-08,0.3505823134750441d-08,
     8      0.1423723966493679d-08,0.5532324818777894d-09/
         data arr1710/
     1      0.2346332271929585d-09,0.3415104798340772d-10,
     2      0.2660410772644393d-09,0.2198836935125191d-08,
     3      0.1234076410347855d-07,0.4947966149180463d-07,
     4      0.1502343137233212d-06,0.3595807341743501d-06,
     5      0.7011654641523500d-06,0.1143606825829838d-05,
     6      0.1594309409514267d-05,0.1934202995713720d-05,
     7      0.2072912711721388d-05,0.1987567184574671d-05,
     8      0.1723483507399493d-05,0.1364058360385494d-05/
         data arr1711/
     1      0.9931996865465484d-06,0.6698641419747478d-06,
     2      0.4209569957991597d-06,0.2477297552611133d-06,
     3      0.1371188577444374d-06,0.7165602718918948d-07,
     4      0.3547217321344887d-07,0.1667783637247465d-07,
     5      0.7458672142414340d-08,0.3174167241069452d-08,
     6      0.1291453017496391d-08,0.5768829146711550d-09,
     7      0.5647391292290615d-10,0.6028063258222629d-10,
     8      0.6630332929981546d-09,0.4472997095986533d-08/
         data arr1712/
     1      0.2077071272377605d-07,0.7228186838663617d-07,
     2      0.1958049131568355d-06,0.4278853820136333d-06,
     3      0.7753084867488499d-06,0.1191781648059076d-05,
     4      0.1583800004487868d-05,0.1848535044505970d-05,
     5      0.1920377529297782d-05,0.1795988343389083d-05,
     6      0.1526774653267317d-05,0.1189651281856439d-05,
     7      0.8557947958796363d-06,0.5718907495336340d-06,
     8      0.3569005828442071d-06,0.2089608165538379d-06/
         data arr1713/
     1      0.1152481349000220d-06,0.6008907417793785d-07,
     2      0.2969827192536158d-07,0.1393353065919113d-07,
     3      0.6207357735252710d-08,0.2639233337812143d-08,
     4      0.1236497376520759d-08,0.1190276323867837d-09,
     5      -.3479491225485061d-11,0.1621641113754875d-09,
     6      0.1475517187593500d-08,0.7808329953823667d-08,
     7      0.3122764818019645d-07,0.9568515603521441d-07,
     8      0.2343665428283176d-06,0.4717591778721890d-06/
         data arr1714/
     1      0.7995835038757181d-06,0.1163993554458826d-05,
     2      0.1479520347417253d-05,0.1665318562429016d-05,
     3      0.1679769903736613d-05,0.1533788283232231d-05,
     4      0.1278934252361896d-05,0.9812977463199272d-06,
     5      0.6973367367708686d-06,0.4615009041732663d-06,
     6      0.2858191947836987d-06,0.1663785226561715d-06,
     7      0.9138086894744279d-07,0.4749139006790888d-07,
     8      0.2338830017176277d-07,0.1091851481676366d-07/
         data arr1715/
     1      0.4861130925047570d-08,0.2401179966982160d-08,
     2      0.2219963226674142d-09,-.3294397331676919d-10,
     3      0.3933515836545161d-11,0.4805776033074571d-09,
     4      0.2641762948734904d-08,0.1231370822954447d-07,
     5      0.4256507741996056d-07,0.1169281088132020d-06,
     6      0.2614408615039309d-06,0.4885666762592509d-06,
     7      0.7791448890705096d-06,0.1078494046133080d-05,
     8      0.1315256410842755d-05,0.1430890846480732d-05/
         data arr1716/
     1      0.1403339693967688d-05,0.1252210451239775d-05,
     2      0.1024787426805021d-05,0.7744137945096522d-06,
     3      0.5434763649091189d-06,0.3560083552175404d-06,
     4      0.2186933725749717d-06,0.1264923224538203d-06,
     5      0.6908541917120926d-07,0.3567071316814886d-07,
     6      0.1741346113379122d-07,0.8089098230685564d-08,
     7      0.4181121010080072d-08,0.4126133452701797d-09,
     8      -.7458556450885914d-10,-.5992476077815373d-10/
         data arr1717/
     1      0.2084886454481271d-09,0.7658981003205602d-09,
     2      0.4518167387019073d-08,0.1739377808446789d-07,
     3      0.5373347492462270d-07,0.1333954645640056d-06,
     4      0.2748195714539758d-06,0.4802082777682316d-06,
     5      0.7237970143731035d-06,0.9563624638108297d-06,
     6      0.1122235236954710d-05,0.1182153307370661d-05,
     7      0.1128777154411266d-05,0.9853261146153595d-06,
     8      0.7918401603589318d-06,0.5892958389387838d-06/
         data arr1718/
     1      0.4083115208444691d-06,0.2647362930679202d-06,
     2      0.1613257291472159d-06,0.9267026355781467d-07,
     3      0.5023286530511008d-07,0.2570015483238099d-07,
     4      0.1250616823499928d-07,0.6826191619832033d-08,
     5      0.6531049527275131d-09,-.1210947368146913d-09,
     6      -.1070622845133341d-09,0.1735779922069651d-09,
     7      0.1175753268880177d-09,0.1611773235226884d-08,
     8      0.6539894846598289d-08,0.2296105385961046d-07/
         data arr1719/
     1      0.6319233915399447d-07,0.1434780666710820d-06,
     2      0.2748327604362766d-06,0.4509616121183620d-06,
     3      0.6455855714130611d-06,0.8171872357125862d-06,
     4      0.9245443322196110d-06,0.9446204775519935d-06,
     5      0.8795216900465501d-06,0.7516449621211116d-06,
     6      0.5931115649950885d-06,0.4345677353414677d-06,
     7      0.2972640583135631d-06,0.1907094940809595d-06,
     8      0.1150612564349073d-06,0.6532348966085057d-07/
         data arr1720/
     1      0.3489339623874438d-07,0.1768096454960839d-07,
     2      0.1007353685600552d-07,0.1066731969515412d-08,
     3      -.2215550966946495d-09,-.1537950507768065d-09,
     4      0.2236780008474213d-09,-.1333809955477485d-09,
     5      0.6511265620733655d-09,0.2202762468205668d-08,
     6      0.9227493205130190d-08,0.2798331881288125d-07,
     7      0.6993783328923219d-07,0.1471013892356518d-06,
     8      0.2625740703505274d-06,0.4072486924472498d-06/
         data arr1721/
     1      0.5562264018275730d-06,0.6758319905074359d-06,
     2      0.7387837582741532d-06,0.7337838379299375d-06,
     3      0.6669783395458207d-06,0.5580850034469441d-06,
     4      0.4324594497414136d-06,0.3122458292562782d-06,
     5      0.2111093505870617d-06,0.1340046628605256d-06,
     6      0.7988461239400268d-07,0.4472479209482679d-07,
     7      0.2374829231950086d-07,0.1430871611154680d-07,
     8      0.1431264421754278d-08,-.2987033749898800d-09/
         data arr1722/
     1      -.2051421040947359d-09,0.2913812786160778d-09,
     2      -.2520095882202487d-09,0.3822610565380802d-09,
     3      0.5761853516406968d-09,0.3556134958475219d-08,
     4      0.1165026931983797d-07,0.3195185654044426d-07,
     5      0.7409703422468806d-07,0.1436364948787033d-06,
     6      0.2413543200936661d-06,0.3558495350264588d-06,
     7      0.4642508693368319d-06,0.5428601003098292d-06,
     8      0.5751613503384438d-06,0.5559586823320672d-06/
         data arr1723/
     1      0.4930438474525645d-06,0.4037428888146472d-06,
     2      0.3073184021631728d-06,0.2185258709012743d-06,
     3      0.1454567364036272d-06,0.9059081425135902d-07,
     4      0.5277353386020823d-07,0.2905495182748683d-07,
     5      0.1816306499262275d-07,0.2102084533145284d-08,
     6      -.4909443722886409d-09,-.2474755052552760d-09,
     7      0.3844767509048581d-09,-.3615717168081167d-09,
     8      0.3713548045046425d-09,-.4380397131378950d-10/
         data arr1724/
     1      0.1397370426300060d-08,0.4590287501811465d-08,
     2      0.1364278910631403d-07,0.3540586553991880d-07,
     3      0.7412393764439722d-07,0.1349169229379092d-06,
     4      0.2150471105066254d-06,0.3011267783014743d-06,
     5      0.3764985849050929d-06,0.4256895004251096d-06,
     6      0.4378234537455924d-06,0.4116674473556135d-06,
     7      0.3564293552311613d-06,0.2864094033481326d-06,
     8      0.2147508613133717d-06,0.1504870406640689d-06/
         data arr1725/
     1      0.9845493851115082d-07,0.6013484637692655d-07,
     2      0.3471939105745038d-07,0.2300179303277817d-07,
     3      0.2429566999785906d-08,-.5683644640802534d-09,
     4      -.2846221026154142d-09,0.4436278349994000d-09,
     5      -.4208777378084821d-09,0.3948834604933421d-09,
     6      -.2628480238112825d-09,0.6232593076422395d-09,
     7      0.1724057036101349d-08,0.5389816796874880d-08,
     8      0.1619175654060760d-07,0.3619971413807414d-07/
         data arr1726/
     1      0.7137384538124673d-07,0.1232386872703902d-06,
     2      0.1850704284946785d-06,0.2472324187701967d-06,
     3      0.2982463809725551d-06,0.3261691311421322d-06,
     4      0.3246878938401231d-06,0.2966091157358671d-06,
     5      0.2508486739357530d-06,0.1974239585591047d-06,
     6      0.1446707126348747d-06,0.9852097196150814d-07,
     7      0.6234063797054820d-07,0.3714169007195402d-07,
     8      0.2538462013843616d-07,0.3233219774958443d-08/
         data arr1727/
     1      -.8405083027598235d-09,-.2919479896810480d-09,
     2      0.5233241291992205d-09,-.5126616418086683d-09,
     3      0.4738184852075301d-09,-.3949313500975842d-09,
     4      0.3950932879899837d-09,0.6362855069219800d-09,
     5      0.1819435362995322d-08,0.7285597029725676d-08,
     6      0.1673920949833651d-07,0.3573050862137461d-07,
     7      0.6734646980592111d-07,0.1082665646379669d-06,
     8      0.1542918756764398d-06,0.1988833340759904d-06/
         data arr1728/
     1      0.2316874104244404d-06,0.2444287900672757d-06,
     2      0.2359387035798005d-06,0.2106963776270029d-06,
     3      0.1750150700621965d-06,0.1351289630590014d-06,
     4      0.9670345845335298d-07,0.6416432452367898d-07,
     5      0.4010670976761127d-07,0.2909460415297430d-07,
     6      0.3093164038843528d-08,-.7924086404569195d-09,
     7      -.2908878253038184d-09,0.5104031454046703d-09,
     8      -.4968380735596264d-09,0.4578101877361411d-09/
         data arr1729/
     1      -.3959231177665688d-09,0.2971219459923139d-09,
     2      0.2361417123942870d-09,0.4343701549038965d-09,
     3      0.3280683969093899d-08,0.7329900514418787d-08,
     4      0.1695767198462387d-07,0.3513897632581222d-07,
     5      0.6029303314489362d-07,0.9146312583381789d-07,
     6      0.1257977658468025d-06,0.1556490270281802d-06,
     7      0.1732829550156260d-06,0.1757661986272890d-06,
     8      0.1644802412055105d-06,0.1426650180874263d-06/
         data arr1730/
     1      0.1144473304210299d-06,0.8461048351972481d-07,
     2      0.5767983642861497d-07,0.3686914835728957d-07,
     3      0.2727143893437707d-07,0.3785814415480128d-08,
     4      -.1074322049571886d-08,-.2482185581701552d-09,
     5      0.5414652611165243d-09,-.5478890135878024d-09,
     6      0.5091527301168221d-09,-.4495480346027680d-09,
     7      0.2965507111425453d-09,0.1109988721392200d-09,
     8      -.1616821159401439d-09,0.1675551736788106d-08/
         data arr1731/
     1      0.2995020393804385d-08,0.7493849506608979d-08,
     2      0.1775463057879057d-07,0.3226741654161048d-07,
     3      0.5181130438061061d-07,0.7645294521598492d-07,
     4      0.1010566525391199d-06,0.1191218773806496d-06,
     5      0.1275155035590756d-06,0.1260713623770481d-06,
     6      0.1156034411935693d-06,0.9785063873429959d-07,
     7      0.7607701400405042d-07,0.5441014584150794d-07,
     8      0.3652284344240047d-07,0.2873808035743952d-07/
         data arr1732/
     1      0.3029327443391568d-08,-.8493303986621293d-09,
     2      -.2087422545335043d-09,0.4419934357448033d-09,
     3      -.4438963502351620d-09,0.4131362407719823d-09,
     4      -.3634839549093767d-09,0.2341463142260552d-09,
     5      0.5711804279546756d-10,-.2671622761856525d-09,
     6      0.8893204253256169d-09,0.1135908807570637d-08,
     7      0.3101378909506349d-08,0.8574646793642691d-08,
     8      0.1637472014562119d-07,0.2769333326221624d-07/
         data arr1733/
     1      0.4359240612818890d-07,0.6101126726342426d-07,
     2      0.7539693886340348d-07,0.8421514356031055d-07,
     3      0.8665752226886923d-07,0.8238607315838429d-07,
     4      0.7190463548428346d-07,0.5731149537580876d-07,
     5      0.4180876545323603d-07,0.2850700145995664d-07,
     6      0.2271538267860868d-07,0.3391070280614253d-08,
     7      -.1043901113830431d-08,-.1376550703966769d-09,
     8      0.4203724377016761d-09,-.4433174797724816d-09/
         data arr1734/
     1      0.4172147933745765d-09,-.3712850031135108d-09,
     2      0.2323337277505895d-09,0.5158412986139465d-10,
     3      -.3546698584363790d-09,0.6463305113009836d-09,
     4      0.3552825474431802d-09,0.1053143224181959d-08,
     5      0.4177321094724950d-08,0.8155251884698656d-08,
     6      0.1424876618495762d-07,0.2433521186102038d-07,
     7      0.3662110610968702d-07,0.4780458916306924d-07,
     8      0.5619773028384079d-07,0.6112090770060992d-07/
         data arr1735/
     1      0.6154252016202215d-07,0.5673772069721712d-07,
     2      0.4756344995212137d-07,0.3639078552535307d-07,
     3      0.2605546401522342d-07,0.2209949136339886d-07,
     4      0.1948758878396124d-08,-.5820303736844069d-09,
     5      -.9727395064973906d-10,0.2562166865583899d-09,
     6      -.2647983248407672d-09,0.2489489854609722d-09,
     7      -.2197394552446072d-09,0.1383878714834485d-09,
     8      0.2766832396804879d-10,-.2168680890080937d-09/
         data arr1736/
     1      0.3467959058416905d-09,0.9419674384492764d-10,
     2      0.3309432176146215d-09,0.1835847770236054d-08,
     3      0.3656914062104477d-08,0.6607244106336813d-08,
     4      0.1194184681399616d-07,0.1878774469244087d-07,
     5      0.2535214366804435d-07,0.3067119863177537d-07,
     6      0.3421623695567903d-07,0.3516675521267164d-07,
     7      0.3291061679079878d-07,0.2786525749884375d-07,
     8      0.2144156802329084d-07,0.1537466633102660d-07/
         data arr1737/
     1      0.1297657299666880d-07,0.2031640966622718d-08,
     2      -.6631539894668702d-09,-.4333950969887191d-10,
     3      0.2219891646157289d-09,-.2436425006667557d-09,
     4      0.2320628914684788d-09,-.2074676655706686d-09,
     5      0.1277334932981293d-09,0.3007431692338390d-10,
     6      -.2191632141367351d-09,0.2993381062833948d-09,
     7      -.1175623893495675d-10,-.1986238781478783d-10,
     8      0.9238007561794833d-09,0.1740045872805876d-08/
         data arr1738/
     1      0.3058457981740663d-08,0.6162554247344417d-08,
     2      0.1055506042926250d-07,0.1498853269027697d-07,
     3      0.1901109328588874d-07,0.2243868872921851d-07,
     4      0.2449380075858300d-07,0.2425909776893161d-07,
     5      0.2162049161220396d-07,0.1745636943160991d-07,
     6      0.1315537055034288d-07,0.1183962982524144d-07,
     7      0.8646756666906388d-09,-.2788729776720816d-09,
     8      -.2173858571090120d-10,0.9736583625250868d-10/
         data arr1739/
     1      -.1055118879616050d-09,0.1007185172263554d-09,
     2      -.8925130405009371d-10,0.5518892355620870d-10,
     3      0.1297932959560207d-10,-.9450531080740372d-10,
     4      0.1269163592041567d-09,-.1413924951807361d-10,
     5      -.3465427959560527d-10,0.3332627038413279d-09,
     6      0.6141874440552626d-09,0.1077804533000546d-08,
     7      0.2289763383225390d-08,0.4062818148356642d-08,
     8      0.5895653511475595d-08,0.7621208867388093d-08/
         data arr1740/
     1      0.9161220453631384d-08,0.1015768047692136d-07,
     2      0.1018047817449289d-07,0.9150748684873235d-08,
     3      0.7432290781761338d-08,0.5621712544779758d-08,
     4      0.5064102796996863d-08,0.8121966264393512d-09,
     5      -.2831853322852722d-09,0.1411027101141186d-11,
     6      0.7432533433582690d-10,-.8696534041978724d-10,
     7      0.8411658900783932d-10,-.7575590496884999d-10,
     8      0.4571805702571346d-10,0.1284657112788955d-10/
         data arr1741/
     1      -.8385367942549838d-10,0.1057875804179246d-09,
     2      -.1946660664833336d-10,-.6859077076311339d-10,
     3      0.1825681930318971d-09,0.2883746994744766d-09,
     4      0.4282092784575478d-09,0.1080867720135780d-08,
     5      0.2132437821256404d-08,0.3231926377397497d-08,
     6      0.4345617189527836d-08,0.5522222367702905d-08,
     7      0.6512316546562780d-08,0.6908310768269813d-08,
     8      0.6528540703371670d-08,0.5555261818640220d-08/
         data arr1742/
     1      0.4410043977106692d-08,0.4231321973907598d-08,
     2      -.6047706763257384d-10,-.1304279117648449d-08,
     3      -.5922676663478761d-08,-.2014381358197135d-07,
     4      -.5153110895590589d-07,-.1040995329039577d-06,
     5      -.1717847126783440d-06,-.2380276230309685d-06,
     6      -.2831378044413776d-06,-.2944484389585049d-06,
     7      -.2717863171536731d-06,-.2255035640329563d-06,
     8      -.1699960332162846d-06,-.1174997233509315d-06/
         data arr1743/
     1      -.7504508945036186d-07,-.4458554254008227d-07,
     2      -.2478277996360038d-07,-.1295190936653143d-07,
     3      -.6391073243155110d-08,-.2988386117272295d-08,
     4      -.1328281767831248d-08,-.5627624207989747d-09,
     5      -.2277437697318096d-09,-.8810343891526279d-10,
     6      -.3254676076397572d-10,-.1149278526869706d-10,
     7      -.4357617168573899d-11,-.2842761629784211d-10,
     8      -.7608062625774156d-09,-.4203594043402063d-08/
         data arr1744/
     1      -.1687425618724356d-07,-.5015515714700916d-07,
     2      -.1160531081035016d-06,-.2167858549698332d-06,
     3      -.3366133082220302d-06,-.4448338467935649d-06,
     4      -.5100793923178502d-06,-.5157336640234686d-06,
     5      -.4660185181241727d-06,-.3806336588492923d-06,
     6      -.2837482652187057d-06,-.1946551785327569d-06,
     7      -.1237609053196341d-06,-.7337300017128729d-07,
     8      -.4077604109008610d-07,-.2133769823901318d-07/
         data arr1745/
     1      -.1055467423801217d-07,-.4951586035568383d-08,
     2      -.2209416546615337d-08,-.9397608203878673d-09,
     3      -.3815554707458831d-09,-.1479399722217900d-09,
     4      -.5497390428007643d-10,-.2211793002363316d-10,
     5      -.9537890519875525d-11,-.3100017333103919d-09,
     6      -.2069666722211979d-08,-.9816484334266965d-08,
     7      -.3389514805342292d-07,-.8983712370957323d-07,
     8      -.1899607651626805d-06,-.3305396847670566d-06/
         data arr1746/
     1      -.4852722865290825d-06,-.6135556184438754d-06,
     2      -.6795346839073304d-06,-.6687141104951689d-06,
     3      -.5917839495471373d-06,-.4757930253717517d-06,
     4      -.3505883100552687d-06,-.2385388519037039d-06,
     5      -.1508378122848170d-06,-.8913895003453035d-07,
     6      -.4946615264671765d-07,-.2588335181440131d-07,
     7      -.1281591587772710d-07,-.6022964127024560d-08,
     8      -.2692989179322240d-08,-.1147245261904993d-08/
         data arr1747/
     1      -.4659192065431050d-09,-.1811181185194864d-09,
     2      -.7648446048073674d-10,-.3630112101663075d-11,
     3      -.1053254507351254d-09,-.8139762341337729d-09,
     4      -.4583908432713918d-08,-.1837643028487528d-07,
     5      -.5579518311359824d-07,-.1335453884355159d-06,
     6      -.2604061363251556d-06,-.4247245339939458d-06,
     7      -.5921125602206637d-06,-.7183441274661932d-06,
     8      -.7698603467863216d-06,-.7381649458811205d-06/
         data arr1748/
     1      -.6400850984926538d-06,-.5065977774318542d-06,
     2      -.3688659654878088d-06,-.2487819764666116d-06,
     3      -.1563386886953748d-06,-.9200373239946083d-07,
     4      -.5092522234697330d-07,-.2661345573139965d-07,
     5      -.1317425950251337d-07,-.6193258324117478d-08,
     6      -.2769278903540220d-08,-.1178642188634436d-08,
     7      -.4798201217448229d-09,-.2134311271588967d-09,
     8      -.5037258030164184d-11,-.3925590500683306d-10/
         data arr1749/
     1      -.2644145140756719d-09,-.1827637657608637d-08,
     2      -.8479951882925821d-08,-.2950781217132421d-07,
     3      -.7993813726005803d-07,-.1746829814161779d-06,
     4      -.3165174027258309d-06,-.4865450656133671d-06,
     5      -.6465815181324817d-06,-.7546610047984640d-06,
     6      -.7839933848505351d-06,-.7332076041862135d-06,
     7      -.6233011902314974d-06,-.4856752899239844d-06,
     8      -.3493784694272521d-06,-.2334714148432504d-06/
         data arr1750/
     1      -.1457022070675283d-06,-.8530949931746542d-07,
     2      -.4705277929271035d-07,-.2453206234307518d-07,
     3      -.1212268537076285d-07,-.5686599071171381d-08,
     4      -.2533859584759232d-08,-.1078130135489380d-08,
     5      -.5029536589554550d-09,-.1399447970244220d-10,
     6      -.2893508468932250d-10,-.5903251019943271d-10,
     7      -.6516941445180502d-09,-.3436638061266399d-08,
     8      -.1373546127935684d-07,-.4209873594762097d-07/
         data arr1751/
     1      -.1031062612374560d-06,-.2075443791296403d-06,
     2      -.3517750380297161d-06,-.5120839269707381d-06,
     3      -.6509018447069723d-06,-.7326482966986722d-06,
     4      -.7389965029822964d-06,-.6747726325094770d-06,
     5      -.5626612046767945d-06,-.4317171539578116d-06,
     6      -.3067825423611056d-06,-.2030292404405876d-06,
     7      -.1257474558281158d-06,-.7320333996884075d-07,
     8      -.4020385752150295d-07,-.2088985017033966d-07/
         data arr1752/
     1      -.1028584143642397d-07,-.4803315774988001d-08,
     2      -.2140564803290956d-08,-.1052704470063514d-08,
     3      -.3290271821242227d-10,-.4094865123750557d-10,
     4      0.2067381273326033d-10,-.2286904158732796d-09,
     5      -.1238776755780395d-08,-.5753061101241332d-08,
     6      -.1991377330422299d-07,-.5468530441105110d-07,
     7      -.1222737848048762d-06,-.2285163282805170d-06,
     8      -.3644015462167432d-06,-.5044187954579758d-06/
         data arr1753/
     1      -.6151662360582020d-06,-.6692302703141063d-06,
     2      -.6563436390039394d-06,-.5856780411790705d-06,
     3      -.4793075413270994d-06,-.3621892745706787d-06,
     4      -.2541796053713648d-06,-.1665149589544759d-06,
     5      -.1022968741029499d-06,-.5916366822500821d-07,
     6      -.3230355107722368d-07,-.1667510738135825d-07,
     7      -.8142942786823386d-08,-.3786167145297757d-08,
     8      -.1947222792343456d-08,-.8200309494171328d-10/
         data arr1754/
     1      -.5463759213917331d-10,0.6189937339929361d-10,
     2      -.1049976102545688d-09,-.3863464090422800d-09,
     3      -.2211478623286307d-08,-.8576598696447781d-08,
     4      -.2645043331570774d-07,-.6567278982285779d-07,
     5      -.1353312911924367d-06,-.2364185484084673d-06,
     6      -.3563731748392979d-06,-.4709017607672539d-06,
     7      -.5525352489381131d-06,-.5820372132313955d-06,
     8      -.5557915911278191d-06,-.4851538043979565d-06/
         data arr1755/
     1      -.3898569522711281d-06,-.2901354437316864d-06,
     2      -.2010545444728000d-06,-.1303720129248836d-06,
     3      -.7943732718781140d-07,-.4561537532402768d-07,
     4      -.2472178308116655d-07,-.1265596940959265d-07,
     5      -.6167198852966272d-08,-.3349905464382564d-08,
     6      -.1567080948912406d-09,-.7252886021272726d-10,
     7      0.1010277877123105d-09,-.8881389550655458d-10,
     8      -.7721320529555474d-10,-.8059800312021752d-09/
         data arr1756/
     1      -.3385648650815332d-08,-.1180225727332051d-07,
     2      -.3250123134618022d-07,-.7385055588737986d-07,
     3      -.1413669738164276d-06,-.2320183348127714d-06,
     4      -.3321858479669843d-06,-.4204135545891151d-06,
     5      -.4756500381495899d-06,-.4860369958256734d-06,
     6      -.4525314386757611d-06,-.3866894791935180d-06,
     7      -.3051340461676838d-06,-.2236139187610218d-06,
     8      -.1529869504201967d-06,-.9813431590838958d-07/
         data arr1757/
     1      -.5918380401782523d-07,-.3359571310534253d-07,
     2      -.1796056826378531d-07,-.9115861446922776d-08,
     3      -.5167668291558223d-08,-.3220240717182310d-09,
     4      -.5081704409607305d-10,0.1237961653313140d-09,
     5      -.1021175427799175d-09,0.3382080462756353d-10,
     6      -.3052372763374090d-09,-.1216421492174580d-08,
     7      -.4911581783759101d-08,-.1494281432740184d-07,
     8      -.3743558667739001d-07,-.7857291040027180d-07/
         data arr1758/
     1      -.1403566729991281d-06,-.2177398635876757d-06,
     2      -.2972710488021773d-06,-.3612113287064662d-06,
     3      -.3949534502612562d-06,-.3922553224582834d-06,
     4      -.3564665053506991d-06,-.2982803087970722d-06,
     5      -.2312120727766371d-06,-.1669769205566343d-06,
     6      -.1128675865466677d-06,-.7160979253211003d-07,
     7      -.4268938747616144d-07,-.2393147857851760d-07,
     8      -.1273586745425959d-07,-.7635851306590554d-08/
         data arr1759/
     1      -.4809692923253221d-09,-.4452990978764566d-10,
     2      0.1602790477047729d-09,-.1299072301345157d-09,
     3      0.8551091042977278d-10,-.1489134067991436d-09,
     4      -.3726516938087047d-09,-.1935041932290518d-08,
     5      -.6418594284661204d-08,-.1773371974131644d-07,
     6      -.4087892415887552d-07,-.7940482615818018d-07,
     7      -.1334908728752264d-06,-.1966398531049864d-06,
     8      -.2565741150659372d-06,-.3001566219491983d-06/
         data arr1760/
     1      -.3179750935132566d-06,-.3072493330721347d-06,
     2      -.2725001574480979d-06,-.2232494647657782d-06,
     3      -.1699759413049474d-06,-.1208211399785513d-06,
     4      -.8036680946556371d-07,-.5004768732942748d-07,
     5      -.2919258388126670d-07,-.1610510157644618d-07,
     6      -.1000727030362049d-07,-.8650244976173887d-09,
     7      0.1026877276645447d-09,0.1277164318395094d-09,
     8      -.1336621101431584d-09,0.1040363612791602d-09/
         data arr1761/
     1      -.1096795984407711d-09,-.6469527773400575d-10,
     2      -.7451727431668061d-09,-.2590255239532288d-08,
     3      -.7873898683994653d-08,-.2004420095721722d-07,
     4      -.4223250773266681d-07,-.7694447076593486d-07,
     5      -.1223712893904690d-06,-.1714256962663521d-06,
     6      -.2145335988755063d-06,-.2424838292742612d-06,
     7      -.2492403573574696d-06,-.2343994319969393d-06,
     8      -.2031070114518943d-06,-.1632674238296377d-06/
         data arr1762/
     1      -.1223590083923584d-06,-.8568408331967615d-07,
     2      -.5607773292737586d-07,-.3432721377845124d-07,
     3      -.1988084277717470d-07,-.1309927550552165d-07,
     4      -.1102197356514643d-08,0.1740226300070091d-09,
     5      0.1296066130512775d-09,-.1449118381306040d-09,
     6      0.1220737163847370d-09,-.1045156254836167d-09,
     7      0.4754313190494898d-10,-.3008279970989024d-09,
     8      -.9786299585485658d-09,-.3274634769768293d-08/
         data arr1763/
     1      -.9325520991907162d-08,-.2119574440875203d-07,
     2      -.4187520768377586d-07,-.7196453768305766d-07,
     3      -.1081717834269207d-06,-.1447513566758202d-06,
     4      -.1745155494752319d-06,-.1906713748898356d-06,
     5      -.1898804237482570d-06,-.1736621383362839d-06,
     6      -.1469454802630101d-06,-.1155818173288750d-06,
     7      -.8463419863876807d-07,-.5766717199954174d-07,
     8      -.3658402245085467d-07,-.2186922519244995d-07/
         data arr1764/
     1      -.1485944454520250d-07,-.1722996293511349d-08,
     2      0.5142286730526570d-09,-.1166136682226216d-10,
     3      -.9631805419863415d-10,0.1050380348979453d-09,
     4      -.1003261492893833d-09,0.7953864902974422d-10,
     5      -.1434991328919078d-09,-.3546572982211613d-09,
     6      -.1249692221228298d-08,-.4170692842732692d-08,
     7      -.1007475000332636d-07,-.2157147037353717d-07,
     8      -.4018895376932405d-07,-.6478284697008505d-07/
         data arr1765/
     1      -.9263772876313638d-07,-.1192389610475799d-06,
     2      -.1386746720647430d-06,-.1464266170427907d-06,
     3      -.1416074751289887d-06,-.1265400794626612d-06,
     4      -.1050234489542832d-06,-.8103552349133794d-07,
     5      -.5807189893840929d-07,-.3868459600310209d-07,
     6      -.2429414162468611d-07,-.1753125693652420d-07,
     7      -.1724701607021878d-08,0.5136820416684962d-09,
     8      -.5131349043746671d-11,-.9484521260307370d-10/
         data arr1766/
     1      0.1082377378742838d-09,-.9586601450395888d-10,
     2      0.9094560803772482d-10,-.8748496939500556d-10,
     3      -.1145565410204934d-09,-.4215301091486735d-09,
     4      -.1813719817911406d-08,-.4530477149597147d-08,
     5      -.1054502805302141d-07,-.2135670877146361d-07,
     6      -.3683564445874202d-07,-.5620258867121982d-07,
     7      -.7711534422435346d-07,-.9517641043895088d-07,
     8      -.1060892015028906d-06,-.1078708479399680d-06/
         data arr1767/
     1      -.1010067885327101d-06,-.8749476382780064d-07,
     2      -.7010677170716669d-07,-.5188009407551665d-07,
     3      -.3549107270214383d-07,-.2277197975028647d-07,
     4      -.1672133221941561d-07,-.2444950228085086d-08,
     5      0.9967030674322338d-09,-.2459563875126860d-09,
     6      0.9512590415722381d-11,0.5698070035243864d-10,
     7      -.7475699956686689d-10,0.7690283419486075d-10,
     8      -.5997894752932267d-10,-.4963098216639552d-10/
         data arr1768/
     1      -.8351501448721002d-10,-.8084457346800777d-09,
     2      -.1941251086618229d-08,-.4865810750909343d-08,
     3      -.1088997168244722d-07,-.2007456158762182d-07,
     4      -.3260335885714844d-07,-.4784218199743524d-07,
     5      -.6297469730761881d-07,-.7443088175605898d-07,
     6      -.7999599318574773d-07,-.7915524574706290d-07,
     7      -.7246591236750455d-07,-.6129771862463478d-07,
     8      -.4778399539380678d-07,-.3437254530502821d-07/
         data arr1769/
     1      -.2320754761465826d-07,-.1815077267445056d-07,
     2      -.2085512833923274d-08,0.8550674248495984d-09,
     3      -.2073011661923772d-09,0.1340682979053153d-10,
     4      0.5006422405266034d-10,-.5814947904452353d-10,
     5      0.6740351738900169d-10,-.4266821481843151d-10,
     6      -.1623751397706624d-10,0.2149489142301513d-10,
     7      -.3665364584695532d-09,-.7773455547290366d-09,
     8      -.2122480366853879d-08,-.5289025103595383d-08/
         data arr1770/
     1      -.1035148344268136d-07,-.1782280090122417d-07,
     2      -.2782309213559529d-07,-.3872765671194249d-07,
     3      -.4804373009291931d-07,-.5394275094461152d-07,
     4      -.5556841707218982d-07,-.5273811060813642d-07,
     5      -.4600197233420189d-07,-.3677424771932567d-07,
     6      -.2698996064166705d-07,-.1851069913725807d-07,
     7      -.1465391331621035d-07,-.2615540920349540d-08,
     8      0.1278967635517800d-08,-.4458824694516869d-09/
         data arr1771/
     1      0.1268353148543569d-09,-.1247954208996171d-10,
     2      -.2760082307397097d-10,0.4093356636005581d-10,
     3      -.2405818393275348d-10,-.2690799941077117d-10,
     4      0.6927456218508047d-10,-.1981720427558969d-09,
     5      -.3080043293452264d-09,-.8363718096255511d-09,
     6      -.2514643902986787d-08,-.5221849515857974d-08,
     7      -.9441395801053202d-08,-.1582081766954847d-07,
     8      -.2359532602304033d-07,-.3103461576790197d-07/
         data arr1772/
     1      -.3678288815795196d-07,-.4005004254565609d-07,
     2      -.4023622739517820d-07,-.3711125619524640d-07,
     3      -.3128002832405026d-07,-.2414689692249643d-07,
     4      -.1742957805285922d-07,-.1470454265866637d-07,
     5      -.1515991354714956d-08,0.7112080336237258d-09,
     6      -.2278128145660865d-09,0.5877922098023266d-10,
     7      0.5349617547965204d-11,-.2034804263290135d-10,
     8      0.3133281689342177d-10,-.1595215705563012d-10/
         data arr1773/
     1      -.9492301078073435d-11,0.4808279394199293d-10,
     2      -.9522307706225698d-10,-.1035789630476960d-09,
     3      -.3105971387808627d-09,-.1094172674505725d-08,
     4      -.2366094784097165d-08,-.4475545011363397d-08,
     5      -.7897996229054184d-08,-.1228652765207234d-07,
     6      -.1671399608642846d-07,-.2039309560379237d-07,
     7      -.2276075794353599d-07,-.2331094099098917d-07,
     8      -.2179037582208083d-07,-.1851706432051329d-07/
         data arr1774/
     1      -.1434696779996996d-07,-.1034616766932916d-07,
     2      -.8656716650596607d-08,-.1762995038806709d-08,
     3      0.9449059786594455d-09,-.3717400983509734d-09,
     4      0.1309249710747943d-09,-.3706962294096416d-10,
     5      0.1842680992755934d-11,0.1112720478900979d-10,
     6      -.3059782496319461d-11,-.2122743721063914d-10,
     7      0.5221424719070137d-10,-.6447799499508162d-10,
     8      -.4584907940522678d-10,-.7523742095570620d-10/
         data arr1775/
     1      -.4992458176541277d-09,-.1135495683981129d-08,
     2      -.2176201741910560d-08,-.4152684962245220d-08,
     3      -.6990620063259700d-08,-.1008738078735609d-07,
     4      -.1296868042737096d-07,-.1530952326991380d-07,
     5      -.1664348170799047d-07,-.1649709300790049d-07,
     6      -.1481079821236131d-07,-.1208702076790138d-07,
     7      -.9187315591489707d-08,-.8212116679525907d-08,
     8      -.8233973898280585d-09,0.4396137286334040d-09/
         data arr1776/
     1      -.1692731356096016d-09,0.6136391317154216d-10,
     2      -.1539793491486758d-10,0.2344619514632872d-11,
     3      0.6412609511625810d-11,-.4005821287454042d-13,
     4      -.7900866974552670d-11,0.2472305136362719d-10,
     5      -.2583698735545500d-10,-.1268042569495723d-10,
     6      -.1370709937786993d-10,-.1752815669977764d-09,
     7      -.4081574079471533d-09,-.7974698596295570d-09,
     8      -.1588580243463413d-08,-.2768117902695179d-08/
         data arr1777/
     1      -.4094173292453417d-08,-.5375255253500467d-08,
     2      -.6468530158598018d-08,-.7147840725195837d-08,
     3      -.7175800748994469d-08,-.6503141127134423d-08,
     4      -.5342825655227547d-08,-.4078527421432011d-08,
     5      -.3651675914719464d-08,-.8344326340676951d-09,
     6      0.4858468618440430d-09,-.2091344605159912d-09,
     7      0.8330738816813992d-10,-.3088310900041614d-10,
     8      0.1049012310825885d-10,-.2473961964775191d-11/
         data arr1778/
     1      0.4752350890119217d-11,-.1230086533701838d-10,
     2      0.2235103195388898d-10,-.1811733550909674d-10,
     3      -.1169125831909725d-10,0.1572175165523614d-10,
     4      -.7817869140214392d-10,-.1951851316197735d-09,
     5      -.3527740431955939d-09,-.7671809025309304d-09,
     6      -.1474396272177267d-08,-.2311826908152216d-08,
     7      -.3179684936077270d-08,-.4037877522407805d-08,
     8      -.4739842088180713d-08,-.5048812181766386d-08/
         data arr1779/
     1      -.4830717974142544d-08,-.4173371346615447d-08,
     2      -.3351287583667048d-08,-.3198286516581416d-08,
     3      0.1823675235049454d-10,0.8821100722716327d-09,
     4      0.3142473759538051d-08,0.9503056213920345d-08,
     5      0.2191729244731483d-07,0.4097843911617850d-07,
     6      0.6360790275565384d-07,0.8406732913574738d-07,
     7      0.9639905662399429d-07,0.9745872252132460d-07,
     8      0.8807297784997248d-07,0.7193464282202925d-07/
         data arr1780/
     1      0.5361891453258679d-07,0.3678727772384483d-07,
     2      0.2339216793835189d-07,0.1386476787319908d-07,
     3      0.7702901990847066d-08,0.4033265957102703d-08,
     4      0.1997480414337091d-08,0.9362436750695603d-09,
     5      0.4154140664846878d-09,0.1757513142097105d-09,
     6      0.7235726366730105d-10,0.2964330790700963d-10,
     7      0.1186501420634131d-10,0.4181664667861723d-11,
     8      0.9984034371384953d-11,0.5933055174563686d-09/
         data arr1781/
     1      0.2551638354366665d-08,0.8915189979378877d-08,
     2      0.2358414589803606d-07,0.4989161106576773d-07,
     3      0.8680058085279213d-07,0.1274397236044329d-06,
     4      0.1611292559231040d-06,0.1784513747347762d-06,
     5      0.1756150708933993d-06,0.1554109023734543d-06,
     6      0.1249469059833751d-06,0.9206959445638052d-07,
     7      0.6264530008430136d-07,0.3961108124930717d-07,
     8      0.2340739886262482d-07,0.1299099294495647d-07/
         data arr1782/
     1      0.6798858708517615d-08,0.3365813657908310d-08,
     2      0.1580512118520586d-08,0.7062606987900934d-09,
     3      0.3014997499288148d-09,0.1233017134622696d-09,
     4      0.4831343404063846d-10,0.1988405266838391d-10,
     5      0.2886174882365709d-11,0.2784460663037660d-09,
     6      0.1438660695298366d-08,0.5816702938115835d-08,
     7      0.1764082167414946d-07,0.4223280875133684d-07,
     8      0.8234631410456241d-07,0.1343102733267076d-06/
         data arr1783/
     1      0.1872427314014501d-06,0.2271593761451599d-06,
     2      0.2434521473829036d-06,0.2334282027115172d-06,
     3      0.2024118915368652d-06,0.1602008072672936d-06,
     4      0.1166461410466328d-06,0.7867118439919061d-07,
     5      0.4943825958727029d-07,0.2909462159467944d-07,
     6      0.1610440846760128d-07,0.8415654919680451d-08,
     7      0.4165562835488260d-08,0.1958373420523910d-08,
     8      0.8760415752591907d-09,0.3730441805764031d-09/
         data arr1784/
     1      0.1516971611160063d-09,0.6665544034538135d-10,
     2      -.2044919595528419d-11,0.1058781771629052d-09,
     3      0.6514534277774793d-09,0.3048171778860569d-08,
     4      0.1059874368558415d-07,0.2871499633569752d-07,
     5      0.6274756239630751d-07,0.1136971683482258d-06,
     6      0.1747712403464617d-06,0.2322594132309074d-06,
     7      0.2710827852638704d-06,0.2816176554829551d-06,
     8      0.2633762306008595d-06,0.2238974164148571d-06/
         data arr1785/
     1      0.1744590942542008d-06,0.1254996390831187d-06,
     2      0.8386618132900106d-07,0.5233889142402756d-07,
     3      0.3064396309087436d-07,0.1690115849462026d-07,
     4      0.8812342193507174d-08,0.4355800564116196d-08,
     5      0.2043912362605785d-08,0.9105597476092398d-09,
     6      0.3866634788995168d-09,0.1786003810606457d-09,
     7      -.8057747794950560d-11,0.3612821249829533d-10,
     8      0.2525833935174090d-09,0.1359566420293882d-08/
         data arr1786/
     1      0.5429877314372805d-08,0.1664025587244617d-07,
     2      0.4075627895318819d-07,0.8204069129316107d-07,
     3      0.1390485016717529d-06,0.2024210878434960d-06,
     4      0.2572922284139624d-06,0.2896016800039135d-06,
     5      0.2921154728317609d-06,0.2667296153283571d-06,
     6      0.2224091369528264d-06,0.1706493098385857d-06,
     7      0.1212686900904772d-06,0.8025660826499890d-07,
     8      0.4970476064603203d-07,0.2893371695367171d-07/
         data arr1787/
     1      0.1589202570066147d-07,0.8259950282759486d-08,
     2      0.4068030348627719d-08,0.1898578766222613d-08,
     3      0.8437776212984764d-09,0.4105071452264410d-09,
     4      -.1784762145233728d-10,0.1450801549152298d-10,
     5      0.8897532688188012d-10,0.5295388696937490d-09,
     6      0.2454838314868895d-08,0.8489301501035940d-08,
     7      0.2331814708514434d-07,0.5214104432016631d-07,
     8      0.9743364546738802d-07,0.1553862571931605d-06/
         data arr1788/
     1      0.2150862043547588d-06,0.2623013736903269d-06,
     2      0.2853641640911132d-06,0.2798708288287284d-06,
     3      0.2497291338157261d-06,0.2043737530653305d-06,
     4      0.1544434396247677d-06,0.1083879953707089d-06,
     5      0.7100026648385227d-07,0.4361552842766373d-07,
     6      0.2522917345308695d-07,0.1378128911047639d-07,
     7      0.7116437866428688d-08,0.3473132455231814d-08,
     8      0.1610367292539691d-08,0.8194682014331204d-09/
         data arr1789/
     1      -.3644215883319051d-10,0.1266565174079210d-10,
     2      0.3349559264691128d-10,0.1761368863717230d-09,
     3      0.1007799234315197d-08,0.3886778466083851d-08,
     4      0.1200261448706693d-07,0.2980478865959914d-07,
     5      0.6139325536298615d-07,0.1072833757446751d-06,
     6      0.1617036845296138d-06,0.2136553140897634d-06,
     7      0.2507160079894444d-06,0.2641045104053775d-06,
     8      0.2521760059543136d-06,0.2201274582251328d-06/
         data arr1790/
     1      0.1769049252014925d-06,0.1316558877034190d-06,
     2      0.9122057513021862d-07,0.5914467067440883d-07,
     3      0.3604465963381069d-07,0.2070831769109444d-07,
     4      0.1122595305889265d-07,0.5741124376505145d-08,
     5      0.2787597223784232d-08,0.1496470219134475d-08,
     6      -.6384886132191994d-10,0.1859446571950003d-10,
     7      0.2035509179917424d-10,0.3732065136579350d-10,
     8      0.3940182954925918d-09,0.1609918013163967d-08/
         data arr1791/
     1      0.5644843046412446d-08,0.1554954756638342d-07,
     2      0.3528581181081289d-07,0.6760487373006182d-07,
     3      0.1109292979724303d-06,0.1587928173978848d-06,
     4      0.2010095043834923d-06,0.2274210914944985d-06,
     5      0.2323526397522297d-06,0.2163404685693869d-06,
     6      0.1848947945771928d-06,0.1459035648287234d-06,
     7      0.1069046460855204d-06,0.7313413364039949d-07,
     8      0.4693185627767080d-07,0.2832891728921803d-07/
         data arr1792/
     1      0.1609144255935735d-07,0.8597085003806733d-08,
     2      0.4350213483704060d-08,0.2440908749413320d-08,
     3      -.1097491053314050d-09,0.3204053863895796d-10,
     4      0.2308289408298213d-10,-.2193979169969448d-10,
     5      0.1700940869121532d-09,0.5907348107277549d-09,
     6      0.2461006626760948d-08,0.7488542264754742d-08,
     7      0.1868091035093207d-07,0.3931890106995113d-07,
     8      0.7018186707167558d-07,0.1088319261348225d-06/
         data arr1793/
     1      0.1486592339300066d-06,0.1806321773531820d-06,
     2      0.1974446473109058d-06,0.1961077139831435d-06,
     3      0.1782660345086760d-06,0.1491672200047928d-06,
     4      0.1155876339091033d-06,0.8346105093591228d-07,
     5      0.5644222836857251d-07,0.3584309905052321d-07,
     6      0.2137528625399283d-07,0.1196570976840018d-07,
     7      0.6340872076722545d-08,0.3756943803509681d-08,
     8      -.1583856894927049d-09,0.4618840341423390d-10/
         data arr1794/
     1      0.3121903121585395d-10,-.5294201087987553d-10,
     2      0.1045317545685686d-09,0.1682233762303582d-09,
     3      0.1014777023767097d-08,0.3362053049514115d-08,
     4      0.9166252879912283d-08,0.2130010459133976d-07,
     5      0.4128572895619377d-07,0.6934408223140295d-07,
     6      0.1022639417839237d-06,0.1334260058159787d-06,
     7      0.1559993674901330d-06,0.1652834691743780d-06,
     8      0.1597878422914901d-06,0.1417185753673303d-06/
         data arr1795/
     1      0.1160537477535819d-06,0.8835122531903431d-07,
     2      0.6285370962801706d-07,0.4186759572474063d-07,
     3      0.2609300399917124d-07,0.1520243023619340d-07,
     4      0.8354638774918608d-08,0.5135822344987542d-08,
     5      -.2394944876155274d-09,0.7233670600684111d-10,
     6      0.4309857827583355d-10,-.8350112505852067d-10,
     7      0.1066853819975495d-09,-.9974783913007329d-11,
     8      0.4175810258880748d-09,0.1427274935748473d-08/
         data arr1796/
     1      0.4156494704817550d-08,0.1085866015173096d-07,
     2      0.2272452206189316d-07,0.4131726139258953d-07,
     3      0.6589503072047394d-07,0.9228514880458870d-07,
     4      0.1153525221953241d-06,0.1304242494920081d-06,
     5      0.1341716825571919d-06,0.1261675195028990d-06,
     6      0.1092328624783254d-06,0.8778386371519920d-07,
     7      0.6585361813667023d-07,0.4618227274935686d-07,
     8      0.3023249282638363d-07,0.1846326461230177d-07/
         data arr1797/
     1      0.1063530815619698d-07,0.6920759923885413d-08,
     2      -.2975848782528317d-09,0.9026370250396083d-10,
     3      0.5358535744674055d-10,-.1048521263513423d-09,
     4      0.1214945998349682d-09,-.8284054600815582d-10,
     5      0.1904365626234103d-09,0.5856782703053585d-09,
     6      0.1717273495231774d-08,0.5268422731924699d-08,
     7      0.1176009952992697d-07,0.2312804096309773d-07,
     8      0.3999217616506510d-07,0.6007324864929684d-07/
         data arr1798/
     1      0.8020935893164805d-07,0.9677212612494718d-07,
     2      0.1058888946260559d-06,0.1054431365422206d-06,
     3      0.9634419295505187d-07,0.8153001949697497d-07,
     4      0.6425222172097758d-07,0.4717184087010499d-07,
     5      0.3218462340664885d-07,0.2039216887551159d-07,
     6      0.1214259021875674d-07,0.8173265515076154d-08,
     7      -.4002637556303532d-09,0.1259990180192260d-09,
     8      0.6553119613325578d-10,-.1360702370888210d-09/
         data arr1799/
     1      0.1541788539910223d-09,-.1322677448882414d-09,
     2      0.1192813086797823d-09,0.2516922455892820d-09,
     3      0.5799397255422423d-09,0.2508445961339701d-08,
     4      0.5737473858749462d-08,0.1216562791928587d-07,
     5      0.2301242008229394d-07,0.3701375540432920d-07,
     6      0.5268720990788184d-07,0.6792359302244338d-07,
     7      0.7918987525814750d-07,0.8356966944709312d-07,
     8      0.8066530481955257d-07,0.7206951107529740d-07/
         data arr1800/
     1      0.5994712777814399d-07,0.4637256511089588d-07,
     2      0.3324163484738974d-07,0.2207535819451200d-07,
     3      0.1378065123137441d-07,0.9831520655377043d-08,
     4      -.4046827756483292d-09,0.1267232761138970d-09,
     5      0.6798605531691753d-10,-.1386164991616396d-09,
     6      0.1570104382764783d-09,-.1398521744144387d-09,
     7      0.9136156838169473d-10,0.1198105830273911d-09,
     8      0.1124275960092878d-09,0.1195392622690721d-08/
         data arr1801/
     1      0.2643180488053284d-08,0.6028785822351949d-08,
     2      0.1258632124607814d-07,0.2161452374352075d-07,
     3      0.3272506007633349d-07,0.4502939695490531d-07,
     4      0.5579293078095963d-07,0.6215353283532700d-07,
     5      0.6306013569642085d-07,0.5906914783502619d-07,
     6      0.5134169375497128d-07,0.4129388102481992d-07,
     7      0.3059740772211381d-07,0.2088477687296223d-07,
     8      0.1333518155753263d-07,0.9699853146304564d-08/
         data arr1802/
     1      -.4958821447243120d-09,0.1618335845916017d-09,
     2      0.7402102380904337d-10,-.1623485718684022d-09,
     3      0.1841653687561007d-09,-.1670238046381827d-09,
     4      0.9291167128393389d-10,0.8321289511213456d-10,
     5      -.1126175870301676d-09,0.6519923616054332d-09,
     6      0.1141644379331872d-08,0.2748741316901608d-08,
     7      0.6641472757542042d-08,0.1208891993710193d-07,
     8      0.1932558764219849d-07,0.2853557448916216d-07/
         data arr1803/
     1      0.3780332327661357d-07,0.4458712049103553d-07,
     2      0.4772072211091451d-07,0.4722218468251640d-07,
     3      0.4340540955241305d-07,0.3684684959545952d-07,
     4      0.2871312080761027d-07,0.2055710537977839d-07,
     5      0.1377888585562339d-07,0.1065391580444797d-07,
     6      -.4270597986754755d-09,0.1391350942734190d-09,
     7      0.6523793048929516d-10,-.1404908007000746d-09,
     8      0.1603040316191521d-09,-.1447317892255959d-09/
         data arr1804/
     1      0.7876278974891757d-10,0.5944952913751518d-10,
     2      -.1535394460292850d-09,0.3740491643538757d-09,
     3      0.4602208564625590d-09,0.1157566509680732d-08,
     4      0.3348342856007346d-08,0.6405241939699776d-08,
     5      0.1075132760911133d-07,0.1696378467567558d-07,
     6      0.2384976245023917d-07,0.2952592977623315d-07,
     7      0.3300956192847599d-07,0.3406059983875975d-07,
     8      0.3254063961844278d-07,0.2855903834569184d-07/
         data arr1805/
     1      0.2287397474394469d-07,0.1674637813673471d-07,
     2      0.1143356173337533d-07,0.8987574478083270d-08,
     3      -.4747057982512544d-09,0.1612253067723093d-09,
     4      0.6293198617339083d-10,-.1485176060869625d-09,
     5      0.1696507700605818d-09,-.1545022285161435d-09,
     6      0.8010548129103387d-10,0.6056498438152070d-10,
     7      -.1974862558273157d-09,0.2918457256637379d-09,
     8      0.1631068142238567d-09,0.3712559994933827d-09/
         data arr1806/
     1      0.1699453529073827d-08,0.3326741132294791d-08,
     2      0.5714970783188112d-08,0.9797627138612753d-08,
     3      0.1484825312033399d-07,0.1941179572814579d-07,
     4      0.2281778303321782d-07,0.2488204397940928d-07,
     5      0.2519411639657907d-07,0.2337005938993718d-07,
     6      0.1968815103801863d-07,0.1511442601542620d-07,
     7      0.1083292076031929d-07,0.9059540955070314d-08,
     8      -.2856962782247114d-09,0.9554830900044024d-10/
         data arr1807/
     1      0.4062729581469469d-10,-.9126846660234962d-10,
     2      0.1048061018954059d-09,-.9471007252475298d-10,
     3      0.5007477948617351d-10,0.3608818588290773d-10,
     4      -.1235988619134579d-09,0.1639843634377514d-09,
     5      0.5166341928508113d-10,0.1066523970215824d-09,
     6      0.7774658650088880d-09,0.1553953362390444d-08,
     7      0.2749340968704952d-08,0.4996490773656604d-08,
     8      0.7928387116662011d-08,0.1072132456911141d-07/
         data arr1808/
     1      0.1297552997085788d-07,0.1452063318138358d-07,
     2      0.1501016754554302d-07,0.1413091160804316d-07,
     3      0.1201861056592243d-07,0.9272113839301887d-08,
     4      0.6647419905180250d-08,0.5520310874113254d-08,
     5      -.2960352798265853d-09,0.1034889792794937d-09,
     6      0.3550268835796178d-10,-.8937435125894873d-10,
     7      0.1027513815099993d-09,-.9368310508794996d-10,
     8      0.4739005797614468d-10,0.3729669636485166d-10/
         data arr1809/
     1      -.1288525262022557d-09,0.1494867612515103d-09,
     2      0.6777665923699863d-11,-.4199590963950956d-10,
     3      0.4093567157864245d-09,0.7757167087925532d-09,
     4      0.1300913987463891d-08,0.2650684188246551d-08,
     5      0.4606765306254103d-08,0.6552419567993308d-08,
     6      0.8300639398419437d-08,0.9830070453360464d-08,
     7      0.1080946493687397d-07,0.1078373018522218d-07,
     8      0.9659772013956524d-08,0.7822177859033034d-08/
         data arr1810/
     1      0.5895862282206716d-08,0.5223283418387157d-08,
     2      -.1414987446572370d-09,0.4935365473836067d-10,
     3      0.1769904070725697d-10,-.4305951354561175d-10,
     4      0.5001968088766026d-10,-.4509145060208437d-10,
     5      0.2326416544554246d-10,0.1830794043775228d-10,
     6      -.6218015130393470d-10,0.7095903126762135d-10,
     7      -.1406227143725558d-11,-.3459834567029362d-10,
     8      0.1605601123577669d-09,0.2955548623085368d-09/
         data arr1811/
     1      0.4840248848422613d-09,0.1053032630905888d-08,
     2      0.1912165927589946d-08,0.2787102625221663d-08,
     3      0.3606584651335348d-08,0.4367607663579017d-08,
     4      0.4901554767935537d-08,0.4970215658731284d-08,
     5      0.4507864490570875d-08,0.3684870288695396d-08,
     6      0.2797866249441314d-08,0.2493119532485341d-08,
     7      -.1333563720036105d-09,0.4849330580621319d-10,
     8      0.1355958414965254d-10,-.3820072869682036d-10/
         data arr1812/
     1      0.4416489900963179d-10,-.4034290712065757d-10,
     2      0.1971810518799491d-10,0.1720715477986380d-10,
     3      -.5778688898734736d-10,0.6243830758845642d-10,
     4      -.4835145618264505d-11,-.5067437511547849d-10,
     5      0.9400949656125346d-10,0.1494559706401192d-09,
     6      0.1905251752678612d-09,0.5075269506700304d-09,
     7      0.1041860261076937d-08,0.1583539151385912d-08,
     8      0.2124037495084215d-08,0.2721502083633422d-08/
         data arr1813/
     1      0.3259549063401027d-08,0.3507009654416976d-08,
     2      0.3348301567101546d-08,0.2870339463010092d-08,
     3      0.2289989121551956d-08,0.2177033176460461d-08,
     4      -.1058962921101264d-09,-.4675646725241503d-09,
     5      -.1626066076184698d-08,-.4307127111050436d-08,
     6      -.9107959947893630d-08,-.1584792113462701d-07,
     7      -.2326743002352478d-07,-.2941720423139168d-07,
     8      -.3258140243277500d-07,-.3206259626202866d-07/
         data arr1814/
     1      -.2837339798790777d-07,-.2281259680342167d-07,
     2      -.1680976201480930d-07,-.1143683697364969d-07,
     3      -.7231802562765101d-08,-.4274044596719674d-08,
     4      -.2371985724697020d-08,-.1240916152845945d-08,
     5      -.6141811007823514d-09,-.2886674420180310d-09,
     6      -.1292741484627180d-09,-.5520246487525882d-10,
     7      -.2237619663038269d-10,-.8545091404989129d-11,
     8      -.3378081797175951d-11,-.6901247933023369d-10/
         data arr1815/
     1      -.3665308599778819d-09,-.1476478036323957d-08,
     2      -.4481539708153651d-08,-.1072660256540555d-07,
     3      -.2091622783073014d-07,-.3411496327309364d-07,
     4      -.4755927479121259d-07,-.5769898445823896d-07,
     5      -.6183678996931470d-07,-.5929053326556213d-07,
     6      -.5141296688549008d-07,-.4069113127453999d-07,
     7      -.2962786188290613d-07,-.1998247555271957d-07,
     8      -.1255757079102567d-07,-.7390087947204025d-08/
         data arr1816/
     1      -.4090330213090776d-08,-.2137465928465863d-08,
     2      -.1058154938484715d-08,-.4975884972272126d-09,
     3      -.2225564428766057d-09,-.9465645716922974d-10,
     4      -.3838373331983093d-10,-.1675279145156294d-10,
     5      -.3085923694946375d-10,-.2003251637075417d-09,
     6      -.9327674607302064d-09,-.3245518232866378d-08,
     7      -.8791915178541825d-08,-.1921259266633727d-07,
     8      -.3481238693387123d-07,-.5351260055302420d-07/
         data arr1817/
     1      -.7111468791781408d-07,-.8300162853205578d-07,
     2      -.8622759743084085d-07,-.8064223458873164d-07,
     3      -.6855407861043687d-07,-.5341700851106142d-07,
     4      -.3842651294795018d-07,-.2567866566643843d-07,
     5      -.1602527207542511d-07,-.9382840064066061d-08,
     6      -.5175275402074084d-08,-.2698554513799012d-08,
     7      -.1333782759088603d-08,-.6257798351590651d-09,
     8      -.2788153990891993d-09,-.1185026555405590d-09/
         data arr1818/
     1      -.5464365616282889d-10,-.9798026113814605d-11,
     2      -.8931740615994214d-10,-.4728250408918460d-09,
     3      -.1890545361450242d-08,-.5793378460405529d-08,
     4      -.1418970549991584d-07,-.2856237445615460d-07,
     5      -.4841119047958565d-07,-.7047359147337370d-07,
     6      -.8957723147399303d-07,-.1008272271819086d-06,
     7      -.1017013786665618d-06,-.9286250724271664d-07,
     8      -.7743340023618543d-07,-.5941325259562751d-07/
         data arr1819/
     1      -.4221991414776669d-07,-.2794099619711173d-07,
     2      -.1730527072185639d-07,-.1007446745407926d-07,
     3      -.5533468321155716d-08,-.2875446571278867d-08,
     4      -.1415743251212693d-08,-.6608350190900792d-09,
     5      -.2940379706751817d-09,-.1427714045154806d-09,
     6      0.4684885212651680d-12,-.3699434338450905d-10,
     7      -.2021501130771709d-09,-.9413474566926477d-09,
     8      -.3255636766156390d-08,-.8942433103302084d-08/
         data arr1820/
     1      -.1999386611119547d-07,-.3736592706807326d-07,
     2      -.5958680336393326d-07,-.8248082509716419d-07,
     3      -.1005901191242274d-06,-.1094316045406719d-06,
     4      -.1073235601610591d-06,-.9576799365551290d-07,
     5      -.7837563270319704d-07,-.5922525125539017d-07,
     6      -.4156308974483804d-07,-.2722817231517811d-07,
     7      -.1672833348065883d-07,-.9676256614026296d-08,
     8      -.5284074249022273d-08,-.2727623336709545d-08/
         data arr1821/
     1      -.1331476311069136d-08,-.6181869559552802d-09,
     2      -.3139031810580929d-09,0.7051125129272381d-11,
     3      -.1941973941948315d-10,-.7156743010076639d-10,
     4      -.4167835686940559d-09,-.1609992274562472d-08,
     5      -.4970076519289100d-08,-.1233765109880541d-07,
     6      -.2542339589957519d-07,-.4441687735562100d-07,
     7      -.6694987451220529d-07,-.8846644137895973d-07,
     8      -.1038048032268672d-06,-.1093454406221623d-06/
         data arr1822/
     1      -.1044137441815461d-06,-.9114532365877522d-07,
     2      -.7324293460341390d-07,-.5450684349577028d-07,
     3      -.3777078605979410d-07,-.2449357072687703d-07,
     4      -.1492636577807371d-07,-.8572055472937405d-08,
     5      -.4644988320372698d-08,-.2376383279820242d-08,
     6      -.1155769531925293d-08,-.6190540282281682d-09,
     7      0.1427457719298110d-10,-.1858751303719638d-10,
     8      -.1427491081746457d-10,-.1723714303207512d-09/
         data arr1823/
     1      -.7113978194288042d-09,-.2489786679834301d-08,
     2      -.6851659557018314d-08,-.1556730765622495d-07,
     3      -.2980565748433328d-07,-.4891196175812341d-07,
     4      -.7002977516289368d-07,-.8863385037460614d-07,
     5      -.1002756796145670d-06,-.1024638773926206d-06,
     6      -.9540505634856390d-07,-.8152755441439692d-07,
     7      -.6433323922467942d-07,-.4714842600909249d-07,
     8      -.3226468288392402d-07,-.2070636344525346d-07/
         data arr1824/
     1      -.1249583654935479d-07,-.7097953190129422d-08,
     2      -.3796907379567490d-08,-.1927252363497145d-08,
     3      -.1081188547887710d-08,0.2268633178236537d-10,
     4      -.2555302392948065d-10,0.1188139437753828d-10,
     5      -.7529295665675207d-10,-.2788085408539773d-09,
     6      -.1144763417091323d-08,-.3473652709371538d-08,
     7      -.8700868499655943d-08,-.1827252760735076d-07,
     8      -.3262920421247199d-07,-.5062175868602548d-07/
         data arr1825/
     1      -.6911873067692264d-07,-.8397905851649315d-07,
     2      -.9182109078519033d-07,-.9120061399948306d-07,
     3      -.8288293801616316d-07,-.6935078432298786d-07,
     4      -.5375702658336823d-07,-.3882950729104539d-07,
     5      -.2625641298901080d-07,-.1666458506252625d-07,
     6      -.9935478571176373d-08,-.5568191954153734d-08,
     7      -.2959331408872768d-08,-.1750621661951613d-08,
     8      0.3401594438050083d-10,-.3647358071899346d-10/
         data arr1826/
     1      0.2802762116575398d-10,-.4431261383887542d-10,
     2      -.8816489750532069d-10,-.4938237469972074d-09,
     3      -.1623240686861223d-08,-.4482511082181054d-08,
     4      -.1034965107514490d-07,-.2008521737423249d-07,
     5      -.3377115627367341d-07,-.4975802817933281d-07,
     6      -.6491392340571956d-07,-.7593687952758391d-07,
     7      -.8045708680959641d-07,-.7775124909537522d-07,
     8      -.6895725224064403d-07,-.5649968167343238d-07/
         data arr1827/
     1      -.4303568649466370d-07,-.3061326745543807d-07,
     2      -.2038026712258765d-07,-.1270049468251810d-07,
     3      -.7411661911045316d-08,-.4087657996000788d-08,
     4      -.2509776980202655d-08,0.4359726937015093d-10,
     5      -.4802525310880893d-10,0.3962699326188446d-10,
     6      -.4010580502105957d-10,-.8701229446876668d-11,
     7      -.2093058711760784d-09,-.7043286934797908d-09,
     8      -.2139776119499389d-08,-.5470668959933026d-08/
         data arr1828/
     1      -.1149917754194269d-07,-.2095953517232087d-07,
     2      -.3334870609248855d-07,-.4670122584230615d-07,
     3      -.5844010168038484d-07,-.6606979075271228d-07,
     4      -.6791704050516611d-07,-.6386536040245417d-07,
     5      -.5533942802549041d-07,-.4450113653198906d-07,
     6      -.3337179574378691d-07,-.2338116342940465d-07,
     7      -.1530375255787472d-07,-.9364295847575411d-08,
     8      -.5414840245799844d-08,-.3516193322582832d-08/
         data arr1829/
     1      0.5461907189819128d-10,-.5841518940198201d-10,
     2      0.5054403071327386d-10,-.4358276829523642d-10,
     3      0.2551790629836914d-10,-.9535347579634887d-10,
     4      -.2831816329190812d-09,-.9448523002467376d-09,
     5      -.2725495443643753d-08,-.6157203436696875d-08,
     6      -.1217598227789740d-07,-.2094754796032971d-07,
     7      -.3146733070592492d-07,-.4210359960879572d-07,
     8      -.5079012834643984d-07,-.5551620667394896d-07/
         data arr1830/
     1      -.5529743810562839d-07,-.5060277777290717d-07,
     2      -.4287709324468619d-07,-.3379772889449236d-07,
     3      -.2481088943618268d-07,-.1695049187104680d-07,
     4      -.1078441709636790d-07,-.6464655433464441d-08,
     5      -.4358436679590434d-08,0.5673131734648483d-10,
     6      -.6403520945470237d-10,0.5555907823844770d-10,
     7      -.4884263564365613d-10,0.3926033923431351d-10,
     8      -.5451143421929714d-10,-.1067347443369153d-09/
         data arr1831/
     1      -.3774803492435251d-09,-.1301306979126588d-08,
     2      -.3096675036747607d-08,-.6648231632081902d-08,
     3      -.1241054582266462d-07,-.1997768266632336d-07,
     4      -.2856138525861951d-07,-.3679219623541924d-07,
     5      -.4280263386024390d-07,-.4518848389673676d-07,
     6      -.4371150805875082d-07,-.3910165704900106d-07,
     7      -.3250370968837392d-07,-.2511721950079109d-07,
     8      -.1801990948136341d-07,-.1201447424437098d-07/
         data arr1832/
     1      -.7545616987146826d-08,-.5376757472644892d-08,
     2      0.6183871608128440d-10,-.6670500324553143d-10,
     3      0.5989677694778545d-10,-.5016656357736912d-10,
     4      0.4555120567176498d-10,-.3908884584231615d-10,
     5      -.3469593959521166d-10,-.1276761397223582d-09,
     6      -.6059589707627586d-09,-.1461712979234329d-08,
     7      -.3422399998763467d-08,-.6961499273058118d-08,
     8      -.1197757854230694d-07,-.1826992209773164d-07/
         data arr1833/
     1      -.2510813902070329d-07,-.3101741973473058d-07,
     2      -.3458445574324360d-07,-.3519948640665625d-07,
     3      -.3303377448130223d-07,-.2870314074886287d-07,
     4      -.2307271888831466d-07,-.1712526810996843d-07,
     5      -.1174986046543792d-07,-.7557864814647482d-08,
     6      -.5498233096692248d-08,0.5023982248593086d-10,
     7      -.5920499099285105d-10,0.5408660402472736d-10,
     8      -.4901119420274649d-10,0.4432335654395748d-10/
         data arr1834/
     1      -.3293048492828611d-10,-.1286282559654555d-10,
     2      -.2047817837901401d-10,-.2923622167849999d-09,
     3      -.6493242040983037d-09,-.1654781221626073d-08,
     4      -.3731293270376514d-08,-.6842068697526072d-08,
     5      -.1110786587882050d-07,-.1633674673792309d-07,
     6      -.2151738715555350d-07,-.2542187648555673d-07,
     7      -.2733603940692242d-07,-.2709896220178108d-07,
     8      -.2486808566654742d-07,-.2107696057121728d-07/
         data arr1835/
     1      -.1645176437064177d-07,-.1184525984172617d-07,
     2      -.7996876666082125d-08,-.6168720373523979d-08,
     3      0.4533607454800353d-10,-.4917070681377398d-10,
     4      0.4871207566327487d-10,-.4144188705807294d-10,
     5      0.4095446347238375d-10,-.2568260658735165d-10,
     6      -.3006027241385245d-11,0.1764182556884244d-10,
     7      -.1467448533375548d-09,-.2660054395236391d-09,
     8      -.7492240813386576d-09,-.1904723577523647d-08/
         data arr1836/
     1      -.3697122443692620d-08,-.6360646252051283d-08,
     2      -.9981254177169746d-08,-.1394012016192775d-07,
     3      -.1732453338455729d-07,-.1951362069609625d-07,
     4      -.2021671900360691d-07,-.1932633160428887d-07,
     5      -.1698462398424449d-07,-.1367700368680359d-07,
     6      -.1011309626245628d-07,-.6987769372572031d-08,
     7      -.5513554983611612d-08,0.2326679663311773d-10,
     8      -.3165365169669450d-10,0.3345207715236488d-10/
         data arr1837/
     1      -.3324774622894769d-10,0.3180083813435860d-10,
     2      -.2004436023013011d-10,-.6009488181711265d-11,
     3      0.3219188092844615d-10,-.8737807759164430d-10,
     4      -.1035293719509603d-09,-.3060506241393033d-09,
     5      -.9483108093453892d-09,-.1935705895349295d-08,
     6      -.3496324288890492d-08,-.5897209151058258d-08,
     7      -.8814035097440783d-08,-.1159273470013776d-07,
     8      -.1376522124670904d-07,-.1505346563970478d-07/
         data arr1838/
     1      -.1520315960378919d-07,-.1408849353043591d-07,
     2      -.1192158071497043d-07,-.9237196654426765d-08,
     3      -.6687279988295603d-08,-.5583954587295753d-08,
     4      0.2108349679542132d-10,-.2331575143028071d-10,
     5      0.2573746449085063d-10,-.2245243729390899d-10,
     6      0.2341448210422362d-10,-.1311641895599675d-10,
     7      -.1427593038073796d-11,0.2435415777808159d-10,
     8      -.4663672057179461d-10,-.3274860605491427d-10/
         data arr1839/
     1      -.1156338885371069d-09,-.4343389545039353d-09,
     2      -.9169238198234607d-09,-.1731222773239592d-08,
     3      -.3087416662713025d-08,-.4826763495761893d-08,
     4      -.6577276816130963d-08,-.8055055416468179d-08,
     5      -.9051941831180922d-08,-.9344809667056893d-08,
     6      -.8800080424375694d-08,-.7527139088916028d-08,
     7      -.5868544470027895d-08,-.4256261742835053d-08,
     8      -.3537477867159444d-08,0.3106045794349198d-11/
         data arr1840/
     1      -.8230075879794455d-11,0.1239509742903776d-10,
     2      -.1443015832707780d-10,0.1474738747486801d-10,
     3      -.8037755564630606d-11,-.5515184535959176d-11,
     4      0.2383015677512952d-10,-.3333809804486911d-10,
     5      -.1182914844139288d-10,-.2827287710515112d-10,
     6      -.2080488035025664d-09,-.4518811812184662d-09,
     7      -.8651861966137240d-09,-.1674278627730797d-08,
     8      -.2826129634976674d-08,-.4074477994960001d-08/
         data arr1841/
     1      -.5250561987295103d-08,-.6233238529650683d-08,
     2      -.6817260455882032d-08,-.6788513067043988d-08,
     3      -.6115160650929222d-08,-.5005165547025471d-08,
     4      -.3811081784549421d-08,-.3363148917701579d-08,
     5      0.2138571763645936d-11,-.2250530847756190d-11,
     6      0.6833211801979454d-11,-.6263022422050680d-11,
     7      0.8462701294941501d-11,-.2870740113688758d-11,
     8      -.2427930398945417d-11,0.1415089322278283d-10/
         data arr1842/
     1      -.1567283539662622d-10,-.2314622158189673d-11,
     2      -.2364935638709261d-11,-.8097516838251006d-10,
     3      -.1786245914333478d-09,-.3448720819699462d-09,
     4      -.7061003183390364d-09,-.1249152523149035d-08,
     5      -.1858656433771495d-08,-.2460855894297427d-08,
     6      -.3002631367723971d-08,-.3370092278730052d-08,
     7      -.3432379219578387d-08,-.3150622221042056d-08,
     8      -.2619974466392261d-08,-.2022961051054225d-08/
         data arr1843/
     1      -.1810490662787102d-08,-.6837468864763323d-11,
     2      0.4600395986676190d-11,-.4253714176987335d-12,
     3      -.2054072146369959d-11,0.3140664845231883d-11,
     4      -.4788438475138483d-12,-.4345253314273841d-11,
     5      0.1111999005737735d-10,-.1070213212102949d-10,
     6      -.3012319497909400d-11,0.8182207981433207d-11,
     7      -.3769012332985300d-10,-.8589537845586967d-10,
     8      -.1530751394923939d-09,-.3439597286560114d-09/
         data arr1844/
     1      -.6675474173377530d-09,-.1047704030062201d-08,
     2      -.1448939549759901d-08,-.1860260708965283d-08,
     3      -.2209495127632293d-08,-.2376598695480123d-08,
     4      -.2291866431560579d-08,-.1994373897105705d-08,
     5      -.1611218774579221d-08,-.1525390325563803d-08,
     6      0.2189585772875945d-09,0.7895235620327666d-09,
     7      0.1901159467566210d-08,0.3694537223073649d-08,
     8      0.6031486117907959d-08,0.8408830602806887d-08/
         data arr1845/
     1      0.1019718711988438d-07,0.1093286548320376d-07,
     2      0.1048204443155070d-07,0.9086593513081117d-08,
     3      0.7193501382111344d-08,0.5239144480086316d-08,
     4      0.3531883647082139d-08,0.2218450271594513d-08,
     5      0.1306657156279692d-08,0.7243598977863098d-09,
     6      0.3781418310061217d-09,0.1861000859602576d-09,
     7      0.8705520601905517d-10,0.3938621317752525d-10,
     8      0.1748497730699595d-10,0.7501140913380478d-11/
         data arr1846/
     1      0.3029137159170488d-11,0.1928073567397258d-09,
     2      0.7963062113230953d-09,0.2169083267080738d-08,
     3      0.4726782551803262d-08,0.8571403478960692d-08,
     4      0.1317486031952286d-07,0.1750485648234308d-07,
     5      0.2043533759113052d-07,0.2122829462111871d-07,
     6      0.1985081989442644d-07,0.1687738120922162d-07,
     7      0.1315186664806399d-07,0.9459223435098973d-08,
     8      0.6320357530215689d-08,0.3945637405962327d-08/
         data arr1847/
     1      0.2311194661031641d-08,0.1274242543470565d-08,
     2      0.6633923874657758d-09,0.3276259436325891d-09,
     3      0.1543109194986919d-09,0.6950958429872940d-10,
     4      0.2987952527737022d-10,0.1338715051665733d-10,
     5      0.1180480221272981d-09,0.5598297257420064d-09,
     6      0.1723833047961069d-08,0.4212865147661499d-08,
     7      0.8485445091717881d-08,0.1438042920328285d-07,
     8      0.2093247237959786d-07,0.2660974462932362d-07/
         data arr1848/
     1      0.2995008189468205d-07,0.3020865033608136d-07,
     2      0.2758496404587208d-07,0.2300192823884783d-07,
     3      0.1764760667586693d-07,0.1254053516350596d-07,
     4      0.8300335819702186d-08,0.5141208922617053d-08,
     5      0.2992406960469017d-08,0.1643023296314106d-08,
     6      0.8539129542092892d-09,0.4209954145403966d-09,
     7      0.1969497745364958d-09,0.8765179948873868d-10,
     8      0.4190679928407289d-10,0.5780218272027859d-10/
         data arr1849/
     1      0.3173281115887818d-09,0.1102065565031082d-08,
     2      0.3021810883623146d-08,0.6760372533851192d-08,
     3      0.1263127040400564d-07,0.2014380263253187d-07,
     4      0.2788466934822496d-07,0.3400482317207612d-07,
     5      0.3699426584468517d-07,0.3628304198807542d-07,
     6      0.3237542429218636d-07,0.2649478286810437d-07,
     7      0.2002184862485636d-07,0.1405173556290265d-07,
     8      0.9204795057520242d-08,0.5654208515600382d-08/
         data arr1850/
     1      0.3270364199134946d-08,0.1786380332985995d-08,
     2      0.9225240414905404d-09,0.4501554912008048d-09,
     3      0.2083204507046175d-09,0.1042647018941049d-09,
     4      0.2333074939440180d-10,0.1549972214214622d-09,
     5      0.6004229802692882d-09,0.1851288486966652d-08,
     6      0.4599809952993269d-08,0.9472540648524854d-08,
     7      0.1655423237912403d-07,0.2495194981266990d-07,
     8      0.3296717752295388d-07,0.3868624776026104d-07/
         data arr1851/
     1      0.4075272136242264d-07,0.3891147064453957d-07,
     2      0.3396604458529610d-07,0.2729726175696518d-07,
     3      0.2031539219829547d-07,0.1407573587090026d-07,
     4      0.9126228515195751d-08,0.5562188673150048d-08,
     5      0.3196050214054401d-08,0.1732703984784825d-08,
     6      0.8857934088513386d-09,0.4292216206652523d-09,
     7      0.2269494282883716d-09,0.6602767000011574d-11,
     8      0.6965062067102251d-10,0.2861236100115736d-09/
         data arr1852/
     1      0.1001651083743426d-08,0.2762514619420001d-08,
     2      0.6264180290619897d-08,0.1200546324242757d-07,
     3      0.1969847974023471d-07,0.2819567881227216d-07,
     4      0.3569399703140548d-07,0.4038457635559385d-07,
     5      0.4125867608129194d-07,0.3841595465582991d-07,
     6      0.3283439792588349d-07,0.2591158490653382d-07,
     7      0.1898651067365265d-07,0.1299111478791170d-07,
     8      0.8340697248445930d-08,0.5038770548624656d-08/
         data arr1853/
     1      0.2865116514661276d-08,0.1532277173402936d-08,
     2      0.7755180102107123d-09,0.4305734230400466d-09,
     3      -.1665996102607829d-11,0.3350330343172105d-10,
     4      0.1179978041070788d-09,0.4900292353015379d-09,
     5      0.1496884333003543d-08,0.3725215527550235d-08,
     6      0.7848545054977349d-08,0.1400740824797155d-07,
     7      0.2171733309223543d-07,0.2966927578266496d-07,
     8      0.3605111843710548d-07,0.3940318839449743d-07/
         data arr1854/
     1      0.3913712490272799d-07,0.3557990007099532d-07,
     2      0.2977316834964899d-07,0.2307047301823398d-07,
     3      0.1666023114662819d-07,0.1127162722437741d-07,
     4      0.7162937637588045d-08,0.4274685019447634d-08,
     5      0.2393751167453110d-08,0.1267375792842362d-08,
     6      0.7412956582019658d-09,-.6527374340056554d-11,
     7      0.2235774786787142d-10,0.3730793584016825d-10,
     8      0.2219867202654263d-09,0.7447798219450329d-09/
         data arr1855/
     1      0.2015859860040864d-08,0.4697300913702644d-08,
     2      0.9101642118077618d-08,0.1528068455448893d-07,
     3      0.2254201981291589d-07,0.2941203374125344d-07,
     4      0.3438274622240390d-07,0.3643023200605011d-07,
     5      0.3522404961438695d-07,0.3124195500098120d-07,
     6      0.2558299438972286d-07,0.1947838975347064d-07,
     7      0.1386284325207909d-07,0.9239605187423012d-08,
     8      0.5760486593447448d-08,0.3355118707259104d-08/
         data arr1856/
     1      0.1839965199714927d-08,0.1113597784832942d-08,
     2      -.1181048942576180d-10,0.2477188793253395d-10,
     3      -.2441230972652729d-11,0.9756754888160950d-10,
     4      0.3489403261705287d-09,0.9905197186087198d-09,
     5      0.2612384951763742d-08,0.5460788686628231d-08,
     6      0.9917383536121416d-08,0.1583001324350717d-07,
     7      0.2217094907567608d-07,0.2770300459465282d-07,
     8      0.3132494054391135d-07,0.3223389415198671d-07/
         data arr1857/
     1      0.3031238731938271d-07,0.2624116705080784d-07,
     2      0.2109208214124637d-07,0.1583316070985903d-07,
     3      0.1111375766829157d-07,0.7280367732822494d-08,
     4      0.4445819113606541d-08,0.2556233934200743d-08,
     5      0.1638386943701877d-08,-.1673229406539884d-10,
     6      0.3160933341928069d-10,-.2245978246808251d-10,
     7      0.4617098742163199d-10,0.1607992694982117d-09,
     8      0.4324647808354524d-09,0.1372036962549405d-08/
         data arr1858/
     1      0.3049185908357141d-08,0.5979089643694291d-08,
     2      0.1036288964147831d-07,0.1556736426290046d-07,
     3      0.2076982467747779d-07,0.2506722070130584d-07,
     4      0.2745059780246131d-07,0.2734623026516133d-07,
     5      0.2499449703802771d-07,0.2117406187084303d-07,
     6      0.1672427649892462d-07,0.1231623878421108d-07,
     7      0.8430701908368454d-08,0.5358142714271258d-08,
     8      0.3197969558320559d-08,0.2134685391947070d-08/
         data arr1859/
     1      -.2326465505620033d-10,0.4264879400678712d-10,
     2      -.3830703177172398d-10,0.2826490097337384d-10,
     3      0.8215018098529762d-10,0.1431407610894711d-09,
     4      0.7046513723428152d-09,0.1593249820483462d-08,
     5      0.3353047059818279d-08,0.6378033374087722d-08,
     6      0.1025908790132961d-07,0.1457934774085836d-07,
     7      0.1880474335656907d-07,0.2194886158289795d-07,
     8      0.2316965679191717d-07,0.2236403217330878d-07/
         data arr1860/
     1      0.1999895165745230d-07,0.1667205932647607d-07,
     2      0.1293476024108368d-07,0.9297840482993465d-08,
     3      0.6187663838529817d-08,0.3866500748701217d-08,
     4      0.2728966837693173d-08,-.2499596969908448d-10,
     5      0.4610279936157172d-10,-.4225830676852611d-10,
     6      0.2195835415614942d-10,0.4873044402307402d-10,
     7      0.1519335205220622d-10,0.3620801568959131d-09,
     8      0.7822077465938659d-09,0.1756454134672170d-08/
         data arr1861/
     1      0.3706520340085516d-08,0.6365257726419809d-08,
     2      0.9612127895602957d-08,0.1323730877471522d-07,
     3      0.1642876624593594d-07,0.1830925597905662d-07,
     4      0.1857677443334412d-07,0.1742027910488641d-07,
     5      0.1517809936990292d-07,0.1224278218066226d-07,
     6      0.9092405714991578d-08,0.6214053840762991d-08,
     7      0.3965947708165166d-08,0.2845755589982348d-08,
     8      -.3152305214156403d-10,0.5772786086740294d-10/
         data arr1862/
     1      -.5460668356785016d-10,0.2249209316583753d-10,
     2      0.4305047551374255d-10,-.5926698282478359d-10,
     3      0.2165492855883329d-09,0.3605099706488458d-09,
     4      0.8313073291965754d-09,0.2069283398199639d-08,
     5      0.3765018052928202d-08,0.5982665443809033d-08,
     6      0.8848640568110894d-08,0.1175752490834201d-07,
     7      0.1387248339134445d-07,0.1484147122038297d-07,
     8      0.1470663179729946d-07,0.1356268444999623d-07/
         data arr1863/
     1      0.1155719844963294d-07,0.9032543956990478d-08,
     2      0.6477243908093332d-08,0.4341287963301055d-08,
     3      0.3313395188603121d-08,-.3067537431233555d-10,
     4      0.5681915773732210d-10,-.5268661531192431d-10,
     5      0.2145423948623599d-10,0.3795767247253542d-10,
     6      -.7791567458235538d-10,0.1411068110601809d-09,
     7      0.1559762953146102d-09,0.3521063710476556d-09,
     8      0.1106067136264539d-08,0.2110019505698003d-08/
         data arr1864/
     1      0.3498424008286768d-08,0.5549308810890985d-08,
     2      0.7859092892520366d-08,0.9751562147147827d-08,
     3      0.1091761219153637d-07,0.1132127756582779d-07,
     4      0.1090784544368822d-07,0.9663834572490461d-08,
     5      0.7806300451672564d-08,0.5758078104417744d-08,
     6      0.3958040391131798d-08,0.3102004408368412d-08,
     7      -.3398671578467054d-10,0.6226437056417953d-10,
     8      -.5962319278563109d-10,0.2172670919622689d-10/
         data arr1865/
     1      0.4076869328355393d-10,-.9920077355007383d-10,
     2      0.1199295768513649d-09,0.6194399138917124d-10,
     3      0.9780158337049839d-10,0.5935322470519287d-09,
     4      0.1154931190940383d-08,0.1932757644816521d-08,
     5      0.3343015035726832d-08,0.5121712031116194d-08,
     6      0.6705630918127974d-08,0.7879670049123251d-08,
     7      0.8632492302772111d-08,0.8819016605914804d-08,
     8      0.8258572701069704d-08,0.7011829220581884d-08/
         data arr1866/
     1      0.5415560026826209d-08,0.3901482947218940d-08,
     2      0.3244587200336109d-08,-.2142753354813231d-10,
     3      0.3991317882107908d-10,-.3696126876233587d-10,
     4      0.1456048878391337d-10,0.2561393345934895d-10,
     5      -.6259270800614860d-10,0.7082685623437601d-10,
     6      0.2273208072871624d-10,0.2126794619760078d-10,
     7      0.2856056709850863d-09,0.5664991242769984d-09,
     8      0.9720004426689794d-09,0.1785109840903324d-08/
         data arr1867/
     1      0.2865840809400240d-08,0.3880904063620108d-08,
     2      0.4695808648302279d-08,0.5278039896088802d-08,
     3      0.5499180660540459d-08,0.5217745818386829d-08,
     4      0.4463417687574719d-08,0.3456720650301267d-08,
     5      0.2483669923109992d-08,0.2041569247754688d-08,
     6      -.2240171246185593d-10,0.4121750070537010d-10,
     7      -.3945308066497214d-10,0.1389697401910016d-10,
     8      0.2721876719487622d-10,-.6896601771738714d-10/
         data arr1868/
     1      0.6896627867775788d-10,0.6704734056486037d-11,
     2      -.3469283552427920d-10,0.1608095916926481d-09,
     3      0.3005468746151062d-09,0.4702155783071726d-09,
     4      0.9806961139157526d-09,0.1740526635761049d-08,
     5      0.2476902476300068d-08,0.3129855447224084d-08,
     6      0.3726162849221970d-08,0.4139928551519384d-08,
     7      0.4170523899857934d-08,0.3760982085725371d-08,
     8      0.3057991460296229d-08,0.2310877161879108d-08/
         data arr1869/
     1      0.2027611823653729d-08,-.1330333735535986d-10,
     2      0.2495226739670157d-10,-.2303040633157201d-10,
     3      0.8578207934016039d-11,0.1670864052744504d-10,
     4      -.4085951070688210d-10,0.4057637191472104d-10,
     5      0.1702996924699363d-11,-.2895156686357351d-10,
     6      0.7357531390975456d-10,0.1303223935860396d-09,
     7      0.1871731673866859d-09,0.4306772820105456d-09,
     8      0.8157299386060476d-09,0.1194767738275404d-08/
         data arr1870/
     1      0.1547471750213465d-08,0.1900191041740848d-08,
     2      0.2178900735313355d-08,0.2254364939787521d-08,
     3      0.2076936076300641d-08,0.1719713360368621d-08,
     4      0.1321549569082092d-08,0.1181500312685280d-08,
     5      -.1212342507363373d-10,0.2216355771094767d-10,
     6      -.2175046705933532d-10,0.6879509753076384d-11,
     7      0.1526204634979033d-10,-.3895429863879927d-10,
     8      0.3626949130502323d-10,-.8899120857363243d-13/
         data arr1871/
     1      -.3501939869683440d-10,0.4640893841448655d-10,
     2      0.7143887887782433d-10,0.6970692207593764d-10,
     3      0.2105099519455854d-09,0.4612934377928482d-09,
     4      0.7018768554726814d-09,0.9359699725960833d-09,
     5      0.1215238238784199d-08,0.1489155727636975d-08,
     6      0.1634735618075923d-08,0.1582825158058947d-08,
     7      0.1370589124114452d-08,0.1103857073586753d-08,
     8      0.1048403046134751d-08,-.1025675947257991d-09/
         data arr1872/
     1      -.3722415823848162d-09,-.8125912229648103d-09,
     2      -.1469050964820568d-08,-.2259196425857379d-08,
     3      -.3002733537919591d-08,-.3503992330428889d-08,
     4      -.3640343724038094d-08,-.3404863251175595d-08,
     5      -.2894284197653019d-08,-.2255005961826247d-08,
     6      -.1622288763799354d-08,-.1084235468560334d-08,
     7      -.6765741397795632d-09,-.3959816561055863d-09,
     8      -.2183671003633135d-09,-.1139287733802911d-09/
         data arr1873/
     1      -.5639739394234167d-10,-.2645292500839406d-10,
     2      -.1172451414236198d-10,-.4892764893729819d-11,
     3      -.2145646810787060d-11,-.1007323904709491d-09,
     4      -.4121119465699717d-09,-.1009462644253383d-08,
     5      -.2027021448237787d-08,-.3437911362103186d-08,
     6      -.5004405915794319d-08,-.6360084712932671d-08,
     7      -.7159672919932561d-08,-.7221769093266356d-08,
     8      -.6593597856079501d-08,-.5498220971240061d-08/
         data arr1874/
     1      -.4219017931540744d-08,-.2997990762464065d-08,
     2      -.1983820138762028d-08,-.1228703653407375d-08,
     3      -.7155039682719373d-09,-.3931170039144894d-09,
     4      -.2042420309673432d-09,-.1004605844891807d-09,
     5      -.4684452424277063d-10,-.2086643033659067d-10,
     6      -.1012379814919303d-10,-.6902405521741608d-10,
     7      -.3179555601137744d-09,-.8742995791641780d-09,
     8      -.1950096686653769d-08,-.3647055170488996d-08/
         data arr1875/
     1      -.5815263517745227d-08,-.8048697097665338d-08,
     2      -.9816971420469331d-08,-.1067967125861924d-07,
     3      -.1047325547477680d-07,-.9345937185912932d-08,
     4      -.7649051017421894d-08,-.5779786910501892d-08,
     5      -.4055719789094484d-08,-.2656942844780415d-08,
     6      -.1632589335645387d-08,-.9443507535841837d-09,
     7      -.5153910484421166d-09,-.2656814425550310d-09,
     8      -.1294532985295811d-09,-.5998750328817043d-10/
         data arr1876/
     1      -.3013722890984972d-10,-.3847139901792220d-10,
     2      -.1971509420776961d-09,-.6101947650288156d-09,
     3      -.1510925305027937d-08,-.3115675039672070d-08,
     4      -.5442886708743300d-08,-.8203144995926718d-08,
     5      -.1084064109099104d-07,-.1272012332275669d-07,
     6      -.1339825188008592d-07,-.1279427817554009d-07,
     7      -.1116900778875005d-07,-.8974983726404838d-08,
     8      -.6678590679097345d-08,-.4627956783904722d-08/
         data arr1877/
     1      -.3001503244353809d-08,-.1829265625685882d-08,
     2      -.1050256093042760d-08,-.5686529106505417d-09,
     3      -.2905607112911365d-09,-.1410474974245586d-09,
     4      -.7464937306707071d-10,-.1907608429489935d-10,
     5      -.1034432963773117d-09,-.3646563055017967d-09,
     6      -.1000095819950811d-08,-.2274125400395641d-08,
     7      -.4354249724571091d-08,-.7143938285078075d-08,
     8      -.1022959213948821d-07,-.1294753814372179d-07/
         data arr1878/
     1      -.1464704525315615d-07,-.1496688037989599d-07,
     2      -.1393693952263212d-07,-.1190997843179597d-07,
     3      -.9397981889329420d-08,-.6888314204691186d-08,
     4      -.4715621546783831d-08,-.3028270202332255d-08,
     5      -.1828930878450000d-08,-.1039786056741121d-08,
     6      -.5569079854635028d-09,-.2832191846178607d-09,
     7      -.1580920368201101d-09,-.9873807973136041d-11,
     8      -.4604236222955538d-10,-.1938693433745628d-09/
         data arr1879/
     1      -.5839608049728794d-09,-.1464755456972556d-08,
     2      -.3077001871355616d-08,-.5491846057837991d-08,
     3      -.8522035378927066d-08,-.1163685720592042d-07,
     4      -.1413677927095150d-07,-.1545692011962075d-07,
     5      -.1535428999138364d-07,-.1395421575396935d-07,
     6      -.1167501895721719d-07,-.9050214659581881d-08,
     7      -.6539192513864987d-08,-.4424109691639601d-08,
     8      -.2809273302570265d-08,-.1675376713948145d-08/
         data arr1880/
     1      -.9391738050105487d-09,-.4992707281601597d-09,
     2      -.2928516513868250d-09,-.6812507096480262d-11,
     3      -.1523065469659915d-10,-.9520219365696491d-10,
     4      -.3063902348504337d-09,-.8491494881143066d-09,
     5      -.1962380572490245d-08,-.3803693128807578d-08,
     6      -.6398624348880409d-08,-.9429156327139996d-08,
     7      -.1229779718043369d-07,-.1438614412308251d-07,
     8      -.1524531638417939d-07,-.1473244606504622d-07/
         data arr1881/
     1      -.1306369786063016d-07,-.1070300329952093d-07,
     2      -.8154093320280232d-08,-.5801733512205195d-08,
     3      -.3861643953253081d-08,-.2404282514152293d-08,
     4      -.1400790123563861d-08,-.7704013785130267d-09,
     5      -.4661741212282214d-09,-.7373717548636079d-11,
     6      0.5717136222014168d-12,-.4641222826722775d-10,
     7      -.1459060065609049d-09,-.4480405641048631d-09,
     8      -.1148686979645236d-08,-.2406649077498532d-08/
         data arr1882/
     1      -.4391749031133927d-08,-.6990276894753091d-08,
     2      -.9783493935001740d-08,-.1224282725956590d-07,
     3      -.1384592632231082d-07,-.1423293593599130d-07,
     4      -.1338016660273285d-07,-.1159333396347821d-07,
     5      -.9326202963922394d-08,-.6996912565431699d-08,
     6      -.4902113155967645d-08,-.3206163234654408d-08,
     7      -.1959192214219607d-08,-.1130399787817644d-08,
     8      -.7239227181648600d-09,-.8570772650207627d-11/
         data arr1883/
     1      0.9489961305671148d-11,-.2519322199603625d-10,
     2      -.6233702590388309d-10,-.2150861665540892d-09,
     3      -.6266248063094563d-09,-.1403645979931376d-08,
     4      -.2783223916044964d-08,-.4793132934454393d-08,
     5      -.7192370176323685d-08,-.9623958672040355d-08,
     6      -.1161870044272374d-07,-.1270409697190578d-07,
     7      -.1265462309071026d-07,-.1158734463042387d-07,
     8      -.9834049596616212d-08,-.7769750714887536d-08/
         data arr1884/
     1      -.5718326536335507d-08,-.3916908777328019d-08,
     2      -.2499859570066738d-08,-.1504386778097931d-08,
     3      -.1010208003862068d-08,-.1126509911937337d-10,
     4      0.1448715094749420d-10,-.1819265286934661d-10,
     5      -.2342557049147749d-10,-.9212412757078926d-10,
     6      -.3260080351839881d-09,-.7590995742100833d-09,
     7      -.1640450578195892d-08,-.3068389177608670d-08,
     8      -.4927852735420592d-08,-.7045359674406360d-08/
         data arr1885/
     1      -.9086710092750477d-08,-.1057379504907332d-07,
     2      -.1115967388134119d-07,-.1079928572247521d-07,
     3      -.9675218637761666d-08,-.8059727553950680d-08,
     4      -.6240395933800073d-08,-.4484723815114969d-08,
     5      -.2995992198141917d-08,-.1886260044792899d-08,
     6      -.1335271024565704d-08,-.1197933567110298d-10,
     7      0.1751040165465472d-10,-.1555100962000195d-10,
     8      -.5583637763695256d-11,-.3257829890197672d-10/
         data arr1886/
     1      -.1653109875890264d-09,-.3801069810341094d-09,
     2      -.9038266849766716d-09,-.1844806189580683d-08,
     3      -.3160382614487281d-08,-.4821952236920186d-08,
     4      -.6639252511587556d-08,-.8202859414600412d-08,
     5      -.9139967958123460d-08,-.9304943632962179d-08,
     6      -.8744719525020915d-08,-.7610185486661011d-08,
     7      -.6121853795332635d-08,-.4543009061040304d-08,
     8      -.3115225105808005d-08,-.2001432880758972d-08/
         data arr1887/
     1      -.1437340687749879d-08,-.1383088183293097d-10,
     2      0.1908227332441235d-10,-.1565818417202726d-10,
     3      0.2231140914005792d-12,-.4399665693105806d-11,
     4      -.8851320407549093d-10,-.1753188674292940d-09,
     5      -.4642205759421067d-09,-.1054576853468201d-08,
     6      -.1916646214506319d-08,-.3112903467354817d-08,
     7      -.4593195575414292d-08,-.6050172411031706d-08,
     8      -.7139523809978682d-08,-.7679107972890820d-08/
         data arr1888/
     1      -.7627022593580225d-08,-.7013381531617944d-08,
     2      -.5950068811631329d-08,-.4644285594981852d-08,
     3      -.3342907823764656d-08,-.2255559922144807d-08,
     4      -.1718332147222262d-08,-.1137129554562791d-10,
     5      0.1951352700489473d-10,-.1341481158609155d-10,
     6      0.3154636107960142d-11,0.8088819172771251d-11,
     7      -.5018406330533222d-10,-.7169932185262208d-10,
     8      -.2202656618283786d-09,-.5731356691310892d-09/
         data arr1889/
     1      -.1095807481639676d-08,-.1886430287002566d-08,
     2      -.2981743294657479d-08,-.4175899153233783d-08,
     3      -.5193734073783472d-08,-.5868125016811477d-08,
     4      -.6116882740194726d-08,-.5890957942087758d-08,
     5      -.5213945950241881d-08,-.4226259135712649d-08,
     6      -.3146997521743379d-08,-.2191500479366369d-08,
     7      -.1727980163708379d-08,-.1163527239248704d-10,
     8      0.1714855290780447d-10,-.1255166271497863d-10/
         data arr1890/
     1      0.1423467281193165d-11,0.1262194171482309d-10,
     2      -.3431404875819117d-10,-.2549749293983110d-10,
     3      -.9364447495215234d-10,-.3037244921640384d-09,
     4      -.6018037487424772d-09,-.1086375032451833d-08,
     5      -.1852233753605346d-08,-.2775913679708634d-08,
     6      -.3648952567146537d-08,-.4343797706731681d-08,
     7      -.4780242572792174d-08,-.4864224337204509d-08,
     8      -.4537706150186406d-08,-.3862842868836750d-08/
         data arr1891/
     1      -.3011977681526217d-08,-.2196315885370832d-08,
     2      -.1830590954190402d-08,-.7431158142746070d-11,
     3      0.1270314993106987d-10,-.8469627952784032d-11,
     4      0.2318828872477855d-11,0.9577315444958323d-11,
     5      -.1980088598430262d-10,-.5721743037131195d-11,
     6      -.3693148661759064d-10,-.1471005397192958d-09,
     7      -.2975475718384667d-09,-.5632313145031109d-09,
     8      -.1017931298517054d-08,-.1593636616116352d-08/
         data arr1892/
     1      -.2167443688833904d-08,-.2659240631762478d-08,
     2      -.3003214410195273d-08,-.3115703441998555d-08,
     3      -.2943031006830405d-08,-.2521445513614586d-08,
     4      -.1968621532518307d-08,-.1429263555171315d-08,
     5      -.1175038857974447d-08,-.6595227593069528d-11,
     6      0.9862669019149643d-11,-.6865548349816499d-11,
     7      0.2194973584709847d-12,0.9646243124896724d-11,
     8      -.1585790708781352d-10,0.4047001755945649d-12/
         data arr1893/
     1      -.8705182687894318d-11,-.7584121570994694d-10,
     2      -.1521842100148418d-09,-.2917083338638007d-09,
     3      -.5772617332397262d-09,-.9758928432567487d-09,
     4      -.1401938432310126d-08,-.1809787238882761d-08,
     5      -.2162187278131811d-08,-.2379497377330531d-08,
     6      -.2378582862701300d-08,-.2147587332808245d-08,
     7      -.1761548650634942d-08,-.1344307159036530d-08,
     8      -.1174612435650458d-08,-.2341300788925650d-11/
         data arr1894/
     1      0.6667626898760705d-11,-.3103104395053097d-11,
     2      0.6299971545205567d-12,0.7359856223882336d-11,
     3      -.8636817456391499d-11,0.2183022427559776d-11,
     4      0.1243505893321503d-11,-.3305531852497843d-10,
     5      -.6574199338678903d-10,-.1260336234087014d-09,
     6      -.2696649726255134d-09,-.4837160286775776d-09,
     7      -.7213835408850004d-09,-.9626159969590360d-09,
     8      -.1191719831619909d-08,-.1358861790599950d-08/
         data arr1895/
     1      -.1402670703588099d-08,-.1301922025540218d-08,
     2      -.1094366591962736d-08,-.8542872371265583d-09,
     3      -.7656116262533648d-09,-.1896177042814458d-11,
     4      0.3760301263768146d-11,-.1955629604067305d-11,
     5      -.1069460455000302d-11,0.5906306573134798d-11,
     6      -.6545719493226509d-11,0.7958760659302600d-12,
     7      0.4873974968205070d-11,-.1707511477881610d-10,
     8      -.3319907949909963d-10,-.5674468929828196d-10/
         data arr1896/
     1      -.1365276913033479d-09,-.2701657974742321d-09,
     2      -.4241434405175237d-09,-.5906048822730438d-09,
     3      -.7706514011858607d-09,-.9324006148080078d-09,
     4      -.1018208561707724d-08,-.9946093420330909d-09,
     5      -.8760078871905392d-09,-.7168093753591760d-09,
     6      -.6810150386317991d-09,0.1580136594805168d-09,
     7      0.3442757727244782d-09,0.5685767486735831d-09,
     8      0.8361819606809265d-09,0.1060624399288928d-08/
         data arr1897/
     1      0.1190648627327156d-08,0.1204947533269882d-08,
     2      0.1100018149025674d-08,0.9145514931548402d-09,
     3      0.7025168451139239d-09,0.5010626214709064d-09,
     4      0.3310976912558232d-09,0.2035458770350458d-09,
     5      0.1182990379848073d-09,0.6598061247458209d-10,
     6      0.3503367445269494d-10,0.1705272292756306d-10,
     7      0.7226662800722201d-11,0.2876124009532494d-11,
     8      0.1909674618416665d-09,0.4606347951866587d-09/
         data arr1898/
     1      0.8432984944354850d-09,0.1354395455151137d-08,
     2      0.1872125667485785d-08,0.2279621354148750d-08,
     3      0.2484502219636998d-08,0.2436307699429971d-08,
     4      0.2170995190296745d-08,0.1777722160063413d-08,
     5      0.1345388490086783d-08,0.9434811286565791d-09,
     6      0.6163451926241003d-09,0.3784936102296777d-09,
     7      0.2200688520959564d-09,0.1209144386845406d-09,
     8      0.6201473451694953d-10,0.2938072636018537d-10/
         data arr1899/
     1      0.1452184760073042d-10,0.1609151752111157d-09,
     2      0.4301476826727704d-09,0.8719347089363939d-09,
     3      0.1531076193491917d-08,0.2305598096461310d-08,
     4      0.3043787488657946d-08,0.3575227878975715d-08,
     5      0.3765649160980863d-08,0.3593379802929202d-08,
     6      0.3137747298940531d-08,0.2523110376355872d-08,
     7      0.1876914513155352d-08,0.1299135123596533d-08,
     8      0.8425357269898735d-09,0.5146606653944292d-09/
         data arr1900/
     1      0.2962023373410456d-09,0.1599374337401716d-09,
     2      0.8103212112611708d-10,0.4397045512685059d-10,
     3      0.1092903820764754d-09,0.3240296020745097d-09,
     4      0.7260390542342235d-09,0.1395527199231819d-08,
     5      0.2288531687200860d-08,0.3274536957377097d-08,
     6      0.4147361091629305d-08,0.4691656817282418d-08,
     7      0.4792127134022428d-08,0.4463242428221980d-08,
     8      0.3815746747262164d-08,0.3010482382081511d-08/
         data arr1901/
     1      0.2205541848556256d-08,0.1510676593229647d-08,
     2      0.9722682065196379d-09,0.5886542396580199d-09,
     3      0.3346311551269980d-09,0.1792545120367870d-09,
     4      0.1043183264254742d-09,0.6342603433433100d-10,
     5      0.2090442203910112d-09,0.5162753333152055d-09,
     6      0.1088383513441298d-08,0.1942411561107358d-08,
     7      0.3011617435916409d-08,0.4114814941860293d-08,
     8      0.4998897162210149d-08,0.5463720571139944d-08/
         data arr1902/
     1      0.5428368456374471d-08,0.4935056683047516d-08,
     2      0.4128094906854568d-08,0.3198525811402932d-08,
     3      0.2312135199918555d-08,0.1566995576853928d-08,
     4      0.9965064231840389d-09,0.5934734397406168d-09,
     5      0.3325214111361201d-09,0.2031797430856708d-09,
     6      0.3258493942421735d-10,0.1195640824165867d-09,
     7      0.3235247640134317d-09,0.7508385203253551d-09,
     8      0.1456291335361146d-08,0.2446314981093186d-08/
         data arr1903/
     1      0.3607514022623644d-08,0.4705486211216577d-08,
     2      0.5502019792405843d-08,0.5831491757973782d-08,
     3      0.5637035867923723d-08,0.4996547827364893d-08,
     4      0.4090790752742537d-08,0.3117015789358220d-08,
     5      0.2220192052374697d-08,0.1477938181358722d-08,
     6      0.9168745062791835d-09,0.5324872643930793d-09,
     7      0.3360692655248147d-09,0.1461257329181640d-10,
     8      0.6286589809789409d-10,0.1805935469609652d-09/
         data arr1904/
     1      0.4690012549111557d-09,0.9845796974848780d-09,
     2      0.1790183520670523d-08,0.2854410821185486d-08,
     3      0.3996064606286443d-08,0.4995784145536158d-08,
     4      0.5651704676575186d-08,0.5813486932196442d-08,
     5      0.5462471291796767d-08,0.4728757342623257d-08,
     6      0.3805814115280502d-08,0.2861022745308721d-08,
     7      0.2006492558572199d-08,0.1308306304403001d-08,
     8      0.7978060488509588d-09,0.5333316498648972d-09/
         data arr1905/
     1      0.5155995269624674d-11,0.3265670836208066d-10,
     2      0.8869598064878931d-10,0.2710147412160290d-09,
     3      0.6092270658602666d-09,0.1195628841970728d-08,
     4      0.2069124909811386d-08,0.3106643626758293d-08,
     5      0.4147919387949903d-08,0.5011827665499195d-08,
     6      0.5489224929312334d-08,0.5466405356889782d-08,
     7      0.5001757865387297d-08,0.4253209702457045d-08,
     8      0.3377033932158508d-08,0.2496785663002181d-08/
         data arr1906/
     1      0.1711417865322540d-08,0.1095696425180777d-08,
     2      0.7761904225086126d-09,-.4143309037482809d-12,
     3      0.1858641134159912d-10,0.3484480415178512d-10,
     4      0.1483462908967703d-09,0.3483858706764414d-09,
     5      0.7339079277699310d-09,0.1389640758819897d-08,
     6      0.2234481117470690d-08,0.3180306235518757d-08,
     7      0.4107292163280197d-08,0.4791828663204529d-08,
     8      0.5052617439073926d-08,0.4880237552823170d-08/
         data arr1907/
     1      0.4379382740347916d-08,0.3666273111431233d-08,
     2      0.2849118991798409d-08,0.2043778701231878d-08,
     3      0.1365404739614026d-08,0.1014744024191700d-08,
     4      -.1667095254143539d-11,0.1225471433417439d-10,
     5      0.8637629251217591d-11,0.7893857575276930d-10,
     6      0.1857459632406822d-09,0.4179528310923547d-09,
     7      0.8716641840011110d-09,0.1496699619582787d-08,
     8      0.2266970929405345d-08,0.3126257085484160d-08/
         data arr1908/
     1      0.3874972451004250d-08,0.4310830191953840d-08,
     2      0.4376367797933324d-08,0.4117139066477560d-08,
     3      0.3597869724827584d-08,0.2899874736294658d-08,
     4      0.2142428219463445d-08,0.1464640114688054d-08,
     5      0.1107302746559893d-08,-.5042983277406811d-11,
     6      0.1255201092122241d-10,-.8987597277235715d-11,
     7      0.4523792741612949d-10,0.9368557556262991d-10,
     8      0.2142963074910086d-09,0.5187975069055987d-09/
         data arr1909/
     1      0.9466530264121867d-09,0.1512537112383887d-08,
     2      0.2240926563072278d-08,0.2971172701777751d-08,
     3      0.3496774318716743d-08,0.3744249377957741d-08,
     4      0.3726027895804769d-08,0.3448884907981732d-08,
     5      0.2935824919995070d-08,0.2280630098176832d-08,
     6      0.1636495320930123d-08,0.1311787698866170d-08,
     7      -.6502797018233304d-11,0.1503603878646447d-10,
     8      -.1765710991072466d-10,0.3013304657098540d-10/
         data arr1910/
     1      0.4649883498998076d-10,0.9589732618243489d-10,
     2      0.2959663747169033d-09,0.5680825433910349d-09,
     3      0.9445949003829429d-09,0.1508731356000643d-08,
     4      0.2143329804712691d-08,0.2660250206192234d-08,
     5      0.2993122962461917d-08,0.3141935297644940d-08,
     6      0.3070588187090807d-08,0.2747905781206307d-08,
     7      0.2231559255053999d-08,0.1669342668834228d-08,
     8      0.1405723561874787d-08,-.1014284785685729d-10/
         data arr1911/
     1      0.1616741166141409d-10,-.2412826898738239d-10,
     2      0.2280875423980141d-10,0.2262271885809582d-10,
     3      0.2918724294753817d-10,0.1640057522810233d-09,
     4      0.3265886110338996d-09,0.5509968982447557d-09,
     5      0.9589066836077123d-09,0.1469447967396664d-08,
     6      0.1918986466425733d-08,0.2262696120371522d-08,
     7      0.2506739786910667d-08,0.2590430923445819d-08,
     8      0.2438786356282124d-08,0.2069618504903523d-08/
         data arr1912/
     1      0.1612961244213105d-08,0.1426299925461657d-08,
     2      -.5048282577463357d-11,0.1075786266374007d-10,
     3      -.1480200707689654d-10,0.1388159001125380d-10,
     4      0.1045529812180376d-10,0.8726222393301780d-11,
     5      0.8261463919163295d-10,0.1685805969763191d-09,
     6      0.2935125804157211d-09,0.5413000586494859d-09,
     7      0.8668691033851515d-09,0.1170219488222393d-08,
     8      0.1421031605562567d-08,0.1613145466702138d-08/
         data arr1913/
     1      0.1695358021561209d-08,0.1611694291839061d-08,
     2      0.1373516992291729d-08,0.1069263227619035d-08,
     3      0.9355368137545355d-09,-.7406321563663241d-11,
     4      0.1184229633277934d-10,-.1782375414473979d-10,
     5      0.1262215165532699d-10,0.6201629953187230d-11,
     6      -.8898852446401371d-11,0.4601621468389891d-10,
     7      0.9276095338409170d-10,0.1492599080343047d-09,
     8      0.3116639537761889d-09,0.5497191912934765d-09/
         data arr1914/
     1      0.7779817096919356d-09,0.9868011647972904d-09,
     2      0.1188431527843265d-08,0.1332026539383198d-08,
     3      0.1341679760679185d-08,0.1201863888102538d-08,
     4      0.9810041756487837d-09,0.9104021868271930d-09,
     5      -.5595740159003206d-11,0.1061168498067730d-10,
     6      -.1421063423924112d-10,0.1005722102688050d-10,
     7      0.4732063392159299d-11,-.1166324788191314d-10,
     8      0.2470437437426809d-10,0.4762965605864202d-10/
         data arr1915/
     1      0.6582132571739839d-10,0.1573371363735028d-09,
     2      0.3042377016898747d-09,0.4457748778595127d-09,
     3      0.5831278333072847d-09,0.7356926842415871d-09,
     4      0.8670292544990991d-09,0.9116200038402036d-09,
     5      0.8461284367363333d-09,0.7136516868698492d-09,
     6      0.6893325074889081d-09,-.6856040531086228d-11,
     7      0.8724022132179047d-11,-.1376975954164159d-10,
     8      0.7756710023515977d-11,0.3077959583494311d-11/
         data arr1916/
     1      -.1397206170726142d-10,0.1409030575448102d-10,
     2      0.2590431902996731d-10,0.2429681689703326d-10,
     3      0.7727627831025689d-10,0.1724111704954382d-09,
     4      0.2605861578218243d-09,0.3498109510026415d-09,
     5      0.4666764978993145d-09,0.5856800946481135d-09,
     6      0.6493870372566828d-09,0.6290059816534910d-09,
     7      0.5519916138489671d-09,0.5607886667833567d-09,
     8      -.1364422373173238d-09,-.2270488505852700d-09/
         data arr1917/
     1      -.3009974853681891d-09,-.3678636534696425d-09,
     2      -.4055576552232971d-09,-.3946730608951702d-09,
     3      -.3502957388574226d-09,-.2888671497081908d-09,
     4      -.2192439644139879d-09,-.1524454686011633d-09,
     5      -.9884587722192477d-10,-.6119567708813222d-10,
     6      -.3619311753954347d-10,-.1978653886000363d-10,
     7      -.9595029997489087d-11,-.4025787975799601d-11,
     8      -.1805612507492475d-11,-.1965655263591230d-09/
         data arr1918/
     1      -.3569617380949410d-09,-.5188871786522827d-09,
     2      -.6866620561246450d-09,-.8133592250874199d-09,
     3      -.8524214016482342d-09,-.8112511668825490d-09,
     4      -.7113479638371168d-09,-.5730725138891680d-09,
     5      -.4244935414880405d-09,-.2927466297519203d-09,
     6      -.1906350829747347d-09,-.1174749104822533d-09,
     7      -.6764638095376675d-10,-.3582210177766475d-10,
     8      -.1747407543299414d-10,-.9266101794227519d-11/
         data arr1919/
     1      -.1973708675271841d-09,-.3921318133990259d-09,
     2      -.6235876616051320d-09,-.8940784603259474d-09,
     3      -.1139684635420311d-08,-.1284561006278179d-08,
     4      -.1309734553303196d-08,-.1223279024416742d-08,
     5      -.1047104586211521d-08,-.8241673139951761d-09,
     6      -.6028104972185849d-09,-.4142537489734057d-09,
     7      -.2683666383083111d-09,-.1630493939695184d-09,
     8      -.9228354461707205d-10,-.4902140015063172d-10/
         data arr1920/
     1      -.2869042761309671d-10,-.1595548332816012d-09,
     2      -.3481924181217944d-09,-.6038221314211437d-09,
     3      -.9384174113189817d-09,-.1288961222240305d-08,
     4      -.1560927837245411d-08,-.1703940012583508d-08,
     5      -.1696679088336858d-08,-.1543625151659404d-08,
     6      -.1288817377138326d-08,-.9974939882716591d-09,
     7      -.7226765344468284d-09,-.4916924263653372d-09,
     8      -.3130443547040125d-09,-.1856319652443082d-09/
         data arr1921/
     1      -.1032756932275498d-09,-.6305050212339402d-10,
     2      -.1098815397718554d-09,-.2655747611446160d-09,
     3      -.4996098268593616d-09,-.8423686344555593d-09,
     4      -.1248329824214424d-08,-.1622621353233051d-08,
     5      -.1895537594900611d-08,-.2013232203440290d-08,
     6      -.1946501391798737d-08,-.1721629791398825d-08,
     7      -.1407514328895401d-08,-.1073270838327359d-08,
     8      -.7649110029509266d-09,-.5073064229547583d-09/
         data arr1922/
     1      -.3115081997050608d-09,-.1780738616212208d-09,
     2      -.1100490241793746d-09,-.6547040966289979d-10,
     3      -.1814647300206992d-09,-.3639229977458088d-09,
     4      -.6674279292820701d-09,-.1070931602206341d-08,
     5      -.1490878602051715d-08,-.1862569243424581d-08,
     6      -.2113708128862552d-08,-.2174411220470901d-08,
     7      -.2037751881357434d-08,-.1762278157773333d-08,
     8      -.1421288418234315d-08,-.1070629783906831d-08/
         data arr1923/
     1      -.7491591550218521d-09,-.4846891514429207d-09,
     2      -.2924928525292025d-09,-.1936284576170561d-09,
     3      -.3251727512838864d-10,-.1157882086183828d-09,
     4      -.2366365773875424d-09,-.4755592040539039d-09,
     5      -.8324047410916768d-09,-.1235797479295373d-08,
     6      -.1649281297654344d-08,-.2004786492407689d-08,
     7      -.2196721926148592d-08,-.2180343228030246d-08,
     8      -.1995565724731478d-08,-.1706812124313970d-08/
         data arr1924/
     1      -.1364481845781347d-08,-.1011767581147351d-08,
     2      -.6928234825028229d-09,-.4438853779504880d-09,
     3      -.3180844180545029d-09,-.1178580057675568d-10,
     4      -.7222934793668757d-10,-.1383928222700730d-09,
     5      -.3087986253188057d-09,-.5955832750608934d-09,
     6      -.9371912020200153d-09,-.1334124262115474d-08,
     7      -.1739331957252026d-08,-.2028279270847539d-08,
     8      -.2127000246404415d-08,-.2054281526921536d-08/
         data arr1925/
     1      -.1855211730641500d-08,-.1562450206546113d-08,
     2      -.1214496046874359d-08,-.8672863724116854d-09,
     3      -.5778301900388894d-09,-.4324364294134805d-09,
     4      -.1012541050069579d-11,-.4461887272637915d-10,
     5      -.7268013562579871d-10,-.1845731090463919d-09,
     6      -.3953679597048579d-09,-.6557034497509353d-09,
     7      -.9948883059881240d-09,-.1389022852252854d-08,
     8      -.1717268717374674d-08,-.1894852131992911d-08/
         data arr1926/
     1      -.1920375267498780d-08,-.1813541371633300d-08,
     2      -.1586148729607602d-08,-.1269111573306279d-08,
     3      -.9246723542789906d-09,-.6227637180633931d-09,
     4      -.4644657945547644d-09,0.6965633131126776d-11,
     5      -.3358856968037152d-10,-.3056412719863929d-10,
     6      -.9932970406351208d-10,-.2524457213086492d-09,
     7      -.4281942831581602d-09,-.6885359938476022d-09,
     8      -.1044152260080924d-08,-.1378058896653852d-08/
         data arr1927/
     1      -.1602395857119841d-08,-.1715315355014349d-08,
     2      -.1720964971188167d-08,-.1599137880186740d-08,
     3      -.1353121026923068d-08,-.1038675714949536d-08,
     4      -.7379126742635362d-09,-.5895459672808850d-09,
     5      0.1303174483819493d-10,-.2977563910968162d-10,
     6      -.5055325600199883d-11,-.4555152029517384d-10,
     7      -.1581241761341956d-09,-.2612988498456969d-09,
     8      -.4413218710691187d-09,-.7398478420083956d-09/
         data arr1928/
     1      -.1045799620964691d-08,-.1276851587082275d-08,
     2      -.1443048976424557d-08,-.1543519347458714d-08,
     3      -.1529158203449533d-08,-.1371064719177736d-08,
     4      -.1110030574501362d-08,-.8326909384666244d-09,
     5      -.7135601102483068d-09,0.1454794185962162d-10,
     6      -.2804781223184202d-10,0.6163937274747992d-11,
     7      -.1636445827373245d-10,-.9904626629006581d-10,
     8      -.1502676877807708d-09,-.2619127445879941d-09/
         data arr1929/
     1      -.4922920644111965d-09,-.7439102347968360d-09,
     2      -.9468279519696598d-09,-.1122665737097772d-08,
     3      -.1271927727470559d-08,-.1331472823859266d-08,
     4      -.1251638844515780d-08,-.1055816921485051d-08,
     5      -.8241654645751777d-09,-.7411387839678832d-09,
     6      0.9089164189826578d-11,-.1654030501959669d-10,
     7      0.6047165871506655d-11,-.5767006772245122d-11,
     8      -.5211701065703587d-10,-.7749542726041131d-10/
         data arr1930/
     1      -.1421870990335774d-09,-.2840800080487924d-09,
     2      -.4449534874870021d-09,-.5833777522820358d-09,
     3      -.7099279325601074d-09,-.8177834782925892d-09,
     4      -.8616471802492181d-09,-.8091076665539595d-09,
     5      -.6775859512934049d-09,-.5209344246933580d-09,
     6      -.4536324523183175d-09,0.9943556065079697d-11,
     7      -.1701750858293123d-10,0.8516034343283630d-11,
     8      0.2313356635011399d-11,-.3518124076929967d-10/
         data arr1931/
     1      -.3995554925611082d-10,-.7160375524175587d-10,
     2      -.1741014008236663d-09,-.2945979885073617d-09,
     3      -.3990849422361207d-09,-.5103215888852268d-09,
     4      -.6302524478847652d-09,-.7109973292842020d-09,
     5      -.7078462135815233d-09,-.6245496366721637d-09,
     6      -.5064903146138605d-09,-.4726752808211347d-09,
     7      0.1001476071529043d-10,-.1456998561246505d-10,
     8      0.9399978255983422d-11,0.5947032991938882d-11/
         data arr1932/
     1      -.2351145388900674d-10,-.1813865013400219d-10,
     2      -.2954771942776616d-10,-.9885995157829134d-10,
     3      -.1810876494847133d-09,-.2501173998509070d-09,
     4      -.3337905933041071d-09,-.4408458037320048d-09,
     5      -.5297570902382866d-09,-.5549860941264325d-09,
     6      -.5118077185502787d-09,-.4339300608476220d-09,
     7      -.4285571586360347d-09,0.8095913574901385d-11,
     8      -.1272730232132654d-10,0.7352586559383462d-11/
         data arr1933/
     1      0.5925928223182406d-11,-.1703076211658607d-10,
     2      -.8458698122530652d-11,-.8857892215864006d-11,
     3      -.5385916482633003d-10,-.1074286254513169d-09,
     4      -.1489329356062295d-09,-.2054978418158901d-09,
     5      -.2902081920701637d-09,-.3711598400382079d-09,
     6      -.4085399046405409d-09,-.3927041818124009d-09,
     7      -.3469834164262632d-09,-.3612268991700440d-09,
     8      0.8207190940085217d-10,0.1149968575700567d-09/
         data arr1934/
     1      0.1277781053996560d-09,0.1313372716061393d-09,
     2      0.1299850111646317d-09,0.1141782201776859d-09,
     3      0.8882710973891125d-10,0.6545826361720080d-10,
     4      0.4713385847179905d-10,0.3152970224693140d-10,
     5      0.1837341906930638d-10,0.9255477808809962d-11,
     6      0.4610664150054455d-11,0.3381014134315337d-11,
     7      0.1374156716854166d-09,0.2076861561025060d-09,
     8      0.2510262997799826d-09,0.2784030205192682d-09/
         data arr1935/
     1      0.2920016854022902d-09,0.2733228445906254d-09,
     2      0.2288990280060121d-09,0.1796081137523604d-09,
     3      0.1347756475776791d-09,0.9438218010005529d-10,
     4      0.5981030961814814d-10,0.3448204988744543d-10,
     5      0.1930115653283541d-10,0.1342129447743528d-10,
     6      0.1603422911143747d-09,0.2621259778243826d-09,
     7      0.3439864908161735d-09,0.4110016110140281d-09,
     8      0.4583800264868716d-09,0.4572768670756227d-09/
         data arr1936/
     1      0.4098654193264804d-09,0.3413383124705261d-09,
     2      0.2683398046629126d-09,0.1967259774021408d-09,
     3      0.1323043469069262d-09,0.8177671901399595d-10,
     4      0.4804183337640668d-10,0.3254081246737286d-10,
     5      0.1507113070662732d-09,0.2674541142371132d-09,
     6      0.3803446504868116d-09,0.4887587832637607d-09,
     7      0.5809723486619495d-09,0.6178074309227235d-09,
     8      0.5904885702730985d-09,0.5208337735281310d-09/
         data arr1937/
     1      0.4297830400617132d-09,0.3295853200757542d-09,
     2      0.2321628388252810d-09,0.1498056557618823d-09,
     3      0.9003231036113858d-10,0.5928728377487731d-10,
     4      0.1203904501620619d-09,0.2343625047723852d-09,
     5      0.3605112709195037d-09,0.4965499502324941d-09,
     6      0.6308673430846940d-09,0.7167604338892613d-09,
     7      0.7297520918597080d-09,0.6822537972189813d-09,
     8      0.5949030918385403d-09,0.4827066931712326d-09/
         data arr1938/
     1      0.3608705770851151d-09,0.2475187030382151d-09,
     2      0.1578158616408485d-09,0.1105478898980340d-09,
     3      0.8338696043126250d-10,0.1826299045471921d-09,
     4      0.3031967849689824d-09,0.4448584376478894d-09,
     5      0.6061233877623275d-09,0.7380546491630428d-09,
     6      0.7999069906214843d-09,0.7928531536934148d-09,
     7      0.7340326551550493d-09,0.6350281681514023d-09,
     8      0.5077725600708584d-09,0.3731324293671518d-09/
         data arr1939/
     1      0.2558273422116984d-09,0.1968365247267233d-09,
     2      0.5036455170706564d-10,0.1294090631888821d-09,
     3      0.2307055202429711d-09,0.3584357283513376d-09,
     4      0.5250175333504076d-09,0.6848585211618522d-09,
     5      0.7872970559365112d-09,0.8242019063794363d-09,
     6      0.8061482039863795d-09,0.7359404491446467d-09,
     7      0.6183812312199289d-09,0.4747642829490696d-09,
     8      0.3383561058468840d-09,0.2705236128331070d-09/
         data arr1940/
     1      0.2662091184482816d-10,0.8489327224329692d-10,
     2      0.1607821447782217d-09,0.2634015879810009d-09,
     3      0.4152638671488995d-09,0.5780344687453433d-09,
     4      0.7010447369365912d-09,0.7711843849039884d-09,
     5      0.7900386552407730d-09,0.7496115452128673d-09,
     6      0.6477819808755166d-09,0.5058705884598223d-09,
     7      0.3621814850013831d-09,0.2845809322509838d-09,
     8      0.9470858319584425d-11,0.5313273983984429d-10/
         data arr1941/
     1      0.1058854745048169d-09,0.1771562842627936d-09,
     2      0.3046484358451568d-09,0.4588077565646024d-09,
     3      0.5886595799533701d-09,0.6830610564445327d-09,
     4      0.7434089289551816d-09,0.7516059277392534d-09,
     5      0.6897640540522495d-09,0.5696729489642519d-09,
     6      0.4314489939100523d-09,0.3640418664423573d-09,
     7      -.1937105964519806d-11,0.3274969337031798d-10,
     8      0.6793923269984048d-10,0.1088377234711284d-09/
         data arr1942/
     1      0.2084318709274334d-09,0.3458569600209102d-09,
     2      0.4694775563654626d-09,0.5741045645109645d-09,
     3      0.6687759358784234d-09,0.7296891205081644d-09,
     4      0.7205207715208961d-09,0.6372951799355820d-09,
     5      0.5177132978571486d-09,0.4789152952172175d-09,
     6      -.7338349631183424d-11,0.1946956398822147d-10,
     7      0.4148137754622074d-10,0.6048540330022817d-10,
     8      0.1315213245162848d-09,0.2407007943948473d-09/
         data arr1943/
     1      0.3427601673636225d-09,0.4377729806747543d-09,
     2      0.5395603792715858d-09,0.6241098828060529d-09,
     3      0.6484810078209374d-09,0.5990285576493844d-09,
     4      0.5065729009869484d-09,0.4911036701329012d-09,
     5      -.5031227468044621d-11,0.1065697595353354d-10,
     6      0.2180842927751136d-10,0.3157673500871671d-10,
     7      0.7456020500709727d-10,0.1419955824880287d-09,
     8      0.2077908655035868d-09,0.2728707112523655d-09/
         data arr1944/
     1      0.3427211481543026d-09,0.3980162068062430d-09,
     2      0.4106826603475226d-09,0.3738886239527945d-09,
     3      0.3088226989065352d-09,0.2860597669795795d-09,
     4      -.6227410062216274d-11,0.6614586063995831d-11,
     5      0.1353335327724876d-10,0.1396117129988883d-10,
     6      0.4176189500526502d-10,0.9155453162691833d-10,
     7      0.1397624871986628d-09,0.1907461881209816d-09,
     8      0.2557202705261488d-09,0.3194053493018415d-09/
         data arr1945/
     1      0.3515517135196491d-09,0.3385932472968905d-09,
     2      0.2955775700326817d-09,0.2936420089345677d-09,
     3      -.6501811543168889d-11,0.4451866539107863d-11,
     4      0.9616680554974740d-11,0.4461329550474613d-11,
     5      0.2173948208949717d-10,0.5895788727193345d-10,
     6      0.9347146210766702d-10,0.1310335190157994d-09,
     7      0.1881544582027365d-09,0.2551937943543796d-09,
     8      0.3016555537200516d-09,0.3086678839319064d-09/
         data arr1946/
     1      0.2857253609383192d-09,0.3058322692465163d-09,
     2      -.5796696992664669d-11,0.2326052097758832d-11,
     3      0.5969592600554071d-11,-.3324992263656150d-12,
     4      0.9178725904717329d-11,0.3368385128131865d-10,
     5      0.5514845473762515d-10,0.7849866943797224d-10,
     6      0.1199146486018405d-09,0.1748042432148444d-09,
     7      0.2190931117000501d-09,0.2350583183123789d-09,
     8      0.2273104580509206d-09,0.2568555136019385d-09/
         data arr1947/
     1      -.4388484056689125d-10,-.4636291312983697d-10,
     2      -.4412353510683749d-10,-.3449815825892415d-10,
     3      -.2575279459721107d-10,-.2027339602741044d-10,
     4      -.1546197236736382d-10,-.9876698195880676d-11,
     5      -.4830463570657898d-11,-.2109906369838820d-11,
     6      -.9034164630129386d-10,-.1021917071685267d-09,
     7      -.1037472024684646d-09,-.8747882653236198d-10,
     8      -.6997274181733006d-10,-.5744144155692340d-10/
         data arr1948/
     1      -.4519702235439683d-10,-.3062227433657882d-10,
     2      -.1704060579700055d-10,-.9594391356909940d-11,
     3      -.1291424989509251d-09,-.1563130480194056d-09,
     4      -.1685057529558732d-09,-.1525256337464162d-09,
     5      -.1303700014900735d-09,-.1110755309166318d-09,
     6      -.8903330672004546d-10,-.6196959118330056d-10,
     7      -.3631383763510675d-10,-.2125746408150399d-10,
     8      -.1489119000988155d-09,-.1933561961490717d-09/
         data arr1949/
     1      -.2219643121688273d-09,-.2155016003555404d-09,
     2      -.1970997420674644d-09,-.1767662703095876d-09,
     3      -.1481436392694902d-09,-.1095175546675914d-09,
     4      -.7064542782096447d-10,-.4786387885780331d-10,
     5      -.1467006601226605d-09,-.2052373376026027d-09,
     6      -.2519656207649546d-09,-.2621289145881643d-09,
     7      -.2565118567235345d-09,-.2448498458360799d-09,
     8      -.2187098247676299d-09,-.1748048396697173d-09/
         data arr1950/
     1      -.1253317953355579d-09,-.9914304351485519d-10,
     2      -.1277439785534070d-09,-.1926316392420033d-09,
     3      -.2518687835744245d-09,-.2789790473076264d-09,
     4      -.2896634196221430d-09,-.2907335903105463d-09,
     5      -.2711745758729573d-09,-.2261435138390014d-09,
     6      -.1696487011555237d-09,-.1403587935611190d-09,
     7      -.1005196119981010d-09,-.1628943593677952d-09,
     8      -.2247273419571461d-09,-.2632211331063905d-09/
         data arr1951/
     1      -.2879924991777593d-09,-.2996044402480463d-09,
     2      -.2850217176609417d-09,-.2401581484404366d-09,
     3      -.1802381585335183d-09,-.1445166343253619d-09,
     4      -.7161548065894992d-10,-.1271706994659291d-09,
     5      -.1882112537137577d-09,-.2337516853275655d-09,
     6      -.2716907527438508d-09,-.3013246221285620d-09,
     7      -.3056007043410066d-09,-.2744387034906242d-09,
     8      -.2202819615220114d-09,-.1924958251092717d-09/
         data arr1952/
     1      -.4557200938107762d-10,-.9243630880098453d-10,
     2      -.1508873260447513d-09,-.1985363851921790d-09,
     3      -.2454176626755656d-09,-.2963159978773514d-09,
     4      -.3298016120590598d-09,-.3238395886348478d-09,
     5      -.2845530367132484d-09,-.2803800791765818d-09,
     6      -.2662508298813343d-10,-.6166209111170086d-10,
     7      -.1093100167564432d-09,-.1499497852145661d-09,
     8      -.1936013243355409d-09,-.2472132681258498d-09/
         data arr1953/
     1      -.2902134910343796d-09,-.2976829882058865d-09,
     2      -.2715512385937845d-09,-.2788903775069942d-09,
     3      -.1492621257809124d-10,-.3622384056004502d-10,
     4      -.6468529256386142d-10,-.9141255818517325d-10,
     5      -.1215776375384204d-09,-.1554408506340342d-09,
     6      -.1789867798469952d-09,-.1789071146552688d-09,
     7      -.1579174570028218d-09,-.1524535056347874d-09,
     8      -.7024098757704212d-11,-.2170237127751120d-10/
         data arr1954/
     1      -.4348407597689923d-10,-.6357626198954487d-10,
     2      -.8857206950358489d-10,-.1222427318460493d-09,
     3      -.1520664789766708d-09,-.1623128522289345d-09,
     4      -.1521359605337987d-09,-.1583118520858232d-09,
     5      -.1518319396970219d-11,-.1239155369073233d-10,
     6      -.3164414511934709d-10,-.4749800942580153d-10,
     7      -.6859295802111172d-10,-.1051275487022033d-09,
     8      -.1456549939869439d-09,-.1692864652193066d-09/
         data arr1955/
     1      -.1710254565596075d-09,-.1959293952991307d-09,
     2      0.4002568369724029d-12,-.5919610535778103d-11,
     3      -.1895964202534190d-10,-.2819346924331101d-10,
     4      -.4075303188495345d-10,-.6705496501008471d-10,
     5      -.9975230326581595d-10,-.1218760180418791d-09,
     6      -.1280308535499473d-09,-.1540205831250747d-09,
     7      0.1454169667032845d-10,0.1435633176801788d-10,
     8      0.1266549946848305d-10,0.8201428537215228d-11/
         data arr1956/
     1      0.5428014140531799d-11,0.3360483705489519d-10,
     2      0.3494249358590795d-10,0.3233398954424130d-10,
     3      0.2250905398109198d-10,0.1586037440297995d-10,
     4      0.5314813580702431d-10,0.5949573969775894d-10,
     5      0.5897234198299158d-10,0.4452151523229872d-10,
     6      0.3482240708764319d-10,0.6759450958551104d-10,
     7      0.8299051393187887d-10,0.8950795421449281d-10,
     8      0.7400992062498052d-10,0.6532528035628951d-10/
         data arr1957/
     1      0.7304643960253760d-10,0.9667837803588824d-10,
     2      0.1102170384820928d-09,0.9592678074758593d-10,
     3      0.8867804047270111d-10,0.6950610081828025d-10,
     4      0.9670414703695189d-10,0.1135419211525210d-09,
     5      0.1010252858320522d-09,0.9291613941433640d-10,
     6      0.5971837522687977d-10,0.9265678514900226d-10,
     7      0.1182975438507338d-09,0.1128109109880901d-09,
     8      0.1135483939780989d-09,0.4632027447138547d-10/
         data arr1958/
     1      0.8662578791816375d-10,0.1249597005071374d-09,
     2      0.1303557873299990d-09,0.1487492503101128d-09,
     3      0.3174400882336764d-10,0.6727856737280108d-10,
     4      0.1030565988993142d-09,0.1116522288472344d-09,
     5      0.1327158431160126d-09,0.1973314906589623d-10,
     6      0.3998600418479819d-10,0.5946493694988404d-10,
     7      0.6310569054720904d-10,0.7074567028433135d-10,
     8      0.1186763006428608d-10,0.2981063459807703d-10/
         data arr1959/
     1      0.4925663619641501d-10,0.5570395499910641d-10,
     2      0.6831889140009284d-10,0.6354838385600487d-11,
     3      0.2656722496773665d-10,0.5120189506602069d-10,
     4      0.6261377988248385d-10,0.8634486906372421d-10,
     5      0.1979899813877288d-11,0.1518938500253878d-10,
     6      0.3189341450813543d-10,0.4039419595780554d-10,
     7      0.5858752296473107d-10/
        do 1200 i=1,15341
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c
c
c
c
c
        subroutine lot12geta(arr)
        implicit real *8 (a-h,o-z)
        dimension arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260(16),
     6  arr1261(16),arr1262(16),arr1263(16),arr1264(16),
     7  arr1265(16),arr1266(16),arr1267(16),arr1268(16),
     8  arr1269(16),arr1270(16),arr1271(16),arr1272(16),
     9  arr1273(16),arr1274(16),arr1275(16),arr1276(16),
     a  arr1277(16),arr1278(16),arr1279(16),arr1280(16)
         real *8
     1  arr1281(16),arr1282(16),arr1283(16),arr1284(16),
     2  arr1285(16),arr1286(16),arr1287(16),arr1288(16),
     3  arr1289(16),arr1290(16),arr1291(16),arr1292(16),
     4  arr1293(16),arr1294(16),arr1295(16),arr1296(16),
     5  arr1297(16),arr1298(16),arr1299(16),arr1300(16),
     6  arr1301(16),arr1302(16),arr1303(16),arr1304(16),
     7  arr1305(16),arr1306(16),arr1307(16),arr1308(16),
     8  arr1309(16),arr1310(16),arr1311(16),arr1312(16),
     9  arr1313(16),arr1314(16),arr1315(16),arr1316(16),
     a  arr1317(16),arr1318(16),arr1319(16),arr1320(16)
         real *8
     1  arr1321(16),arr1322(16),arr1323(16),arr1324(16),
     2  arr1325(16),arr1326(16),arr1327(16),arr1328(16),
     3  arr1329(16),arr1330(16),arr1331(16),arr1332(16),
     4  arr1333(16),arr1334(16),arr1335(16),arr1336(16),
     5  arr1337(16),arr1338(16),arr1339(16),arr1340(16),
     6  arr1341(16),arr1342(16),arr1343(16),arr1344(16),
     7  arr1345(16),arr1346(16),arr1347(16),arr1348(16),
     8  arr1349(16),arr1350(16),arr1351(16),arr1352(16),
     9  arr1353(16),arr1354(16),arr1355(16),arr1356(16),
     a  arr1357(16),arr1358(16),arr1359(16),arr1360(16)
         real *8
     1  arr1361(16),arr1362(16),arr1363(16),arr1364(16),
     2  arr1365(16),arr1366(16),arr1367(16),arr1368(16),
     3  arr1369(16),arr1370(16),arr1371(16),arr1372(16),
     4  arr1373(16),arr1374(16),arr1375(16),arr1376(16),
     5  arr1377(16),arr1378(16),arr1379(16),arr1380(16),
     6  arr1381(16),arr1382(16),arr1383(16),arr1384(16),
     7  arr1385(16),arr1386(16),arr1387(16),arr1388(16),
     8  arr1389(16),arr1390(16),arr1391(16),arr1392(16),
     9  arr1393(16),arr1394(16),arr1395(16),arr1396(16),
     a  arr1397(16),arr1398(16),arr1399(16),arr1400(16)
         real *8
     1  arr1401(16),arr1402(16),arr1403(16),arr1404(16),
     2  arr1405(16),arr1406(16),arr1407(16),arr1408(16),
     3  arr1409(16),arr1410(16),arr1411(16),arr1412(16),
     4  arr1413(16),arr1414(16),arr1415(16),arr1416(16),
     5  arr1417(16),arr1418(16),arr1419(16),arr1420(16),
     6  arr1421(16),arr1422(16),arr1423(16),arr1424(16),
     7  arr1425(16),arr1426(16),arr1427(16),arr1428(16),
     8  arr1429(16),arr1430(16),arr1431(16),arr1432(16),
     9  arr1433(16),arr1434(16),arr1435(16),arr1436(16),
     a  arr1437(16),arr1438(16),arr1439(16),arr1440(16)
         real *8
     1  arr1441(16),arr1442(16),arr1443(16),arr1444(16),
     2  arr1445(16),arr1446(16),arr1447(16),arr1448(16),
     3  arr1449(16),arr1450(16),arr1451(16),arr1452(16),
     4  arr1453(16),arr1454(16),arr1455(16),arr1456(16),
     5  arr1457(16),arr1458(16),arr1459(16),arr1460(16),
     6  arr1461(16),arr1462(16),arr1463(16),arr1464(16),
     7  arr1465(16),arr1466(16),arr1467(16),arr1468(16),
     8  arr1469(16),arr1470(16),arr1471(16),arr1472(16),
     9  arr1473(16),arr1474(16),arr1475(16),arr1476(16),
     a  arr1477(16),arr1478(16),arr1479(16),arr1480(16)
         real *8
     1  arr1481(16),arr1482(16),arr1483(16),arr1484(16),
     2  arr1485(16),arr1486(16),arr1487(16),arr1488(16),
     3  arr1489(16),arr1490(16),arr1491(16),arr1492(16),
     4  arr1493(16),arr1494(16),arr1495(16),arr1496(16),
     5  arr1497(16),arr1498(16),arr1499(16),arr1500(16),
     6  arr1501(16),arr1502(16),arr1503(16),arr1504(16),
     7  arr1505(16),arr1506(16),arr1507(16),arr1508(16),
     8  arr1509(16),arr1510(16),arr1511(16),arr1512(16),
     9  arr1513(16),arr1514(16),arr1515(16),arr1516(16),
     a  arr1517(16),arr1518(16),arr1519(16),arr1520(16)
         real *8
     1  arr1521(16),arr1522(16),arr1523(16),arr1524(16),
     2  arr1525(16),arr1526(16),arr1527(16),arr1528(16),
     3  arr1529(16),arr1530(16),arr1531(16),arr1532(16),
     4  arr1533(16),arr1534(16),arr1535(16),arr1536(16),
     5  arr1537(16),arr1538(16),arr1539(16),arr1540(16),
     6  arr1541(16),arr1542(16),arr1543(16),arr1544(16),
     7  arr1545(16),arr1546(16),arr1547(16),arr1548(16),
     8  arr1549(16),arr1550(16),arr1551(16),arr1552(16),
     9  arr1553(16),arr1554(16),arr1555(16),arr1556(16),
     a  arr1557(16),arr1558(16),arr1559(16),arr1560(16)
         real *8
     1  arr1561(16),arr1562(16),arr1563(16),arr1564(16),
     2  arr1565(16),arr1566(16),arr1567(16),arr1568(16),
     3  arr1569(16),arr1570(16),arr1571(16),arr1572(16),
     4  arr1573(16),arr1574(16),arr1575(16),arr1576(16),
     5  arr1577(16),arr1578(16),arr1579(16),arr1580(16),
     6  arr1581(16),arr1582(16),arr1583(16),arr1584(16),
     7  arr1585(16),arr1586(16),arr1587(16),arr1588(16),
     8  arr1589(16),arr1590(16),arr1591(16),arr1592(16),
     9  arr1593(16),arr1594(16),arr1595(16),arr1596(16),
     a  arr1597(16),arr1598(16),arr1599(16),arr1600(16)
         real *8
     1  arr1601(16),arr1602(16),arr1603(16),arr1604(16),
     2  arr1605(16),arr1606(16),arr1607(16),arr1608(16),
     3  arr1609(16),arr1610(16),arr1611(16),arr1612(16),
     4  arr1613(16),arr1614(16),arr1615(16),arr1616(16),
     5  arr1617(16),arr1618(16),arr1619(16),arr1620(16),
     6  arr1621(16),arr1622(16),arr1623(16),arr1624(16),
     7  arr1625(16),arr1626(16),arr1627(16),arr1628(16),
     8  arr1629(16),arr1630(16),arr1631(16),arr1632(16),
     9  arr1633(16),arr1634(16),arr1635(16),arr1636(16),
     a  arr1637(16),arr1638(16),arr1639(16),arr1640(16)
         real *8
     1  arr1641(16),arr1642(16),arr1643(16),arr1644(16),
     2  arr1645(16),arr1646(16),arr1647(16),arr1648(16),
     3  arr1649(16),arr1650(16),arr1651(16),arr1652(16),
     4  arr1653(16),arr1654(16),arr1655(16),arr1656(16),
     5  arr1657(16),arr1658(16),arr1659(16),arr1660(16),
     6  arr1661(16),arr1662(16),arr1663(16),arr1664(16),
     7  arr1665(16),arr1666(16),arr1667(16),arr1668(16),
     8  arr1669(16),arr1670(16),arr1671(16),arr1672(16),
     9  arr1673(16),arr1674(16),arr1675(16),arr1676(16),
     a  arr1677(16),arr1678(16),arr1679(16),arr1680(16)
         real *8
     1  arr1681(16),arr1682(16),arr1683(16),arr1684(16),
     2  arr1685(16),arr1686(16),arr1687(16),arr1688(16),
     3  arr1689(16),arr1690(16),arr1691(16),arr1692(16),
     4  arr1693(16),arr1694(16),arr1695(16),arr1696(16),
     5  arr1697(16),arr1698(16),arr1699(16),arr1700(16),
     6  arr1701(16),arr1702(16),arr1703(16),arr1704(16),
     7  arr1705(16),arr1706(16),arr1707(16),arr1708(16),
     8  arr1709(16),arr1710(16),arr1711(16),arr1712(16),
     9  arr1713(16),arr1714(16),arr1715(16),arr1716(16),
     a  arr1717(16),arr1718(16),arr1719(16),arr1720(16)
         real *8
     1  arr1721(16),arr1722(16),arr1723(16),arr1724(16),
     2  arr1725(16),arr1726(16),arr1727(16),arr1728(16),
     3  arr1729(16),arr1730(16),arr1731(16),arr1732(16),
     4  arr1733(16),arr1734(16),arr1735(16),arr1736(16),
     5  arr1737(16),arr1738(16),arr1739(16),arr1740(16),
     6  arr1741(16),arr1742(16),arr1743(16),arr1744(16),
     7  arr1745(16),arr1746(16),arr1747(16),arr1748(16),
     8  arr1749(16),arr1750(16),arr1751(16),arr1752(16),
     9  arr1753(16),arr1754(16),arr1755(16),arr1756(16),
     a  arr1757(16),arr1758(16),arr1759(16),arr1760(16)
         real *8
     1  arr1761(16),arr1762(16),arr1763(16),arr1764(16),
     2  arr1765(16),arr1766(16),arr1767(16),arr1768(16),
     3  arr1769(16),arr1770(16),arr1771(16),arr1772(16),
     4  arr1773(16),arr1774(16),arr1775(16),arr1776(16),
     5  arr1777(16),arr1778(16),arr1779(16),arr1780(16),
     6  arr1781(16),arr1782(16),arr1783(16),arr1784(16),
     7  arr1785(16),arr1786(16),arr1787(16),arr1788(16),
     8  arr1789(16),arr1790(16),arr1791(16),arr1792(16),
     9  arr1793(16),arr1794(16),arr1795(16),arr1796(16),
     a  arr1797(16),arr1798(16),arr1799(16),arr1800(16)
         real *8
     1  arr1801(16),arr1802(16),arr1803(16),arr1804(16),
     2  arr1805(16),arr1806(16),arr1807(16),arr1808(16),
     3  arr1809(16),arr1810(16),arr1811(16),arr1812(16),
     4  arr1813(16),arr1814(16),arr1815(16),arr1816(16),
     5  arr1817(16),arr1818(16),arr1819(16),arr1820(16),
     6  arr1821(16),arr1822(16),arr1823(16),arr1824(16),
     7  arr1825(16),arr1826(16),arr1827(16),arr1828(16),
     8  arr1829(16),arr1830(16),arr1831(16),arr1832(16),
     9  arr1833(16),arr1834(16),arr1835(16),arr1836(16),
     a  arr1837(16),arr1838(16),arr1839(16),arr1840(16)
         real *8
     1  arr1841(16),arr1842(16),arr1843(16),arr1844(16),
     2  arr1845(16),arr1846(16),arr1847(16),arr1848(16),
     3  arr1849(16),arr1850(16),arr1851(16),arr1852(16),
     4  arr1853(16),arr1854(16),arr1855(16),arr1856(16),
     5  arr1857(16),arr1858(16),arr1859(16),arr1860(16),
     6  arr1861(16),arr1862(16),arr1863(16),arr1864(16),
     7  arr1865(16),arr1866(16),arr1867(16),arr1868(16),
     8  arr1869(16),arr1870(16),arr1871(16),arr1872(16),
     9  arr1873(16),arr1874(16),arr1875(16),arr1876(16),
     a  arr1877(16),arr1878(16),arr1879(16),arr1880(16)
         real *8
     1  arr1881(16),arr1882(16),arr1883(16),arr1884(16),
     2  arr1885(16),arr1886(16),arr1887(16),arr1888(16),
     3  arr1889(16),arr1890(16),arr1891(16),arr1892(16),
     4  arr1893(16),arr1894(16),arr1895(16),arr1896(16),
     5  arr1897(16),arr1898(16),arr1899(16),arr1900(16),
     6  arr1901(16),arr1902(16),arr1903(16),arr1904(16),
     7  arr1905(16),arr1906(16),arr1907(16),arr1908(16),
     8  arr1909(16),arr1910(16),arr1911(16),arr1912(16),
     9  arr1913(16),arr1914(16),arr1915(16),arr1916(16),
     a  arr1917(16),arr1918(16),arr1919(16),arr1920(16)
         real *8
     1  arr1921(16),arr1922(16),arr1923(16),arr1924(16),
     2  arr1925(16),arr1926(16),arr1927(16),arr1928(16),
     3  arr1929(16),arr1930(16),arr1931(16),arr1932(16),
     4  arr1933(16),arr1934(16),arr1935(16),arr1936(16),
     5  arr1937(16),arr1938(16),arr1939(16),arr1940(16),
     6  arr1941(16),arr1942(16),arr1943(16),arr1944(16),
     7  arr1945(16),arr1946(16),arr1947(16),arr1948(16),
     8  arr1949(16),arr1950(16),arr1951(16),arr1952(16),
     9  arr1953(16),arr1954(16),arr1955(16),arr1956(16),
     a  arr1957(16),arr1958(16),arr1959(16),arr1960(16)
         real *8
     1  arr1961(16),arr1962(16),arr1963(16),arr1964(16),
     2  arr1965(16),arr1966(16),arr1967(16),arr1968(16),
     3  arr1969(16),arr1970(16),arr1971(16),arr1972(16),
     4  arr1973(16),arr1974(16),arr1975(16),arr1976(16),
     5  arr1977(16),arr1978(16),arr1979(16),arr1980(16),
     6  arr1981(16),arr1982(16),arr1983(16),arr1984(16),
     7  arr1985(16),arr1986(16),arr1987(16),arr1988(16),
     8  arr1989(16),arr1990(16),arr1991(16),arr1992(16),
     9  arr1993(16),arr1994(16),arr1995(16),arr1996(16),
     a  arr1997(16),arr1998(16),arr1999(16),arr2000(16)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2),
     5  arr2257(2),arr2258(2),arr2259(2),arr2260(2),
     6  arr2261(2),arr2262(2),arr2263(2),arr2264(2),
     7  arr2265(2),arr2266(2),arr2267(2),arr2268(2),
     8  arr2269(2),arr2270(2),arr2271(2),arr2272(2),
     9  arr2273(2),arr2274(2),arr2275(2),arr2276(2),
     a  arr2277(2),arr2278(2),arr2279(2),arr2280(2)
         real *8
     1  arr2281(2),arr2282(2),arr2283(2),arr2284(2),
     2  arr2285(2),arr2286(2),arr2287(2),arr2288(2),
     3  arr2289(2),arr2290(2),arr2291(2),arr2292(2),
     4  arr2293(2),arr2294(2),arr2295(2),arr2296(2),
     5  arr2297(2),arr2298(2),arr2299(2),arr2300(2),
     6  arr2301(2),arr2302(2),arr2303(2),arr2304(2),
     7  arr2305(2),arr2306(2),arr2307(2),arr2308(2),
     8  arr2309(2),arr2310(2),arr2311(2),arr2312(2),
     9  arr2313(2),arr2314(2),arr2315(2),arr2316(2),
     a  arr2317(2),arr2318(2),arr2319(2),arr2320(2)
         real *8
     1  arr2321(2),arr2322(2),arr2323(2),arr2324(2),
     2  arr2325(2),arr2326(2),arr2327(2),arr2328(2),
     3  arr2329(2),arr2330(2),arr2331(2),arr2332(2),
     4  arr2333(2),arr2334(2),arr2335(2),arr2336(2),
     5  arr2337(2),arr2338(2),arr2339(2),arr2340(2),
     6  arr2341(2),arr2342(2),arr2343(2),arr2344(2),
     7  arr2345(2),arr2346(2),arr2347(2),arr2348(2),
     8  arr2349(2),arr2350(2),arr2351(2),arr2352(2),
     9  arr2353(2),arr2354(2),arr2355(2),arr2356(2),
     a  arr2357(2),arr2358(2),arr2359(2),arr2360(2)
         real *8
     1  arr2361(2),arr2362(2),arr2363(2),arr2364(2),
     2  arr2365(2),arr2366(2),arr2367(2),arr2368(2),
     3  arr2369(2),arr2370(2),arr2371(2),arr2372(2),
     4  arr2373(2),arr2374(2),arr2375(2),arr2376(2),
     5  arr2377(2),arr2378(2),arr2379(2),arr2380(2),
     6  arr2381(2),arr2382(2),arr2383(2),arr2384(2),
     7  arr2385(2),arr2386(2),arr2387(2),arr2388(2),
     8  arr2389(2),arr2390(2),arr2391(2),arr2392(2),
     9  arr2393(2),arr2394(2),arr2395(2),arr2396(2),
     a  arr2397(2),arr2398(2),arr2399(2),arr2400(2)
         real *8
     1  arr2401(2),arr2402(2),arr2403(2),arr2404(2),
     2  arr2405(2),arr2406(2),arr2407(2),arr2408(2),
     3  arr2409(2),arr2410(2),arr2411(2),arr2412(2),
     4  arr2413(2),arr2414(2),arr2415(2),arr2416(2),
     5  arr2417(2),arr2418(2),arr2419(2),arr2420(2),
     6  arr2421(2),arr2422(2),arr2423(2),arr2424(2),
     7  arr2425(2),arr2426(2),arr2427(2),arr2428(2),
     8  arr2429(2),arr2430(2),arr2431(2),arr2432(2),
     9  arr2433(2),arr2434(2),arr2435(2),arr2436(2),
     a  arr2437(2),arr2438(2),arr2439(2),arr2440(2)
         real *8
     1  arr2441(2),arr2442(2),arr2443(2),arr2444(2),
     2  arr2445(2),arr2446(2),arr2447(2),arr2448(2),
     3  arr2449(2),arr2450(2),arr2451(2),arr2452(2),
     4  arr2453(2),arr2454(2),arr2455(2),arr2456(2),
     5  arr2457(2),arr2458(2),arr2459(2),arr2460(2),
     6  arr2461(2),arr2462(2),arr2463(2),arr2464(2),
     7  arr2465(2),arr2466(2),arr2467(2),arr2468(2),
     8  arr2469(2),arr2470(2),arr2471(2),arr2472(2),
     9  arr2473(2),arr2474(2),arr2475(2),arr2476(2),
     a  arr2477(2),arr2478(2),arr2479(2),arr2480(2)
         real *8
     1  arr2481(2),arr2482(2),arr2483(2),arr2484(2),
     2  arr2485(2),arr2486(2),arr2487(2),arr2488(2),
     3  arr2489(2),arr2490(2),arr2491(2),arr2492(2),
     4  arr2493(2),arr2494(2),arr2495(2),arr2496(2),
     5  arr2497(2),arr2498(2),arr2499(2),arr2500(2),
     6  arr2501(2),arr2502(2),arr2503(2),arr2504(2),
     7  arr2505(2),arr2506(2),arr2507(2),arr2508(2),
     8  arr2509(2),arr2510(2),arr2511(2),arr2512(2),
     9  arr2513(2),arr2514(2),arr2515(2),arr2516(2),
     a  arr2517(2),arr2518(2),arr2519(2),arr2520(2)
         real *8
     1  arr2521(2),arr2522(2),arr2523(2),arr2524(2),
     2  arr2525(2),arr2526(2),arr2527(2),arr2528(2),
     3  arr2529(2),arr2530(2),arr2531(2),arr2532(2),
     4  arr2533(2),arr2534(2),arr2535(2),arr2536(2),
     5  arr2537(2),arr2538(2),arr2539(2),arr2540(2),
     6  arr2541(2),arr2542(2),arr2543(2),arr2544(2),
     7  arr2545(2),arr2546(2),arr2547(2),arr2548(2),
     8  arr2549(2),arr2550(2),arr2551(2),arr2552(2),
     9  arr2553(2),arr2554(2),arr2555(2),arr2556(2),
     a  arr2557(2),arr2558(2),arr2559(2),arr2560(2)
         real *8
     1  arr2561(2),arr2562(2),arr2563(2),arr2564(2),
     2  arr2565(2),arr2566(2),arr2567(2),arr2568(2),
     3  arr2569(2),arr2570(2),arr2571(2),arr2572(2),
     4  arr2573(2),arr2574(2),arr2575(2),arr2576(2),
     5  arr2577(2),arr2578(2),arr2579(2),arr2580(2),
     6  arr2581(2),arr2582(2),arr2583(2),arr2584(2),
     7  arr2585(2),arr2586(2),arr2587(2),arr2588(2),
     8  arr2589(2),arr2590(2),arr2591(2),arr2592(2),
     9  arr2593(2),arr2594(2),arr2595(2),arr2596(2),
     a  arr2597(2),arr2598(2),arr2599(2),arr2600(2)
         real *8
     1  arr2601(2),arr2602(2),arr2603(2),arr2604(2),
     2  arr2605(2),arr2606(2),arr2607(2),arr2608(2),
     3  arr2609(2),arr2610(2),arr2611(2),arr2612(2),
     4  arr2613(2),arr2614(2),arr2615(2),arr2616(2),
     5  arr2617(2),arr2618(2),arr2619(2),arr2620(2),
     6  arr2621(2),arr2622(2),arr2623(2),arr2624(2),
     7  arr2625(2),arr2626(2),arr2627(2),arr2628(2),
     8  arr2629(2),arr2630(2),arr2631(2),arr2632(2),
     9  arr2633(2),arr2634(2),arr2635(2),arr2636(2),
     a  arr2637(2),arr2638(2),arr2639(2),arr2640(2)
         real *8
     1  arr2641(2),arr2642(2),arr2643(2),arr2644(2),
     2  arr2645(2),arr2646(2),arr2647(2),arr2648(2),
     3  arr2649(2),arr2650(2),arr2651(2),arr2652(2),
     4  arr2653(2),arr2654(2),arr2655(2),arr2656(2),
     5  arr2657(2),arr2658(2),arr2659(2),arr2660(2),
     6  arr2661(2),arr2662(2),arr2663(2),arr2664(2),
     7  arr2665(2),arr2666(2),arr2667(2),arr2668(2),
     8  arr2669(2),arr2670(2),arr2671(2),arr2672(2),
     9  arr2673(2),arr2674(2),arr2675(2),arr2676(2),
     a  arr2677(2),arr2678(2),arr2679(2),arr2680(2)
         real *8
     1  arr2681(2),arr2682(2),arr2683(2),arr2684(2),
     2  arr2685(2),arr2686(2),arr2687(2),arr2688(2),
     3  arr2689(2),arr2690(2),arr2691(2),arr2692(2),
     4  arr2693(2),arr2694(2),arr2695(2),arr2696(2),
     5  arr2697(2),arr2698(2),arr2699(2),arr2700(2),
     6  arr2701(2),arr2702(2),arr2703(2),arr2704(2),
     7  arr2705(2),arr2706(2),arr2707(2),arr2708(2),
     8  arr2709(2),arr2710(2),arr2711(2),arr2712(2),
     9  arr2713(2),arr2714(2),arr2715(2),arr2716(2),
     a  arr2717(2),arr2718(2),arr2719(2),arr2720(2)
         real *8
     1  arr2721(2),arr2722(2),arr2723(2),arr2724(2),
     2  arr2725(2),arr2726(2),arr2727(2),arr2728(2),
     3  arr2729(2),arr2730(2),arr2731(2),arr2732(2),
     4  arr2733(2),arr2734(2),arr2735(2),arr2736(2),
     5  arr2737(2),arr2738(2),arr2739(2),arr2740(2),
     6  arr2741(2),arr2742(2),arr2743(2),arr2744(2),
     7  arr2745(2),arr2746(2),arr2747(2),arr2748(2),
     8  arr2749(2),arr2750(2),arr2751(2),arr2752(2),
     9  arr2753(2),arr2754(2),arr2755(2),arr2756(2),
     a  arr2757(2),arr2758(2),arr2759(2),arr2760(2)
         real *8
     1  arr2761(2),arr2762(2),arr2763(2),arr2764(2),
     2  arr2765(2),arr2766(2),arr2767(2),arr2768(2),
     3  arr2769(2),arr2770(2),arr2771(2),arr2772(2),
     4  arr2773(2),arr2774(2),arr2775(2),arr2776(2),
     5  arr2777(2),arr2778(2),arr2779(2),arr2780(2),
     6  arr2781(2),arr2782(2),arr2783(2),arr2784(2),
     7  arr2785(2),arr2786(2),arr2787(2),arr2788(2),
     8  arr2789(2),arr2790(2),arr2791(2),arr2792(2),
     9  arr2793(2),arr2794(2),arr2795(2),arr2796(2),
     a  arr2797(2),arr2798(2),arr2799(2),arr2800(2)
         real *8
     1  arr2801(2),arr2802(2),arr2803(2),arr2804(2),
     2  arr2805(2),arr2806(2),arr2807(2),arr2808(2),
     3  arr2809(2),arr2810(2),arr2811(2),arr2812(2),
     4  arr2813(2),arr2814(2),arr2815(2),arr2816(2),
     5  arr2817(2),arr2818(2),arr2819(2),arr2820(2),
     6  arr2821(2),arr2822(2),arr2823(2),arr2824(2),
     7  arr2825(2),arr2826(2),arr2827(2),arr2828(2),
     8  arr2829(2),arr2830(2),arr2831(2),arr2832(2),
     9  arr2833(2),arr2834(2),arr2835(2),arr2836(2),
     a  arr2837(2),arr2838(2),arr2839(2),arr2840(2)
         real *8
     1  arr2841(2),arr2842(2),arr2843(2),arr2844(2),
     2  arr2845(2),arr2846(2),arr2847(2),arr2848(2),
     3  arr2849(2),arr2850(2),arr2851(2),arr2852(2),
     4  arr2853(2),arr2854(2),arr2855(2),arr2856(2),
     5  arr2857(2),arr2858(2),arr2859(2),arr2860(2),
     6  arr2861(2),arr2862(2),arr2863(2),arr2864(2),
     7  arr2865(2),arr2866(2),arr2867(2),arr2868(2),
     8  arr2869(2),arr2870(2),arr2871(2),arr2872(2),
     9  arr2873(2),arr2874(2),arr2875(2),arr2876(2),
     a  arr2877(2),arr2878(2),arr2879(2),arr2880(2)
         real *8
     1  arr2881(2),arr2882(2),arr2883(2),arr2884(2),
     2  arr2885(2),arr2886(2),arr2887(2),arr2888(2),
     3  arr2889(2),arr2890(2),arr2891(2),arr2892(2),
     4  arr2893(2),arr2894(2),arr2895(2),arr2896(2),
     5  arr2897(2),arr2898(2),arr2899(2),arr2900(2),
     6  arr2901(2),arr2902(2),arr2903(2),arr2904(2),
     7  arr2905(2),arr2906(2),arr2907(2),arr2908(2),
     8  arr2909(2),arr2910(2),arr2911(2),arr2912(2),
     9  arr2913(2),arr2914(2),arr2915(2),arr2916(2),
     a  arr2917(2),arr2918(2),arr2919(2),arr2920(2)
         real *8
     1  arr2921(2),arr2922(2),arr2923(2),arr2924(2),
     2  arr2925(2),arr2926(2),arr2927(2),arr2928(2),
     3  arr2929(2),arr2930(2),arr2931(2),arr2932(2),
     4  arr2933(2),arr2934(2),arr2935(2),arr2936(2),
     5  arr2937(2),arr2938(2),arr2939(2),arr2940(2),
     6  arr2941(2),arr2942(2),arr2943(2),arr2944(2),
     7  arr2945(2),arr2946(2),arr2947(2),arr2948(2),
     8  arr2949(2),arr2950(2),arr2951(2),arr2952(2),
     9  arr2953(2),arr2954(2),arr2955(2),arr2956(2),
     a  arr2957(2),arr2958(2),arr2959(2),arr2960(2)
         real *8
     1  arr2961(2),arr2962(2),arr2963(2),arr2964(2),
     2  arr2965(2),arr2966(2),arr2967(2),arr2968(2),
     3  arr2969(2),arr2970(2),arr2971(2),arr2972(2),
     4  arr2973(2),arr2974(2),arr2975(2),arr2976(2),
     5  arr2977(2),arr2978(2),arr2979(2),arr2980(2),
     6  arr2981(2),arr2982(2),arr2983(2),arr2984(2),
     7  arr2985(2),arr2986(2),arr2987(2),arr2988(2),
     8  arr2989(2),arr2990(2),arr2991(2),arr2992(2),
     9  arr2993(2),arr2994(2),arr2995(2),arr2996(2)
         real *8
     1  arr2997(2),arr2998(2),arr2999(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2)),
     a  (arr1260(16),arr2260(1)),(arr1261(1),arr2260(2))
         equivalence
     1  (arr1261(16),arr2261(1)),(arr1262(1),arr2261(2)),
     2  (arr1262(16),arr2262(1)),(arr1263(1),arr2262(2)),
     3  (arr1263(16),arr2263(1)),(arr1264(1),arr2263(2)),
     4  (arr1264(16),arr2264(1)),(arr1265(1),arr2264(2)),
     5  (arr1265(16),arr2265(1)),(arr1266(1),arr2265(2)),
     6  (arr1266(16),arr2266(1)),(arr1267(1),arr2266(2)),
     7  (arr1267(16),arr2267(1)),(arr1268(1),arr2267(2)),
     8  (arr1268(16),arr2268(1)),(arr1269(1),arr2268(2)),
     9  (arr1269(16),arr2269(1)),(arr1270(1),arr2269(2)),
     a  (arr1270(16),arr2270(1)),(arr1271(1),arr2270(2))
         equivalence
     1  (arr1271(16),arr2271(1)),(arr1272(1),arr2271(2)),
     2  (arr1272(16),arr2272(1)),(arr1273(1),arr2272(2)),
     3  (arr1273(16),arr2273(1)),(arr1274(1),arr2273(2)),
     4  (arr1274(16),arr2274(1)),(arr1275(1),arr2274(2)),
     5  (arr1275(16),arr2275(1)),(arr1276(1),arr2275(2)),
     6  (arr1276(16),arr2276(1)),(arr1277(1),arr2276(2)),
     7  (arr1277(16),arr2277(1)),(arr1278(1),arr2277(2)),
     8  (arr1278(16),arr2278(1)),(arr1279(1),arr2278(2)),
     9  (arr1279(16),arr2279(1)),(arr1280(1),arr2279(2)),
     a  (arr1280(16),arr2280(1)),(arr1281(1),arr2280(2))
         equivalence
     1  (arr1281(16),arr2281(1)),(arr1282(1),arr2281(2)),
     2  (arr1282(16),arr2282(1)),(arr1283(1),arr2282(2)),
     3  (arr1283(16),arr2283(1)),(arr1284(1),arr2283(2)),
     4  (arr1284(16),arr2284(1)),(arr1285(1),arr2284(2)),
     5  (arr1285(16),arr2285(1)),(arr1286(1),arr2285(2)),
     6  (arr1286(16),arr2286(1)),(arr1287(1),arr2286(2)),
     7  (arr1287(16),arr2287(1)),(arr1288(1),arr2287(2)),
     8  (arr1288(16),arr2288(1)),(arr1289(1),arr2288(2)),
     9  (arr1289(16),arr2289(1)),(arr1290(1),arr2289(2)),
     a  (arr1290(16),arr2290(1)),(arr1291(1),arr2290(2))
         equivalence
     1  (arr1291(16),arr2291(1)),(arr1292(1),arr2291(2)),
     2  (arr1292(16),arr2292(1)),(arr1293(1),arr2292(2)),
     3  (arr1293(16),arr2293(1)),(arr1294(1),arr2293(2)),
     4  (arr1294(16),arr2294(1)),(arr1295(1),arr2294(2)),
     5  (arr1295(16),arr2295(1)),(arr1296(1),arr2295(2)),
     6  (arr1296(16),arr2296(1)),(arr1297(1),arr2296(2)),
     7  (arr1297(16),arr2297(1)),(arr1298(1),arr2297(2)),
     8  (arr1298(16),arr2298(1)),(arr1299(1),arr2298(2)),
     9  (arr1299(16),arr2299(1)),(arr1300(1),arr2299(2)),
     a  (arr1300(16),arr2300(1)),(arr1301(1),arr2300(2))
         equivalence
     1  (arr1301(16),arr2301(1)),(arr1302(1),arr2301(2)),
     2  (arr1302(16),arr2302(1)),(arr1303(1),arr2302(2)),
     3  (arr1303(16),arr2303(1)),(arr1304(1),arr2303(2)),
     4  (arr1304(16),arr2304(1)),(arr1305(1),arr2304(2)),
     5  (arr1305(16),arr2305(1)),(arr1306(1),arr2305(2)),
     6  (arr1306(16),arr2306(1)),(arr1307(1),arr2306(2)),
     7  (arr1307(16),arr2307(1)),(arr1308(1),arr2307(2)),
     8  (arr1308(16),arr2308(1)),(arr1309(1),arr2308(2)),
     9  (arr1309(16),arr2309(1)),(arr1310(1),arr2309(2)),
     a  (arr1310(16),arr2310(1)),(arr1311(1),arr2310(2))
         equivalence
     1  (arr1311(16),arr2311(1)),(arr1312(1),arr2311(2)),
     2  (arr1312(16),arr2312(1)),(arr1313(1),arr2312(2)),
     3  (arr1313(16),arr2313(1)),(arr1314(1),arr2313(2)),
     4  (arr1314(16),arr2314(1)),(arr1315(1),arr2314(2)),
     5  (arr1315(16),arr2315(1)),(arr1316(1),arr2315(2)),
     6  (arr1316(16),arr2316(1)),(arr1317(1),arr2316(2)),
     7  (arr1317(16),arr2317(1)),(arr1318(1),arr2317(2)),
     8  (arr1318(16),arr2318(1)),(arr1319(1),arr2318(2)),
     9  (arr1319(16),arr2319(1)),(arr1320(1),arr2319(2)),
     a  (arr1320(16),arr2320(1)),(arr1321(1),arr2320(2))
         equivalence
     1  (arr1321(16),arr2321(1)),(arr1322(1),arr2321(2)),
     2  (arr1322(16),arr2322(1)),(arr1323(1),arr2322(2)),
     3  (arr1323(16),arr2323(1)),(arr1324(1),arr2323(2)),
     4  (arr1324(16),arr2324(1)),(arr1325(1),arr2324(2)),
     5  (arr1325(16),arr2325(1)),(arr1326(1),arr2325(2)),
     6  (arr1326(16),arr2326(1)),(arr1327(1),arr2326(2)),
     7  (arr1327(16),arr2327(1)),(arr1328(1),arr2327(2)),
     8  (arr1328(16),arr2328(1)),(arr1329(1),arr2328(2)),
     9  (arr1329(16),arr2329(1)),(arr1330(1),arr2329(2)),
     a  (arr1330(16),arr2330(1)),(arr1331(1),arr2330(2))
         equivalence
     1  (arr1331(16),arr2331(1)),(arr1332(1),arr2331(2)),
     2  (arr1332(16),arr2332(1)),(arr1333(1),arr2332(2)),
     3  (arr1333(16),arr2333(1)),(arr1334(1),arr2333(2)),
     4  (arr1334(16),arr2334(1)),(arr1335(1),arr2334(2)),
     5  (arr1335(16),arr2335(1)),(arr1336(1),arr2335(2)),
     6  (arr1336(16),arr2336(1)),(arr1337(1),arr2336(2)),
     7  (arr1337(16),arr2337(1)),(arr1338(1),arr2337(2)),
     8  (arr1338(16),arr2338(1)),(arr1339(1),arr2338(2)),
     9  (arr1339(16),arr2339(1)),(arr1340(1),arr2339(2)),
     a  (arr1340(16),arr2340(1)),(arr1341(1),arr2340(2))
         equivalence
     1  (arr1341(16),arr2341(1)),(arr1342(1),arr2341(2)),
     2  (arr1342(16),arr2342(1)),(arr1343(1),arr2342(2)),
     3  (arr1343(16),arr2343(1)),(arr1344(1),arr2343(2)),
     4  (arr1344(16),arr2344(1)),(arr1345(1),arr2344(2)),
     5  (arr1345(16),arr2345(1)),(arr1346(1),arr2345(2)),
     6  (arr1346(16),arr2346(1)),(arr1347(1),arr2346(2)),
     7  (arr1347(16),arr2347(1)),(arr1348(1),arr2347(2)),
     8  (arr1348(16),arr2348(1)),(arr1349(1),arr2348(2)),
     9  (arr1349(16),arr2349(1)),(arr1350(1),arr2349(2)),
     a  (arr1350(16),arr2350(1)),(arr1351(1),arr2350(2))
         equivalence
     1  (arr1351(16),arr2351(1)),(arr1352(1),arr2351(2)),
     2  (arr1352(16),arr2352(1)),(arr1353(1),arr2352(2)),
     3  (arr1353(16),arr2353(1)),(arr1354(1),arr2353(2)),
     4  (arr1354(16),arr2354(1)),(arr1355(1),arr2354(2)),
     5  (arr1355(16),arr2355(1)),(arr1356(1),arr2355(2)),
     6  (arr1356(16),arr2356(1)),(arr1357(1),arr2356(2)),
     7  (arr1357(16),arr2357(1)),(arr1358(1),arr2357(2)),
     8  (arr1358(16),arr2358(1)),(arr1359(1),arr2358(2)),
     9  (arr1359(16),arr2359(1)),(arr1360(1),arr2359(2)),
     a  (arr1360(16),arr2360(1)),(arr1361(1),arr2360(2))
         equivalence
     1  (arr1361(16),arr2361(1)),(arr1362(1),arr2361(2)),
     2  (arr1362(16),arr2362(1)),(arr1363(1),arr2362(2)),
     3  (arr1363(16),arr2363(1)),(arr1364(1),arr2363(2)),
     4  (arr1364(16),arr2364(1)),(arr1365(1),arr2364(2)),
     5  (arr1365(16),arr2365(1)),(arr1366(1),arr2365(2)),
     6  (arr1366(16),arr2366(1)),(arr1367(1),arr2366(2)),
     7  (arr1367(16),arr2367(1)),(arr1368(1),arr2367(2)),
     8  (arr1368(16),arr2368(1)),(arr1369(1),arr2368(2)),
     9  (arr1369(16),arr2369(1)),(arr1370(1),arr2369(2)),
     a  (arr1370(16),arr2370(1)),(arr1371(1),arr2370(2))
         equivalence
     1  (arr1371(16),arr2371(1)),(arr1372(1),arr2371(2)),
     2  (arr1372(16),arr2372(1)),(arr1373(1),arr2372(2)),
     3  (arr1373(16),arr2373(1)),(arr1374(1),arr2373(2)),
     4  (arr1374(16),arr2374(1)),(arr1375(1),arr2374(2)),
     5  (arr1375(16),arr2375(1)),(arr1376(1),arr2375(2)),
     6  (arr1376(16),arr2376(1)),(arr1377(1),arr2376(2)),
     7  (arr1377(16),arr2377(1)),(arr1378(1),arr2377(2)),
     8  (arr1378(16),arr2378(1)),(arr1379(1),arr2378(2)),
     9  (arr1379(16),arr2379(1)),(arr1380(1),arr2379(2)),
     a  (arr1380(16),arr2380(1)),(arr1381(1),arr2380(2))
         equivalence
     1  (arr1381(16),arr2381(1)),(arr1382(1),arr2381(2)),
     2  (arr1382(16),arr2382(1)),(arr1383(1),arr2382(2)),
     3  (arr1383(16),arr2383(1)),(arr1384(1),arr2383(2)),
     4  (arr1384(16),arr2384(1)),(arr1385(1),arr2384(2)),
     5  (arr1385(16),arr2385(1)),(arr1386(1),arr2385(2)),
     6  (arr1386(16),arr2386(1)),(arr1387(1),arr2386(2)),
     7  (arr1387(16),arr2387(1)),(arr1388(1),arr2387(2)),
     8  (arr1388(16),arr2388(1)),(arr1389(1),arr2388(2)),
     9  (arr1389(16),arr2389(1)),(arr1390(1),arr2389(2)),
     a  (arr1390(16),arr2390(1)),(arr1391(1),arr2390(2))
         equivalence
     1  (arr1391(16),arr2391(1)),(arr1392(1),arr2391(2)),
     2  (arr1392(16),arr2392(1)),(arr1393(1),arr2392(2)),
     3  (arr1393(16),arr2393(1)),(arr1394(1),arr2393(2)),
     4  (arr1394(16),arr2394(1)),(arr1395(1),arr2394(2)),
     5  (arr1395(16),arr2395(1)),(arr1396(1),arr2395(2)),
     6  (arr1396(16),arr2396(1)),(arr1397(1),arr2396(2)),
     7  (arr1397(16),arr2397(1)),(arr1398(1),arr2397(2)),
     8  (arr1398(16),arr2398(1)),(arr1399(1),arr2398(2)),
     9  (arr1399(16),arr2399(1)),(arr1400(1),arr2399(2)),
     a  (arr1400(16),arr2400(1)),(arr1401(1),arr2400(2))
         equivalence
     1  (arr1401(16),arr2401(1)),(arr1402(1),arr2401(2)),
     2  (arr1402(16),arr2402(1)),(arr1403(1),arr2402(2)),
     3  (arr1403(16),arr2403(1)),(arr1404(1),arr2403(2)),
     4  (arr1404(16),arr2404(1)),(arr1405(1),arr2404(2)),
     5  (arr1405(16),arr2405(1)),(arr1406(1),arr2405(2)),
     6  (arr1406(16),arr2406(1)),(arr1407(1),arr2406(2)),
     7  (arr1407(16),arr2407(1)),(arr1408(1),arr2407(2)),
     8  (arr1408(16),arr2408(1)),(arr1409(1),arr2408(2)),
     9  (arr1409(16),arr2409(1)),(arr1410(1),arr2409(2)),
     a  (arr1410(16),arr2410(1)),(arr1411(1),arr2410(2))
         equivalence
     1  (arr1411(16),arr2411(1)),(arr1412(1),arr2411(2)),
     2  (arr1412(16),arr2412(1)),(arr1413(1),arr2412(2)),
     3  (arr1413(16),arr2413(1)),(arr1414(1),arr2413(2)),
     4  (arr1414(16),arr2414(1)),(arr1415(1),arr2414(2)),
     5  (arr1415(16),arr2415(1)),(arr1416(1),arr2415(2)),
     6  (arr1416(16),arr2416(1)),(arr1417(1),arr2416(2)),
     7  (arr1417(16),arr2417(1)),(arr1418(1),arr2417(2)),
     8  (arr1418(16),arr2418(1)),(arr1419(1),arr2418(2)),
     9  (arr1419(16),arr2419(1)),(arr1420(1),arr2419(2)),
     a  (arr1420(16),arr2420(1)),(arr1421(1),arr2420(2))
         equivalence
     1  (arr1421(16),arr2421(1)),(arr1422(1),arr2421(2)),
     2  (arr1422(16),arr2422(1)),(arr1423(1),arr2422(2)),
     3  (arr1423(16),arr2423(1)),(arr1424(1),arr2423(2)),
     4  (arr1424(16),arr2424(1)),(arr1425(1),arr2424(2)),
     5  (arr1425(16),arr2425(1)),(arr1426(1),arr2425(2)),
     6  (arr1426(16),arr2426(1)),(arr1427(1),arr2426(2)),
     7  (arr1427(16),arr2427(1)),(arr1428(1),arr2427(2)),
     8  (arr1428(16),arr2428(1)),(arr1429(1),arr2428(2)),
     9  (arr1429(16),arr2429(1)),(arr1430(1),arr2429(2)),
     a  (arr1430(16),arr2430(1)),(arr1431(1),arr2430(2))
         equivalence
     1  (arr1431(16),arr2431(1)),(arr1432(1),arr2431(2)),
     2  (arr1432(16),arr2432(1)),(arr1433(1),arr2432(2)),
     3  (arr1433(16),arr2433(1)),(arr1434(1),arr2433(2)),
     4  (arr1434(16),arr2434(1)),(arr1435(1),arr2434(2)),
     5  (arr1435(16),arr2435(1)),(arr1436(1),arr2435(2)),
     6  (arr1436(16),arr2436(1)),(arr1437(1),arr2436(2)),
     7  (arr1437(16),arr2437(1)),(arr1438(1),arr2437(2)),
     8  (arr1438(16),arr2438(1)),(arr1439(1),arr2438(2)),
     9  (arr1439(16),arr2439(1)),(arr1440(1),arr2439(2)),
     a  (arr1440(16),arr2440(1)),(arr1441(1),arr2440(2))
         equivalence
     1  (arr1441(16),arr2441(1)),(arr1442(1),arr2441(2)),
     2  (arr1442(16),arr2442(1)),(arr1443(1),arr2442(2)),
     3  (arr1443(16),arr2443(1)),(arr1444(1),arr2443(2)),
     4  (arr1444(16),arr2444(1)),(arr1445(1),arr2444(2)),
     5  (arr1445(16),arr2445(1)),(arr1446(1),arr2445(2)),
     6  (arr1446(16),arr2446(1)),(arr1447(1),arr2446(2)),
     7  (arr1447(16),arr2447(1)),(arr1448(1),arr2447(2)),
     8  (arr1448(16),arr2448(1)),(arr1449(1),arr2448(2)),
     9  (arr1449(16),arr2449(1)),(arr1450(1),arr2449(2)),
     a  (arr1450(16),arr2450(1)),(arr1451(1),arr2450(2))
         equivalence
     1  (arr1451(16),arr2451(1)),(arr1452(1),arr2451(2)),
     2  (arr1452(16),arr2452(1)),(arr1453(1),arr2452(2)),
     3  (arr1453(16),arr2453(1)),(arr1454(1),arr2453(2)),
     4  (arr1454(16),arr2454(1)),(arr1455(1),arr2454(2)),
     5  (arr1455(16),arr2455(1)),(arr1456(1),arr2455(2)),
     6  (arr1456(16),arr2456(1)),(arr1457(1),arr2456(2)),
     7  (arr1457(16),arr2457(1)),(arr1458(1),arr2457(2)),
     8  (arr1458(16),arr2458(1)),(arr1459(1),arr2458(2)),
     9  (arr1459(16),arr2459(1)),(arr1460(1),arr2459(2)),
     a  (arr1460(16),arr2460(1)),(arr1461(1),arr2460(2))
         equivalence
     1  (arr1461(16),arr2461(1)),(arr1462(1),arr2461(2)),
     2  (arr1462(16),arr2462(1)),(arr1463(1),arr2462(2)),
     3  (arr1463(16),arr2463(1)),(arr1464(1),arr2463(2)),
     4  (arr1464(16),arr2464(1)),(arr1465(1),arr2464(2)),
     5  (arr1465(16),arr2465(1)),(arr1466(1),arr2465(2)),
     6  (arr1466(16),arr2466(1)),(arr1467(1),arr2466(2)),
     7  (arr1467(16),arr2467(1)),(arr1468(1),arr2467(2)),
     8  (arr1468(16),arr2468(1)),(arr1469(1),arr2468(2)),
     9  (arr1469(16),arr2469(1)),(arr1470(1),arr2469(2)),
     a  (arr1470(16),arr2470(1)),(arr1471(1),arr2470(2))
         equivalence
     1  (arr1471(16),arr2471(1)),(arr1472(1),arr2471(2)),
     2  (arr1472(16),arr2472(1)),(arr1473(1),arr2472(2)),
     3  (arr1473(16),arr2473(1)),(arr1474(1),arr2473(2)),
     4  (arr1474(16),arr2474(1)),(arr1475(1),arr2474(2)),
     5  (arr1475(16),arr2475(1)),(arr1476(1),arr2475(2)),
     6  (arr1476(16),arr2476(1)),(arr1477(1),arr2476(2)),
     7  (arr1477(16),arr2477(1)),(arr1478(1),arr2477(2)),
     8  (arr1478(16),arr2478(1)),(arr1479(1),arr2478(2)),
     9  (arr1479(16),arr2479(1)),(arr1480(1),arr2479(2)),
     a  (arr1480(16),arr2480(1)),(arr1481(1),arr2480(2))
         equivalence
     1  (arr1481(16),arr2481(1)),(arr1482(1),arr2481(2)),
     2  (arr1482(16),arr2482(1)),(arr1483(1),arr2482(2)),
     3  (arr1483(16),arr2483(1)),(arr1484(1),arr2483(2)),
     4  (arr1484(16),arr2484(1)),(arr1485(1),arr2484(2)),
     5  (arr1485(16),arr2485(1)),(arr1486(1),arr2485(2)),
     6  (arr1486(16),arr2486(1)),(arr1487(1),arr2486(2)),
     7  (arr1487(16),arr2487(1)),(arr1488(1),arr2487(2)),
     8  (arr1488(16),arr2488(1)),(arr1489(1),arr2488(2)),
     9  (arr1489(16),arr2489(1)),(arr1490(1),arr2489(2)),
     a  (arr1490(16),arr2490(1)),(arr1491(1),arr2490(2))
         equivalence
     1  (arr1491(16),arr2491(1)),(arr1492(1),arr2491(2)),
     2  (arr1492(16),arr2492(1)),(arr1493(1),arr2492(2)),
     3  (arr1493(16),arr2493(1)),(arr1494(1),arr2493(2)),
     4  (arr1494(16),arr2494(1)),(arr1495(1),arr2494(2)),
     5  (arr1495(16),arr2495(1)),(arr1496(1),arr2495(2)),
     6  (arr1496(16),arr2496(1)),(arr1497(1),arr2496(2)),
     7  (arr1497(16),arr2497(1)),(arr1498(1),arr2497(2)),
     8  (arr1498(16),arr2498(1)),(arr1499(1),arr2498(2)),
     9  (arr1499(16),arr2499(1)),(arr1500(1),arr2499(2)),
     a  (arr1500(16),arr2500(1)),(arr1501(1),arr2500(2))
         equivalence
     1  (arr1501(16),arr2501(1)),(arr1502(1),arr2501(2)),
     2  (arr1502(16),arr2502(1)),(arr1503(1),arr2502(2)),
     3  (arr1503(16),arr2503(1)),(arr1504(1),arr2503(2)),
     4  (arr1504(16),arr2504(1)),(arr1505(1),arr2504(2)),
     5  (arr1505(16),arr2505(1)),(arr1506(1),arr2505(2)),
     6  (arr1506(16),arr2506(1)),(arr1507(1),arr2506(2)),
     7  (arr1507(16),arr2507(1)),(arr1508(1),arr2507(2)),
     8  (arr1508(16),arr2508(1)),(arr1509(1),arr2508(2)),
     9  (arr1509(16),arr2509(1)),(arr1510(1),arr2509(2)),
     a  (arr1510(16),arr2510(1)),(arr1511(1),arr2510(2))
         equivalence
     1  (arr1511(16),arr2511(1)),(arr1512(1),arr2511(2)),
     2  (arr1512(16),arr2512(1)),(arr1513(1),arr2512(2)),
     3  (arr1513(16),arr2513(1)),(arr1514(1),arr2513(2)),
     4  (arr1514(16),arr2514(1)),(arr1515(1),arr2514(2)),
     5  (arr1515(16),arr2515(1)),(arr1516(1),arr2515(2)),
     6  (arr1516(16),arr2516(1)),(arr1517(1),arr2516(2)),
     7  (arr1517(16),arr2517(1)),(arr1518(1),arr2517(2)),
     8  (arr1518(16),arr2518(1)),(arr1519(1),arr2518(2)),
     9  (arr1519(16),arr2519(1)),(arr1520(1),arr2519(2)),
     a  (arr1520(16),arr2520(1)),(arr1521(1),arr2520(2))
         equivalence
     1  (arr1521(16),arr2521(1)),(arr1522(1),arr2521(2)),
     2  (arr1522(16),arr2522(1)),(arr1523(1),arr2522(2)),
     3  (arr1523(16),arr2523(1)),(arr1524(1),arr2523(2)),
     4  (arr1524(16),arr2524(1)),(arr1525(1),arr2524(2)),
     5  (arr1525(16),arr2525(1)),(arr1526(1),arr2525(2)),
     6  (arr1526(16),arr2526(1)),(arr1527(1),arr2526(2)),
     7  (arr1527(16),arr2527(1)),(arr1528(1),arr2527(2)),
     8  (arr1528(16),arr2528(1)),(arr1529(1),arr2528(2)),
     9  (arr1529(16),arr2529(1)),(arr1530(1),arr2529(2)),
     a  (arr1530(16),arr2530(1)),(arr1531(1),arr2530(2))
         equivalence
     1  (arr1531(16),arr2531(1)),(arr1532(1),arr2531(2)),
     2  (arr1532(16),arr2532(1)),(arr1533(1),arr2532(2)),
     3  (arr1533(16),arr2533(1)),(arr1534(1),arr2533(2)),
     4  (arr1534(16),arr2534(1)),(arr1535(1),arr2534(2)),
     5  (arr1535(16),arr2535(1)),(arr1536(1),arr2535(2)),
     6  (arr1536(16),arr2536(1)),(arr1537(1),arr2536(2)),
     7  (arr1537(16),arr2537(1)),(arr1538(1),arr2537(2)),
     8  (arr1538(16),arr2538(1)),(arr1539(1),arr2538(2)),
     9  (arr1539(16),arr2539(1)),(arr1540(1),arr2539(2)),
     a  (arr1540(16),arr2540(1)),(arr1541(1),arr2540(2))
         equivalence
     1  (arr1541(16),arr2541(1)),(arr1542(1),arr2541(2)),
     2  (arr1542(16),arr2542(1)),(arr1543(1),arr2542(2)),
     3  (arr1543(16),arr2543(1)),(arr1544(1),arr2543(2)),
     4  (arr1544(16),arr2544(1)),(arr1545(1),arr2544(2)),
     5  (arr1545(16),arr2545(1)),(arr1546(1),arr2545(2)),
     6  (arr1546(16),arr2546(1)),(arr1547(1),arr2546(2)),
     7  (arr1547(16),arr2547(1)),(arr1548(1),arr2547(2)),
     8  (arr1548(16),arr2548(1)),(arr1549(1),arr2548(2)),
     9  (arr1549(16),arr2549(1)),(arr1550(1),arr2549(2)),
     a  (arr1550(16),arr2550(1)),(arr1551(1),arr2550(2))
         equivalence
     1  (arr1551(16),arr2551(1)),(arr1552(1),arr2551(2)),
     2  (arr1552(16),arr2552(1)),(arr1553(1),arr2552(2)),
     3  (arr1553(16),arr2553(1)),(arr1554(1),arr2553(2)),
     4  (arr1554(16),arr2554(1)),(arr1555(1),arr2554(2)),
     5  (arr1555(16),arr2555(1)),(arr1556(1),arr2555(2)),
     6  (arr1556(16),arr2556(1)),(arr1557(1),arr2556(2)),
     7  (arr1557(16),arr2557(1)),(arr1558(1),arr2557(2)),
     8  (arr1558(16),arr2558(1)),(arr1559(1),arr2558(2)),
     9  (arr1559(16),arr2559(1)),(arr1560(1),arr2559(2)),
     a  (arr1560(16),arr2560(1)),(arr1561(1),arr2560(2))
         equivalence
     1  (arr1561(16),arr2561(1)),(arr1562(1),arr2561(2)),
     2  (arr1562(16),arr2562(1)),(arr1563(1),arr2562(2)),
     3  (arr1563(16),arr2563(1)),(arr1564(1),arr2563(2)),
     4  (arr1564(16),arr2564(1)),(arr1565(1),arr2564(2)),
     5  (arr1565(16),arr2565(1)),(arr1566(1),arr2565(2)),
     6  (arr1566(16),arr2566(1)),(arr1567(1),arr2566(2)),
     7  (arr1567(16),arr2567(1)),(arr1568(1),arr2567(2)),
     8  (arr1568(16),arr2568(1)),(arr1569(1),arr2568(2)),
     9  (arr1569(16),arr2569(1)),(arr1570(1),arr2569(2)),
     a  (arr1570(16),arr2570(1)),(arr1571(1),arr2570(2))
         equivalence
     1  (arr1571(16),arr2571(1)),(arr1572(1),arr2571(2)),
     2  (arr1572(16),arr2572(1)),(arr1573(1),arr2572(2)),
     3  (arr1573(16),arr2573(1)),(arr1574(1),arr2573(2)),
     4  (arr1574(16),arr2574(1)),(arr1575(1),arr2574(2)),
     5  (arr1575(16),arr2575(1)),(arr1576(1),arr2575(2)),
     6  (arr1576(16),arr2576(1)),(arr1577(1),arr2576(2)),
     7  (arr1577(16),arr2577(1)),(arr1578(1),arr2577(2)),
     8  (arr1578(16),arr2578(1)),(arr1579(1),arr2578(2)),
     9  (arr1579(16),arr2579(1)),(arr1580(1),arr2579(2)),
     a  (arr1580(16),arr2580(1)),(arr1581(1),arr2580(2))
         equivalence
     1  (arr1581(16),arr2581(1)),(arr1582(1),arr2581(2)),
     2  (arr1582(16),arr2582(1)),(arr1583(1),arr2582(2)),
     3  (arr1583(16),arr2583(1)),(arr1584(1),arr2583(2)),
     4  (arr1584(16),arr2584(1)),(arr1585(1),arr2584(2)),
     5  (arr1585(16),arr2585(1)),(arr1586(1),arr2585(2)),
     6  (arr1586(16),arr2586(1)),(arr1587(1),arr2586(2)),
     7  (arr1587(16),arr2587(1)),(arr1588(1),arr2587(2)),
     8  (arr1588(16),arr2588(1)),(arr1589(1),arr2588(2)),
     9  (arr1589(16),arr2589(1)),(arr1590(1),arr2589(2)),
     a  (arr1590(16),arr2590(1)),(arr1591(1),arr2590(2))
         equivalence
     1  (arr1591(16),arr2591(1)),(arr1592(1),arr2591(2)),
     2  (arr1592(16),arr2592(1)),(arr1593(1),arr2592(2)),
     3  (arr1593(16),arr2593(1)),(arr1594(1),arr2593(2)),
     4  (arr1594(16),arr2594(1)),(arr1595(1),arr2594(2)),
     5  (arr1595(16),arr2595(1)),(arr1596(1),arr2595(2)),
     6  (arr1596(16),arr2596(1)),(arr1597(1),arr2596(2)),
     7  (arr1597(16),arr2597(1)),(arr1598(1),arr2597(2)),
     8  (arr1598(16),arr2598(1)),(arr1599(1),arr2598(2)),
     9  (arr1599(16),arr2599(1)),(arr1600(1),arr2599(2)),
     a  (arr1600(16),arr2600(1)),(arr1601(1),arr2600(2))
         equivalence
     1  (arr1601(16),arr2601(1)),(arr1602(1),arr2601(2)),
     2  (arr1602(16),arr2602(1)),(arr1603(1),arr2602(2)),
     3  (arr1603(16),arr2603(1)),(arr1604(1),arr2603(2)),
     4  (arr1604(16),arr2604(1)),(arr1605(1),arr2604(2)),
     5  (arr1605(16),arr2605(1)),(arr1606(1),arr2605(2)),
     6  (arr1606(16),arr2606(1)),(arr1607(1),arr2606(2)),
     7  (arr1607(16),arr2607(1)),(arr1608(1),arr2607(2)),
     8  (arr1608(16),arr2608(1)),(arr1609(1),arr2608(2)),
     9  (arr1609(16),arr2609(1)),(arr1610(1),arr2609(2)),
     a  (arr1610(16),arr2610(1)),(arr1611(1),arr2610(2))
         equivalence
     1  (arr1611(16),arr2611(1)),(arr1612(1),arr2611(2)),
     2  (arr1612(16),arr2612(1)),(arr1613(1),arr2612(2)),
     3  (arr1613(16),arr2613(1)),(arr1614(1),arr2613(2)),
     4  (arr1614(16),arr2614(1)),(arr1615(1),arr2614(2)),
     5  (arr1615(16),arr2615(1)),(arr1616(1),arr2615(2)),
     6  (arr1616(16),arr2616(1)),(arr1617(1),arr2616(2)),
     7  (arr1617(16),arr2617(1)),(arr1618(1),arr2617(2)),
     8  (arr1618(16),arr2618(1)),(arr1619(1),arr2618(2)),
     9  (arr1619(16),arr2619(1)),(arr1620(1),arr2619(2)),
     a  (arr1620(16),arr2620(1)),(arr1621(1),arr2620(2))
         equivalence
     1  (arr1621(16),arr2621(1)),(arr1622(1),arr2621(2)),
     2  (arr1622(16),arr2622(1)),(arr1623(1),arr2622(2)),
     3  (arr1623(16),arr2623(1)),(arr1624(1),arr2623(2)),
     4  (arr1624(16),arr2624(1)),(arr1625(1),arr2624(2)),
     5  (arr1625(16),arr2625(1)),(arr1626(1),arr2625(2)),
     6  (arr1626(16),arr2626(1)),(arr1627(1),arr2626(2)),
     7  (arr1627(16),arr2627(1)),(arr1628(1),arr2627(2)),
     8  (arr1628(16),arr2628(1)),(arr1629(1),arr2628(2)),
     9  (arr1629(16),arr2629(1)),(arr1630(1),arr2629(2)),
     a  (arr1630(16),arr2630(1)),(arr1631(1),arr2630(2))
         equivalence
     1  (arr1631(16),arr2631(1)),(arr1632(1),arr2631(2)),
     2  (arr1632(16),arr2632(1)),(arr1633(1),arr2632(2)),
     3  (arr1633(16),arr2633(1)),(arr1634(1),arr2633(2)),
     4  (arr1634(16),arr2634(1)),(arr1635(1),arr2634(2)),
     5  (arr1635(16),arr2635(1)),(arr1636(1),arr2635(2)),
     6  (arr1636(16),arr2636(1)),(arr1637(1),arr2636(2)),
     7  (arr1637(16),arr2637(1)),(arr1638(1),arr2637(2)),
     8  (arr1638(16),arr2638(1)),(arr1639(1),arr2638(2)),
     9  (arr1639(16),arr2639(1)),(arr1640(1),arr2639(2)),
     a  (arr1640(16),arr2640(1)),(arr1641(1),arr2640(2))
         equivalence
     1  (arr1641(16),arr2641(1)),(arr1642(1),arr2641(2)),
     2  (arr1642(16),arr2642(1)),(arr1643(1),arr2642(2)),
     3  (arr1643(16),arr2643(1)),(arr1644(1),arr2643(2)),
     4  (arr1644(16),arr2644(1)),(arr1645(1),arr2644(2)),
     5  (arr1645(16),arr2645(1)),(arr1646(1),arr2645(2)),
     6  (arr1646(16),arr2646(1)),(arr1647(1),arr2646(2)),
     7  (arr1647(16),arr2647(1)),(arr1648(1),arr2647(2)),
     8  (arr1648(16),arr2648(1)),(arr1649(1),arr2648(2)),
     9  (arr1649(16),arr2649(1)),(arr1650(1),arr2649(2)),
     a  (arr1650(16),arr2650(1)),(arr1651(1),arr2650(2))
         equivalence
     1  (arr1651(16),arr2651(1)),(arr1652(1),arr2651(2)),
     2  (arr1652(16),arr2652(1)),(arr1653(1),arr2652(2)),
     3  (arr1653(16),arr2653(1)),(arr1654(1),arr2653(2)),
     4  (arr1654(16),arr2654(1)),(arr1655(1),arr2654(2)),
     5  (arr1655(16),arr2655(1)),(arr1656(1),arr2655(2)),
     6  (arr1656(16),arr2656(1)),(arr1657(1),arr2656(2)),
     7  (arr1657(16),arr2657(1)),(arr1658(1),arr2657(2)),
     8  (arr1658(16),arr2658(1)),(arr1659(1),arr2658(2)),
     9  (arr1659(16),arr2659(1)),(arr1660(1),arr2659(2)),
     a  (arr1660(16),arr2660(1)),(arr1661(1),arr2660(2))
         equivalence
     1  (arr1661(16),arr2661(1)),(arr1662(1),arr2661(2)),
     2  (arr1662(16),arr2662(1)),(arr1663(1),arr2662(2)),
     3  (arr1663(16),arr2663(1)),(arr1664(1),arr2663(2)),
     4  (arr1664(16),arr2664(1)),(arr1665(1),arr2664(2)),
     5  (arr1665(16),arr2665(1)),(arr1666(1),arr2665(2)),
     6  (arr1666(16),arr2666(1)),(arr1667(1),arr2666(2)),
     7  (arr1667(16),arr2667(1)),(arr1668(1),arr2667(2)),
     8  (arr1668(16),arr2668(1)),(arr1669(1),arr2668(2)),
     9  (arr1669(16),arr2669(1)),(arr1670(1),arr2669(2)),
     a  (arr1670(16),arr2670(1)),(arr1671(1),arr2670(2))
         equivalence
     1  (arr1671(16),arr2671(1)),(arr1672(1),arr2671(2)),
     2  (arr1672(16),arr2672(1)),(arr1673(1),arr2672(2)),
     3  (arr1673(16),arr2673(1)),(arr1674(1),arr2673(2)),
     4  (arr1674(16),arr2674(1)),(arr1675(1),arr2674(2)),
     5  (arr1675(16),arr2675(1)),(arr1676(1),arr2675(2)),
     6  (arr1676(16),arr2676(1)),(arr1677(1),arr2676(2)),
     7  (arr1677(16),arr2677(1)),(arr1678(1),arr2677(2)),
     8  (arr1678(16),arr2678(1)),(arr1679(1),arr2678(2)),
     9  (arr1679(16),arr2679(1)),(arr1680(1),arr2679(2)),
     a  (arr1680(16),arr2680(1)),(arr1681(1),arr2680(2))
         equivalence
     1  (arr1681(16),arr2681(1)),(arr1682(1),arr2681(2)),
     2  (arr1682(16),arr2682(1)),(arr1683(1),arr2682(2)),
     3  (arr1683(16),arr2683(1)),(arr1684(1),arr2683(2)),
     4  (arr1684(16),arr2684(1)),(arr1685(1),arr2684(2)),
     5  (arr1685(16),arr2685(1)),(arr1686(1),arr2685(2)),
     6  (arr1686(16),arr2686(1)),(arr1687(1),arr2686(2)),
     7  (arr1687(16),arr2687(1)),(arr1688(1),arr2687(2)),
     8  (arr1688(16),arr2688(1)),(arr1689(1),arr2688(2)),
     9  (arr1689(16),arr2689(1)),(arr1690(1),arr2689(2)),
     a  (arr1690(16),arr2690(1)),(arr1691(1),arr2690(2))
         equivalence
     1  (arr1691(16),arr2691(1)),(arr1692(1),arr2691(2)),
     2  (arr1692(16),arr2692(1)),(arr1693(1),arr2692(2)),
     3  (arr1693(16),arr2693(1)),(arr1694(1),arr2693(2)),
     4  (arr1694(16),arr2694(1)),(arr1695(1),arr2694(2)),
     5  (arr1695(16),arr2695(1)),(arr1696(1),arr2695(2)),
     6  (arr1696(16),arr2696(1)),(arr1697(1),arr2696(2)),
     7  (arr1697(16),arr2697(1)),(arr1698(1),arr2697(2)),
     8  (arr1698(16),arr2698(1)),(arr1699(1),arr2698(2)),
     9  (arr1699(16),arr2699(1)),(arr1700(1),arr2699(2)),
     a  (arr1700(16),arr2700(1)),(arr1701(1),arr2700(2))
         equivalence
     1  (arr1701(16),arr2701(1)),(arr1702(1),arr2701(2)),
     2  (arr1702(16),arr2702(1)),(arr1703(1),arr2702(2)),
     3  (arr1703(16),arr2703(1)),(arr1704(1),arr2703(2)),
     4  (arr1704(16),arr2704(1)),(arr1705(1),arr2704(2)),
     5  (arr1705(16),arr2705(1)),(arr1706(1),arr2705(2)),
     6  (arr1706(16),arr2706(1)),(arr1707(1),arr2706(2)),
     7  (arr1707(16),arr2707(1)),(arr1708(1),arr2707(2)),
     8  (arr1708(16),arr2708(1)),(arr1709(1),arr2708(2)),
     9  (arr1709(16),arr2709(1)),(arr1710(1),arr2709(2)),
     a  (arr1710(16),arr2710(1)),(arr1711(1),arr2710(2))
         equivalence
     1  (arr1711(16),arr2711(1)),(arr1712(1),arr2711(2)),
     2  (arr1712(16),arr2712(1)),(arr1713(1),arr2712(2)),
     3  (arr1713(16),arr2713(1)),(arr1714(1),arr2713(2)),
     4  (arr1714(16),arr2714(1)),(arr1715(1),arr2714(2)),
     5  (arr1715(16),arr2715(1)),(arr1716(1),arr2715(2)),
     6  (arr1716(16),arr2716(1)),(arr1717(1),arr2716(2)),
     7  (arr1717(16),arr2717(1)),(arr1718(1),arr2717(2)),
     8  (arr1718(16),arr2718(1)),(arr1719(1),arr2718(2)),
     9  (arr1719(16),arr2719(1)),(arr1720(1),arr2719(2)),
     a  (arr1720(16),arr2720(1)),(arr1721(1),arr2720(2))
         equivalence
     1  (arr1721(16),arr2721(1)),(arr1722(1),arr2721(2)),
     2  (arr1722(16),arr2722(1)),(arr1723(1),arr2722(2)),
     3  (arr1723(16),arr2723(1)),(arr1724(1),arr2723(2)),
     4  (arr1724(16),arr2724(1)),(arr1725(1),arr2724(2)),
     5  (arr1725(16),arr2725(1)),(arr1726(1),arr2725(2)),
     6  (arr1726(16),arr2726(1)),(arr1727(1),arr2726(2)),
     7  (arr1727(16),arr2727(1)),(arr1728(1),arr2727(2)),
     8  (arr1728(16),arr2728(1)),(arr1729(1),arr2728(2)),
     9  (arr1729(16),arr2729(1)),(arr1730(1),arr2729(2)),
     a  (arr1730(16),arr2730(1)),(arr1731(1),arr2730(2))
         equivalence
     1  (arr1731(16),arr2731(1)),(arr1732(1),arr2731(2)),
     2  (arr1732(16),arr2732(1)),(arr1733(1),arr2732(2)),
     3  (arr1733(16),arr2733(1)),(arr1734(1),arr2733(2)),
     4  (arr1734(16),arr2734(1)),(arr1735(1),arr2734(2)),
     5  (arr1735(16),arr2735(1)),(arr1736(1),arr2735(2)),
     6  (arr1736(16),arr2736(1)),(arr1737(1),arr2736(2)),
     7  (arr1737(16),arr2737(1)),(arr1738(1),arr2737(2)),
     8  (arr1738(16),arr2738(1)),(arr1739(1),arr2738(2)),
     9  (arr1739(16),arr2739(1)),(arr1740(1),arr2739(2)),
     a  (arr1740(16),arr2740(1)),(arr1741(1),arr2740(2))
         equivalence
     1  (arr1741(16),arr2741(1)),(arr1742(1),arr2741(2)),
     2  (arr1742(16),arr2742(1)),(arr1743(1),arr2742(2)),
     3  (arr1743(16),arr2743(1)),(arr1744(1),arr2743(2)),
     4  (arr1744(16),arr2744(1)),(arr1745(1),arr2744(2)),
     5  (arr1745(16),arr2745(1)),(arr1746(1),arr2745(2)),
     6  (arr1746(16),arr2746(1)),(arr1747(1),arr2746(2)),
     7  (arr1747(16),arr2747(1)),(arr1748(1),arr2747(2)),
     8  (arr1748(16),arr2748(1)),(arr1749(1),arr2748(2)),
     9  (arr1749(16),arr2749(1)),(arr1750(1),arr2749(2)),
     a  (arr1750(16),arr2750(1)),(arr1751(1),arr2750(2))
         equivalence
     1  (arr1751(16),arr2751(1)),(arr1752(1),arr2751(2)),
     2  (arr1752(16),arr2752(1)),(arr1753(1),arr2752(2)),
     3  (arr1753(16),arr2753(1)),(arr1754(1),arr2753(2)),
     4  (arr1754(16),arr2754(1)),(arr1755(1),arr2754(2)),
     5  (arr1755(16),arr2755(1)),(arr1756(1),arr2755(2)),
     6  (arr1756(16),arr2756(1)),(arr1757(1),arr2756(2)),
     7  (arr1757(16),arr2757(1)),(arr1758(1),arr2757(2)),
     8  (arr1758(16),arr2758(1)),(arr1759(1),arr2758(2)),
     9  (arr1759(16),arr2759(1)),(arr1760(1),arr2759(2)),
     a  (arr1760(16),arr2760(1)),(arr1761(1),arr2760(2))
         equivalence
     1  (arr1761(16),arr2761(1)),(arr1762(1),arr2761(2)),
     2  (arr1762(16),arr2762(1)),(arr1763(1),arr2762(2)),
     3  (arr1763(16),arr2763(1)),(arr1764(1),arr2763(2)),
     4  (arr1764(16),arr2764(1)),(arr1765(1),arr2764(2)),
     5  (arr1765(16),arr2765(1)),(arr1766(1),arr2765(2)),
     6  (arr1766(16),arr2766(1)),(arr1767(1),arr2766(2)),
     7  (arr1767(16),arr2767(1)),(arr1768(1),arr2767(2)),
     8  (arr1768(16),arr2768(1)),(arr1769(1),arr2768(2)),
     9  (arr1769(16),arr2769(1)),(arr1770(1),arr2769(2)),
     a  (arr1770(16),arr2770(1)),(arr1771(1),arr2770(2))
         equivalence
     1  (arr1771(16),arr2771(1)),(arr1772(1),arr2771(2)),
     2  (arr1772(16),arr2772(1)),(arr1773(1),arr2772(2)),
     3  (arr1773(16),arr2773(1)),(arr1774(1),arr2773(2)),
     4  (arr1774(16),arr2774(1)),(arr1775(1),arr2774(2)),
     5  (arr1775(16),arr2775(1)),(arr1776(1),arr2775(2)),
     6  (arr1776(16),arr2776(1)),(arr1777(1),arr2776(2)),
     7  (arr1777(16),arr2777(1)),(arr1778(1),arr2777(2)),
     8  (arr1778(16),arr2778(1)),(arr1779(1),arr2778(2)),
     9  (arr1779(16),arr2779(1)),(arr1780(1),arr2779(2)),
     a  (arr1780(16),arr2780(1)),(arr1781(1),arr2780(2))
         equivalence
     1  (arr1781(16),arr2781(1)),(arr1782(1),arr2781(2)),
     2  (arr1782(16),arr2782(1)),(arr1783(1),arr2782(2)),
     3  (arr1783(16),arr2783(1)),(arr1784(1),arr2783(2)),
     4  (arr1784(16),arr2784(1)),(arr1785(1),arr2784(2)),
     5  (arr1785(16),arr2785(1)),(arr1786(1),arr2785(2)),
     6  (arr1786(16),arr2786(1)),(arr1787(1),arr2786(2)),
     7  (arr1787(16),arr2787(1)),(arr1788(1),arr2787(2)),
     8  (arr1788(16),arr2788(1)),(arr1789(1),arr2788(2)),
     9  (arr1789(16),arr2789(1)),(arr1790(1),arr2789(2)),
     a  (arr1790(16),arr2790(1)),(arr1791(1),arr2790(2))
         equivalence
     1  (arr1791(16),arr2791(1)),(arr1792(1),arr2791(2)),
     2  (arr1792(16),arr2792(1)),(arr1793(1),arr2792(2)),
     3  (arr1793(16),arr2793(1)),(arr1794(1),arr2793(2)),
     4  (arr1794(16),arr2794(1)),(arr1795(1),arr2794(2)),
     5  (arr1795(16),arr2795(1)),(arr1796(1),arr2795(2)),
     6  (arr1796(16),arr2796(1)),(arr1797(1),arr2796(2)),
     7  (arr1797(16),arr2797(1)),(arr1798(1),arr2797(2)),
     8  (arr1798(16),arr2798(1)),(arr1799(1),arr2798(2)),
     9  (arr1799(16),arr2799(1)),(arr1800(1),arr2799(2)),
     a  (arr1800(16),arr2800(1)),(arr1801(1),arr2800(2))
         equivalence
     1  (arr1801(16),arr2801(1)),(arr1802(1),arr2801(2)),
     2  (arr1802(16),arr2802(1)),(arr1803(1),arr2802(2)),
     3  (arr1803(16),arr2803(1)),(arr1804(1),arr2803(2)),
     4  (arr1804(16),arr2804(1)),(arr1805(1),arr2804(2)),
     5  (arr1805(16),arr2805(1)),(arr1806(1),arr2805(2)),
     6  (arr1806(16),arr2806(1)),(arr1807(1),arr2806(2)),
     7  (arr1807(16),arr2807(1)),(arr1808(1),arr2807(2)),
     8  (arr1808(16),arr2808(1)),(arr1809(1),arr2808(2)),
     9  (arr1809(16),arr2809(1)),(arr1810(1),arr2809(2)),
     a  (arr1810(16),arr2810(1)),(arr1811(1),arr2810(2))
         equivalence
     1  (arr1811(16),arr2811(1)),(arr1812(1),arr2811(2)),
     2  (arr1812(16),arr2812(1)),(arr1813(1),arr2812(2)),
     3  (arr1813(16),arr2813(1)),(arr1814(1),arr2813(2)),
     4  (arr1814(16),arr2814(1)),(arr1815(1),arr2814(2)),
     5  (arr1815(16),arr2815(1)),(arr1816(1),arr2815(2)),
     6  (arr1816(16),arr2816(1)),(arr1817(1),arr2816(2)),
     7  (arr1817(16),arr2817(1)),(arr1818(1),arr2817(2)),
     8  (arr1818(16),arr2818(1)),(arr1819(1),arr2818(2)),
     9  (arr1819(16),arr2819(1)),(arr1820(1),arr2819(2)),
     a  (arr1820(16),arr2820(1)),(arr1821(1),arr2820(2))
         equivalence
     1  (arr1821(16),arr2821(1)),(arr1822(1),arr2821(2)),
     2  (arr1822(16),arr2822(1)),(arr1823(1),arr2822(2)),
     3  (arr1823(16),arr2823(1)),(arr1824(1),arr2823(2)),
     4  (arr1824(16),arr2824(1)),(arr1825(1),arr2824(2)),
     5  (arr1825(16),arr2825(1)),(arr1826(1),arr2825(2)),
     6  (arr1826(16),arr2826(1)),(arr1827(1),arr2826(2)),
     7  (arr1827(16),arr2827(1)),(arr1828(1),arr2827(2)),
     8  (arr1828(16),arr2828(1)),(arr1829(1),arr2828(2)),
     9  (arr1829(16),arr2829(1)),(arr1830(1),arr2829(2)),
     a  (arr1830(16),arr2830(1)),(arr1831(1),arr2830(2))
         equivalence
     1  (arr1831(16),arr2831(1)),(arr1832(1),arr2831(2)),
     2  (arr1832(16),arr2832(1)),(arr1833(1),arr2832(2)),
     3  (arr1833(16),arr2833(1)),(arr1834(1),arr2833(2)),
     4  (arr1834(16),arr2834(1)),(arr1835(1),arr2834(2)),
     5  (arr1835(16),arr2835(1)),(arr1836(1),arr2835(2)),
     6  (arr1836(16),arr2836(1)),(arr1837(1),arr2836(2)),
     7  (arr1837(16),arr2837(1)),(arr1838(1),arr2837(2)),
     8  (arr1838(16),arr2838(1)),(arr1839(1),arr2838(2)),
     9  (arr1839(16),arr2839(1)),(arr1840(1),arr2839(2)),
     a  (arr1840(16),arr2840(1)),(arr1841(1),arr2840(2))
         equivalence
     1  (arr1841(16),arr2841(1)),(arr1842(1),arr2841(2)),
     2  (arr1842(16),arr2842(1)),(arr1843(1),arr2842(2)),
     3  (arr1843(16),arr2843(1)),(arr1844(1),arr2843(2)),
     4  (arr1844(16),arr2844(1)),(arr1845(1),arr2844(2)),
     5  (arr1845(16),arr2845(1)),(arr1846(1),arr2845(2)),
     6  (arr1846(16),arr2846(1)),(arr1847(1),arr2846(2)),
     7  (arr1847(16),arr2847(1)),(arr1848(1),arr2847(2)),
     8  (arr1848(16),arr2848(1)),(arr1849(1),arr2848(2)),
     9  (arr1849(16),arr2849(1)),(arr1850(1),arr2849(2)),
     a  (arr1850(16),arr2850(1)),(arr1851(1),arr2850(2))
         equivalence
     1  (arr1851(16),arr2851(1)),(arr1852(1),arr2851(2)),
     2  (arr1852(16),arr2852(1)),(arr1853(1),arr2852(2)),
     3  (arr1853(16),arr2853(1)),(arr1854(1),arr2853(2)),
     4  (arr1854(16),arr2854(1)),(arr1855(1),arr2854(2)),
     5  (arr1855(16),arr2855(1)),(arr1856(1),arr2855(2)),
     6  (arr1856(16),arr2856(1)),(arr1857(1),arr2856(2)),
     7  (arr1857(16),arr2857(1)),(arr1858(1),arr2857(2)),
     8  (arr1858(16),arr2858(1)),(arr1859(1),arr2858(2)),
     9  (arr1859(16),arr2859(1)),(arr1860(1),arr2859(2)),
     a  (arr1860(16),arr2860(1)),(arr1861(1),arr2860(2))
         equivalence
     1  (arr1861(16),arr2861(1)),(arr1862(1),arr2861(2)),
     2  (arr1862(16),arr2862(1)),(arr1863(1),arr2862(2)),
     3  (arr1863(16),arr2863(1)),(arr1864(1),arr2863(2)),
     4  (arr1864(16),arr2864(1)),(arr1865(1),arr2864(2)),
     5  (arr1865(16),arr2865(1)),(arr1866(1),arr2865(2)),
     6  (arr1866(16),arr2866(1)),(arr1867(1),arr2866(2)),
     7  (arr1867(16),arr2867(1)),(arr1868(1),arr2867(2)),
     8  (arr1868(16),arr2868(1)),(arr1869(1),arr2868(2)),
     9  (arr1869(16),arr2869(1)),(arr1870(1),arr2869(2)),
     a  (arr1870(16),arr2870(1)),(arr1871(1),arr2870(2))
         equivalence
     1  (arr1871(16),arr2871(1)),(arr1872(1),arr2871(2)),
     2  (arr1872(16),arr2872(1)),(arr1873(1),arr2872(2)),
     3  (arr1873(16),arr2873(1)),(arr1874(1),arr2873(2)),
     4  (arr1874(16),arr2874(1)),(arr1875(1),arr2874(2)),
     5  (arr1875(16),arr2875(1)),(arr1876(1),arr2875(2)),
     6  (arr1876(16),arr2876(1)),(arr1877(1),arr2876(2)),
     7  (arr1877(16),arr2877(1)),(arr1878(1),arr2877(2)),
     8  (arr1878(16),arr2878(1)),(arr1879(1),arr2878(2)),
     9  (arr1879(16),arr2879(1)),(arr1880(1),arr2879(2)),
     a  (arr1880(16),arr2880(1)),(arr1881(1),arr2880(2))
         equivalence
     1  (arr1881(16),arr2881(1)),(arr1882(1),arr2881(2)),
     2  (arr1882(16),arr2882(1)),(arr1883(1),arr2882(2)),
     3  (arr1883(16),arr2883(1)),(arr1884(1),arr2883(2)),
     4  (arr1884(16),arr2884(1)),(arr1885(1),arr2884(2)),
     5  (arr1885(16),arr2885(1)),(arr1886(1),arr2885(2)),
     6  (arr1886(16),arr2886(1)),(arr1887(1),arr2886(2)),
     7  (arr1887(16),arr2887(1)),(arr1888(1),arr2887(2)),
     8  (arr1888(16),arr2888(1)),(arr1889(1),arr2888(2)),
     9  (arr1889(16),arr2889(1)),(arr1890(1),arr2889(2)),
     a  (arr1890(16),arr2890(1)),(arr1891(1),arr2890(2))
         equivalence
     1  (arr1891(16),arr2891(1)),(arr1892(1),arr2891(2)),
     2  (arr1892(16),arr2892(1)),(arr1893(1),arr2892(2)),
     3  (arr1893(16),arr2893(1)),(arr1894(1),arr2893(2)),
     4  (arr1894(16),arr2894(1)),(arr1895(1),arr2894(2)),
     5  (arr1895(16),arr2895(1)),(arr1896(1),arr2895(2)),
     6  (arr1896(16),arr2896(1)),(arr1897(1),arr2896(2)),
     7  (arr1897(16),arr2897(1)),(arr1898(1),arr2897(2)),
     8  (arr1898(16),arr2898(1)),(arr1899(1),arr2898(2)),
     9  (arr1899(16),arr2899(1)),(arr1900(1),arr2899(2)),
     a  (arr1900(16),arr2900(1)),(arr1901(1),arr2900(2))
         equivalence
     1  (arr1901(16),arr2901(1)),(arr1902(1),arr2901(2)),
     2  (arr1902(16),arr2902(1)),(arr1903(1),arr2902(2)),
     3  (arr1903(16),arr2903(1)),(arr1904(1),arr2903(2)),
     4  (arr1904(16),arr2904(1)),(arr1905(1),arr2904(2)),
     5  (arr1905(16),arr2905(1)),(arr1906(1),arr2905(2)),
     6  (arr1906(16),arr2906(1)),(arr1907(1),arr2906(2)),
     7  (arr1907(16),arr2907(1)),(arr1908(1),arr2907(2)),
     8  (arr1908(16),arr2908(1)),(arr1909(1),arr2908(2)),
     9  (arr1909(16),arr2909(1)),(arr1910(1),arr2909(2)),
     a  (arr1910(16),arr2910(1)),(arr1911(1),arr2910(2))
         equivalence
     1  (arr1911(16),arr2911(1)),(arr1912(1),arr2911(2)),
     2  (arr1912(16),arr2912(1)),(arr1913(1),arr2912(2)),
     3  (arr1913(16),arr2913(1)),(arr1914(1),arr2913(2)),
     4  (arr1914(16),arr2914(1)),(arr1915(1),arr2914(2)),
     5  (arr1915(16),arr2915(1)),(arr1916(1),arr2915(2)),
     6  (arr1916(16),arr2916(1)),(arr1917(1),arr2916(2)),
     7  (arr1917(16),arr2917(1)),(arr1918(1),arr2917(2)),
     8  (arr1918(16),arr2918(1)),(arr1919(1),arr2918(2)),
     9  (arr1919(16),arr2919(1)),(arr1920(1),arr2919(2)),
     a  (arr1920(16),arr2920(1)),(arr1921(1),arr2920(2))
         equivalence
     1  (arr1921(16),arr2921(1)),(arr1922(1),arr2921(2)),
     2  (arr1922(16),arr2922(1)),(arr1923(1),arr2922(2)),
     3  (arr1923(16),arr2923(1)),(arr1924(1),arr2923(2)),
     4  (arr1924(16),arr2924(1)),(arr1925(1),arr2924(2)),
     5  (arr1925(16),arr2925(1)),(arr1926(1),arr2925(2)),
     6  (arr1926(16),arr2926(1)),(arr1927(1),arr2926(2)),
     7  (arr1927(16),arr2927(1)),(arr1928(1),arr2927(2)),
     8  (arr1928(16),arr2928(1)),(arr1929(1),arr2928(2)),
     9  (arr1929(16),arr2929(1)),(arr1930(1),arr2929(2)),
     a  (arr1930(16),arr2930(1)),(arr1931(1),arr2930(2))
         equivalence
     1  (arr1931(16),arr2931(1)),(arr1932(1),arr2931(2)),
     2  (arr1932(16),arr2932(1)),(arr1933(1),arr2932(2)),
     3  (arr1933(16),arr2933(1)),(arr1934(1),arr2933(2)),
     4  (arr1934(16),arr2934(1)),(arr1935(1),arr2934(2)),
     5  (arr1935(16),arr2935(1)),(arr1936(1),arr2935(2)),
     6  (arr1936(16),arr2936(1)),(arr1937(1),arr2936(2)),
     7  (arr1937(16),arr2937(1)),(arr1938(1),arr2937(2)),
     8  (arr1938(16),arr2938(1)),(arr1939(1),arr2938(2)),
     9  (arr1939(16),arr2939(1)),(arr1940(1),arr2939(2)),
     a  (arr1940(16),arr2940(1)),(arr1941(1),arr2940(2))
         equivalence
     1  (arr1941(16),arr2941(1)),(arr1942(1),arr2941(2)),
     2  (arr1942(16),arr2942(1)),(arr1943(1),arr2942(2)),
     3  (arr1943(16),arr2943(1)),(arr1944(1),arr2943(2)),
     4  (arr1944(16),arr2944(1)),(arr1945(1),arr2944(2)),
     5  (arr1945(16),arr2945(1)),(arr1946(1),arr2945(2)),
     6  (arr1946(16),arr2946(1)),(arr1947(1),arr2946(2)),
     7  (arr1947(16),arr2947(1)),(arr1948(1),arr2947(2)),
     8  (arr1948(16),arr2948(1)),(arr1949(1),arr2948(2)),
     9  (arr1949(16),arr2949(1)),(arr1950(1),arr2949(2)),
     a  (arr1950(16),arr2950(1)),(arr1951(1),arr2950(2))
         equivalence
     1  (arr1951(16),arr2951(1)),(arr1952(1),arr2951(2)),
     2  (arr1952(16),arr2952(1)),(arr1953(1),arr2952(2)),
     3  (arr1953(16),arr2953(1)),(arr1954(1),arr2953(2)),
     4  (arr1954(16),arr2954(1)),(arr1955(1),arr2954(2)),
     5  (arr1955(16),arr2955(1)),(arr1956(1),arr2955(2)),
     6  (arr1956(16),arr2956(1)),(arr1957(1),arr2956(2)),
     7  (arr1957(16),arr2957(1)),(arr1958(1),arr2957(2)),
     8  (arr1958(16),arr2958(1)),(arr1959(1),arr2958(2)),
     9  (arr1959(16),arr2959(1)),(arr1960(1),arr2959(2)),
     a  (arr1960(16),arr2960(1)),(arr1961(1),arr2960(2))
         equivalence
     1  (arr1961(16),arr2961(1)),(arr1962(1),arr2961(2)),
     2  (arr1962(16),arr2962(1)),(arr1963(1),arr2962(2)),
     3  (arr1963(16),arr2963(1)),(arr1964(1),arr2963(2)),
     4  (arr1964(16),arr2964(1)),(arr1965(1),arr2964(2)),
     5  (arr1965(16),arr2965(1)),(arr1966(1),arr2965(2)),
     6  (arr1966(16),arr2966(1)),(arr1967(1),arr2966(2)),
     7  (arr1967(16),arr2967(1)),(arr1968(1),arr2967(2)),
     8  (arr1968(16),arr2968(1)),(arr1969(1),arr2968(2)),
     9  (arr1969(16),arr2969(1)),(arr1970(1),arr2969(2)),
     a  (arr1970(16),arr2970(1)),(arr1971(1),arr2970(2))
         equivalence
     1  (arr1971(16),arr2971(1)),(arr1972(1),arr2971(2)),
     2  (arr1972(16),arr2972(1)),(arr1973(1),arr2972(2)),
     3  (arr1973(16),arr2973(1)),(arr1974(1),arr2973(2)),
     4  (arr1974(16),arr2974(1)),(arr1975(1),arr2974(2)),
     5  (arr1975(16),arr2975(1)),(arr1976(1),arr2975(2)),
     6  (arr1976(16),arr2976(1)),(arr1977(1),arr2976(2)),
     7  (arr1977(16),arr2977(1)),(arr1978(1),arr2977(2)),
     8  (arr1978(16),arr2978(1)),(arr1979(1),arr2978(2)),
     9  (arr1979(16),arr2979(1)),(arr1980(1),arr2979(2)),
     a  (arr1980(16),arr2980(1)),(arr1981(1),arr2980(2))
         equivalence
     1  (arr1981(16),arr2981(1)),(arr1982(1),arr2981(2)),
     2  (arr1982(16),arr2982(1)),(arr1983(1),arr2982(2)),
     3  (arr1983(16),arr2983(1)),(arr1984(1),arr2983(2)),
     4  (arr1984(16),arr2984(1)),(arr1985(1),arr2984(2)),
     5  (arr1985(16),arr2985(1)),(arr1986(1),arr2985(2)),
     6  (arr1986(16),arr2986(1)),(arr1987(1),arr2986(2)),
     7  (arr1987(16),arr2987(1)),(arr1988(1),arr2987(2)),
     8  (arr1988(16),arr2988(1)),(arr1989(1),arr2988(2)),
     9  (arr1989(16),arr2989(1)),(arr1990(1),arr2989(2)),
     a  (arr1990(16),arr2990(1)),(arr1991(1),arr2990(2))
         equivalence
     1  (arr1991(16),arr2991(1)),(arr1992(1),arr2991(2)),
     2  (arr1992(16),arr2992(1)),(arr1993(1),arr2992(2)),
     3  (arr1993(16),arr2993(1)),(arr1994(1),arr2993(2)),
     4  (arr1994(16),arr2994(1)),(arr1995(1),arr2994(2)),
     5  (arr1995(16),arr2995(1)),(arr1996(1),arr2995(2)),
     6  (arr1996(16),arr2996(1)),(arr1997(1),arr2996(2)),
     7  (arr1997(16),arr2997(1)),(arr1998(1),arr2997(2)),
     8  (arr1998(16),arr2998(1)),(arr1999(1),arr2998(2)),
     9  (arr1999(16),arr2999(1)),(arr2000(1),arr2999(2))
c
         data arr1001/
     1      0.9861255747535785d+00,-.2755545431489066d-01,
     2      0.3849930890850982d-03,-.3585973142983799d-05,
     3      0.2505084665616658d-07,-.1400027886568520d-09,
     4      0.6514355965712252d-12,-.1036437411908451d-13,
     5      -.7741888136777915d-14,-.1491074850988750d-14,
     6      0.6123968340607365d-14,0.1160512783270409d-13,
     7      0.1826877436514589d-12,-.8079729516249150d-13,
     8      0.1032051284713177d-11,-.9940831443210205d-12/
         data arr1002/
     1      0.3804971969190955d-11,-.4638805599154773d-11,
     2      0.9736388697767410d-11,-.1571433424678053d-10,
     3      0.1795390845333020d-10,-.4035427906075411d-10,
     4      0.2219976680025585d-10,-.8113527299744154d-10,
     5      0.1329492311808359d-10,-.1275168542215386d-09,
     6      -.1015445740326243d-10,-.1535328916866498d-09,
     7      -.3729207241661261d-10,-.1384429114556516d-09,
     8      -.4372754492579615d-10,-.8433201300424821d-10/
         data arr1003/
     1      -.3124189042099438d-10,-.3112852709193954d-10,
     2      -.8137900844602962d-11,0.9296469885867545d+00,
     3      -.1356361409198170d+00,0.9894703553866445d-02,
     4      -.4812147055344097d-03,0.1755238988867029d-04,
     5      -.5121811749045687d-06,0.1245459649296761d-07,
     6      -.2595929558953981d-09,0.4738955197453367d-11,
     7      -.7162200362121239d-13,0.5227385814007669d-13,
     8      -.7373318836583812d-14,0.2072856112217301d-12/
         data arr1004/
     1      -.2904224478711635d-12,0.6498943744975743d-12,
     2      -.1803618302904490d-11,0.1951087853528573d-11,
     3      -.6990844607828151d-11,0.5497685449651858d-11,
     4      -.2067555618649825d-10,0.1351159903845696d-10,
     5      -.4903637897021157d-10,0.2688762478920384d-10,
     6      -.9296115733114685d-10,0.4226008529300555d-10,
     7      -.1409172992660246d-09,0.5284020569895271d-10,
     8      -.1650573352879415d-09,0.5028114139682719d-10/
         data arr1005/
     1      -.1465388631745780d-09,0.3953495138138717d-10,
     2      -.8793153980148486d-10,0.2070517639186604d-10,
     3      -.3242353058285081d-10,0.1009157435825562d-10,
     4      0.8381509731766630d+00,-.2959629027617791d+00,
     5      0.5225433281977244d-01,-.6150580073740258d-02,
     6      0.5429640931488258d-03,-.3834565233458374d-04,
     7      0.2256731568857244d-05,-.1138405238068174d-06,
     8      0.5024827799340317d-08,-.1971292013207530d-09/
         data arr1006/
     1      0.6947785996448803d-11,-.1595965291293382d-12,
     2      0.1236108229527207d-12,-.2389561847253846d-13,
     3      0.1089264335964218d-11,-.1107776649634533d-11,
     4      0.5190537570283450d-11,-.5743395814570958d-11,
     5      0.1647417866416409d-10,-.1920982719581760d-10,
     6      0.3966823428017986d-10,-.4817139823096509d-10,
     7      0.7414238970202060d-10,-.9371696792134077d-10,
     8      0.1111949273287530d-09,-.1424869410330815d-09/
         data arr1007/
     1      0.1345594203036277d-09,-.1668074967627207d-09,
     2      0.1300160863052850d-09,-.1449608829531366d-09,
     3      0.1018424180672139d-09,-.8616787308340416d-10,
     4      0.5621184964036795d-10,-.2918629848986243d-10,
     5      0.2384649341513888d-10,0.7252521921733580d+00,
     6      -.4659539846690750d+00,0.1496811165633085d+00,
     7      -.3205529214299279d-01,0.5148654242256462d-02,
     8      -.6615728944358573d-03,0.7084030668483960d-04/
         data arr1008/
     1      -.6501841414257215d-05,0.5221561098598970d-06,
     2      -.3727448402178459d-07,0.2394798947859336d-08,
     3      -.1398318542362190d-09,0.7656204464170668d-11,
     4      -.5012501049129444d-12,0.1040096488989842d-11,
     5      -.1557857270998804d-11,0.4327882275613024d-11,
     6      -.6987837765464095d-11,0.1333463823152198d-10,
     7      -.2171517564008378d-10,0.3109310678757196d-10,
     8      -.5121960975218939d-10,0.5652054820942043d-10/
         data arr1009/
     1      -.9439905581294272d-10,0.7994391403174932d-10,
     2      -.1365339607825291d-09,0.9107044366895472d-10,
     3      -.1525958821723040d-09,0.7897011304804564d-10,
     4      -.1259232989877088d-09,0.5844432128723104d-10,
     5      -.7132994914096997d-10,0.2827884224111686d-10,
     6      -.2145299248004935d-10,0.1473317087486878d-10,
     7      0.6047455172411342d+00,-.6083105429864279d+00,
     8      0.3059482924293387d+00,-.1025839611249528d+00/
         data arr1010/
     1      0.2579717555340486d-01,-.5189850415097065d-02,
     2      0.8700741700478820d-03,-.1250290472201279d-03,
     3      0.1572076299994676d-04,-.1757048679504916d-05,
     4      0.1767407110447165d-06,-.1616201977835606d-07,
     5      0.1355041760439930d-08,-.1049213682854940d-09,
     6      0.8567313379029129d-11,-.1482221168815482d-11,
     7      0.3035490867818204d-11,-.4058355291709930d-11,
     8      0.6550546455137402d-11,-.1165256178102439d-10/
         data arr1011/
     1      0.1081559258807212d-10,-.2644470163249947d-10,
     2      0.1377833612917728d-10,-.4812930610659687d-10,
     3      0.1304439712876422d-10,-.7082809866988497d-10,
     4      0.1274847941036191d-10,-.8167629365525934d-10,
     5      0.1223678851858562d-10,-.7106079248742143d-10,
     6      0.2077602478503807d-10,-.4256804635098952d-10,
     7      0.1722540809829272d-10,-.1475732647018827d-10,
     8      0.1608721113205630d-10,0.4878571659887999d+00/
         data arr1012/
     1      -.7003019927560019d+00,0.5026295760809717d+00,
     2      -.2405024245393514d+00,0.8630821627176062d-01,
     3      -.2477848848394984d-01,0.5928109725727946d-02,
     4      -.1215656473602694d-02,0.2181290729891293d-03,
     5      -.3479074410234278d-04,0.4994090308207796d-05,
     6      -.6517129203022828d-06,0.7795938922834436d-07,
     7      -.8608300656293714d-08,0.8833340025783543d-09,
     8      -.8546850702882659d-10,0.1015657057519929d-10/
         data arr1013/
     1      -.5495894403895599d-11,0.6535794018550869d-11,
     2      -.1485106562091673d-10,0.1136975611627029d-10,
     3      -.3370118338679998d-10,0.1217133009687598d-10,
     4      -.5930209656532647d-10,0.2534232466636058d-11,
     5      -.8164428298195160d-10,-.1862878104815975d-10,
     6      -.8669636230056289d-10,-.3949318590092775d-10,
     7      -.6734620853029933d-10,-.4368754225401514d-10,
     8      -.3586159087443665d-10,-.2907389514848664d-10/
         data arr1014/
     1      -.9254703852522020d-11,-.8617905064732664d-11,
     2      0.3821314584897415d+00,-.7352137400783253d+00,
     3      0.7072687050371084d+00,-.4535905627222317d+00,
     4      0.2181749282048435d+00,-.8395289180888543d-01,
     5      0.2692063084832216d-01,-.7399255357786791d-02,
     6      0.1779503520493378d-02,-.3804145899333302d-03,
     7      0.7319105173763398d-04,-.1280165514268017d-04,
     8      0.2052512093732672d-05,-.3037687923943353d-06/
         data arr1015/
     1      0.4174667924072188d-07,-.5355262097630681d-08,
     2      0.6461831784180914d-09,-.7631282154260666d-10,
     3      0.1459683626484477d-10,-.1146313173391112d-10,
     4      0.1594438662458918d-10,-.2408417002286083d-10,
     5      0.2937069797638255d-10,-.4242398879603182d-10,
     6      0.4394488860860551d-10,-.5713445538675827d-10,
     7      0.5349734633701207d-10,-.6008605090555173d-10,
     8      0.5162918491243771d-10,-.4352402254524411d-10/
         data arr1016/
     1      0.4121039147725481d-10,-.2227706204621999d-10,
     2      0.2266462249131405d-10,-.3237692376559445d-11,
     3      0.1060939991707064d-10,0.2915438924539284d+00,
     4      -.7186934265507593d+00,0.8858361549263081d+00,
     5      -.7279002556446356d+00,0.4485920837795353d+00,
     6      -.2211675086735067d+00,0.9086775540174410d-01,
     7      -.3200011102615039d-01,0.9860551892290017d-02,
     8      -.2700837396464535d-02,0.6657913724620934d-03/
         data arr1017/
     1      -.1492056271099169d-03,0.3065093161153894d-04,
     2      -.5812192947055633d-05,0.1023414588978457d-05,
     3      -.1681895896427241d-06,0.2591290268906714d-07,
     4      -.3758470307820429d-08,0.5151117975191787d-09,
     5      -.7213295481366020d-10,0.1015653434779814d-10,
     6      -.1536383140740990d-10,0.3019196128936604d-11,
     7      -.2665163920744740d-10,0.1886796446193131d-11,
     8      -.3614218538801254d-10,-.1828438970550424d-11/
         data arr1018/
     1      -.3709697720070214d-10,-.6150747330785208d-11,
     2      -.2563660478391998d-10,-.6751488245068524d-11,
     3      -.1218026000981761d-10,-.4533819000159333d-11,
     4      -.6910951443117253d-12,-.1777165998658932d-12,
     5      0.2172460559986061d+00,-.6633498259624591d+00,
     6      0.1012752543611771d+01,-.1030796194756877d+01,
     7      0.7868709897305687d+00,-.4805341406023318d+00,
     8      0.2445477756180919d+00,-.1066734633817417d+00/
         data arr1019/
     1      0.4071525202368793d-01,-.1381355103944937d-01,
     2      0.4217897828245503d-02,-.1170830666603099d-02,
     3      0.2979226770222352d-03,-.6997629231101496d-04,
     4      0.1526207601054597d-04,-.3106798451681492d-05,
     5      0.5929033151506844d-06,-.1064948258776376d-06,
     6      0.1806494992927221d-07,-.2905238404619148d-08,
     7      0.4407007550578953d-09,-.6793114543950887d-10,
     8      0.4387773137983702d-12,-.5035368535180131d-11/
         data arr1020/
     1      -.1852101600363326d-10,-.1951338901627335d-11,
     2      -.2903594859894845d-10,0.1300592324419864d-11,
     3      -.3356104377930273d-10,0.4876568806399052d-11,
     4      -.2659426255132234d-10,0.4357371621275310d-11,
     5      -.1433158299557120d-10,0.3298202509692482d-11,
     6      -.2864645862132344d-11,0.1584824003220763d+00,
     7      -.5838845775196605d+00,0.1075580629686564d+01,
     8      -.1320893130249974d+01,0.1216616365188277d+01/
         data arr1021/
     1      -.8964573112822926d+00,0.5504581764270954d+00,
     2      -.2897158468900768d+00,0.1334222400392593d+00,
     3      -.5461748300597164d-01,0.2012230123046326d-01,
     4      -.6739550390380372d-02,0.2069167472263830d-02,
     5      -.5864057956822191d-03,0.1543178559934542d-03,
     6      -.3790276374680846d-04,0.8727639513371534d-05,
     7      -.1891444584036967d-05,0.3871365090046709d-06,
     8      -.7506783433583963d-07,0.1382331385255852d-07/
         data arr1022/
     1      -.2426699282393720d-08,0.3981097181019857d-09,
     2      -.6901430062428484d-10,-.6316488342911057d-12,
     3      -.7830265348854408d-11,-.1111214351201987d-10,
     4      -.6565727652770209d-11,-.8874963456146674d-11,
     5      -.2463774222578067d-11,-.4925523579835654d-11,
     6      0.1769921021461408d-12,-.1085686265476894d-11,
     7      0.2107813410709032d-11,0.1832611638972385d-12,
     8      0.1134175738240896d+00,-.4937472859478880d+00/
         data arr1023/
     1      0.1074729312932660d+01,-.1559560432295878d+01,
     2      0.1697331164727875d+01,-.1477817991837800d+01,
     3      0.1072245093937247d+01,-.6668380860870599d+00,
     4      0.3628731025436507d+00,-.1755240523858743d+00,
     5      0.7641190122658066d-01,-.3024075913182218d-01,
     6      0.1097073719309181d-01,-.3673811148760476d-02,
     7      0.1142386758015408d-02,-.3315478898866032d-03,
     8      0.9020916056704236d-04,-.2310074731979575d-04/
         data arr1024/
     1      0.5586982611823550d-05,-.1280105618756881d-05,
     2      0.2786195219740900d-06,-.5774533447551774d-07,
     3      0.1138831388897174d-07,-.2132919309810659d-08,
     4      0.3215557841494015d-09,-.2282947345412312d-10,
     5      -.8475984694791610d-10,0.5176647429933461d-10,
     6      -.1013010760878732d-09,0.4892152421760847d-10,
     7      -.8046904598922242d-10,0.3018698131723244d-10,
     8      -.4322669047743087d-10,0.1178150902145582d-10/
         data arr1025/
     1      -.1383676853099580d-10,0.7976745471311113d-01,
     2      -.4034063044564054d+00,0.1020069194011943d+01,
     3      -.1719591635988127d+01,0.2174113833589884d+01,
     4      -.2199020215024829d+01,0.1853509934092396d+01,
     5      -.1339102511839244d+01,0.8465269412384930d+00,
     6      -.4756803611420053d+00,0.2405648485098396d+00,
     7      -.1106003317774360d+00,0.4661139817215127d-01,
     8      -.1813283562774066d-01,0.6550201130584844d-02/
         data arr1026/
     1      -.2208413142340819d-02,0.6980351373306724d-03,
     2      -.2076563897799656d-03,0.5834312002873534d-04,
     3      -.1552932626132433d-04,0.3926776822639539d-05,
     4      -.9456270450719717d-06,0.2173152865503006d-06,
     5      -.4772877243520311d-07,0.9954485065930368d-08,
     6      -.1934474352628966d-08,0.2391877106347782d-09,
     7      0.4386825468186678d-10,-.1501782528544972d-09,
     8      0.1004320903643114d-09,-.1286374337027007d-09/
         data arr1027/
     1      0.6127727836230809d-10,-.6939864073252750d-10,
     2      0.2234614251418454d-10,-.2253258380898457d-10,
     3      0.5522013319885179d-01,-.3198822424089997d+00,
     4      0.9265157749631994d+00,-.1789057278893007d+01,
     5      0.2590937494254091d+01,-.3001785209821945d+01,
     6      0.2898151237370264d+01,-.2398367259357541d+01,
     7      0.1736674317410852d+01,-.1117811451097992d+01,
     8      0.6475320011996760d+00,-.3410053816774475d+00/
         data arr1028/
     1      0.1646162366352961d+00,-.7335369555818994d-01,
     2      0.3035195325649815d-01,-.1172163159302403d-01,
     3      0.4243857243249832d-02,-.1446120644230482d-02,
     4      0.4653981956277615d-03,-.1418939085246620d-03,
     5      0.4109852533311718d-04,-.1133702307062280d-04,
     6      0.2985133160344738d-05,-.7518191103130923d-06,
     7      0.1814078653057676d-06,-.4199795373593322d-07,
     8      0.9284059740660797d-08,-.1949812709759995d-08/
         data arr1029/
     1      0.3319278342038979d-09,-.3068554396629987d-10,
     2      -.4508053064755679d-10,0.2900491541370720d-10,
     3      -.2970875241744186d-10,0.1117395382933520d-10,
     4      -.7618428851404564d-11,0.3767848162474303d-01,
     5      -.2470703228147409d+00,0.8100610983179085d+00,
     6      -.1770613255724899d+01,0.2902624852488318d+01,
     7      -.3806695112912606d+01,0.4160294107087874d+01,
     8      -.3897204390254386d+01,0.3194408005758347d+01/
         data arr1030/
     1      -.2327421627386796d+01,0.1526167690438011d+01,
     2      -.9097807836828395d+00,0.4971445730257049d+00,
     3      -.2507647802515535d+00,0.1174534272524602d+00,
     4      -.5134540978512832d-01,0.2104305697554262d-01,
     5      -.8116842128712701d-02,0.2956935031821883d-02,
     6      -.1020505547731573d-02,0.3345896821689613d-03,
     7      -.1044769357629102d-03,0.3114042346714276d-04,
     8      -.8878176404917141d-05,0.2425665049079005d-05/
         data arr1031/
     1      -.6362368841728626d-06,0.1603957013449785d-06,
     2      -.3895984081327402d-07,0.9054164453198846d-08,
     3      -.2056207082975894d-08,0.3920808912168263d-09,
     4      -.9169577823171332d-10,-.1359341873716495d-10,
     5      -.3018915997100377d-11,-.1169655391134215d-10,
     6      0.2537109898633972d-01,-.1864341720628707d+00,
     7      0.6849861042969134d+00,-.1677825325290091d+01,
     8      0.3082286419234316d+01,-.4529906386317623d+01/
         data arr1032/
     1      0.5547843677762084d+01,-.5823879949581915d+01,
     2      0.5349444249431540d+01,-.4367695919484472d+01,
     3      0.3209509264891869d+01,-.2144036562842163d+01,
     4      0.1312916722294808d+01,-.7421301337951808d+00,
     5      0.3895276306637594d+00,-.1908241114747985d+00,
     6      0.8763942205176382d-01,-.3788234214265679d-01,
     7      0.1546502247981120d-01,-.5981129329470752d-02,
     8      0.2197553383918693d-02,-.7689646527117843d-03/
         data arr1033/
     1      0.2568442783625396d-03,-.8205939121262163d-04,
     2      0.2512480165541109d-04,-.7384971341816795d-05,
     3      0.2087140022433598d-05,-.5680317158472139d-06,
     4      0.1490240291001765d-06,-.3775789280109944d-07,
     5      0.9209391677316055d-08,-.2177510273420410d-08,
     6      0.4786535364570930d-09,-.1022394807365569d-09,
     7      0.1436683772979268d-10,0.1687705909676575d-01,
     8      -.1377775606252202d+00,0.5623804509718844d+00/
         data arr1034/
     1      -.1530349694101764d+01,0.3123290712972936d+01,
     2      -.5099459249263220d+01,0.6938324304043530d+01,
     3      -.8091672098936444d+01,0.8257146852263768d+01,
     4      -.7489782724889960d+01,0.6114359068909173d+01,
     5      -.4537743822820610d+01,0.3087027144686673d+01,
     6      -.1938558075241639d+01,0.1130400915423751d+01,
     7      -.6152093985987335d+00,0.3138952176386521d+00,
     8      -.1507361774686625d+00,0.6836388150846434d-01/
         data arr1035/
     1      -.2937344141424252d-01,0.1198965140307979d-01,
     2      -.4660891335842490d-02,0.1729529677080168d-02,
     3      -.6138776505844266d-03,0.2088104965343465d-03,
     4      -.6818557729599462d-04,0.2140924204601670d-04,
     5      -.6472814618079477d-05,0.1887218005901204d-05,
     6      -.5307819938169191d-06,0.1444557506859873d-06,
     7      -.3759166817923406d-07,0.9600633142214238d-08,
     8      -.2094864528691797d-08,0.5064970333879155d-09/
         data arr1036/
     1      0.1110120771867516d-01,-.9992644164497957d-01,
     2      0.4497390731203876d+00,-.1349427509285920d+01,
     3      0.3036685121969861d+01,-.5466885159246742d+01,
     4      0.8201605847597467d+01,-.1054656534282653d+02,
     5      0.1186673527998249d+02,-.1186858483751370d+02,
     6      0.1068339121498612d+02,-.8742318820116061d+01,
     7      0.6557761052959444d+01,-.4540696027002414d+01,
     8      0.2919473834792197d+01,-.1751957319591008d+01/
         data arr1037/
     1      0.9856295892366812d+00,-.5218852288328133d+00,
     2      0.2609832851200924d+00,-.1236429291081913d+00,
     3      0.5564799011741978d-01,-.2385285464303270d-01,
     4      0.9759506976183160d-02,-.3819529885388723d-02,
     5      0.1432547149092746d-02,-.5157917919807860d-03,
     6      0.1785714384149543d-03,-.5952449877390786d-04,
     7      0.1913619558878161d-04,-.5929614116901285d-05,
     8      0.1779437816955796d-05,-.5074670125402659d-06/
         data arr1038/
     1      0.1429021531983501d-06,-.3336954204230873d-07,
     2      0.8877204443107425d-08,0.7226242144630899d-02,
     3      -.7125126981011491d-01,0.3512713349445304d+00,
     4      -.1154520250025505d+01,0.2845913276547493d+01,
     5      -.5612182118035953d+01,0.9222753549085629d+01,
     6      -.1299100236463197d+02,0.1601152777716482d+02,
     7      -.1754164678757027d+02,0.1729619051173675d+02,
     8      -.1550378986344464d+02,0.1273904071357245d+02/
         data arr1039/
     1      -.9662143240626675d+01,0.6804959333351676d+01,
     2      -.4473159389474384d+01,0.2756604679370647d+01,
     3      -.1598842432326149d+01,0.8758167743558076d+00,
     4      -.4545061365357856d+00,0.2240731683208806d+00,
     5      -.1052084413476798d+00,0.4715285778962457d-01,
     6      -.2021432927851180d-01,0.8304784488060242d-02,
     7      -.3275345418199157d-02,0.1242125904282555d-02,
     8      -.4534774569842850d-03,0.1596958064790238d-03/
         data arr1040/
     1      -.5414183008298642d-04,0.1779947190783462d-04,
     2      -.5520412919496142d-05,0.1703662185371241d-05,
     3      -.4234016239511589d-06,0.1235111941342085d-06,
     4      0.4658327473804824d-02,-.5002204095950273d-01,
     5      0.2685732804127869d+00,-.9613309862093219d+00,
     6      0.2580740525339048d+01,-.5542500349762727d+01,
     7      0.9919410670921401d+01,-.1521665599832698d+02,
     8      0.2042493238976276d+02,-.2436966224805863d+02/
         data arr1041/
     1      0.2616862489799713d+02,-.2554580594685169d+02,
     2      0.2285965936983174d+02,-.1888242612939300d+02,
     3      0.1448308737044339d+02,-.1036815028086943d+02,
     4      0.6958452912201883d+01,-.4395367190112504d+01,
     5      0.2622128972019063d+01,-.1481944097432293d+01,
     6      0.7956704360990882d+00,-.4068600899715138d+00,
     7      0.1985883875006337d+00,-.9271604066832465d-01,
     8      0.4148350987832676d-01,-.1781727577666927d-01/
         data arr1042/
     1      0.7358737934399145d-02,-.2925034967926417d-02,
     2      0.1121849555478061d-02,-.4134997378651885d-03,
     3      0.1480720702968785d-03,-.4956243658731562d-04,
     4      0.1666796545451293d-04,-.4373786198191012d-05,
     5      0.1391373255974632d-05,0.2975685845441442d-02,
     6      -.3462079985611628d-01,0.2013989118691036d+00,
     7      -.7810626727433484d+00,0.2271830417640204d+01,
     8      -.5286350124400944d+01,0.1025072757070559d+02/
         data arr1043/
     1      -.1703753141958370d+02,0.2477802580457861d+02,
     2      -.3203127378863876d+02,0.3726698235506225d+02,
     3      -.3941681787973324d+02,0.3821644918239191d+02,
     4      -.3420243283537734d+02,0.2842359334934729d+02,
     5      -.2204640290575630d+02,0.1603126434843949d+02,
     6      -.1097157224296754d+02,0.7091635104522666d+01,
     7      -.4342529062702557d+01,0.2526171147701867d+01,
     8      -.1399564199323269d+01,0.7401509533450490d+00/
         data arr1044/
     1      -.3744002830989365d+00,0.1814997891747370d+00,
     2      -.8445623155614305d-01,0.3779348792509390d-01,
     3      -.1626927153607852d-01,0.6761073657126471d-02,
     4      -.2693295854088580d-02,0.1045222279216051d-02,
     5      -.3748295656404202d-03,0.1366858279628902d-03,
     6      -.3758933728858172d-04,0.1297540825229149d-04,
     7      0.1884558944095528d-02,-.2364767730876447d-01,
     8      0.1483669809915950d+00,-.6205757056539469d+00/
         data arr1045/
     1      0.1946765061200314d+01,-.4885649462673295d+01,
     2      0.1021762167887471d+02,-.1831599613300669d+02,
     3      0.2872892139318914d+02,-.4005489305045093d+02,
     4      0.5026137221104157d+02,-.5733507977512592d+02,
     5      0.5995396911511509d+02,-.5786998271131580d+02,
     6      0.5186854692814904d+02,-.4339019345818842d+02,
     7      0.3402909259531258d+02,-.2511771872750681d+02,
     8      0.1751001251146788d+02,-.1156408870398954d+02/
         data arr1046/
     1      0.7255381108860776d+01,-.4335287154512167d+01,
     2      0.2472716588329916d+01,-.1348995237390384d+01,
     3      0.7053111492488534d+00,-.3539235383060936d+00,
     4      0.1708175578046414d+00,-.7924845129274916d-01,
     5      0.3552300501648498d-01,-.1520793064951753d-01,
     6      0.6367656993026216d-02,-.2429529539253458d-02,
     7      0.9564692585145029d-03,-.2737954753730540d-03,
     8      0.1021089671991715d-03,0.1183828471999284d-02/
         data arr1047/
     1      -.1595564399526936d-01,0.1075251107736085d+00,
     2      -.4830745975164040d+00,0.1627720248633731d+01,
     3      -.4387683760553245d+01,0.9856202663102898d+01,
     4      -.1897741879254762d+02,0.3197221401532336d+02,
     5      -.4788017828939984d+02,0.6453291983763845d+02,
     6      -.7907044585175953d+02,0.8880931043853732d+02,
     7      -.9207478286659983d+02,0.8864173002257542d+02,
     8      -.7964756765175296d+02,0.6709313589999350d+02/
         data arr1048/
     1      -.5319302156779415d+02,0.3982976329019166d+02,
     2      -.2825394337874554d+02,0.1904034311375900d+02,
     3      -.1222014418415606d+02,0.7486523939387459d+01,
     4      -.4386770148634042d+01,0.2463573541303269d+01,
     5      -.1327512934943298d+01,0.6882172183495436d+00,
     6      -.3425476087436505d+00,0.1649512535335322d+00,
     7      -.7548507759018470d-01,0.3396545459982470d-01,
     8      -.1369584278296785d-01,0.5798565997260585d-02/
         data arr1049/
     1      -.1717118493260469d-02,0.6892132834516174d-03,
     2      0.7378741667498725d-03,-.1064270925016590d-01,
     3      0.7675242255898121d-01,-.3690122037339760d+00,
     4      0.1330609527709616d+01,-.3838402524211873d+01,
     5      0.9227183490419243d+01,-.1901257800649902d+02,
     6      0.3427842925658149d+02,-.5493489466359313d+02,
     7      0.7923520516159007d+02,-.1038951789840887d+03,
     8      0.1248774549999886d+03,-.1385512926978607d+03/
         data arr1050/
     1      0.1427422159024004d+03,-.1372559097062004d+03,
     2      0.1237316941563978d+03,-.1049788279215774d+03,
     3      0.8411997750512076d+02,-.6385776910505231d+02,
     4      0.4605258648441026d+02,-.3162956573536886d+02,
     5      0.2073685649136403d+02,-.1300214604396744d+02,
     6      0.7814249800276810d+01,-.4504274967196974d+01,
     7      0.2499115729736217d+01,-.1328761268204566d+01,
     8      0.6849106877029580d+00,-.3332627307810092d+00/
         data arr1051/
     1      0.1605868591350843d+00,-.6799359537227728d-01,
     2      0.3085348468176763d-01,-.9398423518536200d-02,
     3      0.4046264488572149d-02,0.4564753156739859d-03,
     4      -.7022394356366582d-02,0.5401608707559320d-01,
     5      -.2769936298031823d+00,0.1065314163640254d+01,
     6      -.3277748386148220d+01,0.8404120559304127d+01,
     7      -.1846979819547970d+02,0.3551731073319869d+02,
     8      -.6071073414033084d+02,0.9339710062635628d+02/
         data arr1052/
     1      -.1306196855562499d+03,0.1674539104596363d+03,
     2      -.1981617684750132d+03,0.2177507871449465d+03,
     3      -.2233244840165567d+03,0.2147258167658510d+03,
     4      -.1943133457028328d+03,0.1660726682868377d+03,
     5      -.1344646234275703d+03,0.1034301096640730d+03,
     6      -.7576514018783772d+02,0.5298103565893674d+02,
     7      -.3542577265141845d+02,0.2270930755568847d+02,
     8      -.1395196713764891d+02,0.8257476842888019d+01/
         data arr1053/
     1      -.4670400480170938d+01,0.2568638449029377d+01,
     2      -.1321978596110581d+01,0.6800691814055657d+00,
     3      -.3004796868554811d+00,0.1456979395578895d+00,
     4      -.4541868237684010d-01,0.2091145794379390d-01,
     5      0.2803435713142215d-03,-.4586137748442528d-02,
     6      0.3751228244995090d-01,-.2045543527711050d+00,
     7      0.8365756049732911d+00,-.2737106409728466d+01,
     8      0.7462715773724247d+01,-.1744035638631600d+02/
         data arr1054/
     1      0.3566332548061024d+02,-.6482400097666117d+02,
     2      0.1060455123284219d+03,-.1577088747897479d+03,
     3      0.2149964729787332d+03,-.2705481148934975d+03,
     4      0.3161352373301584d+03,-.3447767478440719d+03,
     5      0.3525124362259332d+03,-.3392190585447987d+03,
     6      0.3082936444869388d+03,-.2654339525549806d+03,
     7      0.2171128493661142d+03,-.1691085249939656d+03,
     8      0.1257511941125125d+03,-.8938566411883919d+02/
         data arr1055/
     1      0.6093515566891095d+02,-.3976431355909573d+02,
     2      0.2503117677721876d+02,-.1499775844710918d+02,
     3      0.8776178369278121d+01,-.4752421376536019d+01,
     4      0.2602976335667115d+01,-.1192973009892549d+01,
     5      0.6164932158399381d+00,-.1957444536605724d+00,
     6      0.9612853984066838d-01,0.1709500086864645d-03,
     7      -.2965689040306736d-02,0.2572476833679298d-01,
     8      -.1487601962505429d+00,0.6451832935945147d+00/
         data arr1056/
     1      -.2238564594808759d+01,0.6472540814632879d+01,
     2      -.1604106852982347d+02,0.3478561813258697d+02,
     3      -.6705231702860058d+02,0.1163242295945050d+03,
     4      -.1834569345536660d+03,0.2652218113353519d+03,
     5      -.3539341874679718d+03,0.4385819748156992d+03,
     6      -.5072423542008497d+03,0.5499863681127193d+03,
     7      -.5612480131344062d+03,0.5409283187096829d+03,
     8      -.4938747206062731d+03,0.4283999144259745d+03/
         data arr1057/
     1      -.3538075965724701d+03,0.2790153573686649d+03,
     2      -.2102085401022520d+03,0.1519844485140128d+03,
     3      -.1049902001097854d+03,0.7010953061652367d+02,
     4      -.4431252683741505d+02,0.2752027552659612d+02,
     5      -.1559752280703708d+02,0.9074222073862316d+01,
     6      -.4289034220751048d+01,0.2356788616313196d+01,
     7      -.7588944743891896d+00,0.3966114035791755d+00,
     8      0.1035119986420989d-03,-.1899615893598122d-02/
         data arr1058/
     1      0.1743040538253303d-01,-.1066257315783913d+00,
     2      0.4891893232316509d+00,-.1795489006787503d+01,
     3      0.5491699703645104d+01,-.1439741657195892d+02,
     4      0.3302705853389981d+02,-.6734468610973983d+02,
     5      0.1235886478245744d+03,-.2061873423312389d+03,
     6      0.3153231629518493d+03,-.4451317269896296d+03,
     7      0.5834928208651291d+03,-.7138688391484144d+03,
     8      0.8187923489302053d+03,-.8838706059420016d+03/
         data arr1059/
     1      0.9011437826227224d+03,-.8702785895476597d+03,
     2      0.7985786168925724d+03,-.6974857590000267d+03,
     3      0.5818933473398473d+03,-.4633260897028667d+03,
     4      0.3544374713731100d+03,-.2583042976507764d+03,
     5      0.1825568822872738d+03,-.1211882399597040d+03,
     6      0.7970631269939216d+02,-.4703007958584507d+02,
     7      0.2900292085970315d+02,-.1405952217080306d+02,
     8      0.8198538969908327d+01,-.2666652196809858d+01/
         data arr1060/
     1      0.1480181489388222d+01,0.6224065425412925d-04,
     2      -.1205531963236847d-02,0.1167446505971003d-01,
     3      -.7537497200624292d-01,0.3649845804750477d+00,
     4      -.1413891320212054d+01,0.4564298599715440d+01,
     5      -.1262954289371160d+02,0.3057786627972598d+02,
     6      -.6580768402074122d+02,0.1274635468948917d+03,
     7      -.2244427691976886d+03,0.3622708998643365d+03,
     8      -.5397615751004540d+03,0.7467630065780286d+03/
         data arr1061/
     1      -.9642691825594271d+03,0.1167315390891595d+04,
     2      -.1329908575125734d+04,0.1431085020759532d+04,
     3      -.1458474502494409d+04,0.1412567792647904d+04,
     4      -.1301496277132382d+04,0.1146142078999243d+04,
     5      -.9617529135039413d+03,0.7767734485058895d+03,
     6      -.5951051120615219d+03,0.4442497855940533d+03,
     7      -.3083393327976630d+03,0.2143700665483086d+03,
     8      -.1309777555976053d+03,0.8547234333029223d+02/
         data arr1062/
     1      -.4226878105956836d+02,0.2611336957709844d+02,
     2      -.8547952587893388d+01,0.5030943287921957d+01,
     3      0.3716942585277849d-04,-.7582009990351252d-03,
     4      0.7731879929682280d-02,-.5257943213056140d-01,
     5      0.2681575621639958d+00,-.1094141089407414d+01,
     6      0.3720198238058662d+01,-.1084230221688165d+02,
     7      0.2764885110852736d+02,-.6267419239960996d+02,
     8      0.1278598561401192d+03,-.2371353637610583d+03/
         data arr1063/
     1      0.4031437539439158d+03,-.6326588124950218d+03,
     2      0.9219050899446552d+03,-.1253818266371126d+04,
     3      0.1598683078280641d+04,-.1918222134854590d+04,
     4      0.2174145834376321d+04,-.2333089625987938d+04,
     5      0.2380197369420925d+04,-.2307804221506718d+04,
     6      0.2141056239902834d+04,-.1887806205450597d+04,
     7      0.1606792726605769d+04,-.1289252690803237d+04,
     8      0.1014845033816596d+04,-.7329420808178342d+03/
         data arr1064/
     1      0.5378265934076765d+03,-.3384435088797516d+03,
     2      0.2333777041261890d+03,-.1171387843082052d+03,
     3      0.7656354855463161d+02,-.2513632353179479d+02,
     4      0.1566495599969144d+02,0.2206956367737030d-04,
     5      -.4729467719799048d-03,0.5064866142468926d-02,
     6      -.3620959037480915d-01,0.1941192443892970d+00,
     7      -.8326946905606430d+00,0.2976364047547460d+01,
     8      -.9119589675584200d+01,0.2444807505005266d+02/
         data arr1065/
     1      -.5826268692248996d+02,0.1249542095088905d+03,
     2      -.2436390701626962d+03,0.4354371611450840d+03,
     3      -.7183968793932353d+03,0.1100517600013685d+04,
     4      -.1573457361251445d+04,0.2109134229446511d+04,
     5      -.2660045460132167d+04,0.3169699422180862d+04,
     6      -.3573882540891940d+04,0.3833606979031711d+04,
     7      -.3901766474944535d+04,0.3806965998009440d+04,
     8      -.3516001936933516d+04,0.3148780523723893d+04/
         data arr1066/
     1      -.2635372545017941d+04,0.2184392764185103d+04,
     2      -.1633398491167850d+04,0.1263503132587335d+04,
     3      -.8144962219969075d+03,0.5928220565884401d+03,
     4      -.3005279153595978d+03,0.2075938283787686d+03,
     5      -.6813605372646576d+02,0.4491323692101395d+02,
     6      0.1310515608460201d-04,-.2935337862619775d-03,
     7      0.3283019790428458d-02,-.2463134374679805d-01,
     8      0.1385157662713496d+00,-.6236382320226966d+00/
         data arr1067/
     1      0.2339142522634580d+01,-.7522490887495747d+01,
     2      0.2116322639266907d+02,-.5293490819199907d+02,
     3      0.1191406951495468d+03,-.2438188214343488d+03,
     4      0.4573051255627680d+03,-.7918487849424660d+03,
     5      0.1273033394451885d+04,-.1910073627241236d+04,
     6      0.2687068095170449d+04,-.3555464189734741d+04,
     7      0.4446737051695555d+04,-.5256609995303605d+04,
     8      0.5919327019667029d+04,-.6307215903791230d+04/
         data arr1068/
     1      0.6462746838700829d+04,-.6230573742380212d+04,
     2      0.5863652012141876d+04,-.5096519175104284d+04,
     3      0.4443601693244393d+04,-.3422199321567917d+04,
     4      0.2788180365183074d+04,-.1831329965419236d+04,
     5      0.1405787825919543d+04,-.7163930140913193d+03,
     6      0.5225814440038232d+03,-.1709509240419167d+03,
     7      0.1190974715357725d+03,0.7993386251519555d-05,
     8      -.1836858986618878d-03,0.2109023720242215d-02/
         data arr1069/
     1      -.1657255595733607d-01,0.9747000996773812d-01,
     2      -.4599498343341095d+00,0.1806911622443053d+01,
     3      -.6090447932951401d+01,0.1795059284610764d+02,
     4      -.4705837542315899d+02,0.1109670624603012d+03,
     5      -.2380036700234761d+03,0.4677095267684560d+03,
     6      -.8487053170081673d+03,0.1429635623201023d+04,
     7      -.2247413057316306d+04,0.3312970951746473d+04,
     8      -.4590502882153607d+04,0.6017066752559803d+04/
         data arr1070/
     1      -.7440407143763709d+04,0.8783863433052540d+04,
     2      -.9769585870137396d+04,0.1050085290045805d+05,
     3      -.1052664499904125d+05,0.1040127534327470d+05,
     4      -.9343357374796455d+04,0.8563345242914886d+04,
     5      -.6755193142903811d+04,0.5793767593753058d+04,
     6      -.3856679974212293d+04,0.3120970574975036d+04,
     7      -.1591508057053777d+04,0.1225448334121581d+04,
     8      -.3983690340800430d+03,0.2931967640461994d+03/
         data arr1071/
     1      0.5521066457425924d-05,-.1215432067257889d-03,
     2      0.1351271638071270d-02,-.1107823514634647d-01,
     3      0.6769915719815800d-01,-.3344669998053723d+00,
     4      0.1372716718403672d+01,-.4844547537568030d+01,
     5      0.1493045788332338d+02,-.4097825995471791d+02,
     6      0.1010680105976539d+03,-.2269200445828685d+03,
     7      0.4664713418409846d+03,-.8858881960645249d+03,
     8      0.1561208258942460d+04,-.2567386263008211d+04/
         data arr1072/
     1      0.3960247372434697d+04,-.5735139211375720d+04,
     2      0.7868748715968587d+04,-.1015192673144934d+05,
     3      0.1255194588084130d+05,-.1452256981695578d+05,
     4      0.1636162559614619d+05,-.1697959667852097d+05,
     5      0.1760626450755246d+05,-.1625946701797539d+05,
     6      0.1566075579504060d+05,-.1258198638038726d+05,
     7      0.1135876370775228d+05,-.7622025354724827d+04,
     8      0.6501923426245664d+04,-.3302983020893023d+04/
         data arr1073/
     1      0.2684426560798022d+04,-.8646723797491426d+03,
     2      0.6722653726566282d+03,0.5332428574551115d-05,
     3      -.9652335093568040d-04,0.8836748227884091d-03,
     4      -.7466706980389188d-02,0.4655077686423296d-01,
     5      -.2405840955832856d+00,0.1026624744248921d+01,
     6      -.3791985197302445d+01,0.1218772273665478d+02,
     7      -.3500023794412935d+02,0.9010504143165589d+02,
     8      -.2116036433029294d+03,0.4542348144202309d+03/
         data arr1074/
     1      -.9018246573139737d+03,0.1660206681696908d+04,
     2      -.2851596853973656d+04,0.4596888459521231d+04,
     3      -.6942507695575104d+04,0.9960580363950221d+04,
     4      -.1336719726508741d+05,0.1729769437525731d+05,
     5      -.2073541460070137d+05,0.2447886448175286d+05,
     6      -.2616592061677059d+05,0.2847205659466299d+05,
     7      -.2687759317650004d+05,0.2721216502915836d+05,
     8      -.2213409714860138d+05,0.2104068270963700d+05/
         data arr1075/
     1      -.1415653234358953d+05,0.1273495140804877d+05,
     2      -.6416099231174997d+04,0.5506183407073620d+04,
     3      -.1752181131752485d+04,0.1439646275165890d+04,
     4      0.7961012549370113d-05,-.1082844208454724d-03,
     5      0.6323928912514375d-03,-.5292899030242513d-02,
     6      0.3197881397634049d-01,-.1726523138827923d+00,
     7      0.7573223228134968d+00,-.2929728461978182d+01,
     8      0.9772589137923644d+01,-.2937474784240759d+02/
         data arr1076/
     1      0.7869867734714187d+02,-.1932703879996568d+03,
     2      0.4323117347347007d+03,-.8965270782533858d+03,
     3      0.1721392420859959d+04,-.3083195708932743d+04,
     4      0.5188694452197785d+04,-.8151452077912239d+04,
     5      0.1222246503857382d+05,-.1699975532384159d+05,
     6      0.2302166783991097d+05,-.2845705076369192d+05,
     7      0.3521420105975884d+05,-.3854983842060590d+05,
     8      0.4405143133894907d+05,-.4224437757516136d+05/
         data arr1077/
     1      0.4500097352365828d+05,-.3682904081900406d+05,
     2      0.3690391177484669d+05,-.2475985733949206d+05,
     3      0.2351469219712811d+05,-.1169564512827570d+05,
     4      0.1061020430348219d+05,-.3325182701547184d+04,
     5      0.2890426578946746d+04,-.9742324302367947d-02,
     6      0.1571727704593235d-03,-.1552771919230969d-05,
     7      0.1120307884992225d-07,-.6390092809756416d-10,
     8      0.3018243562017107d-12,-.1232183684198048d-14/
         data arr1078/
     1      0.6742581036486928d-16,-.1259178648409336d-15,
     2      0.1123597027537310d-15,-.2781777561206733d-15,
     3      -.1514202006343196d-15,-.1432060056724122d-14,
     4      -.1914570401426547d-14,-.4169424709945276d-14,
     5      -.6522082304418540d-14,-.1480482455489022d-13,
     6      -.1624711753239717d-13,-.3852398771469863d-13,
     7      -.3046564847008656d-13,-.8759007437592315d-13,
     8      -.4895273228630359d-13,-.1537961259792355d-12/
         data arr1079/
     1      -.6822046187766882d-13,-.2216266811100519d-12,
     2      -.9516801178265473d-13,-.2472632774730116d-12,
     3      -.1127088509482129d-12,-.2170366652345979d-12,
     4      -.1339152523740872d-12,-.1312248418992968d-12,
     5      -.9454314149238012d-13,-.5180862779842193d-13,
     6      -.6450066426381485d-13,-.4795461750918857d-01,
     7      0.4039495810512568d-02,-.2083720798338307d-03,
     8      0.7849667392053030d-05,-.2337776519472706d-06/
         data arr1080/
     1      0.5765358631130236d-08,-.1214124419977185d-09,
     2      0.2232007487998434d-11,-.3702235591524754d-13,
     3      0.8673667488845791d-15,-.1928765034169853d-14,
     4      -.1657030377385139d-14,-.9231497537160466d-14,
     5      -.1457439306639964d-13,-.2142857842353688d-13,
     6      -.4958755076620768d-13,-.4096135187770919d-13,
     7      -.1313289170959972d-12,-.2719860175466100d-13,
     8      -.2743085368626321d-12,0.6172219415420446d-13/
         data arr1081/
     1      -.5217335159208600d-12,0.2902650806801271d-12,
     2      -.8696805802523577d-12,0.5969191137837346d-12,
     3      -.1325678797278746d-11,0.8476187200073573d-12,
     4      -.1613051723518695d-11,0.8377975551939542d-12,
     5      -.1668328956814941d-11,0.5590435759688419d-12,
     6      -.1099682104538719d-11,0.2194357439483970d-12,
     7      -.5740351484862347d-12,-.1046386877612548d+00,
     8      0.2133274204300186d-01,-.2663279295934825d-02/
         data arr1082/
     1      0.2428209243247852d-03,-.1750231563795027d-04,
     2      0.1044663723997013d-05,-.5324403019862718d-07,
     3      0.2368730970591016d-08,-.9351703810642247d-10,
     4      0.3319555885123589d-11,-.1076845350588875d-12,
     5      0.5955993869876697d-16,-.2774570268482798d-14,
     6      -.2244629874456002d-13,-.4016846620142514d-14,
     7      -.7680708019389673d-13,-.3090626116888668d-13,
     8      -.1883335829035115d-12,-.6203065275015424d-13/
         data arr1083/
     1      -.3988142556053527d-12,-.6467075729823836d-13,
     2      -.7746903418259813d-12,0.1021958529025520d-12,
     3      -.1398976255019537d-11,0.4842194760365419d-12,
     4      -.2250781716273603d-11,0.8726978486039660d-12,
     5      -.2858673619326313d-11,0.1031490590538921d-11,
     6      -.2942582646077078d-11,0.6846687076701826d-12,
     7      -.1928817307077363d-11,0.3179200574182278d-12,
     8      -.9288033933208633d-12,-.1647396111401982d+00/
         data arr1084/
     1      0.6110705995169268d-01,-.1388034866078206d-01,
     2      0.2302548175665994d-02,-.3019653314309659d-03,
     3      0.3279268990209978d-04,-.3040957869915776d-05,
     4      0.2461467518111653d-06,-.1768084983910399d-07,
     5      0.1141667758412976d-08,-.6696075886585241d-10,
     6      0.3592675974071177d-11,-.1944296482146134d-12,
     7      -.2453433835104054d-13,-.6202055976093896d-13,
     8      -.1143860922675985d-12,-.2661336617160951d-12/
         data arr1085/
     1      -.2971295588985333d-12,-.8195019256543273d-12,
     2      -.6642543547363871d-12,-.2008415105431216d-11,
     3      -.1307200903737334d-11,-.3781065966072127d-11,
     4      -.2273952416587611d-11,-.5538118358477811d-11,
     5      -.3405244698466461d-11,-.6309524405047306d-11,
     6      -.4013742885499039d-11,-.5338767816273723d-11,
     7      -.3870503680277260d-11,-.3204793539186037d-11,
     8      -.2406816370139483d-11,-.1056246384885496d-11/
         data arr1086/
     1      -.1148973383170648d-11,-.2150702550064873d+00,
     2      0.1249028673546156d+00,-.4442015817752220d-01,
     3      0.1153684763298216d-01,-.2368831785355113d-02,
     4      0.4027660774621103d-03,-.5847698226205644d-04,
     5      0.7410838748261933d-05,-.8334413764155806d-06,
     6      0.8425780678031265d-07,-.7737001770499828d-08,
     7      0.6508116142743335d-09,-.5055461646449686d-10,
     8      0.3616207421888513d-11,-.3822349559619586d-12/
         data arr1087/
     1      -.7723380768869937d-13,-.3018686575502322d-12,
     2      -.3650803104873719d-12,-.2139462976378332d-12,
     3      -.1303122174205365d-11,0.8839044107558974d-12,
     4      -.3727390265992542d-11,0.3976986939621845d-11,
     5      -.8225981145659895d-11,0.9222057505103512d-11,
     6      -.1407849511604686d-10,0.1386859412299474d-10,
     7      -.1796765301696899d-10,0.1534435399429632d-10,
     8      -.1743583051953511d-10,0.1060241622607771d-10/
         data arr1088/
     1      -.1105208070896817d-10,0.5023354112935476d-11,
     2      -.4631894528276244d-11,-.2475941439781110d+00,
     3      0.2051976651716326d+00,-.1041406046614142d+00,
     4      0.3859820772008195d-01,-.1130978090295130d-01,
     5      0.2744181568869014d-02,-.5685712530306578d-03,
     6      0.1028270311264317d-03,-.1650269894042222d-04,
     7      0.2380839136159096d-05,-.3119838432805945d-06,
     8      0.3745041655475467d-07,-.4147606679070524d-08/
         data arr1089/
     1      0.4263250057191696d-09,-.4100925585775756d-10,
     2      0.3660528058614895d-11,-.7525702334548435d-12,
     3      0.1897520892646146d-12,-.1134836332664503d-11,
     4      0.7124889340002660d-12,-.2359218210553788d-11,
     5      0.1673494382646791d-11,-.3752880955366166d-11,
     6      0.2535323639228369d-11,-.4719418777960691d-11,
     7      0.2527867923766544d-11,-.4490339565442965d-11,
     8      0.1350640562451960d-11,-.3160381811663448d-11/
         data arr1090/
     1      -.3052074600670023d-12,-.1487661910756543d-11,
     2      -.9445769388865500d-12,-.3809841176529453d-12,
     3      -.7320510158959638d-12,-.2599373106154539d+00,
     4      0.2887412397299892d+00,-.1964104751171655d+00,
     5      0.9757079409043286d-01,-.3831907717626398d-01,
     6      0.1246183056896663d-01,-.3460684808261724d-02,
     7      0.8388660043237527d-03,-.1804464839117387d-03,
     8      0.3489246484217645d-04,-.6128325862251832d-05/
         data arr1091/
     1      0.9859948547483917d-06,-.1463595172178839d-06,
     2      0.2016526893067449d-07,-.2592431577170701d-08,
     3      0.3124071399831233d-09,-.3594213218186127d-10,
     4      0.4338170490635794d-11,-.1753933973706686d-11,
     5      0.1838236615418970d-11,-.2889243060886942d-11,
     6      0.4100132320588596d-11,-.4746182286408143d-11,
     7      0.6944357549441828d-11,-.6301972817891674d-11,
     8      0.9299676226208672d-11,-.6578952742917529d-11/
         data arr1092/
     1      0.9755372678551473d-11,-.5608937777726970d-11,
     2      0.8244684664017897d-11,-.3343272414617245d-11,
     3      0.4893683683299843d-11,-.1585875587266153d-11,
     4      0.2181147221616998d-11,-.2540964977541191d+00,
     5      0.3616410958797465d+00,-.3151900564047200d+00,
     6      0.2006164786998639d+00,-.1009486945730823d+00,
     7      0.4206359718607587d-01,-.1496668147482400d-01,
     8      0.4648308739524485d-02,-.1281119664408161d-02/
         data arr1093/
     1      0.3174035829673090d-03,-.7142675609131327d-04,
     2      0.1472423134237858d-04,-.2800384832832774d-05,
     3      0.4943563069653232d-06,-.8142467080817360d-07,
     4      0.1256960348921384d-07,-.1826152890038603d-08,
     5      0.2505131339821123d-09,-.3376701717611256d-10,
     6      0.4903395403603528d-11,-.4029597133960241d-11,
     7      0.2938968812177899d-11,-.7661644728725917d-11,
     8      0.5740556044985657d-11,-.1244475413579554d-10/
         data arr1094/
     1      0.8452818235138256d-11,-.1554142049840195d-10,
     2      0.9254235796798775d-11,-.1464421227257213d-10,
     3      0.7563819270819177d-11,-.9438249866939890d-11,
     4      0.4277620827011926d-11,-.3980127820138376d-11,
     5      0.1446979058542751d-11,-.2345295801184854d+00,
     6      0.4134544945924338d+00,-.4463478453918933d+00,
     7      0.3518994045120175d+00,-.2193328237160468d+00,
     8      0.1132036230109489d+00,-.4989194402938307d-01/
         data arr1095/
     1      0.1919335386911312d-01,-.6552342578955998d-02,
     2      0.2010803892249010d-02,-.5604925094299217d-03,
     3      0.1431174247431337d-03,-.3371542133390066d-04,
     4      0.7372283101858604d-05,-.1504072421179079d-05,
     5      0.2876003952509519d-06,-.5174713179074313d-07,
     6      0.8792000488036064d-08,-.1415234635668722d-08,
     7      0.2165097754582763d-09,-.3129519268974397d-10,
     8      0.3373920418465552d-11,0.1757852787968283d-11/
         data arr1096/
     1      -.4604202848256087d-11,0.6217024983988994d-11,
     2      -.1022585986672098d-10,0.1006360464754268d-10,
     3      -.1466841000005507d-10,0.1084864458996378d-10,
     4      -.1433603892586618d-10,0.7539975294062710d-11,
     5      -.9029739930762500d-11,0.2883370654366414d-11,
     6      -.3100112908759524d-11,-.2064343720971968d+00,
     7      0.4391039533255842d+00,-.5719635032404118d+00,
     8      0.5440873790199379d+00,-.4091749093581177d+00/
         data arr1097/
     1      0.2548126219101742d+00,-.1355021798227158d+00,
     2      0.6289584712857332d-01,-.2590734695467198d-01,
     3      0.9592930716406451d-02,-.3226314118973529d-02,
     4      0.9939959018304878d-03,-.2825373821784024d-03,
     5      0.7454260662738560d-04,-.1834959709987182d-04,
     6      0.4233527789333149d-05,-.9190777276680969d-06,
     7      0.1884072745478170d-06,-.3658429330425178d-07,
     8      0.6748378105975769d-08,-.1185206411982167d-08/
         data arr1098/
     1      0.1998686168745470d-09,-.3109621595898483d-10,
     2      0.5893214663760820d-11,0.1247993476137440d-11,
     3      0.3492403557586247d-12,0.3260496998477033d-11,
     4      -.8103899334967473d-12,0.3101073964116490d-11,
     5      -.7536913350353049d-12,0.2084686137798379d-11,
     6      -.3177544378318045d-12,0.3188083303333433d-12,
     7      0.5270703485405891d-12,-.1745660270431021d+00,
     8      0.4387564047161601d+00,-.6753094765526347d+00/
         data arr1099/
     1      0.7590695729320829d+00,-.6745285416804555d+00,
     2      0.4963530299248043d+00,-.3118849563237301d+00,
     3      0.1710600210125463d+00,-.8325836845232185d-01,
     4      0.3642794459636451d-01,-.1447666127603612d-01,
     5      0.5270171677974627d-02,-.1770086502603134d-02,
     6      0.5518252305499980d-03,-.1605099328910172d-03,
     7      0.4375787210840406d-04,-.1122494791088479d-04,
     8      0.2718990188571664d-05,-.6238518656483103d-06/
         data arr1100/
     1      0.1359659091902753d-06,-.2822030199824131d-07,
     2      0.5596482847938843d-08,-.1063541963560985d-08,
     3      0.2020880251864906d-09,-.3825329382955930d-10,
     4      0.1541092283688582d-10,-.3446689638984076d-11,
     5      0.6456131820475143d-11,0.6719296514181279d-12,
     6      0.2077251973895729d-11,0.2186797394198968d-11,
     7      -.2896736206226713d-12,0.1500199125998838d-11,
     8      -.2377508712152597d-12,-.1426256667272643d+00/
         data arr1101/
     1      0.4164415046102256d+00,-.7446050204504797d+00,
     2      0.9722932645459277d+00,-.1003710813482466d+01,
     3      0.8580083760554171d+00,-.6263078506338547d+00,
     4      0.3990566270712296d+00,-.2256350069130349d+00,
     5      0.1146847916708558d+00,-.5294587788533404d-01,
     6      0.2239139140690854d-01,-.8736618812138821d-02,
     7      0.3164047745674233d-02,-.1069143416464355d-02,
     8      0.3385967794518355d-03,-.1009028721774811d-03/
         data arr1102/
     1      0.2839351953194387d-04,-.7568067323385416d-05,
     2      0.1916089344374645d-05,-.4619632186307480d-06,
     3      0.1063037334568197d-06,-.2339585042590223d-07,
     4      0.4927967590618778d-08,-.9931920260409987d-09,
     5      0.1775645201245484d-09,-.2391333601586302d-10,
     6      -.1952577504445778d-10,0.1506390899932398d-10,
     7      -.2726997877063214d-10,0.1275696803363894d-10,
     8      -.1818883633197068d-10,0.6008155917289338d-11/
         data arr1103/
     1      -.7060270796738234d-11,-.1130954513942811d+00,
     2      0.3782484812165270d+00,-.7746845261734016d+00,
     3      0.1158702472521022d+01,-.1370121226837380d+01,
     4      0.1341583333869037d+01,-.1121733571521489d+01,
     5      0.8186761243691567d+00,-.5302245270131500d+00,
     6      0.3086987692416482d+00,-.1632438981544665d+00,
     7      0.7907908217643837d-01,-.3534269485993451d-01,
     8      0.1466138632150567d-01,-.5674710494917846d-02/
         data arr1104/
     1      0.2058573140606435d-02,-.7026883291397273d-03,
     2      0.2264926770101555d-03,-.6915054492460097d-04,
     3      0.2005404269690530d-04,-.5538198639767744d-05,
     4      0.1459787666998760d-05,-.3680193379432853d-06,
     5      0.8891260603081071d-07,-.2062287599297117d-07,
     6      0.4600349983875590d-08,-.9893121947104981d-09,
     7      0.1994457792940419d-09,-.3833514848767855d-10,
     8      -.3757441057649019d-11,0.2711371643976624d-11/
         data arr1105/
     1      -.9949163972434733d-11,0.2996326242608234d-11,
     2      -.5423761038435062d-11,-.8735255034612610d-01,
     3      0.3307060585595654d+00,-.7666980298676158d+00,
     4      0.1298093296668834d+01,-.1737510652405756d+01,
     5      0.1925841952653625d+01,-.1822750449320393d+01,
     6      0.1505858375165551d+01,-.1103993012711715d+01,
     7      0.7275718988740267d+00,-.4355243922069471d+00,
     8      0.2388205279586292d+00,-.1208214943029780d+00/
         data arr1106/
     1      0.5673539548222984d-01,-.2485748962621463d-01,
     2      0.1020738195479385d-01,-.3944076335293895d-02,
     3      0.1439034615726415d-02,-.4973328914799418d-03,
     4      0.1632630624359716d-03,-.5103743513365578d-04,
     5      0.1522799385864573d-04,-.4345640833970736d-05,
     6      0.1188364331403062d-05,-.3119594012423713d-06,
     7      0.7873495551710138d-07,-.1914145021188268d-07,
     8      0.4473488350952948d-08,-.1013122925439639d-08/
         data arr1107/
     1      0.2017005631052148d-09,-.4148412877492383d-10,
     2      -.7516683317307848d-11,0.2666054533691384d-11,
     3      -.8551727844608023d-11,-.6591443365527747d-01,
     4      0.2796444060707164d+00,-.7265196774070523d+00,
     5      0.1378440391906467d+01,-.2067609925977393d+01,
     6      0.2568152593634103d+01,-.2723870429129730d+01,
     7      0.2521752202901621d+01,-.2071780084889178d+01,
     8      0.1530073506955804d+01,-.1026379362643014d+01/
         data arr1108/
     1      0.6307047925228638d+00,-.3575672454574218d+00,
     2      0.1881597216340053d+00,-.9238232572578316d-01,
     3      0.4251136401267023d-01,-.1840750956151057d-01,
     4      0.7526273780370617d-02,-.2914841884362059d-02,
     5      0.1072296269932296d-02,-.3756424871165444d-03,
     6      0.1255993594965592d-03,-.4016584234513024d-04,
     7      0.1230863073533871d-04,-.3620812867200605d-05,
     8      0.1024106333046991d-05,-.2789274873187137d-06/
         data arr1109/
     1      0.7324852605700410d-07,-.1857893040260044d-07,
     2      0.4542936657934982d-08,-.1076862919111262d-08,
     3      0.2361062751289177d-09,-.4924348695528234d-10,
     4      0.3828090452864374d-11,-.4871172370671687d-01,
     5      0.2295908576995681d+00,-.6626608558829344d+00,
     6      0.1396778069540253d+01,-.2327574051583186d+01,
     7      0.3211820049711947d+01,-.3784533085042270d+01,
     8      0.3892456354992589d+01,-.3552715888565213d+01/
         data arr1110/
     1      0.2914906314709754d+01,-.2172279472011267d+01,
     2      0.1482959872274776d+01,-.9340206515777594d+00,
     3      0.5460355179887143d+00,-.2978369694009553d+00,
     4      0.1522615456135157d+00,-.7324461663682107d-01,
     5      0.3327025804097314d-01,-.1431484463371394d-01,
     6      0.5850350846918678d-02,-.2276865041366426d-02,
     7      0.8457567070305227d-03,-.3004762277768344d-03,
     8      0.1022958425492688d-03,-.3343072120121851d-04/
         data arr1111/
     1      0.1050451629044133d-04,-.3178075074929446d-05,
     2      0.9271836189140865d-06,-.2609145582388909d-06,
     3      0.7103060008467436d-07,-.1848785605945900d-07,
     4      0.4708563336539712d-08,-.1026303225060543d-08,
     5      0.2399616702715955d-09,-.3532933225350350d-01,
     6      0.1836052077562008d+00,-.5843192518035825d+00,
     7      0.1358046871797370d+01,-.2495280267508052d+01,
     8      0.3796605772058914d+01,-.4932704265010114d+01/
         data arr1112/
     1      0.5594032658014188d+01,-.5629764103422416d+01,
     2      0.5093106924882182d+01,-.4185066511513702d+01,
     3      0.3150246511515984d+01,-.2187762087667322d+01,
     4      0.1410239841354067d+01,-.8481626902526208d+00,
     5      0.4781005769600540d+00,-.2535906386538059d+00,
     6      0.1270112382118493d+00,-.6025611008696260d-01,
     7      0.2715343881069153d-01,-.1165221987853912d-01,
     8      0.4772493067195039d-02,-.1869554791032310d-02/
         data arr1113/
     1      0.7018019200534477d-03,-.2528876531534448d-03,
     2      0.8761669098571786d-04,-.2922588593631022d-04,
     3      0.9401691293043669d-05,-.2914954195524087d-05,
     4      0.8752512121804057d-06,-.2497432652747522d-06,
     5      0.7035765932795340d-07,-.1645616950849358d-07,
     6      0.4370474836201677d-08,-.2519112802544240d-01,
     7      0.1434059219800639d+00,-.4999219328528210d+00,
     8      0.1272731108885871d+01,-.2561598952396162d+01/
         data arr1114/
     1      0.4269305305496046d+01,-.6075984994902779d+01,
     2      0.7547906578926643d+01,-.8320733663834188d+01,
     3      0.8245635294702565d+01,-.7421874344107129d+01,
     4      0.6119637212135475d+01,-.4655337098474362d+01,
     5      0.3287107648065532d+01,-.2165558977495031d+01,
     6      0.1337149677764988d+01,-.7768977757054190d+00,
     7      0.4262287253270698d+00,-.2214988916830030d+00,
     8      0.1093365106025983d+00,-.5139476584704245d-01/
         data arr1115/
     1      0.2305820228626830d-01,-.9894357314084763d-02,
     2      0.4068496889391137d-02,-.1605869065956993d-02,
     3      0.6094534050701556d-03,-.2226522036866465d-03,
     4      0.7845940724935524d-04,-.2661580864462277d-04,
     5      0.8755326037572855d-05,-.2717012507124861d-05,
     6      0.8390525311954139d-06,-.2089494071005998d-06,
     7      0.6094855856423817d-07,-.1768546218562570d-01,
     8      0.1096445825927907d+00,-.4162685277511829d+00/
         data arr1116/
     1      0.1154142249389313d+01,-.2529793722120925d+01,
     2      0.4591794888518588d+01,-.7116939164766212d+01,
     3      0.9628405465384743d+01,-.1155954577692620d+02,
     4      0.1247540242611702d+02,-.1222912355146353d+02,
     5      0.1098142515449604d+02,-.9097780552288580d+01,
     6      0.6995995851037005d+01,-.5019459170463364d+01,
     7      0.3375345452495919d+01,-.2135764551879149d+01,
     8      0.1276096464232348d+01,-.7222102127133532d+00/
         data arr1117/
     1      0.3882474175629756d+00,-.1987528580877317d+00,
     2      0.9711163650070248d-01,-.4538193952369943d-01,
     3      0.2032268646321837d-01,-.8735624274765902d-02,
     4      0.3610591477077554d-02,-.1436154039117545d-02,
     5      0.5511725871173156d-03,-.2032739145751371d-03,
     6      0.7283644555791668d-04,-.2439456496659376d-04,
     7      0.8209889495212203d-05,-.2159313369733915d-05,
     8      0.6867979246687889d-06,-.1224030117415776d-01/
         data arr1118/
     1      0.8222076147182339d-01,-.3382100582714921d+00,
     2      0.1015993449438886d+01,-.2412877675002108d+01,
     3      0.4745164811124905d+01,-.7968575661049007d+01,
     4      0.1168047338054847d+02,-.1519376722921591d+02,
     5      0.1776633674477472d+02,-.1886936496940828d+02,
     6      0.1835858835749885d+02,-.1647914447708560d+02,
     7      0.1372989998946814d+02,-.1067316890575426d+02,
     8      0.7776305435544789d+01,-.5331225810307274d+01/
         data arr1119/
     1      0.3451245369318924d+01,-.2116286837812684d+01,
     2      0.1232645295220300d+01,-.6836929135607881d+00,
     3      0.3619409477528492d+00,-.1832585111103538d+00,
     4      0.8891637465982949d-01,-.4140793406874477d-01,
     5      0.1854352195709913d-01,-.7987957160748920d-02,
     6      0.3321780936522190d-02,-.1324005222773991d-02,
     7      0.5141596058517439d-03,-.1845006228000351d-03,
     8      0.6733356751607855d-04,-.1856525907465609d-04/
         data arr1120/
     1      0.6406446268293620d-05,-.8360716491968208d-02,
     2      0.6057056635090805d-01,-.2687171630316324d+00,
     3      0.8706198026115858d+00,-.2229983682292558d+01,
     4      0.4729839761077341d+01,-.8566522778305643d+01,
     5      0.1354294342213731d+02,-.1899970402051014d+02,
     6      0.2396116904332732d+02,-.2744707979788631d+02,
     7      0.2880095516133098d+02,-.2788245532634933d+02,
     8      0.2505488848703493d+02,-.2100618702615162d+02/
         data arr1121/
     1      0.1650653446365148d+02,-.1220501729922201d+02,
     2      0.8521497293650341d+01,-.5635639311500094d+01,
     3      0.3540263397395372d+01,-.2117805255284565d+01,
     4      0.1209182182698888d+01,-.6602949417431461d+00,
     5      0.3455304802715687d+00,-.1735240986721654d+00,
     6      0.8381237844320527d-01,-.3890939915241343d-01,
     7      0.1745294211131876d-01,-.7476092226038081d-02,
     8      0.3132472438068301d-02,-.1195955773431234d-02/
         data arr1122/
     1      0.4712382003310700d-03,-.1352876644346681d-03,
     2      0.5042745386622804d-04,-.5641172032148707d-02,
     3      0.4389694265372140d-01,-.2091774366695492d+00,
     4      0.7279386248477369d+00,-.2002694475601194d+01,
     5      0.4562535266390263d+01,-.8875874900198617d+01,
     6      0.1507184622603205d+02,-.2271156272122497d+02,
     7      0.3076486241714805d+02,-.3785209411729795d+02,
     8      0.4266261274997216d+02,-.4436274031586524d+02/
         data arr1123/
     1      0.4281802345324088d+02,-.3855921247961494d+02,
     2      0.3254495114110421d+02,-.2584716126216987d+02,
     3      0.1938372203767803d+02,-.1376926579930189d+02,
     4      0.9290735481047712d+01,-.5969586244951171d+01,
     5      0.3660981742750036d+01,-.2147195094845895d+01,
     6      0.1206899519403659d+01,-.6508580949525100d+00,
     7      0.3376773020388713d+00,-.1681816128309875d+00,
     8      0.8104384215634663d-01,-.3710771457684728d-01/
         data arr1124/
     1      0.1670971214676875d-01,-.6742442495553586d-02,
     2      0.2857330187420737d-02,-.8488838182863090d-03,
     3      0.3404578635892719d-03,-.3762765931068059d-02,
     4      0.3133404528815615d-01,-.1597869712648693d+00,
     5      0.5950666710129656d+00,-.1751983038709365d+01,
     6      0.4271355969343174d+01,-.8892319113114933d+01,
     7      0.1615900651383754d+02,-.2605790849705325d+02,
     8      0.3777390191708446d+02,-.4973603021504638d+02/
         data arr1125/
     1      0.5998918886980314d+02,-.6675568249106864d+02,
     2      0.6895104057876492d+02,-.6644872898146325d+02,
     3      0.6001868645626080d+02,-.5101053349627174d+02,
     4      0.4093818431304807d+02,-.3112040826995516d+02,
     5      0.2247135684251801d+02,-.1545114033577455d+02,
     6      0.1014051797188673d+02,-.6364140685014498d+01,
     7      0.3828183738407394d+01,-.2208347815814320d+01,
     8      0.1226206900047892d+01,-.6523716140384678d+00/
         data arr1126/
     1      0.3365163511863374d+00,-.1638279765736465d+00,
     2      0.7900813945588014d-01,-.3347646515315968d-01,
     3      0.1520628318864525d-01,-.4648799640985057d-02,
     4      0.1999255632040953d-02,-.2482791281946116d-02,
     5      0.2205197514346574d-01,-.1199417594597991d+00,
     6      0.4764229769787656d+00,-.1496080603498630d+01,
     7      0.3890351864280543d+01,-.8638457082006768d+01,
     8      0.1674302082613893d+02,-.2879762959620293d+02/
         data arr1127/
     1      0.4452532058067509d+02,-.6252941305561946d+02,
     2      0.8044225603215273d+02,-.9547672524778953d+02,
     3      0.1051836209479187d+03,-.1081164865486715d+03,
     4      0.1041573137644134d+03,-.9441927078878287d+02,
     5      0.8082161727393444d+02,-.6552984653684595d+02,
     6      0.5046869892970856d+02,-.3701139154943572d+02,
     7      0.2590820681547808d+02,-.1733965139221842d+02,
     8      0.1112523274193402d+02,-.6840211795580354d+01/
         data arr1128/
     1      0.4051597140341940d+01,-.2292915713127896d+01,
     2      0.1262077194540476d+01,-.6498655498937415d+00,
     3      0.3346200063550544d+00,-.1479579136905464d+00,
     4      0.7182221768241437d-01,-.2247920561271298d-01,
     5      0.1033468256745174d-01,-.1621444287670213d-02,
     6      0.1531432485037218d-01,-.8857463005577068d-01,
     7      0.3741279816769763d+00,-.1249312416213421d+01,
     8      0.3454566114872278d+01,-.8156979666878561d+01/
         data arr1129/
     1      0.1681185275345546d+02,-.3074872277676900d+02,
     2      0.5055521377524778d+02,-.7549737183844013d+02,
     3      0.1032809619445957d+03,-.1303533245424921d+03,
     4      0.1527078161327824d+03,-.1669142540788846d+03,
     5      0.1709936131135898d+03,-.1648306191244257d+03,
     6      0.1500354166688570d+03,-.1293559883520823d+03,
     7      0.1059400778320853d+03,-.8260924712636486d+02,
     8      0.6149337606759250d+02,-.4375039457144602d+02/
         data arr1130/
     1      0.2985193395926618d+02,-.1949456883905033d+02,
     2      0.1228180206291138d+02,-.7362746227135156d+01,
     3      0.4312233999291546d+01,-.2336206367606792d+01,
     4      0.1280891946089568d+01,-.5875087929611948d+00,
     5      0.3039666341861000d+00,-.9694384046844497d-01,
     6      0.4751758842080278d-01,-.1048528241402884d-02,
     7      0.1050209113133259d-01,-.6441504150399997d-01,
     8      0.2885347285512954d+00,-.1021760183866463d+01/
         data arr1131/
     1      0.2996204114862503d+01,-.7502522281488043d+01,
     2      0.1639809715345017d+02,-.3180570331938922d+02,
     3      0.5545539771395948d+02,-.8782330290878573d+02,
     4      0.1274084231521833d+03,-.1705296744403937d+03,
     5      0.2118551669925091d+03,-.2455673323106133d+03,
     6      0.2667824090652660d+03,-.2727165590036981d+03,
     7      0.2632500867545918d+03,-.2406824674594638d+03,
     8      0.2090370533655635d+03,-.1728321681422422d+03/
         data arr1132/
     1      0.1364403492827428d+03,-.1028849831592021d+03,
     2      0.7445642523304095d+02,-.5146911005609941d+02,
     3      0.3440012339485843d+02,-.2175259032396321d+02,
     4      0.1352280501232054d+02,-.7667400880881076d+01,
     5      0.4465814546269407d+01,-.2112582950637330d+01,
     6      0.1162287047371677d+01,-.3761152956259164d+00,
     7      0.1960839517518380d+00,-.6716109000987170d-03,
     8      0.7115926533111433d-02,-.4617024376464214d-01/
         data arr1133/
     1      0.2187720653800667d+00,-.8195245089873862d+00,
     2      0.2542162658369089d+01,-.6733772840598805d+01,
     3      0.1556910260714391d+02,-.3194437612384600d+02,
     4      0.5891856393656243d+02,-.9870460208955244d+02,
     5      0.1514762889092317d+03,-.2144694945418518d+03,
     6      0.2818535793815172d+03,-.3455989949586362d+03,
     7      0.3971719174508676d+03,-.4294800870455635d+03,
     8      0.4385527728343560d+03,-.4241121164795483d+03/
         data arr1134/
     1      0.3896634074579432d+03,-.3407074076850454d+03,
     2      0.2845476242356397d+03,-.2267601610740798d+03,
     3      0.1736358550007882d+03,-.1266179020721659d+03,
     4      0.8957415958676111d+02,-.5948462353852798d+02,
     5      0.3916754590647692d+02,-.2311868449142429d+02,
     6      0.1427531144589186d+02,-.6926368732644382d+01,
     7      0.4044115527123431d+01,-.1322634880535850d+01,
     8      0.7318908263550838d+00,-.4262024886575136d-03/
         data arr1135/
     1      0.4766054598210284d-02,-.3263812842593643d-01,
     2      0.1632258705283980d+00,-.6453488594042414d+00,
     3      0.2112858435540600d+01,-.5906919855490284d+01,
     4      0.1441453631570904d+02,-.3121527643071082d+02,
     5      0.6076581484936893d+02,-.1074435269620531d+03,
     6      0.1740290834340272d+03,-.2600623970455044d+03,
     7      0.3607199091217150d+03,-.4668201657639671d+03,
     8      0.5662283699807334d+03,-.6462054365763282d+03/
         data arr1136/
     1      0.6964512658558776d+03,-.7107390010058675d+03,
     2      0.6892503606850831d+03,-.6357233576001336d+03,
     3      0.5604588199494881d+03,-.4706599324178482d+03,
     4      0.3805288260503194d+03,-.2916791319277850d+03,
     5      0.2179773338524402d+03,-.1513276760474701d+03,
     6      0.1053460375479446d+03,-.6438393174156526d+02,
     7      0.4207482291992685d+02,-.2082792263205563d+02,
     8      0.1288363533035827d+02,-.4243216190745686d+01/
         data arr1137/
     1      0.2487755343713857d+01,-.2680058285061908d-03,
     2      0.3156435414382868d-02,-.2276691784077448d-01,
     3      0.1199230151890313d+00,-.4994004925985502d+00,
     4      0.1722112712215270d+01,-.5070995794677379d+01,
     5      0.1303376486810326d+02,-.2972881533935820d+02,
     6      0.6095462924061772d+02,-.1135190103840196d+03,
     7      0.1936631901864729d+03,-.3048184940222187d+03,
     8      0.4453193001324961d+03,-.6069866027195174d+03/
         data arr1138/
     1      0.7754653510876524d+03,-.9320416854435593d+03,
     2      0.1058055145637737d+04,-.1136895205647723d+04,
     3      0.1161373208447131d+04,-.1127161781074269d+04,
     4      0.1046938211080167d+04,-.9237238478062435d+03,
     5      0.7871187982661429d+03,-.6317912585923854d+03,
     6      0.4979418549721935d+03,-.3596544611368292d+03,
     7      0.2643104298376175d+03,-.1663622792201215d+03,
     8      0.1148957813213440d+03,-.5773353275278703d+02/
         data arr1139/
     1      0.3778099352137633d+02,-.1248876860590036d+02,
     2      0.7746005930055105d+01,-.1670296454642460d-03,
     3      0.2067425480397654d-02,-.1567722015242796d-01,
     4      0.8681051597929976d-01,-.3800580782793477d+00,
     5      0.1377774406432921d+01,-.4265214735819246d+01,
     6      0.1152484045076581d+02,-.2763590979898221d+02,
     7      0.5956904465869079d+02,-.1166305334252753d+03,
     8      0.2091746286431221d+03,-.3461194568734599d+03/
         data arr1140/
     1      0.5315901802555393d+03,-.7616987751852427d+03,
     2      0.1023048104562173d+04,-.1292405782715364d+04,
     3      0.1542500363502822d+04,-.1741350223569509d+04,
     4      0.1870460571076612d+04,-.1905383029936813d+04,
     5      0.1861439441556834d+04,-.1720048629100149d+04,
     6      0.1542407425061737d+04,-.1291124401951686d+04,
     7      0.1071753438581344d+04,-.8013273626917380d+03,
     8      0.6209526201572041d+03,-.4003503406822205d+03/
         data arr1141/
     1      0.2918804324760323d+03,-.1481570300153410d+03,
     2      0.1024519290973645d+03,-.3388474313998793d+02,
     3      0.2220576441093721d+02,-.1032555904915606d-03,
     4      0.1339391600874903d-02,-.1065997871515733d-01,
     5      0.6193937838778043d-01,-.2846124976424083d+00,
     6      0.1082769263618658d+01,-.3518085593840014d+01,
     7      0.9976162532005468d+01,-.2510777167274080d+02,
     8      0.5679648468605913d+02,-.1167113774695981d+03/
         data arr1142/
     1      0.2196744066506624d+03,-.3814856121282489d+03,
     2      0.6149024098395181d+03,-.9245733132152166d+03,
     3      0.1303321635230600d+04,-.1727234325543651d+04,
     4      0.2163826226501963d+04,-.2560772856803885d+04,
     5      0.2887876150552648d+04,-.3079261820071119d+04,
     6      0.3159694148805965d+04,-.3047027284875510d+04,
     7      0.2871986742105714d+04,-.2496002115071070d+04,
     8      0.2180054117490520d+04,-.1678392397241015d+04/
         data arr1143/
     1      0.1370240628294760d+04,-.9000984719618920d+03,
     2      0.6921717185229954d+03,-.3532688093437346d+03,
     3      0.2579176145881559d+03,-.8510023668460506d+02,
     4      0.5886739665249200d+02,-.6353999394327891d-04,
     5      0.8585005650635719d-03,-.7160931231748659d-02,
     6      0.4357106967055623d-01,-.2098359495473639d+00,
     7      0.8363167190798676d+00,-.2847913208504483d+01,
     8      0.8461215622166689d+01,-.2231785444296287d+02/
         data arr1144/
     1      0.5289697429377836d+02,-.1139142791330985d+03,
     2      0.2246584108384662d+03,-.4088188668054047d+03,
     3      0.6904923463173251d+03,-.1087659926440218d+04,
     4      0.1606751226930436d+04,-.2229493735183315d+04,
     5      0.2927603792366775d+04,-.3623403793427682d+04,
     6      0.4284758882706319d+04,-.4767611826427642d+04,
     7      0.5133080654867047d+04,-.5145441104864988d+04,
     8      0.5093627064506816d+04,-.4573601808291078d+04/
         data arr1145/
     1      0.4200628244015849d+04,-.3311727797247958d+04,
     2      0.2847094921505188d+04,-.1895365697036158d+04,
     3      0.1536598152559261d+04,-.7850216043609007d+03,
     4      0.6047763280015649d+03,-.1985163700647498d+03,
     5      0.1448546165519801d+03,-.3946631301527804d-04,
     6      0.5451203924354383d-03,-.4759235478502291d-02,
     7      0.3022696137195225d-01,-.1524103832048092d+00,
     8      0.6351300347798667d+00,-.2264253610808550d+01/
         data arr1146/
     1      0.7036271042999468d+01,-.1942800389540479d+02,
     2      0.4817059214385586d+02,-.1085767167882078d+03,
     3      0.2240283323062459d+03,-.4265892076604923d+03,
     4      0.7539070555136834d+03,-.1242027053968059d+04,
     5      0.1920276811229829d+04,-.2784077071429637d+04,
     6      0.3827612694974440d+04,-.4940997435988887d+04,
     7      0.6121139772803894d+04,-.7082282824579714d+04,
     8      0.7995609451786353d+04,-.8293566929050819d+04/
         data arr1147/
     1      0.8619525922323537d+04,-.7953589204325426d+04,
     2      0.7680230863111719d+04,-.6165078631677272d+04,
     3      0.5580706951807195d+04,-.3745241343892480d+04,
     4      0.3200604350971802d+04,-.1629645663860042d+04,
     5      0.1324507833862412d+04,-.4313474834852559d+03,
     6      0.3319026427945016d+03,-.2591242028228551d-04,
     7      0.3447975632345980d-03,-.3145162968062260d-02,
     8      0.2069873247271502d-01,-.1092236604347921d+00/
         data arr1148/
     1      0.4744692854808617d+00,-.1769861445013049d+01,
     2      0.5740446086243844d+01,-.1657946173794781d+02,
     3      0.4292743499434420d+02,-.1011740474201668d+03,
     4      0.2180676838385921d+03,-.4339457320027457d+03,
     5      0.8013971011863736d+03,-.1378423201710956d+04,
     6      0.2228030135119055d+04,-.3367183631345298d+04,
     7      0.4842910315236370d+04,-.6499425297574196d+04,
     8      0.8431339519636853d+04,-.1010136726447605d+05/
         data arr1149/
     1      0.1195637619344512d+05,-.1276689601570907d+05,
     2      0.1393251816064245d+05,-.1313516647877952d+05,
     3      0.1333949268281012d+05,-.1083792702741614d+05,
     4      0.1033379933916615d+05,-.6954323937714767d+04,
     5      0.6266445309082696d+04,-.3166325668909084d+04,
     6      0.2715552716090770d+04,-.8750308351679179d+03,
     7      0.7100448599405856d+03,-.2014609650824439d-04,
     8      0.2214544837597938d-03,-.2098760022137167d-02/
         data arr1150/
     1      0.1402749190807463d-01,-.7751584065468928d-01,
     2      0.3488161384402690d+00,-.1362172720976395d+01,
     3      0.4595613241129703d+01,-.1388398305065919d+02,
     4      0.3745290061032461d+02,-.9225005695790986d+02,
     5      0.2073549698492731d+03,-.4307202294222203d+03,
     6      0.8302216447936989d+03,-.1488046210952116d+04,
     7      0.2512730050009434d+04,-.3947177239325378d+04,
     8      0.5937550992338757d+04,-.8251981044484977d+04/
         data arr1151/
     1      0.1121174638275785d+05,-.1384017710930963d+05,
     2      0.1718561433483943d+05,-.1878005114234915d+05,
     3      0.2153952522400895d+05,-.2061781345494853d+05,
     4      0.2204410161071383d+05,-.1801597810359764d+05,
     5      0.1811328120819233d+05,-.1215815910641103d+05,
     6      0.1156295150513013d+05,-.5772587445413427d+04,
     7      0.5228707203142219d+04,-.1662328921312127d+04,
     8      0.1423532210463707d+04,0.7858638522966330d-04/
         data arr1152/
     1      -.9820591903064170d-06,0.7921773023828615d-08,
     2      -.4830455668870344d-10,0.2386098468400567d-12,
     3      -.9937931128417416d-15,0.3666388932115541d-17,
     4      0.5869269736887582d-18,-.1670512496255046d-18,
     5      0.1833379300988933d-17,-.5499992544728653d-18,
     6      0.5497550896265661d-17,0.1199458342957312d-17,
     7      0.1446431378385533d-16,0.1316012223784597d-16,
     8      0.2500598001353642d-16,0.4068355367252366d-16/
         data arr1153/
     1      0.2928108831795251d-16,0.8056008897359873d-16,
     2      -.1854442821591806d-16,0.1033191006591797d-15,
     3      -.1029070325606789d-15,0.1106189242729578d-15,
     4      -.2729334024194375d-15,0.8486740363898914d-16,
     5      -.3420485350776379d-15,0.1099707612541164d-15,
     6      -.4414080743147649d-15,0.8098582115636963d-16,
     7      -.2706030765326569d-15,0.9033912269041797d-16,
     8      -.2198243933954263d-15,0.1151989198346833d-16/
         data arr1154/
     1      0.2019747905256283d-02,-.1317860746122830d-03,
     2      0.5550553042969310d-05,-.1767192940423666d-06,
     3      0.4557916207071100d-08,-.9913281176416273d-10,
     4      0.1867236147973264d-11,-.3102963727790601d-13,
     5      0.4606433823015161d-15,0.4696513800031674d-16,
     6      0.1073458038559476d-16,0.1599751375124742d-15,
     7      0.1230293276987847d-15,0.3365005349242340d-15,
     8      0.5959944503947559d-15,0.2766073208804183d-15/
         data arr1155/
     1      0.1397053114966600d-14,-.7375030192683059d-15,
     2      0.2027786837312186d-14,-.4442173522609706d-14,
     3      0.7709141324713093d-15,-.1071772597585020d-13,
     4      -.2316634573004249d-14,-.1954256438937959d-13,
     5      -.7037234303000205d-14,-.2422327107047530d-13,
     6      -.8234924822009222d-14,-.2556428844985382d-13,
     7      -.8302717453312226d-14,-.1626195692957975d-13,
     8      -.3813640573316905d-14,-.9494926722337428d-14/
         data arr1156/
     1      -.2559960054649328d-14,0.1066637102150094d-01,
     2      -.1684405724064760d-02,0.1717003222040313d-03,
     3      -.1323050701308410d-04,0.8258791891677531d-06,
     4      -.4347356849039453d-07,0.1981822221031577d-08,
     5      -.7975063095640458d-10,0.2874258000008424d-11,
     6      -.9363895808609675d-13,0.3062922795687872d-14,
     7      0.5682646809322408d-15,0.6359333697948988d-15,
     8      0.1790986120853780d-14,0.1195003157891780d-14/
         data arr1157/
     1      0.3016547065975187d-14,-.1979914494988999d-14,
     2      0.3324795269449893d-14,-.1764882521377122d-13,
     3      -.2161316067856848d-14,-.6469752288596718d-13,
     4      -.9272287711031839d-14,-.1480868752028522d-12,
     5      -.2300480009299222d-13,-.2554620936504164d-12,
     6      -.2293728863121525d-13,-.3182639853932713d-12,
     7      -.3480161220105319d-13,-.3050949179775160d-12,
     8      -.1975696787819790d-13,-.1886163365594750d-12/
         data arr1158/
     1      -.2536493547071232d-13,-.7946228807823464d-13,
     2      0.3055352997584639d-01,-.8778703297067777d-02,
     3      0.1628147429022155d-02,-.2282643347225595d-03,
     4      0.2592489767366365d-04,-.2482931703347721d-05,
     5      0.2059411476231488d-06,-.1507827778714202d-07,
     6      0.9887126578168725d-09,-.5872543407162775d-10,
     7      0.3188756885626419d-11,-.1570254001155925d-12,
     8      0.8419947026183057d-14,0.6774549487313023d-14/
         data arr1159/
     1      0.8926239915287409d-14,0.1391460080337013d-13,
     2      0.3024147075276372d-13,0.1892865621332968d-13,
     3      0.8315552877774806d-13,0.7230642895080086d-14,
     4      0.1695340805723259d-12,-.1661638906703349d-13,
     5      0.3056199911434629d-12,-.6108654862177349d-13,
     6      0.4186249259608516d-12,-.7326249237250060d-13,
     7      0.4929427502692252d-12,-.9945495837927672d-13,
     8      0.3922071661265460d-12,-.5711630528380188d-13/
         data arr1160/
     1      0.2493784247659642d-12,-.5954600668432912d-13,
     2      0.5910695384310939d-13,0.6245143367730789d-01,
     3      -.2809377477318485d-01,0.8157783194797682d-02,
     4      -.1790668514798359d-02,0.3184145422579566d-03,
     5      -.4774625607953889d-04,0.6200352543088458d-05,
     6      -.7107611908378783d-06,0.7296940017369270d-07,
     7      -.6785789600081239d-08,0.5768853108096023d-09,
     8      -.4516909259488732d-10,0.3286271491845193d-11/
         data arr1161/
     1      -.2104218264974661d-12,0.5521690730519839d-13,
     2      0.5295113741382403d-14,0.1485147510891267d-12,
     3      -.3695917991625391d-13,0.3891740914909186d-12,
     4      -.1556189015147048d-12,0.7336186512538769d-12,
     5      -.3134265567571830d-12,0.1056249620560402d-11,
     6      -.4435541175938432d-12,0.1020013036112316d-11,
     7      -.4003419953606049d-12,0.6534708983023178d-12,
     8      -.2720441284465953d-12,-.5798874768214453d-13/
         data arr1162/
     1      -.8040024126199451d-13,-.3012181064843628d-12,
     2      -.3612456976054484d-13,-.3739774888116259d-12,
     3      0.1025988325858164d+00,-.6586430152744337d-01,
     4      0.2729305442051692d-01,-.8549390757667533d-02,
     5      0.2169466017670188d-02,-.4642364841133451d-03,
     6      0.8603126659090551d-04,-.1407354894279668d-04,
     7      0.2061867176314513d-05,-.2736279277436215d-06,
     8      0.3319625600039771d-07,-.3709696271934542d-08/
         data arr1163/
     1      0.3843214745845281d-09,-.3707685605601669d-10,
     2      0.3413589588285066d-11,-.2136873943649540d-12,
     3      0.2171247541157047d-12,0.1536754962911067d-12,
     4      0.5119474329256785d-12,0.3191567461909381d-12,
     5      0.1060396270456876d-11,0.6386982953679577d-12,
     6      0.1845444773060336d-11,0.1045555813997018d-11,
     7      0.2600832664352834d-11,0.1390610845092906d-11,
     8      0.2998765881680099d-11,0.1292757377342217d-11/
         data arr1164/
     1      0.2584205215663586d-11,0.8594665015714139d-12,
     2      0.1592092977311190d-11,0.2573229142025032d-12,
     3      0.5444964041321580d-12,0.1443706198649947d+00,
     4      -.1242208915372140d+00,0.6899297014710139d-01,
     5      -.2896649962225311d-01,0.9851942103262099d-02,
     6      -.2825637313613511d-02,0.7018456534364974d-03,
     7      -.1538852785319840d-03,0.3021776095680320d-04,
     8      -.5374897331121474d-05,0.8739910364238366d-06/
         data arr1165/
     1      -.1309078733936413d-06,0.1817675190097652d-07,
     2      -.2352387294691053d-08,0.2851815078319891d-09,
     3      -.3232086015469579d-10,0.3744972475464481d-11,
     4      0.5291139791995968d-13,0.7809777126951561d-12,
     5      0.8509379518341981d-12,0.1705841436761506d-11,
     6      0.1679175650538200d-11,0.3187342368605221d-11,
     7      0.2743645744295769d-11,0.4817149649667826d-11,
     8      0.3686968147327762d-11,0.5832950541709705d-11/
         data arr1166/
     1      0.3559456170302043d-11,0.5602946910638580d-11,
     2      0.2428355571243147d-11,0.3702098602156732d-11,
     3      0.8441799025994149d-12,0.1723784836016900d-11,
     4      0.1808205479398733d+00,-.1993436948151714d+00,
     5      0.1418572725064399d+00,-.7631004029056861d-01,
     6      0.3325419342196179d-01,-.1222024425202739d-01,
     7      0.3889054113347174d-02,-.1092542520753091d-02,
     8      0.2748795661028219d-03,-.6264540921966862d-04/
         data arr1167/
     1      0.1305163613944475d-04,-.2504740319806365d-05,
     2      0.4456068484518823d-06,-.7389158730984523d-07,
     3      0.1147467713528030d-07,-.1675312799155250d-08,
     4      0.2313634627607026d-09,-.2954245737485680d-10,
     5      0.4993517946172542d-11,0.8650028062344542d-12,
     6      0.2904196384837072d-11,0.2480162245888016d-11,
     7      0.5477355846345323d-11,0.3792356009654987d-11,
     8      0.8592869430264498d-11,0.4570643964183163d-11/
         data arr1168/
     1      0.1079782814608523d-10,0.4045627366260797d-11,
     2      0.1039976310786361d-10,0.2480359547389504d-11,
     3      0.6920421079987297d-11,0.7935275411691053d-12,
     4      0.2961558506158218d-11,0.2067272472962168d+00,
     5      -.2822951640294146d+00,0.2488304552259552d+00,
     6      -.1658000302589227d+00,0.8949532202441235d-01,
     7      -.4073660171582805d-01,0.1605831195741169d-01,
     8      -.5587856526560631d-02,0.1741407252722268d-02/
         data arr1169/
     1      -.4915844501464748d-03,0.1268600381709799d-03,
     2      -.3015598954231433d-04,0.6645286240884538d-05,
     3      -.1364923309187948d-05,0.2625422066041921d-06,
     4      -.4748599150115195d-07,0.8106302700764193d-08,
     5      -.1309472564397629d-08,0.2027752301878189d-09,
     6      -.2821065999350139d-10,0.7346267675307851d-11,
     7      0.2252940740025999d-11,0.4855640289783224d-11,
     8      0.5378361460505440d-11,0.5444699302342826d-11/
         data arr1170/
     1      0.7858440816075501d-11,0.5051954047227543d-11,
     2      0.8302744581859625d-11,0.3471593625284512d-11,
     3      0.5827173239232697d-11,0.1922055242506694d-11,
     4      0.2414478046098167d-11,0.5855756818145085d-12,
     5      0.2195519766627920d+00,-.3617414817457600d+00,
     6      0.3847278752630132d+00,-.3093071579682789d+00,
     7      0.2014470654488692d+00,-.1106370665334997d+00,
     8      0.5262244112747522d-01,-.2209385971843055d-01/
         data arr1171/
     1      0.8307721697152225d-02,-.2829664670825390d-02,
     2      0.8810831962357691d-03,-.2527091170220472d-03,
     3      0.6719179766354728d-04,-.1665198790578533d-04,
     4      0.3864664720423519d-05,-.8434034445592527d-06,
     5      0.1737037454593481d-06,-.3387063057388197d-07,
     6      0.6273591366480083d-08,-.1105921271647602d-08,
     7      0.1917870383298763d-09,-.3062361741355171d-10,
     8      0.1461821399610559d-10,-.3999619720462581d-12/
         data arr1172/
     1      0.1394936276278695d-10,0.2133980646421605d-11,
     2      0.1520606798304628d-10,0.3506528765972035d-11,
     3      0.1315887575263720d-10,0.3088243316246762d-11,
     4      0.7940227367892541d-11,0.1417141035885704d-11,
     5      0.3242367111630980d-11,0.2193782023580802d+00,
     6      -.4271032142804798d+00,0.5367432424126517d+00,
     7      -.5098956495718716d+00,0.3924015245220236d+00,
     8      -.2546530004811170d+00,0.1431190817192752d+00/
         data arr1173/
     1      -.7100297518653176d-01,0.3154752542810114d-01,
     2      -.1269687186492339d-01,0.4671507898712941d-02,
     3      -.1583213498300014d-02,0.4974085409553537d-03,
     4      -.1456603904841098d-03,0.3994528928151138d-04,
     5      -.1030071812368940d-04,0.2506784542416395d-05,
     6      -.5775729144981706d-06,0.1263542948530038d-06,
     7      -.2631140502159183d-07,0.5232251038620825d-08,
     8      -.9899020518566405d-09,0.1877826528218100d-09/
         data arr1174/
     1      -.2536797811263250d-10,0.1596211202456684d-10,
     2      0.7538521540250239d-11,0.1315281986578524d-10,
     3      0.8042226556826734d-11,0.1250994764023236d-10,
     4      0.5256923862071411d-11,0.8273771857542484d-11,
     5      0.1817761661026079d-11,0.3604264766533796d-11,
     6      0.2082207523051124d+00,-.4709295643639542d+00,
     7      0.6875151606624305d+00,-.7587340573431250d+00,
     8      0.6783151799593484d+00,-.5113782186507339d+00/
         data arr1175/
     1      0.3338747281940127d+00,-.1924221804350419d+00,
     2      0.9931994301468140d-01,-.4643660678855308d-01,
     3      0.1984784713135625d-01,-.7814269422872869d-02,
     4      0.2852034096205228d-02,-.9702318407619566d-03,
     5      0.3090951567377185d-03,-.9259482555502952d-04,
     6      0.2617753244287608d-04,-.7006668748892138d-05,
     7      0.1780664750746628d-05,-.4307838963137211d-06,
     8      0.9944935600334700d-07,-.2195092137804923d-07/
         data arr1176/
     1      0.4659544279381460d-08,-.9444012892336227d-09,
     2      0.2085362262948671d-09,-.3502997333265890d-10,
     3      0.3231803531886384d-10,0.4782149594534769d-12,
     4      0.2104544810224196d-10,0.2039439293811746d-11,
     5      0.1167251435778106d-10,0.1123422865281490d-11,
     6      0.3887664044573216d-11,0.1891242406082631d+00,
     7      -.4899535141592544d+00,0.8193263756972330d+00,
     8      -.1035714294920692d+01,0.1060614751487068d+01/
         data arr1177/
     1      -.9158916258591404d+00,0.6849535879375113d+00,
     2      -.4521769959540669d+00,0.2673409762802525d+00,
     3      -.1431743699792926d+00,0.7009611443098744d-01,
     4      -.3161146728584037d-01,0.1321559503782639d-01,
     5      -.5149715861753707d-02,0.1879211575491622d-02,
     6      -.6448310340842035d-03,0.2088159304042783d-03,
     7      -.6402096271779670d-04,0.1863663149329449d-04,
     8      -.5164393670041926d-05,0.1365511285754382d-05/
         data arr1178/
     1      -.3452279930626006d-06,0.8363967407126772d-07,
     2      -.1943812524841752d-07,0.4373810764484487d-08,
     3      -.9329000655232374d-09,0.2265197994387696d-09,
     4      -.3562598041944251d-10,0.3471394770114989d-10,
     5      0.1441021574178201d-11,0.1605507597494374d-10,
     6      0.1237926863080719d-11,0.5798351945645859d-11,
     7      0.1653530292797822d+00,-.4849024103890938d+00,
     8      0.9178905726873324d+00,-.1313434596168919d+01/
         data arr1179/
     1      0.1522511745972903d+01,-.1488269509754574d+01,
     2      0.1259891508122568d+01,-.9414884046468980d+00,
     3      0.6300957475045845d+00,-.3819801607889020d+00,
     4      0.2116917722806806d+00,-.1080660297617351d+00,
     5      0.5114059438614575d-01,-.2255780426712843d-01,
     6      0.9318022249371833d-02,-.3619332666758191d-02,
     7      0.1326724361619847d-02,-.4604407852704438d-03,
     8      0.1517236928883594d-03,-.4759265047829493d-04/
         data arr1180/
     1      0.1424449309125033d-04,-.4076569653810232d-05,
     2      0.1117728600086551d-05,-.2941193836240849d-06,
     3      0.7444398011913472d-07,-.1813294121622945d-07,
     4      0.4307497573839930d-08,-.9775881086190776d-09,
     5      0.2555252332560884d-09,-.5285568167527845d-10,
     6      0.3448989869609320d-10,-.4910724530780423d-11,
     7      0.8561736650187059d-11,0.1398222030353578d+00,
     8      -.4594913891074115d+00,0.9747045485785043d+00/
         data arr1181/
     1      -.1562966192121384d+01,0.2030302893688150d+01,
     2      -.2224030892274557d+01,0.2109849264992028d+01,
     3      -.1766819992918630d+01,0.1325082526681257d+01,
     4      -.9001942508572673d+00,0.5590600458693208d+00,
     5      -.3198178669479478d+00,0.1696048810819478d+00,
     6      -.8383559453576314d-01,0.3880738836627391d-01,
     7      -.1689188925752756d-01,0.6938881570545552d-02,
     8      -.2698619199686812d-02,0.9965067732609790d-03/
         data arr1182/
     1      -.3502884156907074d-03,0.1174874461334343d-03,
     2      -.3767888458420209d-04,0.1157677482997398d-04,
     3      -.3413717754501656d-05,0.9677274079762394d-06,
     4      -.2640941364451384d-06,0.6954801367149927d-07,
     5      -.1765506654327457d-07,0.4388497554393654d-08,
     6      -.1030906143367963d-08,0.2698720342792123d-09,
     7      -.5238406468656358d-10,0.2315490754320991d-10,
     8      0.1147954288497838d+00,-.4191035241653318d+00/
         data arr1183/
     1      0.9876712447845664d+00,-.1759480599593179d+01,
     2      0.2539166697921245d+01,-.3090058324344864d+01,
     3      0.3256662637250823d+01,-.3029766289800234d+01,
     4      0.2524382918190303d+01,-.1905215131103482d+01,
     5      0.1314503431787812d+01,-.8354134677264761d+00,
     6      0.4921897645830206d+00,-.2702826456076829d+00,
     7      0.1389951386215002d+00,-.6721386991006639d-01,
     8      0.3067366231111440d-01,-.1325297088404895d-01/
         data arr1184/
     1      0.5436850257674243d-02,-.2123187592498755d-02,
     2      0.7911329654056716d-03,-.2818716768696437d-03,
     3      0.9621334835028703d-04,-.3151877478176344d-04,
     4      0.9925879001437647d-05,-.3009197221729456d-05,
     5      0.8796655796184001d-06,-.2479671885900668d-06,
     6      0.6768300813775677d-07,-.1763044553036453d-07,
     7      0.4539113552149039d-08,-.9851406367932221d-09,
     8      0.2482134723452711d-09,0.9180260387810013d-01/
         data arr1185/
     1      -.3695559432769538d+00,0.9602841522170967d+00,
     2      -.1886254582638004d+01,0.3001480404362055d+01,
     3      -.4027536167108359d+01,0.4680303512086623d+01,
     4      -.4801078959050995d+01,0.4410759981138378d+01,
     5      -.3670546145256220d+01,0.2792395079452356d+01,
     6      -.1956793898647661d+01,0.1271173014675642d+01,
     7      -.7696950995969248d+00,0.4364441179273673d+00,
     8      -.2327107298690586d+00,0.1170985757230510d+00/
         data arr1186/
     1      -.5578631782934864d-01,0.2523424399142777d-01,
     2      -.1086575101248024d-01,0.4464258470245060d-02,
     3      -.1753797760303682d-02,0.6600727214187796d-03,
     4      -.2384246325983422d-03,0.8278998119795860d-04,
     5      -.2767278919736180d-04,0.8919230827443558d-05,
     6      -.2770176967117755d-05,0.8332315190257358d-06,
     7      -.2380303707458078d-06,0.6719910241020227d-07,
     8      -.1569482718532887d-07,0.4195742491289178d-08/
         data arr1187/
     1      0.7170296099003159d-01,-.3161783920177334d+00,
     2      0.8999567977202710d+00,-.1936386796206798d+01,
     3      0.3375182198002118d+01,-.4961020974106232d+01,
     4      0.6315031718601460d+01,-.7095945510934404d+01,
     5      0.7140929635553853d+01,-.6509414411786176d+01,
     6      0.5424478616746424d+01,-.4163860084136208d+01,
     7      0.2962958793263031d+01,-.1965212749859667d+01,
     8      0.1220645068769449d+01,-.7129302933033681d+00/
         data arr1188/
     1      0.3929634681519044d+00,-.2050681256844416d+00,
     2      0.1016086471186639d+00,-.4792586558664374d-01,
     3      0.2156897286270269d-01,-.9281728655123269d-02,
     4      0.3826583180373723d-02,-.1514025987413112d-02,
     5      0.5758784093812998d-03,-.2108190969773394d-03,
     6      0.7443209129527964d-04,-.2529292879065422d-04,
     7      0.8333964007645536d-05,-.2589062220927309d-05,
     8      0.8006873394202085d-06,-.1990667373579838d-06/
         data arr1189/
     1      0.5820663338384352d-07,0.5482229129639486d-01,
     2      -.2632713331877439d+00,0.8161018109970740d+00,
     3      -.1912344302006908d+01,0.3630132599009388d+01,
     4      -.5810956494701645d+01,0.8055701972149381d+01,
     5      -.9858013761540267d+01,0.1080401542344955d+02,
     6      -.1072565087988224d+02,0.9733993023929578d+01,
     7      -.8137302303596011d+01,0.6306105440904393d+01,
     8      -.4555084973849475d+01,0.3081254739266619d+01/
         data arr1190/
     1      -.1959911966693835d+01,0.1176502807558799d+01,
     2      -.6686367273105087d+00,0.3608062343010902d+00,
     3      -.1853379873055492d+00,0.9083961293727782d-01,
     4      -.4257201737847892d-01,0.1911428917406592d-01,
     5      -.8236001919279617d-02,0.3411675030155006d-02,
     6      -.1359814008878680d-02,0.5228732940796010d-03,
     7      -.1931595422342147d-03,0.6932574862258262d-04,
     8      -.2324036297998559d-04,0.7832085705389985d-05/
         data arr1191/
     1      -.2055570752221880d-05,0.6553358198758269d-06,
     2      0.4111038073591022d-01,-.2139028223431869d+00,
     3      0.7184158577393148d+00,-.1823964077735167d+01,
     4      0.3751382169009002d+01,-.6506314782104448d+01,
     5      0.9772585168497516d+01,-.1295728822959357d+02,
     6      0.1538609895314420d+02,-.1654952786539326d+02,
     7      0.1627314929399513d+02,-.1473939490348741d+02,
     8      0.1237596460412338d+02,-.9685742952758826d+01/
         data arr1192/
     1      0.7098763165841559d+01,-.4892268311640549d+01,
     2      0.3181891002503567d+01,-.1959300851560340d+01,
     3      0.1145522365769830d+01,-.6375468418712469d+00,
     4      0.3385646991146292d+00,-.1719115625081764d+00,
     5      0.8362930036031026d-01,-.3903953167106833d-01,
     6      0.1752183503867416d-01,-.7563214506053893d-02,
     7      0.3151153067068341d-02,-.1258019863769325d-02,
     8      0.4893274398810321d-03,-.1757200903997554d-03/
         data arr1193/
     1      0.6421440357196051d-04,-.1765841895816823d-04,
     2      0.6109153275084267d-05,0.3028528317544426d-01,
     3      -.1699516563113282d+00,0.6156211662616502d+00,
     4      -.1685709214588370d+01,0.3739266653154560d+01,
     5      -.6994536558875184d+01,0.1133083940288971d+02,
     6      -.1620300203049885d+02,0.2075098109571317d+02,
     7      -.2407268144109283d+02,0.2552931815921865d+02,
     8      -.2493882618514650d+02,0.2258417127942112d+02/
         data arr1194/
     1      -.1906280406614138d+02,0.1506833542877213d+02,
     2      -.1120009187186767d+02,0.7856432230687232d+01,
     3      -.5217587806620896d+01,0.3290038685202402d+01,
     4      -.1974862828649568d+01,0.1131085844795521d+01,
     5      -.6194101834966336d+00,0.3249842827665440d+00,
     6      -.1635979882349476d+00,0.7919390850045377d-01,
     7      -.3683935852342862d-01,0.1655579791199596d-01,
     8      -.7102633395674331d-02,0.2980758629955782d-02/
         data arr1195/
     1      -.1138623887163451d-02,0.4492347838205291d-03,
     2      -.1285579200016930d-03,0.4805601514422386d-04,
     3      0.2194847132678711d-01,-.1322954269951944d+00,
     4      0.5147303379151212d+00,-.1513894724098757d+01,
     5      0.3607000836633908d+01,-.7247121508382840d+01,
     6      0.1261001126319098d+02,-.1936848576417375d+02,
     7      0.2664315239575122d+02,-.3319848267701224d+02,
     8      0.3781636435623872d+02,-.3967924112819053d+02/
         data arr1196/
     1      0.3859564472270198d+02,-.3499191484758401d+02,
     2      0.2970933959524281d+02,-.2371898091634734d+02,
     3      0.1787090805163645d+02,-.1274786050479152d+02,
     4      0.8634067989781002d+01,-.5566662298163326d+01,
     5      0.3424530794022454d+01,-.2014237357954133d+01,
     6      0.1135129877587489d+01,-.6136193539303769d+00,
     7      0.3190645334210652d+00,-.1592262337820460d+00,
     8      0.7687308353388311d-01,-.3524797526334943d-01/
         data arr1197/
     1      0.1589728683694891d-01,-.6416317595348242d-02,
     2      0.2722642537301256d-02,-.8058007014824453d-03,
     3      0.3242180998225264d-03,0.1566702264357789d-01,
     4      -.1010581539038264d+00,0.4207756783155090d+00,
     5      -.1324374691643595d+01,0.3376803389948567d+01,
     6      -.7260548150021596d+01,0.1351959481727746d+02,
     7      -.2222225901602678d+02,0.3271315865048885d+02,
     8      -.4362138404617999d+02,0.5317473252210275d+02/
         data arr1198/
     1      -.5970809708011980d+02,0.6215162776292823d+02,
     2      -.6030123704860785d+02,0.5478931276169638d+02,
     3      -.4681046976412958d+02,0.3774313657423919d+02,
     4      -.2881188327603950d+02,0.2088307752360637d+02,
     5      -.1440822686839505d+02,0.9485558546985700d+01,
     6      -.5970027749668494d+01,0.3600510125025874d+01,
     7      -.2081950475294915d+01,0.1158585464474633d+01,
     8      -.6175859432552387d+00,0.3191673944709637d+00/
         data arr1199/
     1      -.1555804568391547d+00,0.7514686207852828d-01,
     2      -.3183956233150520d-01,0.1448143057226203d-01,
     3      -.4407601960865749d-02,0.1902431674577709d-02,
     4      0.1102598756873594d-01,-.7585782918344706d-01,
     5      0.3368819176398683d+00,-.1130930632367079d+01,
     6      0.3075593196627090d+01,-.7053270658839114d+01,
     7      0.1400821624056615d+02,-.2455870094134238d+02,
     8      0.3856005867615593d+02,-.5484192259162929d+02/
         data arr1200/
     1      0.7130443854416242d+02,-.8539697640989358d+02,
     2      0.9481123280153467d+02,-.9811410204726769d+02,
     3      0.9508217598937686d+02,-.8664503068621265d+02,
     4      0.7451382288231494d+02,-.6066875778941881d+02,
     5      0.4690151732910548d+02,-.3451309879287326d+02,
     6      0.2423474559722131d+02,-.1626566567305183d+02,
     7      0.1046343206996547d+02,-.6448450188791095d+01,
     8      0.3827978612916733d+01,-.2170395178598399d+01/
         data arr1201/
     1      0.1196838692695501d+01,-.6169522928961206d+00,
     2      0.3181556796268961d+00,-.1406283702243317d+00,
     3      0.6835373290375113d-01,-.2128443231828865d-01,
     4      0.9826014950085948d-02,0.7657162409258103d-02,
     5      -.5601951423934565d-01,0.2645484323725366d+00,
     6      -.9443914111363986d+00,0.2731074307236085d+01,
     7      -.6660145943904801d+01,0.1406580512796559d+02,
     8      -.2622259841894147d+02,0.4378209911435351d+02/
         data arr1202/
     1      -.6621557257724230d+02,0.9154878604891158d+02,
     2      -.1165915442100983d+03,0.1376489554633583d+03,
     3      -.1514721637906726d+03,0.1560950573394965d+03,
     4      -.1512587776106033d+03,0.1383256800867005d+03,
     5      -.1197599176053301d+03,0.9845188945723245d+02,
     6      -.7703250933037850d+02,0.5752093205438961d+02,
     7      -.4103965687532002d+02,0.2807539700577791d+02,
     8      -.1837683120523954d+02,0.1160300964910646d+02/
         data arr1203/
     1      -.6968090563002986d+01,0.4088473108797970d+01,
     2      -.2216947351018054d+01,0.1217322049022670d+01,
     3      -.5579517679309471d+00,0.2890660455915199d+00,
     4      -.9165400079975453d-01,0.4513837468348747d-01,
     5      0.5251045489886907d-02,-.4073964696658817d-01,
     6      0.2040248607828139d+00,-.7723780682720439d+00,
     7      0.2368707308779118d+01,-.6125783504136453d+01,
     8      0.1371963219678514d+02,-.2712399283017738d+02/
         data arr1204/
     1      0.4802578173616396d+02,-.7702611953128171d+02,
     2      0.1129354874264083d+03,-.1525263167318658d+03,
     3      0.1909636204331460d+03,-.2228484836005912d+03,
     4      0.2435377117830988d+03,-.2502611077116028d+03,
     5      0.2427039324003056d+03,-.2228266190640033d+03,
     6      0.1942605913802433d+03,-.1611622869296401d+03,
     7      0.1276242544376565d+03,-.9650634485242823d+02,
     8      0.7002203388166413d+02,-.4851284297121649d+02/
         data arr1205/
     1      0.3249476333915359d+02,-.2058133828285260d+02,
     2      0.1281732238340702d+02,-.7271983145209865d+01,
     3      0.4241772919212053d+01,-.2004355003081568d+01,
     4      0.1104334664943096d+01,-.3549970740548938d+00,
     5      0.1860867371564634d+00,0.3557962941039915d-02,
     6      -.2920061656652748d-01,0.1546952007725971d+00,
     7      -.6195021756584981d+00,0.2009755936299324d+01,
     8      -.5498101352207430d+01,0.1302604493479673d+02/
         data arr1206/
     1      -.2724224709133238d+02,0.5102496688730647d+02,
     2      -.8656961237591884d+02,0.1342693406218833d+03,
     3      -.1918271023457759d+03,0.2540591854582442d+03,
     4      -.3136250124390319d+03,0.3625658737759998d+03,
     5      -.3941148414190790d+03,0.4043228992155031d+03,
     6      -.3926432221564192d+03,0.3621145165813051d+03,
     7      -.3176928527282804d+03,0.2661530000645527d+03,
     8      -.2126860427226880d+03,0.1632810423195337d+03/
         data arr1207/
     1      -.1193248857189563d+03,0.8459624476052376d+02,
     2      -.5626127572311778d+02,0.3710907937459051d+02,
     3      -.2191090628365228d+02,0.1354958687756995d+02,
     4      -.6563951417860099d+01,0.3838581680229545d+01,
     5      -.1246032324272425d+01,0.6938582611084136d+00,
     6      0.2383026027003580d-02,-.2064213021627444d-01,
     7      0.1154180803100075d+00,-.4878374356164961d+00,
     8      0.1670360832980184d+01,-.4822975680546440d+01/
         data arr1208/
     1      0.1206006297758949d+02,-.2662044655569478d+02,
     2      0.5262471515295847d+02,-.9423402273413899d+02,
     3      0.1542601451492606d+03,-.2326059812846728d+03,
     4      0.3251477678009110d+03,-.4236288530235689d+03,
     5      0.5168902405394858d+03,-.5929873015197105d+03,
     6      0.6420856368432023d+03,-.6579858078761733d+03,
     7      0.6405050819761905d+03,-.5927468764456761d+03,
     8      0.5241962588156136d+03,-.4413928640289587d+03/
         data arr1209/
     1      0.3577860621550823d+03,-.2748067051401496d+03,
     2      0.2058033619989178d+03,-.1430553723058688d+03,
     3      0.9975486927657855d+02,-.6096558007810703d+02,
     4      0.3990132260848179d+02,-.1971115954316084d+02,
     5      0.1221474118706536d+02,-.3989070544449985d+01,
     6      0.2355866899253421d+01,0.1578213153939968d-02,
     7      -.1439894750725648d-01,0.8479823645776699d-01,
     8      -.3775097926074348d+00,0.1361448134015478d+01/
         data arr1210/
     1      -.4140436764078790d+01,0.1090481813818351d+02,
     2      -.2535271662301509d+02,0.5278817158322478d+02,
     3      -.9956214199226940d+02,0.1716635396471625d+03,
     4      -.2726349365541802d+03,0.4014026906762309d+03,
     5      -.5508194386484832d+03,0.7078885654873490d+03,
     6      -.8552613782771330d+03,0.9754409629648896d+03,
     7      -.1052456750831500d+04,0.1079184767776341d+04,
     8      -.1050852617821829d+04,0.9790932422448442d+03/
         data arr1211/
     1      -.8661048094363766d+03,0.7399089753975463d+03,
     2      -.5950108917820005d+03,0.4699315394992772d+03,
     3      -.3397602762157890d+03,0.2501014964122147d+03,
     4      -.1573520048827805d+03,0.1088464796479378d+03,
     5      -.5454979990587290d+02,0.3577261442730210d+02,
     6      -.1171308658519293d+02,0.7326639730445820d+01,
     7      0.1033697723680139d-02,-.9914789308241093d-02,
     8      0.6138384391131186d-01,-.2872922995420949d+00/
         data arr1212/
     1      0.1089221393786248d+01,-.3482490338076698d+01,
     2      0.9642334379698468d+01,-.2356766845827116d+02,
     3      0.5158802582300094d+02,-.1022898445983560d+03,
     4      0.1854117612707138d+03,-.3095693411441272d+03,
     5      0.4791601276964155d+03,-.6911933932719235d+03,
     6      0.9338745083134930d+03,-.1185872448113688d+04,
     7      0.1421993103956747d+04,-.1611853820133857d+04,
     8      0.1737924425543645d+04,-.1776057057045365d+04/
         data arr1213/
     1      0.1740483134730567d+04,-.1612220660231585d+04,
     2      0.1449384769444034d+04,-.1215261202300793d+04,
     3      0.1010852995411328d+04,-.7563036733572618d+03,
     4      0.5870209726340128d+03,-.3781353301328360d+03,
     5      0.2761659861551376d+03,-.1397203919331936d+03,
     6      0.9686230939484113d+02,-.3169583712022652d+02,
     7      0.2097678900380964d+02,0.6696499240645929d-03,
     8      -.6740951839944394d-02,0.4379636072481308d-01/
         data arr1214/
     1      -.2151337105421594d+00,0.8559894377701240d+00,
     2      -.2872382817489227d+01,0.8346538792427401d+01,
     3      -.2141108394103385d+02,0.4918635291019743d+02,
     4      -.1023572279072911d+03,0.1947153373411058d+03,
     5      -.3411844559692471d+03,0.5542391336824811d+03,
     6      -.8389304466920586d+03,0.1189655395597697d+04,
     7      -.1584672163975480d+04,0.1994584426990089d+04,
     8      -.2369882060976749d+04,0.2682769501233341d+04/
         data arr1215/
     1      -.2869339961154307d+04,0.2953438300878064d+04,
     2      -.2854523431253283d+04,0.2697324794364848d+04,
     3      -.2347406826630178d+04,0.2054450141195967d+04,
     4      -.1582152795295076d+04,0.1293816553135793d+04,
     5      -.8486734115847069d+03,0.6539290821465138d+03,
     6      -.3324036005682545d+03,0.2434391369843590d+03,
     7      -.7936428805868174d+02,0.5553319883760690d+02,
     8      0.4291198218289686d-03,-.4526297523836737d-02/
         data arr1216/
     1      0.3080547993117668d-01,-.1585863290132998d+00,
     2      0.6611248523887262d+00,-.2324988745365340d+01,
     3      0.7078830775787177d+01,-.1903035956792869d+02,
     4      0.4580775155340017d+02,-.9989504826251272d+02,
     5      0.1991238083657547d+03,-.3655878023140099d+03,
     6      0.6223276661594369d+03,-.9867518986661115d+03,
     7      0.1466452929208420d+04,-.2044995355885937d+04,
     8      0.2698104541676777d+04,-.3352116145675714d+04/
         data arr1217/
     1      0.3979165048623404d+04,-.4440212928797400d+04,
     2      0.4795522605451585d+04,-.4816520638466834d+04,
     3      0.4780033353138067d+04,-.4296324164541761d+04,
     4      0.3954086561121787d+04,-.3116823940076803d+04,
     5      0.2684250952616831d+04,-.1783235703427839d+04,
     6      0.1449138468044630d+04,-.7366912394617570d+03,
     7      0.5697512212008719d+03,-.1845058204374491d+03,
     8      0.1364480976208288d+03,0.2722133301040597d-03/
         data arr1218/
     1      -.3003405293899924d-02,0.2136340708331546d-01,
     2      -.1151255372950884d+00,0.5020056500466601d+00,
     3      -.1847959277789447d+01,0.5886102213963524d+01,
     4      -.1656240137646287d+02,0.4171074933110550d+02,
     5      -.9519246094792561d+02,0.1985418030803172d+03,
     6      -.3813768578205093d+03,0.6793706991015852d+03,
     7      -.1126414936215665d+04,0.1752176969177323d+04,
     8      -.2552523871012120d+04,0.3526263579612711d+04/
         data arr1219/
     1      -.4568201609287346d+04,0.5681407444800127d+04,
     2      -.6590194675632668d+04,0.7463680116136724d+04,
     3      -.7754129034493157d+04,0.8079485141381147d+04,
     4      -.7459335881626745d+04,0.7218410709739239d+04,
     5      -.5790112065277995d+04,0.5251609514325112d+04,
     6      -.3514312660107327d+04,0.3012145586853974d+04,
     7      -.1524480652182108d+04,0.1245139042337770d+04,
     8      -.3993448000026326d+03,0.3121388875473615d+03/
         data arr1220/
     1      0.1715328430448301d-03,-.1973909159749030d-02,
     2      0.1461093892026383d-01,-.8236643587907592d-01,
     3      0.3748345031490767d+00,-.1443246251676708d+01,
     4      0.4800680884839180d+01,-.1412546214587051d+02,
     5      0.3716103374359072d+02,-.8865287589628086d+02,
     6      0.1932032119422002d+03,-.3877229803253891d+03,
     7      0.7219017441490832d+03,-.1249249670268437d+04,
     8      0.2031989822680000d+04,-.3084505868875010d+04/
         data arr1221/
     1      0.4458596258096215d+04,-.6002575746652155d+04,
     2      0.7818296954116247d+04,-.9386518878017794d+04,
     3      0.1114680313991212d+05,-.1191548042201250d+05,
     4      0.1303806505143581d+05,-.1229152925824574d+05,
     5      0.1251202106413624d+05,-.1015105964496410d+05,
     6      0.9701667679784337d+04,-.6504039677964050d+04,
     7      0.5882948462845704d+04,-.2950780671257967d+04,
     8      0.2546629436517323d+04,-.8064740890980165d+03/
         data arr1222/
     1      0.6665887374282793d+03,0.1086850243268351d-03,
     2      -.1294108422986843d-02,0.9860394116527489d-02,
     3      -.5816277415283067d-01,0.2751485064525283d+00,
     4      -.1108207236821842d+01,0.3840063706134671d+01,
     5      -.1181077777571918d+02,0.3240002739960058d+02,
     6      -.8072812581631273d+02,0.1835860797788960d+03,
     7      -.3843495691315093d+03,0.7472780433932110d+03,
     8      -.1346753888141701d+04,0.2289421714857897d+04/
         data arr1223/
     1      -.3610195886068570d+04,0.5459693386656105d+04,
     2      -.7607314397307448d+04,0.1038044435445955d+05,
     3      -.1283291776004928d+05,0.1599114471823158d+05,
     4      -.1748248313106371d+05,0.2010992033613411d+05,
     5      -.1923456193175229d+05,0.2062160214762751d+05,
     6      -.1681414439424044d+05,0.1695572056991865d+05,
     7      -.1132404024185330d+05,0.1082349586343436d+05,
     8      -.5354895050725974d+04,0.4889728286602356d+04/
         data arr1224/
     1      -.1524036264556661d+04,0.1333790418801358d+04,
     2      -.4009239855769321d-06,0.4234365792986032d-08,
     3      -.2958037904847304d-10,0.1590732687303691d-12,
     4      -.7028171957241194d-15,0.2647582532571063d-17,
     5      -.8443996746645035d-20,-.1995246462136212d-20,
     6      -.8132041201561766d-21,0.8341873743932583d-21,
     7      -.1372408169145793d-20,0.1427537381665148d-19,
     8      -.1574347939760538d-19,0.3814453932493130d-19/
         data arr1225/
     1      -.5869712964525565d-19,-.1745727821158803d-19,
     2      -.1846765061751706d-18,-.4345679772579554d-18,
     3      -.4121271587696115d-18,-.1694122430708356d-17,
     4      -.6889282418211306d-18,-.4040774741163446d-17,
     5      -.8381727768130443d-18,-.7062750102941839d-17,
     6      -.7132047461397011d-18,-.8987791190469224d-17,
     7      -.3082250045578053d-18,-.8757012775939321d-17,
     8      -.3082909279972216d-19,-.5555640081259219d-17/
         data arr1226/
     1      0.1749968878803323d-18,-.2461320646863404d-17,
     2      -.5380143966740763d-04,0.2966895399130083d-05,
     3      -.1082180245274182d-06,0.3038610804714607d-08,
     4      -.7009748553300795d-10,0.1379045051645801d-11,
     5      -.2371189045231054d-13,0.3626970343598834d-15,
     6      -.4653063931144056d-17,0.8271290688222342d-18,
     7      0.1054446385901597d-17,0.2490147803577918d-17,
     8      0.2277903963394333d-17,0.3742971855032151d-17/
         data arr1227/
     1      0.6931572060760174d-17,-.1148512755590106d-16,
     2      0.1930277434165281d-16,-.8260830553855602d-16,
     3      0.5709861390097567d-16,-.2735014152230125d-15,
     4      0.1322157616374995d-15,-.6098179668830052d-15,
     5      0.2424831165054027d-15,-.1025381088506383d-14,
     6      0.3173091350334645d-15,-.1279470779004905d-14,
     7      0.3186740087160481d-15,-.1220427149209079d-14,
     8      0.1951131210039689d-15,-.7672042691082081d-15/
         data arr1228/
     1      0.9097349272231476d-16,-.3253949867329249d-15,
     2      -.6876557572969840d-03,0.9177768269802634d-04,
     3      -.8101997805094276d-05,0.5505861261160095d-06,
     4      -.3074045508502984d-07,0.1463672699085092d-08,
     5      -.6091058125895453d-10,0.2254691326438114d-11,
     6      -.7522945565863456d-13,0.2296059503553826d-14,
     7      -.5807654370689393d-16,0.4848174460536526d-16,
     8      0.5191095396632257d-17,0.1050022188805381d-15/
         data arr1229/
     1      -.3002885346344378d-16,0.1035865471217057d-16,
     2      -.2420292084924100d-15,-.7760713385024909d-15,
     3      -.7793356885252995d-15,-.3156254985714229d-14,
     4      -.1642221237926846d-14,-.7653096170820188d-14,
     5      -.2398916433733908d-14,-.1350702611823248d-13,
     6      -.2480374789642426d-14,-.1747915078869991d-13,
     7      -.1469663552410141d-14,-.1735005763256843d-13,
     8      -.4936894683219962d-15,-.1127170615718915d-13/
         data arr1230/
     1      0.3980568283201552d-15,-.5187685735137239d-14,
     2      -.3583890613517402d-02,0.8702814077939585d-03,
     3      -.1397827866365460d-03,0.1728326511576793d-04,
     4      -.1755697844697853d-05,0.1520976174549748d-06,
     5      -.1151622503082162d-07,0.7756100402015237d-09,
     6      -.4708563354490215d-10,0.2603647071149137d-11,
     7      -.1321987689581443d-12,0.6452142667812916d-14,
     8      -.1027144250510462d-15,0.6914020659989509d-15/
         data arr1231/
     1      0.6475741774111668d-15,0.5806022544131841d-15,
     2      0.1903200901264569d-14,-.2508019607276803d-14,
     3      0.5046229286596504d-14,-.1339059974888338d-13,
     4      0.1103459324922037d-13,-.3436391904630626d-13,
     5      0.1931731879768824d-13,-.6289597325550816d-13,
     6      0.2619595964648127d-13,-.8206572661195270d-13,
     7      0.2757935288525220d-13,-.8280011641696685d-13,
     8      0.1915989442307869d-13,-.5369471631139688d-13/
         data arr1232/
     1      0.9338890524687533d-14,-.2533524742037814d-13,
     2      -.1146923552382953d-01,0.4360518535787877d-02,
     3      -.1096556039930866d-02,0.2122763615053009d-03,
     4      -.3376170145020098d-04,0.4579263834706809d-05,
     5      -.5428528268224599d-06,0.5724190688590520d-07,
     6      -.5440737419873916d-08,0.4710246052180086d-09,
     7      -.3745717525483526d-10,0.2755854264700038d-11,
     8      -.1886818327198997d-12,0.1439463966360373d-13/
         data arr1233/
     1      -.2492164700780805d-14,0.5484003661432162d-14,
     2      -.1037564128577670d-13,0.1039463446491012d-13,
     3      -.3722617524473831d-13,0.1570737208201521d-13,
     4      -.9126943108978244d-13,0.2185300807122176d-13,
     5      -.1713730426351650d-12,0.2337775565926941d-13,
     6      -.2317926930184201d-12,0.1981157444698028d-13,
     7      -.2422878780722392d-12,0.3700535326292924d-14,
     8      -.1624625668449357d-12,-.4817029560748632d-14/
         data arr1234/
     1      -.7428879633764573d-13,-.1396910250768252d-13,
     2      -.2688898850117518d-01,0.1458875124002148d-01,
     3      -.5235411241988016d-02,0.1446310678446715d-02,
     4      -.3282647659908130d-03,0.6353830125280824d-04,
     5      -.1074885055520762d-04,0.1617461686669503d-05,
     6      -.2193904224210329d-06,0.2710462846601837d-07,
     7      -.3075927242199016d-08,0.3228865355368288d-09,
     8      -.3153413780792925d-10,0.2882522032963380d-11/
         data arr1235/
     1      -.2389510827138221d-12,0.9932492376824612d-14,
     2      0.2211919644832286d-13,-.7051709739256912d-13,
     3      0.5994761865286481d-13,-.2385728250078484d-12,
     4      0.1277874191253691d-12,-.5460357633450485d-12,
     5      0.2214657702138491d-12,-.9322571905730243d-12,
     6      0.2869442779375932d-12,-.1180896478955814d-11,
     7      0.2909325795449344d-12,-.1140095162402973d-11,
     8      0.1832261221259040d-12,-.7271464962782795d-12/
         data arr1236/
     1      0.9012946830224206d-13,-.3232196943059206d-12,
     2      -.5071296660996459d-01,0.3687829376948230d-01,
     3      -.1773828592726047d-01,0.6567961402174678d-02,
     4      -.1998027305629996d-02,0.5183473675132301d-03,
     5      -.1175318228693177d-03,0.2370476196535442d-04,
     6      -.4309505211297299d-05,0.7136106927063588d-06,
     7      -.1085430896205349d-06,0.1527151776591972d-07,
     8      -.1999195903016756d-08,0.2447316105366834d-09/
         data arr1237/
     1      -.2811820344083741d-10,0.2973111354306385d-11,
     2      -.2289005663053408d-12,-.2810452451435051d-12,
     3      0.2371349534257667d-12,-.8701839566649081d-12,
     4      0.5286707039162306d-12,-.1829400396732880d-11,
     5      0.9330344389786922d-12,-.2965565488365607d-11,
     6      0.1243738919679196d-11,-.3687796670542134d-11,
     7      0.1314825614102225d-11,-.3484185116603931d-11,
     8      0.8923596044215646d-12,-.2227335768965730d-11/
         data arr1238/
     1      0.4497778907190513d-12,-.9374393061204940d-12,
     2      -.8138172262304388d-01,0.7582590164876084d-01,
     3      -.4673016524078001d-01,0.2216946228130801d-01,
     4      -.8641017578364741d-02,0.2872256815867343d-02,
     5      -.8344431335527645d-03,0.2156332725288337d-03,
     6      -.5022806960820703d-04,0.1065661627828328d-04,
     7      -.2076820973922699d-05,0.3743846113964253d-06,
     8      -.6279582179835570d-07,0.9849685439118874d-08/
         data arr1239/
     1      -.1450996832696935d-08,0.2014756836816011d-09,
     2      -.2628282403691143d-10,0.2900512359210984d-11,
     3      0.1700916530160752d-12,-.1259708683241380d-11,
     4      0.1250201007285884d-11,-.2934379142099326d-11,
     5      0.2185567423243153d-11,-.4920107954806579d-11,
     6      0.2885209692903949d-11,-.6190903502486855d-11,
     7      0.2914749860676150d-11,-.5815996982528105d-11,
     8      0.1929681701335927d-11,-.3681843248219626d-11/
         data arr1240/
     1      0.8865536054833414d-12,-.1490797382471333d-11,
     2      -.1152465181212245d+00,0.1330054729786455d+00,
     3      -.1015313683680931d+00,0.5966354801627479d-01,
     4      -.2880512731575787d-01,0.1185984936869398d-01,
     5      -.4267795917587234d-02,0.1366072240420042d-02,
     6      -.3941444119569964d-03,0.1035807874152990d-03,
     7      -.2500402563713055d-04,0.5583157146660718d-05,
     8      -.1159961798773866d-05,0.2253647579325386d-06/
         data arr1241/
     1      -.4112415468924064d-07,0.7075123448719123d-08,
     2      -.1151295386877542d-08,0.1775784959759914d-09,
     3      -.2569727557510743d-10,0.2611834208792914d-11,
     4      0.4151127637477046d-12,-.2654681012539741d-11,
     5      0.1601372681149230d-11,-.4926116725140656d-11,
     6      0.2199074710081947d-11,-.6622745554515672d-11,
     7      0.2413624505163577d-11,-.6584823830039960d-11,
     8      0.1669997329493509d-11,-.4392482845384785d-11/
         data arr1242/
     1      0.8894600190581337d-12,-.1930607679256739d-11,
     2      -.1476803415125714d+00,0.2056456994822423d+00,
     3      -.1894111777031792d+00,0.1342980436325793d+00,
     4      -.7823221999642588d-01,0.3886424842411862d-01,
     5      -.1687446409224368d-01,0.6517113084196455d-02,
     6      -.2268779082369784d-02,0.7194014172336349d-03,
     7      -.2095353305749249d-03,0.5645240159440548d-04,
     8      -.1415146850812126d-04,0.3317408893358812d-05/
         data arr1243/
     1      -.7304085543521356d-06,0.1516200101283722d-06,
     2      -.2977308037085431d-07,0.5546763384554376d-08,
     3      -.9819815932957518d-09,0.1638830124479083d-09,
     4      -.2409187289167002d-10,-.1440292635413351d-11,
     5      0.3992006967880532d-11,-.9609335486122017d-11,
     6      0.5860528617216170d-11,-.1257341002132077d-10,
     7      0.5930115601307569d-11,-.1217368345508195d-10,
     8      0.3885759004932245d-11,-.7933336108990770d-11/
         data arr1244/
     1      0.1895831868926963d-11,-.3397530406548277d-11,
     2      -.1743641570816271d+00,0.2869013311106136d+00,
     3      -.3122460408790167d+00,0.2616010163480157d+00,
     4      -.1800668634896995d+00,0.1057004469385115d+00,
     5      -.5422941805989352d-01,0.2474791504053099d-01,
     6      -.1018014522906995d-01,0.3814270227072490d-02,
     7      -.1312731284225022d-02,0.4179067640812040d-03,
     8      -.1237875288887718d-03,0.3428883939950600d-04/
         data arr1245/
     1      -.8920683470669032d-05,0.2188100044712727d-05,
     2      -.5077145133613979d-06,0.1117764375738264d-06,
     3      -.2340948261799374d-07,0.4671522426218870d-08,
     4      -.8868051153923782d-09,0.1519601738393519d-09,
     5      -.1799241799278452d-10,-.1412878197700899d-10,
     6      0.1339350959261968d-10,-.2406149704955809d-10,
     7      0.1424345481260705d-10,-.2270290708120788d-10,
     8      0.9404651331313503d-11,-.1450084222553556d-10/
         data arr1246/
     1      0.4152129663607342d-11,-.5754241963102018d-11,
     2      -.1922561895804765d+00,0.3674923113445226d+00,
     3      -.4646278227405629d+00,0.4522101199728988d+00,
     4      -.3615990061590318d+00,0.2465828285623239d+00,
     5      -.1469648678720085d+00,0.7791297346473963d-01,
     6      -.3723211560153344d-01,0.1620569932153409d-01,
     7      -.6479249921612511d-02,0.2396187926267383d-02,
     8      -.8245385146843659d-03,0.2653257598675028d-03/
         data arr1247/
     1      -.8018947060723721d-04,0.2284962159836068d-04,
     2      -.6159203734998735d-05,0.1575261943072662d-05,
     3      -.3832882212959301d-06,0.8893525762085482d-07,
     4      -.1971924410941962d-07,0.4177551346768815d-08,
     5      -.8436193528740431d-09,0.1468646046336816d-09,
     6      -.1793453091820282d-10,-.2070460939714808d-10,
     7      0.1320151834139366d-10,-.2526035088693747d-10,
     8      0.9606496917081622d-11,-.1647561086803260d-10/
         data arr1248/
     1      0.4603830993764435d-11,-.6758090274604583d-11,
     2      -.2000226845622782d+00,0.4379483694008967d+00,
     3      -.6342428854655370d+00,0.7070765009913781d+00,
     4      -.6476331794769706d+00,0.5058717503452302d+00,
     5      -.3453558852462107d+00,0.2097195161286088d+00,
     6      -.1147948797920894d+00,0.5723323776922351d-01,
     7      -.2621084401494000d-01,0.1110332071798228d-01,
     8      -.4376416944677346d-02,0.1613105961377776d-02/
         data arr1249/
     1      -.5584400561627362d-03,0.1822694850628226d-03,
     2      -.5627756615737744d-04,0.1648692181210501d-04,
     3      -.4595048750840491d-05,0.1221334628274306d-05,
     4      -.3102548820325081d-06,0.7546961106432489d-07,
     5      -.1760725828194310d-07,0.3935777648627074d-08,
     6      -.8412089239813746d-09,0.1578040188179462d-09,
     7      -.2389184249520826d-10,-.1144440539378863d-10,
     8      0.6324656167402967d-11,-.1168313552117064d-10/
         data arr1250/
     1      0.3776096825539157d-11,-.4892382176988644d-11,
     2      -.1979605800831545d+00,0.4906331487922464d+00,
     3      -.8043111427830844d+00,0.1015007830648600d+01,
     4      -.1052365462580639d+01,0.9304915452420429d+00,
     5      -.7190736467029403d+00,0.4942877710704195d+00,
     6      -.3062654764750561d+00,0.1728456082777052d+00,
     7      -.8960361832576466d-01,0.4296669348246376d-01,
     8      -.1917044735685690d-01,0.7998544409470069d-02/
         data arr1251/
     1      -.3134434033354368d-02,0.1158059961257184d-02,
     2      -.4047500423512999d-03,0.1342226183293156d-03,
     3      -.4234586258236340d-04,0.1274063773574596d-04,
     4      -.3663664910062252d-05,0.1008895918781411d-05,
     5      -.2665400433257953d-06,0.6765746384494731d-07,
     6      -.1651865431846110d-07,0.3871179596472802d-08,
     7      -.8661985288381873d-09,0.1739297520570414d-09,
     8      -.2921503136690921d-10,-.3518642916909478d-11/
         data arr1252/
     1      0.3493698901158372d-11,-.3980373376819696d-11,
     2      -.1875865740859671d+00,0.5210014963015607d+00,
     3      -.9571174139795539d+00,0.1353535262458766d+01,
     4      -.1572627325495709d+01,0.1558226950617110d+01,
     5      -.1349431059485164d+01,0.1039480255487477d+01,
     6      -.7217611003396184d+00,0.4564706159856039d+00,
     7      -.2651789664795266d+00,0.1424966022797032d+00,
     8      -.7124655541175011d-01,0.3331207105729955d-01/
         data arr1253/
     1      -.1462880521405086d-01,0.6056752384379280d-02,
     2      -.2372218702691403d-02,0.8815614374414293d-03,
     3      -.3116713937379535d-03,0.1050839415841220d-03,
     4      -.3386263832214638d-04,0.1044997149319562d-04,
     5      -.3093916994670571d-05,0.8802901064496917d-06,
     6      -.2410501481235383d-06,0.6361444561907553d-07,
     7      -.1618508797584672d-07,0.3975081209616101d-08,
     8      -.9317634866083609d-09,0.2100609609216944d-09/
         data arr1254/
     1      -.3955153554515783d-10,0.7178213562832395d-11,
     2      -.1710982972678776d+00,0.5279324869646271d+00,
     3      -.1077457420332374d+01,0.1692777798614161d+01,
     4      -.2185001195406198d+01,0.2405204757815337d+01,
     5      -.2314022226839183d+01,0.1980288886097334d+01,
     6      -.1527570486147170d+01,0.1073287557672508d+01,
     7      -.6926882543145239d+00,0.4135221149446859d+00,
     8      -.2296960806893922d+00,0.1193127424794583d+00/
         data arr1255/
     1      -.5820891882696413d-01,0.2677416749751743d-01,
     2      -.1165001176456018d-01,0.4809719012665949d-02,
     3      -.1889119993269323d-02,0.7076108110303403d-03,
     4      -.2533228551021712d-03,0.8684894926735878d-04,
     5      -.2856628393092559d-04,0.9029687136865227d-05,
     6      -.2746974029508556d-05,0.8055426106833713d-06,
     7      -.2277433503261749d-06,0.6229287136051871d-07,
     8      -.1626600098553452d-07,0.4173223637753826d-08/
         data arr1256/
     1      -.9078504117310430d-09,0.2212150791865673d-09,
     2      -.1508705820735771d+00,0.5132934702207226d+00,
     3      -.1155090313112391d+01,0.2000986936241369d+01,
     4      -.2847898135236398d+01,0.3456633225231299d+01,
     5      -.3666884624551822d+01,0.3460084802092107d+01,
     6      -.2942984163834026d+01,0.2279981034972208d+01,
     7      -.1622487788467265d+01,0.1067998953482194d+01,
     8      -.6541150553915853d+00,0.3746414814619534d+00/
         data arr1257/
     1      -.2015334037937336d+00,0.1022120165712661d+00,
     2      -.4903891095938227d-01,0.2232351776622881d-01,
     3      -.9667872795537330d-02,0.3992954142970818d-02,
     4      -.1576167895866402d-02,0.5958284301307609d-03,
     5      -.2160906663355409d-03,0.7531547499000767d-04,
     6      -.2526171054850368d-04,0.8168303953414759d-05,
     7      -.2544634460944253d-05,0.7675045034620520d-06,
     8      -.2198937208659187d-06,0.6221231719019671d-07/
         data arr1258/
     1      -.1460620327067129d-07,0.3903253808926546d-08,
     2      -.1290792880228529d+00,0.4810471428524973d+00,
     3      -.1185789898842334d+01,0.2250121465334743d+01,
     4      -.3507971572399189d+01,0.4663960018946576d+01,
     5      -.5419617905189635d+01,0.5601806085674072d+01,
     6      -.5219142539448448d+01,0.4429068243888466d+01,
     7      -.3452490394647566d+01,0.2489383312798874d+01,
     8      -.1670109693290275d+01,0.1047795715688660d+01/
         data arr1259/
     1      -.6174157450559650d+00,0.3430066358278447d+00,
     2      -.1802649456332403d+00,0.8988826615550322d-01,
     3      -.4264235123216858d-01,0.1929187585650513d-01,
     4      -.8341647555559424d-02,0.3454145590100893d-02,
     5      -.1372202923212087d-02,0.5238871342545613d-03,
     6      -.1924515661661618d-03,0.6816627727699795d-04,
     7      -.2323453424318796d-04,0.7677255414239442d-05,
     8      -.2392381228365219d-05,0.7416785719142199d-06/
         data arr1260/
     1      -.1855108446897890d-06,0.5428307153342721d-07,
     2      -.1074800717020366d+00,0.4362247670681125d+00,
     3      -.1171066938108922d+01,0.2420088399339574d+01,
     4      -.4108966742583274d+01,0.5949530199821920d+01,
     5      -.7529182377359900d+01,0.8475366995279648d+01,
     6      -.8599652323412332d+01,0.7947772022805507d+01,
     7      -.6747094636597279d+01,0.5298188313979440d+01,
     8      -.3871077860976960d+01,0.2644933893792934d+01/
         data arr1261/
     1      -.1697333551471149d+01,0.1026935841983109d+01,
     2      -.5877644935391338d+00,0.3191878619391480d+00,
     3      -.1649056805238727d+00,0.8124942071257733d-01,
     4      -.3826019634283742d-01,0.1725391601288750d-01,
     5      -.7464515261218942d-02,0.3103666484505684d-02,
     6      -.1241346694310871d-02,0.4788607865518976d-03,
     7      -.1774471049507561d-03,0.6386593992891570d-04,
     8      -.2147924276319065d-04,0.7256248824465128d-05/
         data arr1262/
     1      -.1917190849262399d-05,0.6114351415644620d-06,
     2      -.8732546154698075d-01,0.3840094286979642d+00,
     3      -.1116945324904078d+01,0.2500921446005814d+01,
     4      -.4600659302957546d+01,0.7217532474675194d+01,
     5      -.9896292352219584d+01,0.1206984904616193d+02,
     6      -.1326914211093557d+02,0.1328697075939234d+02,
     7      -.1222126063208760d+02,0.1039789005316435d+02,
     8      -.8231298716791823d+01,0.6093543341320456d+01/
         data arr1263/
     1      -.4236828631207216d+01,0.2777382164941694d+01,
     2      -.1722321579310292d+01,0.1013388351312793d+01,
     3      -.5672614370152500d+00,0.3028214823930762d+00,
     4      -.1544998410595271d+00,0.7548976865266917d-01,
     5      -.3538262744693459d-01,0.1593998235930025d-01,
     6      -.6904360830979364d-02,0.2885944270245577d-02,
     7      -.1155755183675492d-02,0.4508195512609170d-03,
     8      -.1624446937958746d-03,0.5950685310210369d-04/
         data arr1264/
     1      -.1648456356976374d-04,0.5702875202722585d-05,
     2      -.6938247315042460d-01,0.3290633548851996d+00,
     3      -.1032281857610247d+01,0.2492844435434666d+01,
     4      -.4945884232013943d+01,0.8368379496875541d+01,
     5      -.1237524721482552d+02,0.1627840885112625d+02,
     6      -.1930108421285117d+02,0.2084460098966822d+02,
     7      -.2067818228474318d+02,0.1897449915124176d+02,
     8      -.1620026829239936d+02,0.1293458491715260d+02/
         data arr1265/
     1      -.9699564010446410d+01,0.6857656253480892d+01,
     2      -.4586515570972010d+01,0.2910538442900570d+01,
     3      -.1757146883024111d+01,0.1011674019714264d+01,
     4      -.5566744089707124d+00,0.2933541349677808d+00,
     5      -.1482736682852271d+00,0.7204463455930288d-01,
     6      -.3363061878322977d-01,0.1516273766251758d-01,
     7      -.6525802782467297d-02,0.2746434134380193d-02,
     8      -.1052924234772724d-02,0.4164155792477364d-03/
         data arr1266/
     1      -.1201314266255879d-03,0.4488493522727954d-04,
     2      -.5400938190568374d-01,0.2751349387213916d+00,
     3      -.9270673995681550d+00,0.2404667224409219d+01,
     4      -.5124488762485129d+01,0.9313110525766028d+01,
     5      -.1479292535020886d+02,0.2090060830190189d+02,
     6      -.2661800311880301d+02,0.3087693219407872d+02,
     7      -.3290028864390972d+02,0.3242682755857015d+02,
     8      -.2973740923927231d+02,0.2550235073810520d+02/
         data arr1267/
     1      -.2054123947438951d+02,0.1559900731489808d+02,
     2      -.1120599383462948d+02,0.7638143273892741d+01,
     3      -.4952972636846151d+01,0.3062994090251300d+01,
     4      -.1810228871711721d+01,0.1024650788578222d+01,
     5      -.5561426613064511d+00,0.2902627486744518d+00,
     6      -.1453605486922793d+00,0.7040700968049141d-01,
     7      -.3238908211096621d-01,0.1464934138172413d-01,
     8      -.5935588793008731d-02,0.2524552573747729d-02/
         data arr1268/
     1      -.7538088751035106d-03,0.3030002832355716d-03,
     2      -.4125681856051629d-01,0.2249140606995107d+00,
     3      -.8110105555991438d+00,0.2251202259874832d+01,
     4      -.5133982830897881d+01,0.9984882499965266d+01,
     5      -.1697253066532219d+02,0.2566231296325750d+02,
     6      -.3497491575380022d+02,0.4341698725581355d+02,
     7      -.4950733840274063d+02,0.5221781177270547d+02,
     8      -.5124619614159636d+02,0.4703087583691767d+02/
         data arr1269/
     1      -.4053905248069825d+02,0.3294490988519534d+02,
     2      -.2532705214268615d+02,0.1847425090917642d+02,
     3      -.1281980462671925d+02,0.8484145517241576d+01,
     4      -.5365362037732151d+01,0.3250089168805201d+01,
     5      -.1886945978905088d+01,0.1054012685415907d+01,
     6      -.5638237452339703d+00,0.2923352667078989d+00,
     7      -.1429837263507703d+00,0.6925877484146348d-01,
     8      -.2946713521175666d-01,0.1343282809956503d-01/
         data arr1270/
     1      -.4128170828654271d-02,0.1779012154777604d-02,
     2      -.3096882903723738d-01,0.1800709593324121d+00,
     3      -.6925507454080089d+00,0.2050395463877934d+01,
     4      -.4987415506191272d+01,0.1034575333209601d+02,
     5      -.1875701761465598d+02,0.3024899866829320d+02,
     6      -.4397136063965345d+02,0.5821983003636038d+02,
     7      -.7080743036343610d+02,0.7965736769132140d+02,
     8      -.8338094646165980d+02,0.8161806910218286d+02/
         data arr1271/
     1      -.7503677817744934d+02,0.6504099282903681d+02,
     2      -.5333077544297278d+02,0.4149150875707077d+02,
     3      -.3070820330858921d+02,0.2167623770779839d+02,
     4      -.1461821015513537d+02,0.9445111774256187d+01,
     5      -.5844503669920724d+01,0.3482534747911352d+01,
     6      -.1981552656040253d+01,0.1096298341153377d+01,
     7      -.5671151382634922d+00,0.2932858806050929d+00,
     8      -.1302182146709998d+00,0.6343115661307763d-01/
         data arr1272/
     1      -.1996122123167206d-01,0.9194326086399363d-02,
     2      -.2286987069849580d-01,0.1414070849535862d+00,
     3      -.5783192660292497d+00,0.1820716201982254d+01,
     4      -.4709434329805279d+01,0.1038828551870548d+02,
     5      -.2002784007685443d+02,0.3434550403027428d+02,
     6      -.5309056658848910d+02,0.7474926952999805d+02,
     7      -.9667259214736909d+02,0.1156482496227717d+03,
     8      -.1287265517237618d+03,0.1339912150176864d+03/
         data arr1273/
     1      -.1309938473373219d+03,0.1207405298207771d+03,
     2      -.1052746470380731d+03,0.8709563126061613d+02,
     3      -.6853992180695622d+02,0.5144839323314034d+02,
     4      -.3688293265660987d+02,0.2534322361867120d+02,
     5      -.1665589979837885d+02,0.1055624586020133d+02,
     6      -.6362248017690237d+01,0.3745387038636958d+01,
     7      -.2038394268149413d+01,0.1122445595669685d+01,
     8      -.5169658661248326d+00,0.2683759567632116d+00/
         data arr1274/
     1      -.8607886282010084d-01,0.4226358940364783d-01,
     2      -.1663189024887106d-01,0.1090558743642866d+00,
     3      -.4729830271643558d+00,0.1579138192487934d+01,
     4      -.4331582918915547d+01,0.1013261974881894d+02,
     5      -.2071629044841432d+02,0.3767452169350106d+02,
     6      -.6175828068734938d+02,0.9221143336607686d+02,
     7      -.1264680994405134d+03,0.1604415092738496d+03,
     8      -.1893846401087587d+03,0.2090515077608383d+03/
         data arr1275/
     1      -.2167320478646493d+03,0.2118492489548526d+03,
     2      -.1958746550665729d+03,0.1718529330111413d+03,
     3      -.1433940541224410d+03,0.1141510596109940d+03,
     4      -.8673140459370926d+02,0.6320853405514736d+02,
     5      -.4397058500008351d+02,0.2956457642146628d+02,
     6      -.1879370316305216d+02,0.1174329599598246d+02,
     7      -.6688491124929802d+01,0.3912352331037830d+01,
     8      -.1858438074857987d+01,0.1025826259572373d+01/
         data arr1276/
     1      -.3339201297032209d+00,0.1743473091207033d+00,
     2      -.1192109789887432d-01,0.8268805880648863d-01,
     3      -.3793660090552231d+00,0.1339837234206313d+01,
     4      -.3887744199979475d+01,0.9620371128356846d+01,
     5      -.2080660481409935d+02,0.4002727249000829d+02,
     6      -.6941007261007773d+02,0.1096304320639060d+03,
     7      -.1590544648143346d+03,0.2134523103030901d+03,
     8      -.2665293907912359d+03,0.3112244803251754d+03/
         data arr1277/
     1      -.3413117429126748d+03,0.3529214618075037d+03,
     2      -.3451491324235994d+03,0.3203449935330667d+03,
     3      -.2826646739492543d+03,0.2380561852623277d+03,
     4      -.1911424960986909d+03,0.1473956995696078d+03,
     5      -.1081554825593719d+03,0.7697283812850014d+02,
     6      -.5138132935477749d+02,0.3400535647063305d+02,
     7      -.2016098743842490d+02,0.1250173980660722d+02,
     8      -.6091051244680336d+01,0.3567703211993575d+01/
         data arr1278/
     1      -.1174018718779008d+01,0.6504988249274497d+00,
     2      -.8427100287046905d-02,0.6169354309568157d-01,
     3      -.2987380268025335d+00,0.1113573670503988d+01,
     4      -.3410356799964879d+01,0.8906944384394066d+01,
     5      -.2033168332164593d+02,0.4128220480948760d+02,
     6      -.7555518265752278d+02,0.1259527825232594d+03,
     7      -.1928660850209834d+03,0.2731783760329142d+03,
     8      -.3600130379625909d+03,0.4436949330308906d+03/
         data arr1279/
     1      -.5135357753837353d+03,0.5604562633071369d+03,
     2      -.5783888994456697d+03,0.5666226326484326d+03,
     3      -.5273833970397798d+03,0.4688609924356937d+03,
     4      -.3966792593637548d+03,0.3229867062707204d+03,
     5      -.2490932904570072d+03,0.1872741875885695d+03,
     6      -.1306698458289145d+03,0.9143134138424350d+02,
     7      -.5612422535527850d+02,0.3683055509833284d+02,
     8      -.1830800891576325d+02,0.1135957148476444d+02/
         data arr1280/
     1      -.3765330144094484d+01,0.2210004114175320d+01,
     2      -.5878299100412280d-02,0.4532650847614680d-01,
     3      -.2311760177772715d+00,0.9076313215766626d+00,
     4      -.2927724187800812d+01,0.8053733441125217d+01,
     5      -.1936339503067203d+02,0.4141038466190868d+02,
     6      -.7982689319759460d+02,0.1401623444809409d+03,
     7      -.2260549207435413d+03,0.3372443267724431d+03,
     8      -.4680989508880180d+03,0.6076440768311385d+03/
         data arr1281/
     1      -.7406570119863832d+03,0.8514271138495237d+03,
     2      -.9251177886462342d+03,0.9546966964148332d+03,
     3      -.9349454535189157d+03,0.8757436737276810d+03,
     4      -.7783544501060435d+03,0.6679699479745966d+03,
     5      -.5393656439002782d+03,0.4276730917976289d+03,
     6      -.3104138808467607d+03,0.2292934188342602d+03,
     7      -.1449420365629517d+03,0.1005154316817419d+03,
     8      -.5071963851377807d+02,0.3328881591555370d+02/
         data arr1282/
     1      -.1107767901878121d+02,0.6876970060282673d+01,
     2      -.4047553942028605d-02,0.3281086636251476d-01,
     3      -.1759281236801226d+00,0.7261451115888589d+00,
     4      -.2462471802446822d+01,0.7121308387086778d+01,
     5      -.1799991268055579d+02,0.4046876917551381d+02,
     6      -.8201306388482151d+02,0.1513869343924628d+03,
     7      -.2566750949664014d+03,0.4025704777529430d+03,
     8      -.5873781361162652d+03,0.8016200550596847d+03/
         data arr1283/
     1      -.1026930655307205d+04,0.1241191384388678d+04,
     2      -.1416764492257298d+04,0.1537433553867641d+04,
     3      -.1580078675559589d+04,0.1556774476726971d+04,
     4      -.1448834875709341d+04,0.1308535725697034d+04,
     5      -.1101689396601124d+04,0.9200916800936434d+03,
     6      -.6911737143172423d+03,0.5383481569409719d+03,
     7      -.3485555092715466d+03,0.2551543200749849d+03,
     8      -.1300625296447128d+03,0.9019372507836692d+02/
         data arr1284/
     1      -.3003924114009893d+02,0.1969951896358907d+02,
     2      -.2751583066728985d-02,0.2340961017014642d-01,
     3      -.1317369474743633d+00,0.5706521971827309d+00,
     4      -.2031022225948971d+01,0.6164245181888256d+01,
     5      -.1635243968359862d+02,0.3858432719791224d+02,
     6      -.8206474272566977d+02,0.1589809932888815d+03,
     7      -.2828774060825135d+03,0.4656402131979532d+03,
     8      -.7128873225891905d+03,0.1021153682760025d+04/
         data arr1285/
     1      -.1372180571316993d+04,0.1740933566524872d+04,
     2      -.2082858046853034d+04,0.2373227904709450d+04,
     3      -.2552492899282178d+04,0.2641710244086562d+04,
     4      -.2565113423821399d+04,0.2435363211903305d+04,
     5      -.2128222323816895d+04,0.1870327793873279d+04,
     6      -.1446404586697381d+04,0.1186953898377440d+04,
     7      -.7829204008244418d+03,0.6044891457801714d+03,
     8      -.3098319340727988d+03,0.2268198135857191d+03/
         data arr1286/
     1      -.7538539193673162d+02,0.5217429322356139d+02,
     2      -.1846811648015652d-02,0.1646476409108660d-01,
     3      -.9710067323581092d-01,0.4407292850359052d+00,
     4      -.1643858487404432d+01,0.5227834723155975d+01,
     5      -.1453323088258985d+02,0.3593282521876039d+02,
     6      -.8008464104747094d+02,0.1625743695755603d+03,
     7      -.3030822103250882d+03,0.5228209544172513d+03,
     8      -.8384015538364263d+03,0.1258679778464571d+04/
         data arr1287/
     1      -.1770524057832536d+04,0.2354855181021218d+04,
     2      -.2945647886843225d+04,0.3519880060953040d+04,
     3      -.3949298990412927d+04,0.4289326294253088d+04,
     4      -.4327830643487406d+04,0.4316110113493068d+04,
     5      -.3895577067711750d+04,0.3600452250541352d+04,
     6      -.2850582621679210d+04,0.2463468245660225d+04,
     7      -.1646609449389597d+04,0.1340275493743266d+04,
     8      -.6876630900455991d+03,0.5311639422456687d+03/
         data arr1288/
     1      -.1756775396736464d+03,0.1282351184643126d+03,
     2      -.1223602700883652d-02,0.1141548309627630d-01,
     3      -.7046713181646896d-01,0.3346171001526049d+00,
     4      -.1306316574370472d+01,0.4346584012307003d+01,
     5      -.1264616718692174d+02,0.3271611396924267d+02,
     6      -.7630007504692070d+02,0.1620838454156230d+03,
     7      -.3161042723504191d+03,0.5706833989179399d+03,
     8      -.9568320159092436d+03,0.1503749951878057d+04/
         data arr1289/
     1      -.2209324273785414d+04,0.3077303619339418d+04,
     2      -.4013110982408704d+04,0.5025165466400995d+04,
     3      -.5860096892073167d+04,0.6675568479572409d+04,
     4      -.6966420075456374d+04,0.7295781687167224d+04,
     5      -.6764330606926443d+04,0.6574200296258590d+04,
     6      -.5298073003929849d+04,0.4821469946967177d+04,
     7      -.3248488265448498d+04,0.2787236010564026d+04,
     8      -.1425299501558882d+04,0.1161399786136586d+04/
         data arr1290/
     1      -.3812145663140021d+03,0.2933945949846637d+03,
     2      -.8000921727332684d-03,0.7800910842681698d-02,
     3      -.5036382914652771d-01,0.2497605829373306d+00,
     4      -.1019630549322694d+01,0.3544108378917739d+01,
     5      -.1078022241466080d+02,0.2914061835978491d+02,
     6      -.7102558886484786d+02,0.1576891137806157d+03,
     7      -.3212124977187646d+03,0.6062672360569857d+03,
     8      -.1060645038346953d+04,0.1743474033152723d+04/
         data arr1291/
     1      -.2668405914619247d+04,0.3890046010094174d+04,
     2      -.5270556334675391d+04,0.6913922357328335d+04,
     3      -.8343200244398184d+04,0.9968692050907390d+04,
     4      -.1070258194996855d+05,0.1177359929961234d+05,
     5      -.1114748420330277d+05,0.1139740349733708d+05,
     6      -.9293484755473877d+04,0.8910040759749336d+04,
     7      -.6019178597018036d+04,0.5445945983991046d+04,
     8      -.2763637629538880d+04,0.2376271527572643d+04/
         data arr1292/
     1      -.7719697112008123d+03,0.6265129934711449d+03,
     2      -.5160507101180494d-03,0.5250395591355625d-02,
     3      -.3545438592947017d-01,0.1831384194950093d+00,
     4      -.7816620078441698d+00,0.2832820328297783d+01,
     5      -.9002599673939324d+01,0.2539179541220522d+02,
     6      -.6460700571362769d+02,0.1497580942561336d+03,
     7      -.3180959963326526d+03,0.6272555587549205d+03,
     8      -.1142306910497213d+04,0.1963397316807799d+04/
         data arr1293/
     1      -.3120257910877047d+04,0.4761380581915470d+04,
     2      -.6673932406277547d+04,0.9176357746811615d+04,
     3      -.1139895562702770d+05,0.1429754577326779d+05,
     4      -.1569693723722604d+05,0.1815807782622213d+05,
     5      -.1744541142784959d+05,0.1878618277024141d+05,
     6      -.1540271570177703d+05,0.1557583463577255d+05,
     7      -.1049350638615135d+05,0.1002220327595986d+05,
     8      -.5024846635780727d+04,0.4563474927082858d+04/
         data arr1294/
     1      -.1463087317610827d+04,0.1253122551966576d+04,
     2      0.1497074383122430d-08,-.1394432441001393d-10,
     3      0.8712801778506187d-13,-.4238148959842998d-15,
     4      0.1709348997778553d-17,-.5925926767695210d-20,
     5      0.1778544240376441d-22,-.5249014712745793d-23,
     6      0.6894859002596365d-23,-.2521958078328864d-22,
     7      0.4432261563759457d-22,-.1060089429794608d-21,
     8      0.1638804125339654d-21,-.3642714144667613d-21/
         data arr1295/
     1      0.6510791865394602d-21,-.1058880157570276d-20,
     2      0.2015624755087576d-20,-.2475370418678605d-20,
     3      0.5531516848113655d-20,-.4662205544085470d-20,
     4      0.1160458871590611d-19,-.6933512803394209d-20,
     5      0.1983848264852923d-19,-.7997834760864881d-20,
     6      0.2536965183309779d-19,-.7053595017428906d-20,
     7      0.2491638878011856d-19,-.4190526193050997d-20,
     8      0.1619306021507515d-19,-.1683179423625655d-20/
         data arr1296/
     1      0.6590175008282412d-20,0.1048955927898028d-05,
     2      -.5101446599328513d-07,0.1664315681231409d-08,
     3      -.4227037427623317d-10,0.8901697514863963d-12,
     4      -.1610918311260441d-13,0.2564437252905338d-15,
     5      -.3653117148367218d-17,0.5523797460405204d-19,
     6      -.1550804963490773d-19,0.2756621462587970d-19,
     7      -.8342722446802045d-19,0.3788808715158258d-19,
     8      -.3003205297173659d-18,0.8589581152336736d-20/
         data arr1297/
     1      -.8926812721497748d-18,-.2240318976703788d-18,
     2      -.2109793196729538d-17,-.6217497621377085d-18,
     3      -.4041720197199649d-17,-.1294315519956445d-17,
     4      -.6234504461195982d-17,-.1451003623326363d-17,
     5      -.7410157256849788d-17,-.1177798721744929d-17,
     6      -.6954392748339148d-17,0.8325485995115594d-19,
     7      -.4271017330687577d-17,0.6343906262900545d-18,
     8      -.1923495396367340d-17,0.7702354638538290d-18/
         data arr1298/
     1      0.3244831089868092d-04,-.3819318392760170d-05,
     2      0.3015684411232502d-06,-.1853719189189784d-07,
     3      0.9447966648189012d-09,-.4138059184072956d-10,
     4      0.1594307539398588d-11,-.5494049807406195d-13,
     5      0.1715264660208663d-14,-.4915663362564351d-16,
     6      0.3089148336778656d-17,-.1669705274178043d-17,
     7      0.4729890871170455d-17,-.6822658737981674d-17,
     8      0.1277962794102832d-16,-.2282697570875854d-16/
         data arr1299/
     1      0.3240909221891686d-16,-.5764272664272084d-16,
     2      0.8386103740771506d-16,-.1177670575051427d-15,
     3      0.1772200452755114d-15,-.1884365918269385d-15,
     4      0.3128355926128238d-15,-.2369302086521675d-15,
     5      0.4153471914480201d-15,-.2264868703698461d-15,
     6      0.4222206978407748d-15,-.1487325047229868d-15,
     7      0.2837867032690298d-15,-.6420614259007612d-16,
     8      0.1190321679504158d-15,0.3076909424958416d-03/
         data arr1300/
     1      -.6589423754923396d-04,0.9466434171248818d-05,
     2      -.1058725635655708d-05,0.9817858990124373d-07,
     3      -.7823734275677058d-08,0.5484391244307311d-09,
     4      -.3438648286247380d-10,0.1952709010749437d-11,
     5      -.1014285882157788d-12,0.4873180793076304d-14,
     6      -.2383875418782855d-15,0.4348691174814969d-16,
     7      -.9088662477959989d-16,0.6327302352779483d-16,
     8      -.2859770035363106d-15,0.2930926385778444d-16/
         data arr1301/
     1      -.7156278340834120d-15,-.6584618478305297d-16,
     2      -.1436328039753443d-14,-.3821733489095188d-15,
     3      -.2286118142964660d-14,-.6571748899699376d-15,
     4      -.2841033250193632d-14,-.1001218884379482d-14,
     5      -.2713893036410031d-14,-.8915422392356852d-15,
     6      -.1759043018929429d-14,-.6824014793515626d-15,
     7      -.7731829328663297d-15,-.2484004098871879d-15,
     8      0.1541676113072621d-02,-.5169214745241207d-03/
         data arr1302/
     1      0.1162685516215807d-03,-.2035907199897746d-04,
     2      0.2955902094961086d-05,-.3687958732575074d-06,
     3      0.4047614056588268d-07,-.3973352835732647d-08,
     4      0.3532684382102466d-09,-.2872844587701602d-10,
     5      0.2153949899909734d-11,-.1499162393500492d-12,
     6      0.9796079160475083d-14,-.6215116434663153d-15,
     7      0.1253962522274489d-15,0.1979182797111046d-15,
     8      -.5407694489823146d-16,0.7216089303067094d-15/
         data arr1303/
     1      0.5160382099441352d-15,0.1423482261619645d-14,
     2      0.2435576374085542d-14,0.1632893536284206d-14,
     3      0.8244747343183002d-14,0.9581133138262033d-15,
     4      0.1451240695565744d-13,-.6125390805032054d-15,
     5      0.1974295303225890d-13,-.1314043168042588d-14,
     6      0.1527229080136052d-13,-.1382940480712133d-14,
     7      0.8584403682353698d-14,0.5157902465431425d-02,
     8      -.2467996527673337d-02,0.7921769837458832d-03/
         data arr1304/
     1      -.1979511019428132d-03,0.4101379709974760d-04,
     2      -.7302405976274420d-05,0.1143718126972527d-05,
     3      -.1602201110505275d-06,0.2032847115851949d-07,
     4      -.2359128992366212d-08,0.2524110968668082d-09,
     5      -.2506306800448960d-10,0.2322949085073650d-11,
     6      -.2032974273867447d-12,0.1872251127389779d-13,
     7      -.6339193594281138d-14,0.5899206172966737d-14,
     8      -.1322012981998258d-13,0.1440767270334677d-13/
         data arr1305/
     1      -.2759602169176254d-13,0.2854750321899323d-13,
     2      -.4570976729243388d-13,0.4811374339290216d-13,
     3      -.5896873635480774d-13,0.6265166420397883d-13,
     4      -.5918175920082864d-13,0.6410343310956610d-13,
     5      -.4041912524799355d-13,0.4449732980632137d-13,
     6      -.1936750929128756d-13,0.1976549577287024d-13,
     7      0.1303844580149527d-01,-.8361908177194521d-02,
     8      0.3597420616794367d-02,-.1204855798847197d-02/
         data arr1306/
     1      0.3345917869882728d-03,-.7984715028962612d-04,
     2      0.1676179793227137d-04,-.3147217621097649d-05,
     3      0.5352080196730250d-06,-.8324875003197522d-07,
     4      0.1193829545246454d-07,-.1588804386364384d-08,
     5      0.1973201156792526d-09,-.2298238026383315d-10,
     6      0.2526651479504897d-11,-.2779279858824103d-12,
     7      0.4183872718604916d-13,-.4346692920343397d-13,
     8      0.3292657598875143d-13,-.8262862604117628d-13/
         data arr1307/
     1      0.5435144469475324d-13,-.1341441288632122d-12,
     2      0.8263721481663860d-13,-.1713285426609844d-12,
     3      0.9631214008874497d-13,-.1663193298549482d-12,
     4      0.8823719195771068d-13,-.1105600376114129d-12,
     5      0.5346846914477831d-13,-.4686555411248420d-13,
     6      0.1693001266495793d-13,0.2680850462271152d-01,
     7      -.2202881115181562d-01,0.1214271457923241d-01,
     8      -.5210729657145751d-02,0.1854033802314319d-02/
         data arr1308/
     1      -.5668924778528731d-03,0.1524757492550670d-03,
     2      -.3668139565915883d-04,0.7992462208555996d-05,
     3      -.1592848976845284d-05,0.2926699115627160d-06,
     4      -.4990507019399552d-07,0.7941071050788169d-08,
     5      -.1184785926378895d-08,0.1664324754114401d-09,
     6      -.2211259817889499d-10,0.2799105835599165d-11,
     7      -.4026253209699205d-12,0.6088463417036366d-13,
     8      -.1571965916334039d-12,-.1700156162470490d-14/
         data arr1309/
     1      -.2568435499650189d-12,-.4382265471436285d-13,
     2      -.3355019827423832d-12,-.1016554314103718d-12,
     3      -.3266847534071579d-12,-.1275420769212506d-12,
     4      -.2209221461623416d-12,-.1008268541423354d-12,
     5      -.9376219016997019d-13,-.5824128991120149d-13,
     6      0.4702453593906222d-01,-.4786234605081872d-01,
     7      0.3267907110930639d-01,-.1737014533541570d-01,
     8      0.7655499848913676d-02,-.2899396382340063d-02/
         data arr1310/
     1      0.9659589447925761d-03,-.2878423804583470d-03,
     2      0.7768559056153476d-04,-.1917721224765373d-04,
     3      0.4364554706458664d-05,-.9218441798448746d-06,
     4      0.1816948610345533d-06,-.3357779399327738d-07,
     5      0.5842126736921395d-08,-.9604407134403369d-09,
     6      0.1498023314759138d-09,-.2232040539681480d-10,
     7      0.3535886151155765d-11,-.8068536875366484d-12,
     8      0.8918142235076749d-12,-.7231675122504193d-12/
         data arr1311/
     1      0.1371275832955946d-11,-.1013875024098475d-11,
     2      0.1699100919598842d-11,-.1053906691540262d-11,
     3      0.1583908786911667d-11,-.7460023603015112d-12,
     4      0.9954013555038461d-12,-.3301995253640900d-12,
     5      0.3684102737866700d-12,0.7270673431287236d-01,
     6      -.8928928545763221d-01,0.7355806792637698d-01,
     7      -.4717580368085159d-01,0.2508676448491350d-01,
     8      -.1146394089308716d-01,0.4608294855595072d-02/
         data arr1312/
     1      -.1656881975213616d-02,0.5395510629217732d-03,
     2      -.1607062624828518d-03,0.4413087233703927d-04,
     3      -.1124644679605035d-04,0.2674580527247487d-05,
     4      -.5963762275968273d-06,0.1251961968054946d-06,
     5      -.2483295016159940d-07,0.4669040083988251d-08,
     6      -.8345748696115539d-09,0.1427074939579794d-09,
     7      -.2364211268375006d-10,0.4946888634237613d-11,
     8      -.1587791122375875d-11,0.2424440280187174d-11/
         data arr1313/
     1      -.1546677926772902d-11,0.3083110250893757d-11,
     2      -.1713475419737877d-11,0.3047051986450455d-11,
     3      -.1247924757623513d-11,0.2012097246349990d-11,
     4      -.6182616660168913d-12,0.8156957660961740d-12,
     5      0.1014349383798812d+00,-.1471941952694701d+00,
     6      0.1432847777200863d+00,-.1085844042493601d+00,
     7      0.6822934511325621d-01,-.3684163478654619d-01,
     8      0.1749941854538885d-01,-.7434526907519121d-02/
         data arr1314/
     1      0.2860702670303752d-02,-.1006818934764410d-02,
     2      0.3266927453959503d-03,-.9837635247525847d-04,
     3      0.2764454615358472d-04,-.7283707743842542d-05,
     4      0.1806764526002823d-05,-.4234640718692908d-06,
     5      0.9407560441478692d-07,-.1986645827606593d-07,
     6      0.3998594503048200d-08,-.7700015173420541d-09,
     7      0.1429517701043671d-09,-.2774426613853605d-10,
     8      0.6393206139817375d-11,-.4344576367896570d-11/
         data arr1315/
     1      0.2325282518909304d-11,-.3551742994426874d-11,
     2      0.1652987264185501d-11,-.2330143051614499d-11,
     3      0.8284448311437822d-12,-.9675223574803197d-12,
     4      0.1611437993028390d-12,0.1299281526928153d+00,
     5      -.2190276561251963d+00,0.2476856834412745d+00,
     6      -.2180524050899855d+00,0.1591685314137663d+00,
     7      -.9984296683054161d-01,0.5509279187932557d-01,
     8      -.2719049277146510d-01,0.1215427449115029d-01/
         data arr1316/
     1      -.4969357843871219d-02,0.1873186268816453d-02,
     2      -.6552767654587469d-03,0.2139124663967540d-03,
     3      -.6547442883912079d-04,0.1886745456417466d-04,
     4      -.5137132092456475d-05,0.1325782641969474d-05,
     5      -.3252340374609876d-06,0.7603292640631366d-07,
     6      -.1697911078285684d-07,0.3632647013676201d-08,
     7      -.7483250846618423d-09,0.1536419004086066d-09,
     8      -.3420670401112090d-10,0.1367015147345606d-10/
         data arr1317/
     1      -.7321277414326188d-11,0.7798340147379144d-11,
     2      -.4313729923449201d-11,0.4528818003342235d-11,
     3      -.1766883995586202d-11,0.1594447366868592d-11,
     4      0.1548381309064830d+00,-.2989849634880035d+00,
     5      0.3872817494748024d+00,-.3905375014745476d+00,
     6      0.3265388107339793d+00,-.2346231224825757d+00,
     7      0.1482940920017022d+00,-.8383432686429296d-01,
     8      0.4292492832691747d-01,-.2010279968760326d-01/
         data arr1318/
     1      0.8679865080342375d-02,-.3478023510824856d-02,
     2      0.1300527603719135d-02,-.4559643969436147d-03,
     3      0.1505040746987007d-03,-.4693873653362940d-04,
     4      0.1387581543965395d-04,-.3899032650859001d-05,
     5      0.1044067042316421d-05,-.2670347741952517d-06,
     6      0.6537700394576390d-07,-.1535294425065638d-07,
     7      0.3476158925022832d-08,-.7630862250925789d-09,
     8      0.1770826011529363d-09,-.4480549946684252d-10/
         data arr1319/
     1      0.2471804593045222d-10,-.1036617721050541d-10,
     2      0.1174954931966292d-10,-.4187603770913405d-11,
     3      0.4134906830893456d-11,0.1734650132929535d+00,
     4      -.3791559088305482d+00,0.5559426848906228d+00,
     5      -.6346002512197776d+00,0.6006297097515397d+00,
     6      -.4885143456122062d+00,0.3495142347814797d+00,
     7      -.2236646800672706d+00,0.1296342062082816d+00,
     8      -.6872283812989555d-01,0.3358860937629714d-01/
         data arr1320/
     1      -.1523512669419244d-01,0.6448632664263318d-02,
     2      -.2559254671857259d-02,0.9562365426831059d-03,
     3      -.3375848738941613d-03,0.1129651711336989d-03,
     4      -.3593166266685481d-04,0.1089135199964002d-04,
     5      -.3153195873717957d-05,0.8737546613055228d-06,
     6      -.2321791622341312d-06,0.5927927574207276d-07,
     7      -.1456766335126816d-07,0.3467294994481261d-08,
     8      -.8010149753632538d-09,0.1950967802566948d-09/
         data arr1321/
     1      -.4683310988176302d-10,0.2094100779825685d-10,
     2      -.5688225093254072d-11,0.5263662693306081d-11,
     3      0.1842018455215864d+00,-.4511894758777845d+00,
     4      0.7413617956273419d+00,-.9483299588598874d+00,
     5      0.1005831171558605d+01,-.9167578786898757d+00,
     6      0.7350235375647225d+00,-.5270997810476712d+00,
     7      0.3423529619892142d+00,-.2033829830685107d+00,
     8      0.1113947181757420d+00,-.5662102078339731d-01/
         data arr1322/
     1      0.2685705029978413d-01,-.1194436944069293d-01,
     2      0.5001198684040128d-02,-.1978567173099981d-02,
     3      0.7419445138143021d-03,-.2644619533241782d-03,
     4      0.8983106679996510d-04,-.2914433312760856d-04,
     5      0.9049972040643656d-05,-.2694791377000051d-05,
     6      0.7708258957371159d-06,-.2121302554585335d-06,
     7      0.5628515597659112d-07,-.1440118358516935d-07,
     8      0.3593659862201858d-08,-.8567454251759486d-09/
         data arr1323/
     1      0.2198496619942782d-09,-.4616830372310045d-10,
     2      0.1827516320917913d-10,0.1866523207706835d+00,
     3      -.5079182989045252d+00,0.9271725851449147d+00,
     4      -.1317605296661888d+01,0.1552552995206275d+01,
     5      -.1572068534370085d+01,0.1400275700067782d+01,
     6      -.1115579751255906d+01,0.8049656682543795d+00,
     7      -.5312676392450104d+00,0.3232651074953505d+00,
     8      -.1825439346984519d+00,0.9619300825274794d-01/
         data arr1324/
     1      -.4752738320196939d-01,0.2210804119317220d-01,
     2      -.9716781508991095d-02,0.4047981747203493d-02,
     3      -.1602971474687377d-02,0.6049014049340760d-03,
     4      -.2180256125138839d-03,0.7521341621667438d-04,
     5      -.2488092260044647d-04,0.7906379459137196d-05,
     6      -.2417044150522266d-05,0.7120411005016262d-06,
     7      -.2021795904419969d-06,0.5554178498395380d-07,
     8      -.1456758473483862d-07,0.3763729424150798d-08/
         data arr1325/
     1      -.8255968939947085d-09,0.2061404902570056d-09,
     2      0.1814766467659246d+00,-.5445147955231108d+00,
     3      0.1095985682252549d+01,-.1717347191951264d+01,
     4      0.2231247152544676d+01,-.2491157548342769d+01,
     5      0.2446649427039842d+01,-.2149251750549774d+01,
     6      0.1709985776229144d+01,-.1244391328586484d+01,
     7      0.8348931871479089d+00,-.5198379336645814d+00,
     8      0.3020456186749196d+00,-.1645513351369072d+00/
         data arr1326/
     1      0.8439879495389450d-01,-.4090127913054858d-01,
     2      0.1878803982694927d-01,-.8203462079472510d-02,
     3      0.3413378504584604d-02,-.1356549307370579d-02,
     4      0.5160025603134636d-03,-.1882124089437022d-03,
     5      0.6594586245211578d-04,-.2222729005117509d-04,
     6      0.7219836783408772d-05,-.2258629943212090d-05,
     7      0.6839567702875832d-06,-.1966416775066983d-06,
     8      0.5584244221635420d-07,-.1313382487818763d-07/
         data arr1327/
     1      0.3528867242256345d-08,0.1700758483907071d+00,
     2      -.5589867190226167d+00,0.1232442283690417d+01,
     3      -.2115386451069293d+01,0.3010573246792879d+01,
     4      -.3681905332730937d+01,0.3961075070072156d+01,
     5      -.3811522799586865d+01,0.3321801182915984d+01,
     6      -.2647939257022439d+01,0.1946040453763525d+01,
     7      -.1327268597149536d+01,0.8447599127357129d+00,
     8      -.5041178447925556d+00,0.2832284079030813d+00/
         data arr1328/
     1      -.1503513579007673d+00,0.7565224891139806d-01,
     2      -.3618323451832166d-01,0.1649166788460619d-01,
     3      -.7179346468689684d-02,0.2991377504437192d-02,
     4      -.1195171721391110d-02,0.4587125299488921d-03,
     5      -.1693335061768865d-03,0.6025056925780016d-04,
     6      -.2062227042400593d-04,0.6841107074547631d-05,
     7      -.2138915880160293d-05,0.6654985621407442d-06,
     8      -.1666267798384949d-06,0.4901424430995421d-07/
         data arr1329/
     1      0.1542287454576916d+00,-.5520462487734514d+00,
     2      0.1325537007474850d+01,-.2477800174763072d+01,
     3      0.3840405230277995d+01,-.5115072175061246d+01,
     4      0.5992989475406215d+01,-.6280298085636941d+01,
     5      0.5960829017099138d+01,-.5174785362659628d+01,
     6      0.4141784327705907d+01,-.3076420729937756d+01,
     7      0.2132413877776840d+01,-.1385867040762711d+01,
     8      0.8479643629399528d+00,-.4902294739573927d+00/
         data arr1330/
     1      0.2686366145361276d+00,-.1399271055564793d+00,
     2      0.6945609851511923d-01,-.3292912577162568d-01,
     3      0.1494232530671976d-01,-.6501492822594959d-02,
     4      0.2717549213718605d-02,-.1092223160964759d-02,
     5      0.4232510609670365d-03,-.1574903544161261d-03,
     6      0.5690875047589111d-04,-.1920043119343084d-04,
     7      0.6510559056687598d-05,-.1721160620231900d-05,
     8      0.5521886859583686d-06,0.1357678355359467d+00/
         data arr1331/
     1      -.5265330756361208d+00,0.1369811090525763d+01,
     2      -.2774301944756627d+01,0.4658897179187299d+01,
     3      -.6723206732146732d+01,0.8534672108431648d+01,
     4      -.9690411270440679d+01,0.9965228069489209d+01,
     5      -.9373279023875476d+01,0.8128404562072964d+01,
     6      -.6541572892466304d+01,0.4912771700486131d+01,
     7      -.3459356084077102d+01,0.2293347839598601d+01,
     8      -.1436515479701502d+01,0.8528933757901365d+00/
         data arr1332/
     1      -.4813372451613056d+00,0.2588670427402716d+00,
     2      -.1329722055712821d+00,0.6537601027389489d-01,
     3      -.3081772191010164d-01,0.1395690619840655d-01,
     4      -.6074858799271287d-02,0.2550771885168127d-02,
     5      -.1025710375653273d-02,0.4016934281342865d-03,
     6      -.1451797076973840d-03,0.5338607311147769d-04,
     7      -.1479048219184947d-04,0.5150405361632054d-05,
     8      0.1163414648396226d+00,-.4866223344074383d+00/
         data arr1333/
     1      0.1365387129638247d+01,-.2982480409830518d+01,
     2      0.5401765737683648d+01,-.8407324927816784d+01,
     3      0.1151057328548981d+02,-.1409551894277348d+02,
     4      0.1563345074174245d+02,-.1585944184098096d+02,
     5      0.1483304830613060d+02,-.1287466770915369d+02,
     6      0.1042819573466084d+02,-.7919660788069459d+01,
     7      0.5662523244757181d+01,-.3825418253898067d+01,
     8      0.2449583000260783d+01,-.1490988177226501d+01/
         data arr1334/
     1      0.8648297068414642d+00,-.4791083011565705d+00,
     2      0.2540516999035298d+00,-.1291434704994258d+00,
     3      0.6308134362902940d-01,-.2958953302154818d-01,
     4      0.1340148287183529d-01,-.5791018300023798d-02,
     5      0.2447010960076490d-02,-.9407672550840275d-03,
     6      0.3735353342884384d-03,-.1077155883877504d-03,
     7      0.4053709023459084d-04,0.9727489045533284d-01,
     8      -.4370237632300508d+00,0.1317090482097939d+01/
         data arr1335/
     1      -.3090182994024767d+01,0.6011586994560085d+01,
     2      -.1004981378432060d+02,0.1477896186065795d+02,
     3      -.1943904098596499d+02,0.2315769914155516d+02,
     4      -.2523336948035141d+02,0.2534921714806786d+02,
     5      -.2363289631374482d+02,0.2056065238733969d+02,
     6      -.1677185133318010d+02,0.1288045604074727d+02,
     7      -.9346443666476071d+01,0.6428454577626644d+01,
     8      -.4202733712792145d+01,0.2618399822896348d+01/
         data arr1336/
     1      -.1557991392879268d+01,0.8873702206918478d+00,
     2      -.4843850987891674d+00,0.2541480816118769d+00,
     3      -.1278893312162737d+00,0.6222682881742481d-01,
     4      -.2873861887075095d-01,0.1305118953337270d-01,
     5      -.5301576720450280d-02,0.2264235147706017d-02,
     6      -.6754037614322500d-03,0.2736542766960948d-03,
     7      0.7951912875046321d-01,-.3823140422909739d+00,
     8      0.1233034259210639d+01,-.3095908132283211d+01/
         data arr1337/
     1      0.6445213939003708d+01,-.1153056400516094d+02,
     2      0.1814599551356961d+02,-.2554206703596615d+02,
     3      0.3256274041461855d+02,-.3797039503859668d+02,
     4      0.4082054106254514d+02,-.4072634609719315d+02,
     5      0.3791750365716437d+02,-.3309999475419485d+02,
     6      0.2720336179217319d+02,-.2112421346110047d+02,
     7      0.1554839293148829d+02,-.1087794600916505d+02,
     8      0.7252662143852399d+01,-.4617732501649096d+01/
         data arr1338/
     1      0.2814636840686500d+01,-.1643451905572679d+01,
     2      0.9228576142994354d+00,-.4960284225806502d+00,
     3      0.2583582039464609d+00,-.1268467706484818d+00,
     4      0.6169646781489435d-01,-.2630884961190508d-01,
     5      0.1204549715236114d-01,-.3695723695863942d-02,
     6      0.1606755695772621d-02,0.6366469820776166d-01,
     7      -.3264715521079520d+00,0.1123047847197124d+01,
     8      -.3007524707792741d+01,0.6678155057695335d+01/
         data arr1339/
     1      -.1274288413641715d+02,0.2138927206050733d+02,
     2      -.3211214126510621d+02,0.4366487236498102d+02,
     3      -.5430681887695791d+02,0.6227102790110771d+02,
     4      -.6626445196752340d+02,0.6580258710423993d+02,
     5      -.6126725594834821d+02,0.5370581901783125d+02,
     6      -.4448089465180832d+02,0.3492027197521663d+02,
     7      -.2605666714360321d+02,0.1852986274430783d+02,
     8      -.1258114819824848d+02,0.8179570937402991d+01/
         data arr1340/
     1      -.5090176331242831d+01,0.3049108972343904d+01,
     2      -.1743135009771800d+01,0.9688106723501733d+00,
     3      -.5029942642455809d+00,0.2612256588634754d+00,
     4      -.1162035258514933d+00,0.5686786372638419d-01,
     5      -.1785350017012829d-01,0.8304398732707607d-02,
     6      0.4999495427819821d-01,-.2726223157010507d+00,
     7      0.9972473337180033d+00,-.2839895740697757d+01,
     8      0.6705609456820031d+01,-.1360623787872202d+02/
         data arr1341/
     1      0.2428593868723162d+02,-.3877186683836760d+02,
     2      0.5606195129147929d+02,-.7414448777337073d+02,
     3      0.9040639069566502d+02,-.1023014649858608d+03,
     4      0.1080271506268832d+03,-.1069559438470722d+03,
     5      0.9969814157134667d+02,-.8780488938232557d+02,
     6      0.7330170658677160d+02,-.5815751073763323d+02,
     7      0.4398027091886782d+02,-.3174274525064352d+02,
     8      0.2194716425330625d+02,-.1450548916633799d+02/
         data arr1342/
     1      0.9242049430073513d+01,-.5596022335075721d+01,
     2      0.3309498329396847d+01,-.1807363266657091d+01,
     3      0.9995674363133755d+00,-.4610495684913463d+00,
     4      0.2405475105840544d+00,-.7690895279670638d-01,
     5      0.3817498445138323d-01,0.3855707385831923d-01,
     6      -.2229663338637008d+00,0.8649296050955652d+00,
     7      -.2612042721398323d+01,0.6540577869399548d+01,
     8      -.1407394732898132d+02,0.2663990922068227d+02/
         data arr1343/
     1      -.4510186662022364d+02,0.6915857098790184d+02,
     2      -.9699657865948420d+02,0.1254228749301952d+03,
     3      -.1505075391649099d+03,0.1685426172526127d+03,
     4      -.1769605955350765d+03,0.1749284326309406d+03,
     5      -.1633696912742435d+03,0.1446349040312564d+03,
     6      -.1216714419512106d+03,0.9758016197438980d+02,
     7      -.7464185161405887d+02,0.5473686842801046d+02,
     8      -.3829060472749001d+02,0.2588217396839804d+02/
         data arr1344/
     1      -.1652717630320508d+02,0.1037510598536445d+02,
     2      -.5928013200684329d+01,0.3483268190118139d+01,
     3      -.1656224697290212d+01,0.9191982223809703d+00,
     4      -.2979962562734166d+00,0.1574925934640401d+00,
     5      0.2923464233426731d-01,-.1788348380697984d+00,
     6      0.7338590580900780d+00,-.2344397727779402d+01,
     7      0.6209922630677291d+01,-.1413530200782488d+02,
     8      0.2830355348326085d+02,-.5068993133207478d+02/
         data arr1345/
     1      0.8222280688544325d+02,-.1219891016837815d+03,
     2      0.1668632518133262d+03,-.2118156314354973d+03,
     3      0.2509167881339626d+03,-.2786783241984149d+03,
     4      0.2914139188063747d+03,-.2878699355124854d+03,
     5      0.2696067160459937d+03,-.2398389252804180d+03,
     6      0.2034943252660222d+03,-.1644902185189929d+03,
     7      0.1276343911231888d+03,-.9417246741183473d+02,
     8      0.6737843161763307d+02,-.4517247678443795d+02/
         data arr1346/
     1      0.3003747725901888d+02,-.1785933029589264d+02,
     2      0.1112752409594387d+02,-.5423598463397983d+01,
     3      0.3195850658134560d+01,-.1046327843522602d+01,
     4      0.5876699770599352d+00,0.2181195664832952d-01,
     5      -.1408264066050098d+00,0.6099293475157840d+00,
     6      -.2056521676026558d+01,0.5749406987873876d+01,
     7      -.1381264986296569d+02,0.2919091796765144d+02,
     8      -.5517763560451701d+02,0.9446452061271511d+02/
         data arr1347/
     1      -.1479211522633061d+03,0.2135529939918593d+03,
     2      -.2861076917564604d+03,0.3577167130107880d+03,
     3      -.4192944787704635d+03,0.4627761918850115d+03,
     4      -.4823935706878991d+03,0.4768695234958646d+03,
     5      -.4474624233442107d+03,0.4007749450814039d+03,
     6      -.3413361967075857d+03,0.2796610115861099d+03,
     7      -.2168467993569890d+03,0.1639053302703679d+03,
     8      -.1148363748206768d+03,0.8074120554922618d+02/
         data arr1348/
     1      -.4968362915262598d+02,0.3277096532569684d+02,
     2      -.1628505211507904d+02,0.1017198034076017d+02,
     3      -.3350802255585628d+01,0.1996795337828651d+01,
     4      0.1602532425252031d-01,-.1089772535552482d+00,
     5      0.4971298973575336d+00,-.1765481274607940d+01,
     6      0.5198659434749151d+01,-.1315480647227660d+02,
     7      0.2928153200749716d+02,-.5829709147599633d+02,
     8      0.1051215243394167d+03,-.1733749229613218d+03/
         data arr1349/
     1      0.2636347267190599d+03,-.3720017198798241d+03,
     2      0.4898927595718428d+03,-.6047244983818684d+03,
     3      0.7030240387041790d+03,-.7715467345251141d+03,
     4      0.8034461706165296d+03,-.7932006019359628d+03,
     5      0.7485210052862280d+03,-.6696587614905179d+03,
     6      0.5782912967418877d+03,-.4694042169719157d+03,
     7      0.3742208022081362d+03,-.2726588655110847d+03,
     8      0.2024133690446250d+03,-.1282007423408731d+03/
         data arr1350/
     1      0.8939986952443326d+02,-.4506024528239274d+02,
     2      0.2979683454691019d+02,-.9841605087221492d+01,
     3      0.6214473218108168d+01,0.1160033969865597d-01,
     4      -.8293280098003043d-01,0.3977252423708935d+00,
     5      -.1484917668001227d+01,0.4596774559653189d+01,
     6      -.1222844031297238d+02,0.2861563773579756d+02,
     7      -.5989316771536181d+02,0.1135394409907203d+03,
     8      -.1968568234594871d+03,0.3146996336527731d+03/
         data arr1351/
     1      -.4667833673055125d+03,0.6462687611262205d+03,
     2      -.8384246954221618d+03,0.1024819422241409d+04,
     3      -.1181491399041317d+04,0.1293779197058398d+04,
     4      -.1340342630114484d+04,0.1330458951748843d+04,
     5      -.1246197743006408d+04,0.1132622530756808d+04,
     6      -.9583748582318838d+03,0.8048345232325355d+03,
     7      -.6066819675190518d+03,0.4750220756537313d+03,
     8      -.3079701542931080d+03,0.2268280226411802d+03/
         data arr1352/
     1      -.1153827473276909d+03,0.8069702037587336d+02,
     2      -.2663690572839572d+02,0.1780511481805405d+02,
     3      0.8276387762192937d-02,-.6209993521764809d-01,
     4      0.3125566372166801d+00,-.1224727810167574d+01,
     5      0.3978972367299117d+01,-.1110903238814744d+02,
     6      0.2728292876710703d+02,-.5992959830190193d+02,
     7      0.1192334649966441d+03,-.2169456271105023d+03,
     8      0.3639951590111704d+03,-.5664951508903094d+03/
         data arr1353/
     1      0.8232266142239512d+03,-.1120205269581225d+04,
     2      0.1437347558862723d+04,-.1736725109789008d+04,
     3      0.1996880439888618d+04,-.2164703573633783d+04,
     4      0.2257225492027281d+04,-.2205485707621836d+04,
     5      0.2107299206316471d+04,-.1850217404671522d+04,
     6      0.1635304169408707d+04,-.1268404297331532d+04,
     7      0.1046727688898212d+04,-.6908470462312023d+03,
     8      0.5370738021878666d+03,-.2743909345895316d+03/
         data arr1354/
     1      0.2028388228216627d+03,-.6670382046592972d+02,
     2      0.4716774880383235d+02,0.5820732066080908d-02,
     3      -.4576984100521549d-01,0.2413905713210256d+00,
     4      -.9912189467258863d+00,0.3374466822307667d+01,
     5      -.9872691226928049d+01,0.2540747757673695d+02,
     6      -.5848019951789235d+02,0.1219244252490894d+03,
     7      -.2324229397660516d+03,0.4086730615032151d+03,
     8      -.6661594322262177d+03,0.1014630712178759d+04/
         data arr1355/
     1      -.1445155073234803d+04,0.1943956130268623d+04,
     2      -.2455495753792366d+04,0.2961070167737693d+04,
     3      -.3347962034221158d+04,0.3663859572223304d+04,
     4      -.3718824865475613d+04,0.3732945066677999d+04,
     5      -.3383717493541116d+04,0.3146105841185560d+04,
     6      -.2496697625507822d+04,0.2170859387484954d+04,
     7      -.1450588462488571d+04,0.1190002440564211d+04,
     8      -.6077633410893984d+03,0.4747497898052170d+03/
         data arr1356/
     1      -.1550672547889975d+03,0.1159617479917736d+03,
     2      0.4034845325962476d-02,-.3320901317783757d-01,
     3      0.1832596966723191d+00,-.7875787356547289d+00,
     4      0.2805484011045329d+01,-.8589664262311238d+01,
     5      0.2313153094019734d+02,-.5570843462259545d+02,
     6      0.1215463873469887d+03,-.2423650075413299d+03,
     7      0.4460333114820972d+03,-.7600767109775314d+03,
     8      0.1211975549620875d+04,-.1802722241553441d+04/
         data arr1357/
     1      0.2539705113837499d+04,-.3343783797661963d+04,
     2      0.4225829506381750d+04,-.4964572100625275d+04,
     3      0.5699232652882540d+04,-.5980671421399733d+04,
     4      0.6305740310316312d+04,-.5868281272155742d+04,
     5      0.5739913918466023d+04,-.4632850513531474d+04,
     6      0.4244938780233349d+04,-.2855965125999466d+04,
     7      0.2472779739581456d+04,-.1256636970809085d+04,
     8      0.1037427523017820d+04,-.3355520805453956d+03/
         data arr1358/
     1      0.2654002312336868d+03,0.2755297655523906d-02,
     2      -.2371977818559307d-01,0.1367567009010279d+00,
     3      -.6144927646705942d+00,0.2287166313647727d+01,
     4      -.7319758458290096d+01,0.2060003763619272d+02,
     5      -.5183899281278786d+02,0.1182267425910654d+03,
     6      -.2461818861071914d+03,0.4737215716835805d+03,
     7      -.8421283022207340d+03,0.1404698556682356d+04,
     8      -.2175964487063160d+04,0.3208973825847183d+04/
         data arr1359/
     1      -.4387982451348032d+04,0.5810558890516853d+04,
     2      -.7060843499201565d+04,0.8504016721281587d+04,
     3      -.9175776503349702d+04,0.1016608825062312d+05,
     4      -.9654284827425305d+04,0.9940322245045083d+04,
     5      -.8109445299529420d+04,0.7835815085393962d+04,
     6      -.5278502352697244d+04,0.4827060483732166d+04,
     7      -.2429504337306049d+04,0.2121193453354599d+04,
     8      -.6773121971034220d+03,0.5669507213688607d+03/
         data arr1360/
     1      0.1850091802007986d-02,-.1666568618849264d-01,
     2      0.1002113128393773d+00,-.4705645485717011d+00,
     3      0.1827325297284002d+01,-.6107454104191492d+01,
     4      0.1794212690792071d+02,-.4711513093409271d+02,
     5      0.1122268889483538d+03,-.2435806905050078d+03,
     6      0.4898477662387623d+03,-.9060805491942864d+03,
     7      0.1580813084285750d+04,-.2541535882361526d+04,
     8      0.3924483892703905d+04,-.5548795258509954d+04/
         data arr1361/
     1      0.7704099313904673d+04,-.9631080165427187d+04,
     2      0.1218225470480705d+05,-.1343095029859454d+05,
     3      0.1565753062343964d+05,-.1507287688608209d+05,
     4      0.1636123863287097d+05,-.1340304107678549d+05,
     5      0.1367881232035476d+05,-.9173032636169452d+04,
     6      0.8873490198535845d+04,-.4401664611194628d+04,
     7      0.4070493181542785d+04,-.1278837486815796d+04,
     8      0.1134493698939088d+04,-.4409582556792611d-11/
         data arr1362/
     1      0.3715151161164683d-13,-.2119074481581641d-15,
     2      0.9481766835080732d-18,-.3540548292964667d-20,
     3      0.1142386233448081d-22,-.2356567371498569d-25,
     4      -.6649507649112672d-26,0.2786927974405770d-25,
     5      -.2346860793100027d-25,0.2064894259806065d-24,
     6      -.3793944049033123d-25,0.9283882889950489d-24,
     7      0.2644849538178703d-25,0.3645317430923175d-23,
     8      0.4690319029531918d-24,0.1052405710666058d-22/
         data arr1363/
     1      0.2077962447312584d-23,0.2339691319244732d-22,
     2      0.5482520498811178d-23,0.4082855017775123d-22,
     3      0.1075886282387720d-22,0.5302946452311349d-22,
     4      0.1485435882539470d-22,0.5383921688224979d-22,
     5      0.1631259514692473d-22,0.3502976167462231d-22,
     6      0.1104964666435988d-22,0.1612521883471019d-22,
     7      0.5952848610976582d-23,-.1613219061559833d-07,
     8      0.7096665909599919d-09,-.2113518713819869d-10/
         data arr1364/
     1      0.4937773358075796d-12,-.9627078137952862d-14,
     2      0.1621889312020499d-15,-.2415120920073348d-17,
     3      0.3227347581008115d-19,-.3488416507698296d-21,
     4      -.8074182044841183d-22,0.2933119091639583d-21,
     5      -.2061750328369528d-21,0.1507647123526962d-20,
     6      -.4865098735621158d-21,0.6654481788968083d-20,
     7      -.9887810195636107d-21,0.2093978664581610d-19,
     8      -.3386462833151984d-21,0.4785866004041007d-19/
         data arr1365/
     1      0.2575240348053823d-20,0.8860028563157456d-19,
     2      0.1090186600761905d-19,0.1174140698481782d-18,
     3      0.1839773400816606d-19,0.1295531329627987d-18,
     4      0.2571592281890259d-19,0.8639257057168322d-19,
     5      0.1831195511672616d-19,0.4742564287947650d-19,
     6      0.1203022442021860d-19,-.1207774523049561d-05,
     7      0.1285892153554137d-06,-.9268595945948583d-08,
     8      0.5240788953676644d-09,-.2472963361597957d-10/
         data arr1366/
     1      0.1008328574575589d-11,-.3633970817343061d-13,
     2      0.1176307655966962d-14,-.3460026036279585d-16,
     3      0.9180089304179275d-18,0.5163576297290251d-19,
     4      -.3055454108155743d-19,0.3339520636099977d-18,
     5      -.8710699687954798d-20,0.1244457470082828d-17,
     6      0.1275366771215526d-18,0.3555196172722730d-17,
     7      0.5978115225593802d-18,0.7717559370541196d-17,
     8      0.1477390710891030d-17,0.1320100415069571d-16/
         data arr1367/
     1      0.2875302824671894d-17,0.1680171292967509d-16,
     2      0.3904662196257266d-17,0.1663303158559670d-16,
     3      0.4461713910521524d-17,0.1063181861453104d-16,
     4      0.3081501737746356d-17,0.4728823676441889d-17,
     5      0.1818423653341550d-17,-.2083758753357703d-04,
     6      0.4036501093286754d-05,-.5293628178278724d-06,
     7      0.5445968308325993d-07,-.4675575519161930d-08,
     8      0.3468633579605428d-09,-.2274452057419792d-10/
         data arr1368/
     1      0.1339544860003846d-11,-.7171825990750001d-13,
     2      0.3523338531837323d-14,-.1597022785507472d-15,
     3      0.6061626504529025d-17,0.2056481914522767d-17,
     4      -.1330692899922934d-17,0.1077630557585797d-16,
     5      -.2540533883096159d-17,0.3505065217613742d-16,
     6      -.7689478671918772d-18,0.7962125717772924d-16,
     7      0.5230609463366500d-17,0.1455567609311467d-15,
     8      0.2347994813616401d-16,0.1872310641400711d-15/
         data arr1369/
     1      0.4186872615739726d-16,0.1994502748317732d-15,
     2      0.5978210108825568d-16,0.1273654296939143d-15,
     3      0.4568420389875690d-16,0.6787751836048434d-16,
     4      0.2896828342805548d-16,-.1634649230948921d-03,
     5      0.4957707699069934d-04,-.1017953599948864d-04,
     6      0.1639639472098340d-05,-.2203976893605949d-06,
     7      0.2559935901749758d-07,-.2628125864490350d-08,
     8      0.2423401460852068d-09,-.2031406164951506d-10/
         data arr1370/
     1      0.1562611960983905d-11,-.1111334383910930d-12,
     2      0.7347474038336531d-14,-.4002434314960356d-15,
     3      -.1633185893536641d-16,0.2114115698216334d-15,
     4      -.1546207250178929d-15,0.6401516876674501d-15,
     5      -.3992405559485126d-15,0.1441483142722384d-14,
     6      -.7994841242795438d-15,0.2585636569062856d-14,
     7      -.1202744272245310d-14,0.3410224782565211d-14,
     8      -.1408359749816168d-14,0.3550730318369041d-14/
         data arr1371/
     1      -.1158948840035768d-14,0.2353009460058682d-14,
     2      -.6727922784495357d-15,0.1124896737216650d-14,
     3      -.1685123947083625d-15,-.7804490284834505d-03,
     4      0.3377854008300936d-03,-.9897555097140630d-04,
     5      0.2275036129917220d-04,-.4364022269908240d-05,
     6      0.7233508564896571d-06,-.1059756422103653d-06,
     7      0.1394521614160766d-07,-.1668156048278992d-08,
     8      0.1831181095635583d-09,-.1858694124175812d-10/
         data arr1372/
     1      0.1755485806130408d-11,-.1549250984625717d-12,
     2      0.1289438056300547d-13,-.4276300562603224d-15,
     3      0.9993206896371647d-16,0.1634422465425159d-14,
     4      0.5620922190538261d-16,0.3586898581933848d-14,
     5      0.4844164153064906d-16,0.6348941673279651d-14,
     6      0.1126629641093208d-15,0.8383861136485358d-14,
     7      0.3312972628761176d-16,0.8909340378534994d-14,
     8      0.2079012905209612d-15,0.6020498823481346d-14/
         data arr1373/
     1      0.1074262246810992d-15,0.3026225331737026d-14,
     2      0.2999298998365348d-15,-.2644267542512147d-02,
     3      0.1533945305065992d-02,-.6024278994235938d-03,
     4      0.1855981298977456d-03,-.4771779919999972d-04,
     5      0.1060109182907720d-04,-.2081688786772151d-05,
     6      0.3671496723904530d-06,-.5886575541013894d-07,
     7      0.8660949139451512d-08,-.1178287473547648d-08,
     8      0.1491578590923865d-09,-.1766168300661497d-10/
         data arr1374/
     1      0.1965418589625886d-11,-.2044770382535048d-12,
     2      0.2143599893742720d-13,0.3064690061435886d-14,
     3      0.3463901185821061d-14,0.1038202498904569d-13,
     4      0.8105180248135541d-14,0.1729307079603539d-13,
     5      0.1623104321791791d-13,0.2057890485981430d-13,
     6      0.2342956011778989d-13,0.1967022724909054d-13,
     7      0.2682726115492580d-13,0.1144200793073497d-13,
     8      0.1918749275781060d-13,0.5147792404244715d-14/
         data arr1375/
     1      0.1014486872838342d-13,-.6966121738545439d-02,
     2      0.5177670893588107d-02,-.2605364828572869d-02,
     3      0.1028432913951958d-02,-.3387830539731337d-03,
     4      0.9643413111729930d-04,-.2426246266423857d-04,
     5      0.5482783841952152d-05,-.1126314312727482d-05,
     6      0.2123250683828796d-06,-.3701058932626706d-07,
     7      0.6002881248040432d-08,-.9107468243391792d-09,
     8      0.1298397222068820d-09,-.1746217722460863d-10/
         data arr1376/
     1      0.2229741678244237d-11,-.2699685242807281d-12,
     2      0.5256238497935176d-13,-.5237127138948962d-14,
     3      0.4856716539478524d-13,0.3183922628746843d-15,
     4      0.8549835504512061d-13,-.3961792943684250d-17,
     5      0.1108281186609199d-12,0.3777719682691239d-14,
     6      0.1115337533197296d-12,0.9532579076950222d-15,
     7      0.7218616876070481d-13,0.3092461093562221d-14,
     8      0.3186108325066904d-13,-.1513540276797520d-01/
         data arr1377/
     1      0.1393440274068009d-01,-.8685072667707835d-02,
     2      0.4246507268394627d-02,-.1732720752986758d-02,
     3      0.6109260783514329d-03,-.1903898388693641d-03,
     4      0.5329187546867688d-04,-.1356033682408311d-04,
     5      0.3166380779487431d-05,-.6836579378606622d-06,
     6      0.1373483948835998d-06,-.2581144053021696d-07,
     7      0.4557925985100703d-08,-.7592346230967870d-09,
     8      0.1197136115839695d-09,-.1786034751267511d-10/
         data arr1378/
     1      0.2548312349463299d-11,-.2156075478801985d-12,
     2      0.4976505477166333d-13,0.2130539993108095d-12,
     3      0.4227814752462874d-13,0.2682868957046101d-12,
     4      0.8957180589005731d-13,0.2515798071347225d-12,
     5      0.1327517972286825d-12,0.1540952499702939d-12,
     6      0.1081358067872786d-12,0.5923007237310555d-13,
     7      0.6765610502269915d-13,-.2823575126950669d-01,
     8      0.3136526555127638d-01,-.2358790184042577d-01/
         data arr1379/
     1      0.1391563318243766d-01,-.6851015065568203d-02,
     2      0.2914541574663467d-02,-.1095924414550265d-02,
     3      0.3701289756126011d-03,-.1136364879805114d-03,
     4      0.3201589977458620d-04,-.8340588167814230d-05,
     5      0.2021792827059817d-05,-.4584380328409031d-06,
     6      0.9767670548429466d-07,-.1963208360493063d-07,
     7      0.3735050204504889d-08,-.6745580588928371d-09,
     8      0.1160125865017391d-09,-.1878064115905645d-10/
         data arr1380/
     1      0.3001374223457848d-11,-.1323580154974237d-13,
     2      0.1587354376972212d-12,0.5390960867634616d-12,
     3      0.1894982516437833d-12,0.5136005874381349d-12,
     4      0.2876052403867383d-12,0.3189010345854639d-12,
     5      0.2307173225838718d-12,0.1160324944977773d-12,
     6      0.1502532725092291d-12,-.4654689154071057d-01,
     7      0.6109683450555347d-01,-.5429220212467995d-01,
     8      0.3784683112264202d-01,-.2201708795576460d-01/
         data arr1381/
     1      0.1106760406640356d-01,-.4917477328178617d-02,
     2      0.1962425841880074d-02,-.7119284961984056d-03,
     3      0.2370078278583863d-03,-.7295785563032553d-04,
     4      0.2089731259726072d-04,-.5599030625399349d-05,
     5      0.1409618570733162d-05,-.3347775001709586d-06,
     6      0.7526011092749703d-07,-.1606341774914603d-07,
     7      0.3264044261604745d-08,-.6325923562765214d-09,
     8      0.1174093822547476d-09,-.2028800641436950d-10/
         data arr1382/
     1      0.3743008814885306d-11,0.1017448860518656d-12,
     2      0.4530312237012069d-12,0.6183240312347582d-12,
     3      0.4979889966250456d-12,0.3816714315334292d-12,
     4      0.3840593028842789d-12,0.1432403520561077d-12,
     5      0.2310965475723381d-12,-.6926262639237465d-01,
     6      0.1056135302814173d+00,-.1090262025449926d+00,
     7      0.8829081560809771d-01,-.5966758519834413d-01,
     8      0.3484374099925917d-01,-.1798482047464897d-01/
         data arr1383/
     1      0.8337763514662391d-02,-.3513866629541907d-02,
     2      0.1358952150050728d-02,-.4859662556497406d-03,
     3      0.1617026252286761d-03,-.5033059373689450d-04,
     4      0.1472018974753697d-04,-.4061259191361190d-05,
     5      0.1060625601627628d-05,-.2629856414980467d-06,
     6      0.6207926904227116d-07,-.1398413224351705d-07,
     7      0.3014051680371647d-08,-.6216586550205568d-09,
     8      0.1252867935981265d-09,-.2313375586597989d-10/
         data arr1384/
     1      0.6940242002582563d-11,-.5531493744236694d-12,
     2      0.2752942978305240d-11,0.3118391420105184d-13,
     3      0.1747465986372450d-11,-.4817414782281420d-13,
     4      0.7483853725288173d-12,-.9454734707643693d-01,
     5      0.1651374928389638d+00,-.1952687507372737d+00,
     6      0.1811311423892912d+00,-.1402141342012709d+00,
     7      0.9378941885438734d-01,-.5545119505335457d-01,
     8      0.2944625790163779d-01,-.1421482597993481d-01/
         data arr1385/
     1      0.6297035969935980d-02,-.2579371269881235d-02,
     2      0.9831064606900437d-03,-.3505026199216696d-03,
     3      0.1174216981626411d-03,-.3710832889556230d-04,
     4      0.1110065137977981d-04,-.3152785227108851d-05,
     5      0.8524744486097845d-06,-.2199662427538430d-06,
     6      0.5428689406810542d-07,-.1283625409365195d-07,
     7      0.2919253009113935d-08,-.6346550852532881d-09,
     8      0.1400954054573875d-09,-.2602533895337078d-10/
         data arr1386/
     1      0.1210167075497124d-10,-.5321116425707177d-12,
     2      0.4934581085252728d-11,-.1889590160300219d-12,
     3      0.2368529968305882d-11,-.1198996260215677d+00,
     4      0.2370547573426842d+00,-.3173001256098890d+00,
     5      0.3331694178578813d+00,-.2919431609729893d+00,
     6      0.2210522113120639d+00,-.1479402801317074d+00,
     7      0.8892833180316902d-01,-.4859438486403777d-01,
     8      0.2436773837671588d-01,-.1129867235400231d-01/
         data arr1387/
     1      0.4874708093074652d-02,-.1967314715386745d-02,
     2      0.7460457074525181d-03,-.2668842755067250d-03,
     3      0.9037213563883097d-04,-.2905461090556680d-04,
     4      0.8892748512884753d-05,-.2597453615213226d-05,
     5      0.7256077203653680d-06,-.1942454274913305d-06,
     6      0.4992941527552777d-07,-.1233797967775244d-07,
     7      0.2947107464962111d-08,-.6751422016019708d-09,
     8      0.1602955069637054d-09,-.3298308637013852d-10/
         data arr1388/
     1      0.1396542132492949d-10,-.2101189629516723d-11,
     2      0.3637569436068305d-11,-.1426786400071391d+00,
     3      0.3161177318128620d+00,-.4741649794299437d+00,
     4      0.5579347482330105d+00,-.5478676222214239d+00,
     5      0.4648697025077711d+00,-.3486437341921851d+00,
     6      0.2348521944019836d+00,-.1438134865056911d+00,
     7      0.8081422242416157d-01,-.4199127286713047d-01,
     8      0.2030202172608401d-01,-.9181709826067379d-02/
         data arr1389/
     1      0.3901882687903616d-02,-.1564194691457472d-02,
     2      0.5935556083249865d-03,-.2138459255392190d-03,
     3      0.7334675193923745d-04,-.2400776515290298d-04,
     4      0.7515578881463433d-05,-.2254606982572795d-05,
     5      0.6493408918029585d-06,-.1798189547572597d-06,
     6      0.4797593949713917d-07,-.1232601501829843d-07,
     7      0.3077415418930576d-08,-.7267221043519638d-09,
     8      0.1801091160301372d-09,-.3432303316229355d-10/
         data arr1390/
     1      0.1323207761758224d-10,-.1606178689816497d+00,
     2      0.3953477186763582d+00,-.6588026483309438d+00,
     3      0.8612014510909877d+00,-.9394906440567581d+00,
     4      0.8856121128801989d+00,-.7378866473706099d+00,
     5      0.5522018927756810d+00,-.3756629503351175d+00,
     6      0.2345211579771253d+00,-.1353782052338977d+00,
     7      0.7271507934274619d-01,-.3653459008698277d-01,
     8      0.1724846155106808d-01,-.7681790272972049d-02/
         data arr1391/
     1      0.3238385396046738d-02,-.1296174818664162d-02,
     2      0.4938999244346265d-03,-.1795995677027456d-03,
     3      0.6246133341417424d-04,-.2081686400654825d-04,
     4      0.6660506704332593d-05,-.2049136777559355d-05,
     5      0.6072154911680033d-06,-.1733568566787089d-06,
     6      0.4785914855360510d-07,-.1260925883245044d-07,
     7      0.3267889633700415d-08,-.7195832310185351d-09,
     8      0.1798036328116634d-09,-.1721906973513877d+00/
         data arr1392/
     1      0.4673298651434719d+00,-.8586735959756321d+00,
     2      0.1237673233343514d+01,-.1488751386069298d+01,
     3      0.1547396965078371d+01,-.1421596409206215d+01,
     4      0.1173040564948441d+01,-.8799175468931475d+00,
     5      0.6056951786543970d+00,-.3855221297175653d+00,
     6      0.2283250261741743d+00,-.1264916175158372d+00,
     7      0.6584705343284358d-01,-.3233530031914230d-01,
     8      0.1503043185971107d-01,-.6633381305019324d-02/
         data arr1393/
     1      0.2787011875029644d-02,-.1117463595131786d-02,
     2      0.4285167975833799d-03,-.1574698819514554d-03,
     3      0.5555434344917337d-04,-.1884422821647292d-04,
     4      0.6157097707351882d-05,-.1936910258938259d-05,
     5      0.5895024442715766d-06,-.1704085699386371d-06,
     6      0.4858471437793263d-07,-.1153542010977418d-07,
     7      0.3100073097967587d-08,-.1767671213896032d+00,
     8      0.5255151554994828d+00,-.1057693225534643d+01/
         data arr1394/
     1      0.1669965570746432d+01,-.2200359295270393d+01,
     2      0.2505203840867794d+01,-.2521085361039530d+01,
     3      0.2278736811979090d+01,-.1872375804809093d+01,
     4      0.1411806130958368d+01,-.9843287362112942d+00,
     5      0.6385784704728360d+00,-.3875184698669997d+00,
     6      0.2209718292746850d+00,-.1188631851221789d+00,
     7      0.6052179915833748d-01,-.2925803651926033d-01,
     8      0.1346539053964219d-01,-.5914019499033970d-02/
         data arr1395/
     1      0.2484204033983086d-02,-.9999539770615600d-03,
     2      0.3864306429690297d-03,-.1435618128538772d-03,
     3      0.5138239693906407d-04,-.1768617495988811d-04,
     4      0.5896819530403635d-05,-.1854342328343664d-05,
     5      0.5792692890950468d-06,-.1466152425865073d-06,
     6      0.4312273068273961d-07,-.1745723519876039d+00,
     7      0.5652108790990193d+00,-.1238900087381495d+01,
     8      0.2130273534819563d+01,-.3056840301221155d+01/
         data arr1396/
     1      0.3790299347139946d+01,-.4154026723483248d+01,
     2      0.4089094970833909d+01,-.3659125821102314d+01,
     3      0.3004766162823075d+01,-.2281534676256723d+01,
     4      0.1611953375100386d+01,-.1065324468539450d+01,
     5      0.6615728903763011d+00,-.3875604291426204d+00,
     6      0.2149092920170384d+00,-.1131461158520724d+00,
     7      0.5671066827292245d-01,-.2712552376655091d-01,
     8      0.1240892884769890d-01,-.5439558528487980d-02/
         data arr1397/
     1      0.2289332905076880d-02,-.9260061645125482d-03,
     2      0.3609568980799463d-03,-.1350804000801819d-03,
     3      0.4905615215231030d-04,-.1665251608641616d-04,
     4      0.5668136610580826d-05,-.1516512226233630d-05,
     5      0.4860442155696365d-06,-.1665043782423874d+00,
     6      0.5840894115438896d+00,-.1387150972377899d+01,
     7      0.2584291179487986d+01,-.4017884516359621d+01,
     8      0.5397800589067622d+01,-.6409604580836588d+01/
         data arr1398/
     1      0.6836090058139849d+01,-.6627909159540027d+01,
     2      0.5896964461008912d+01,-.4851360298353922d+01,
     3      0.3713706333542405d+01,-.2659228175282314d+01,
     4      0.1789245899515737d+01,-.1135665209310198d+01,
     5      0.6823147047980853d+00,-.3892129584270277d+00,
     6      0.2113640694470294d+00,-.1095365416314446d+00,
     7      0.5429185487932865d-01,-.2578415178718628d-01,
     8      0.1175768551953052d-01,-.5150504534155014d-02/
         data arr1399/
     1      0.2175383153856750d-02,-.8798783286483472d-03,
     2      0.3462915054241178d-03,-.1259764719222207d-03,
     3      0.4648985503804409d-04,-.1305133886609435d-04,
     4      0.4535919900086616d-05,-.1538834937035818d+00,
     5      0.5822030282830639d+00,-.1491240204911709d+01,
     6      0.2996360514652365d+01,-.5024337640796508d+01,
     7      0.7279925751254741d+01,-.9323309430365116d+01,
     8      0.1072445873223515d+02,-.1121431886990760d+02/
         data arr1400/
     1      0.1076102426225703d+02,-.9548109114494689d+01,
     2      0.7882975010168116d+01,-.6087891676521213d+01,
     3      0.4417841171639588d+01,-.3024258728608602d+01,
     4      0.1959666437387890d+01,-.1205624558572887d+01,
     5      0.7061306257711688d+00,-.3946683912858957d+00,
     6      0.2109787547464419d+00,-.1080508397113174d+00,
     7      0.5314174335228175d-01,-.2508822831940562d-01,
     8      0.1142952401563485d-01,-.4968633335483147d-02/
         data arr1401/
     1      0.2109738718144794d-02,-.8168258132762322d-03,
     2      0.3253819030319127d-03,-.9520629581593330d-04,
     3      0.3572211743991388d-04,-.1381990483426408d+00,
     4      0.5616092685757170d+00,-.1545091496986387d+01,
     5      0.3334628485480220d+01,-.6005912476371651d+01,
     6      0.9347036186232991d+01,-.1285771704083246d+02,
     7      0.1588605055029874d+02,-.1784268665936673d+02,
     8      0.1839025499516835d+02,-.1752662495796011d+02/
         data arr1402/
     1      0.1554239228469020d+02,-.1289262468629549d+02,
     2      0.1004919657232271d+02,-.7389012912808752d+01,
     3      0.5142763943215689d+01,-.3398364163393511d+01,
     4      0.2137915471778023d+01,-.1283408063048003d+01,
     5      0.7369231653806849d+00,-.4052776738911371d+00,
     6      0.2141044256116094d+00,-.1084414356379826d+00,
     7      0.5307259794458474d-01,-.2466400585216399d-01,
     8      0.1125393393960017d-01,-.4606502428359002d-02/
         data arr1403/
     1      0.1973050876208915d-02,-.5980449431182848d-03,
     2      0.2413029833890634d-03,-.1208983155113039d+00,
     3      0.5257675747015437d+00,-.1547954065976357d+01,
     4      0.3575161436493535d+01,-.6890829987952802d+01,
     5      0.1147653524507925d+02,-.1689448931924465d+02,
     6      0.2233785562806277d+02,-.2684912373718108d+02,
     7      0.2961433302516336d+02,-.3020346643260313d+02,
     8      0.2866293854322565d+02,-.2544416841562473d+02/
         data arr1404/
     1      0.2122377745108938d+02,-.1670015962301408d+02,
     2      0.1243871617212726d+02,-.8796001626364800d+01,
     3      0.5921780203789773d+01,-.3803913434028857d+01,
     4      0.2337443884324127d+01,-.1375085956379568d+01,
     5      0.7774640623481975d+00,-.4206414362811521d+00,
     6      0.2203642004431443d+00,-.1089010831409678d+00,
     7      0.5321022057402480d-01,-.2287959946908606d-01,
     8      0.1050076428919078d-01,-.3278873066092433d-02/
         data arr1405/
     1      0.1417746419836330d-02,-.1032393695950056d+00,
     2      0.4788692110009580d+00,-.1503762352973671d+01,
     3      0.3704373919823445d+01,-.7615329829188862d+01,
     4      0.1352776343048415d+02,-.2124018486456103d+02,
     5      0.2995385526511508d+02,-.3840071945003274d+02,
     6      0.4517615161419941d+02,-.4914303171809862d+02,
     7      0.4974208009011954d+02,-.4709651445521388d+02,
     8      0.4190071747390049d+02,-.3516524865600130d+02/
         data arr1406/
     1      0.2793622790849267d+02,-.2106968578394959d+02,
     2      0.1512960597043631d+02,-.1036397291361255d+02,
     3      0.6792851422659318d+01,-.4259162183923243d+01,
     4      0.2568797314882198d+01,-.1478436202859815d+01,
     5      0.8264099045168711d+00,-.4320348260359334d+00,
     6      0.2253476856731700d+00,-.1011610877720282d+00,
     7      0.4959833997399432d-01,-.1587367407885162d-01,
     8      0.7332545797731793d-02,-.8621074587745375d-01/
         data arr1407/
     1      0.4252276916153778d+00,-.1419947865774193d+01,
     2      0.3719602875702371d+01,-.8131282322434185d+01,
     3      0.1535977621865831d+02,-.2564517889027735d+02,
     4      0.3845818099337406d+02,-.5242806788837891d+02,
     5      0.6558768823348933d+02,-.7586879131687135d+02,
     6      0.8166084873221749d+02,-.8221768834611733d+02,
     7      0.7778345006684316d+02,-.6941592613747495d+02,
     8      0.5864141657258185d+02,-.4702693286239200d+02/
         data arr1408/
     1      0.3590992424105176d+02,-.2614918191673329d+02,
     2      0.1822657136583419d+02,-.1213818762280662d+02,
     3      0.7786513853634573d+01,-.4747293125793835d+01,
     4      0.2823395370386622d+01,-.1553320633888713d+01,
     5      0.8625347457609021d+00,-.4018488540595501d+00,
     6      0.2099081565105143d+00,-.6853887814936327d-01,
     7      0.3373103372699049d-01,-.7050814571964632d-01,
     8      0.3688072216272367d+00,-.1306021340370437d+01/
         data arr1409/
     1      0.3628059800260950d+01,-.8410791951442629d+01,
     2      0.1684855770107432d+02,-.2983207850842929d+02,
     3      0.4744238680499994d+02,-.6858692868035850d+02,
     4      0.9099131176270494d+02,-.1116193527808117d+03,
     5      0.1274062354977796d+03,-.1360306904657810d+03,
     6      0.1364773547101553d+03,-.1291553638263007d+03,
     7      0.1157081489737795d+03,-.9838588131633249d+02,
     8      0.7967468990273709d+02,-.6149071155840851d+02/
         data arr1410/
     1      0.4545849495750205d+02,-.3204505186966716d+02,
     2      0.2180734493389403d+02,-.1402484751463151d+02,
     3      0.8852660051570947d+01,-.5098604298756706d+01,
     4      0.3006806543274685d+01,-.1445554927375436d+01,
     5      0.8025807911486709d+00,-.2662299660274655d+00,
     6      0.1392571345909932d+00,-.5655254154385179d-01,
     7      0.3129185487448637d+00,-.1172198782258576d+01,
     8      0.3444645185872384d+01,-.8447457495987992d+01/
         data arr1411/
     1      0.1790073787604582d+02,-.3352822932345680d+02,
     2      0.5640437376843281d+02,-.8625928129162826d+02,
     3      0.1210553033108617d+03,-.1570865715308888d+03,
     4      0.1896752266199889d+03,-.2142217141315271d+03,
     5      0.2273581797431233d+03,-.2275822515382516d+03,
     6      0.2156862585145796d+03,-.1939411714425447d+03,
     7      0.1661557130019422d+03,-.1355158520558509d+03,
     8      0.1060026770105897d+03,-.7882508842554886d+02/
         data arr1412/
     1      0.5677575874677119d+02,-.3834902302999303d+02,
     2      0.2563532547508998d+02,-.1537482526848037d+02,
     3      0.9609467135784413d+01,-.4741202114574673d+01,
     4      0.2792144747422327d+01,-.9373099337615344d+00,
     5      0.5199899565019681d+00,-.4453322056049024d-01,
     6      0.2600747281302550d+00,-.1028260539680595d+01,
     7      0.3189196737790120d+01,-.8254632821113537d+01,
     8      0.1846195329510770d+02,-.3649654344938142d+02/
         data arr1413/
     1      0.6480210145311284d+02,-.1045959037045529d+03,
     2      0.1549275339322498d+03,-.2121827510233516d+03,
     3      0.2704082574910209d+03,-.3223141157767125d+03,
     4      0.3610534253082130d+03,-.3813693677903118d+03,
     5      0.3814987312585795d+03,-.3618413479044544d+03,
     6      0.3272432577307998d+03,-.2812352737247729d+03,
     7      0.2322753141934199d+03,-.1815511465867876d+03,
     8      0.1381311563161860d+03,-.9754392156655291d+02/
         data arr1414/
     1      0.6892716556785402d+02,-.4282009312098377d+02,
     2      0.2831394851689230d+02,-.1426156899229410d+02,
     3      0.8892958956702415d+01,-.3010373478500106d+01,
     4      0.1768035633131881d+01,-.3446163479447920d-01,
     5      0.2119768313693312d+00,-.8827396387701016d+00,
     6      0.2883695835903869d+01,-.7861486081230685d+01,
     7      0.1851925183732149d+02,-.3855979440123471d+02,
     8      0.7211268119763261d+02,-.1225940911445538d+03/
         data arr1415/
     1      0.1912603992839361d+03,-.2758825160623277d+03,
     2      0.3703234786921082d+03,-.4648548558666665d+03,
     3      0.5484926963551666d+03,-.6099731089662698d+03,
     4      0.6427667582823706d+03,-.6414521031443966d+03,
     5      0.6112036662032702d+03,-.5518231411968753d+03,
     6      0.4803423149613106d+03,-.3931364471111935d+03,
     7      0.3154302853514090d+03,-.2317674763721579d+03,
     8      0.1728551266384507d+03,-.1106396141525146d+03/
         data arr1416/
     1      0.7728326524780795d+02,-.3954094830745684d+02,
     2      0.2606832466154569d+02,-.8869200039834784d+01,
     3      0.5506082894200560d+01,-.2622565633520783d-01,
     4      0.1695903879723957d+00,-.7424557563035284d+00,
     5      0.2549826658592369d+01,-.7307846424103610d+01,
     6      0.1809806936252880d+02,-.3961527613798719d+02,
     7      0.7788711948179902d+02,-.1391972646498547d+03,
     8      0.2283059880449532d+03,-.3461715637677615d+03/
         data arr1417/
     1      0.4885309366602618d+03,-.6444998279253160d+03,
     2      0.7995545294919168d+03,-.9340849795194267d+03,
     3      0.1035051178547668d+04,-.1084000772235914d+04,
     4      0.1086430307622914d+04,-.1027123778259975d+04,
     5      0.9408856135584087d+03,-.8030452011356087d+03,
     6      0.6785513831597378d+03,-.5161679226306926d+03,
     7      0.4058203264678871d+03,-.2662081711971156d+03,
     8      0.1962033656528674d+03,-.1014787138455111d+03/
         data arr1418/
     1      0.7064955809697187d+02,-.2408487984255567d+02,
     2      0.1578485740763372d+02,-.1963772243317942d-01,
     3      0.1332739195949553d+00,-.6123551272885558d+00,
     4      0.2207121521091100d+01,-.6638790189764664d+01,
     5      0.1725509177063799d+02,-.3963875911198977d+02,
     6      0.8179258678360067d+02,-.1533993214324820d+03,
     7      0.2640663508516987d+03,-.4201115963863274d+03,
     8      0.6222930293755148d+03,-.8610999210849664d+03/
         data arr1419/
     1      0.1121403228499948d+04,-.1373090747109985d+04,
     2      0.1597574744864389d+04,-.1750911184289395d+04,
     3      0.1843327203458497d+04,-.1818324309620453d+04,
     4      0.1750824895905770d+04,-.1551344172301948d+04,
     5      0.1379117751250894d+04,-.1080396848838785d+04,
     6      0.8946611536038778d+03,-.5982802361700925d+03,
     7      0.4648611486503598d+03,-.2419342007446208d+03,
     8      0.1777094686596512d+03,-.6052767336267417d+02/
         data arr1420/
     1      0.4183738116865362d+02,-.1447367101274117d-01,
     2      0.1029273884265943d+00,-.4955862092087482d+00,
     3      0.1871775115665773d+01,-.5899726963715945d+01,
     4      0.1606868791070141d+02,-.3867850943370244d+02,
     5      0.8363693583486346d+02,-.1643360520330215d+03,
     6      0.2964724967417104d+03,-.4940030421669815d+03,
     7      0.7669645616507441d+03,-.1110870568678413d+04,
     8      0.1516642180722847d+04,-.1941452054982950d+04/
         data arr1421/
     1      0.2369013131655152d+04,-.2708479563187668d+04,
     2      0.2992288395527508d+04,-.3067320229423347d+04,
     3      0.3102074564356478d+04,-.2839545025999385d+04,
     4      0.2654169747664320d+04,-.2129609625050753d+04,
     5      0.1856458730952516d+04,-.1258940923119565d+04,
     6      0.1030686719923799d+04,-.5373744424570968d+03,
     7      0.4162167449365733d+03,-.1412447250866267d+03,
     8      0.1028987954435760d+03,-.1050149986274756d-01/
         data arr1422/
     1      0.7813725139117919d-01,-.3937318551849962d+00,
     2      0.1556093098308996d+01,-.5132480899735583d+01,
     3      0.1462859228323777d+02,-.3684145599259734d+02,
     4      0.8337346502062188d+02,-.1713484783252277d+03,
     5      0.3235592889986095d+03,-.5636010567892657d+03,
     6      0.9160978337546343d+03,-.1385675743718374d+04,
     7      0.1981388615289689d+04,-.2643952546450711d+04,
     8      0.3380962288673931d+04,-.4017380984960409d+04/
         data arr1423/
     1      0.4655084438682421d+04,-.4935820089109147d+04,
     2      0.5241301099544185d+04,-.4929921451183995d+04,
     3      0.4844348773417301d+04,-.3958386192860559d+04,
     4      0.3632197886243914d+04,-.2484806941395411d+04,
     5      0.2143144945415047d+04,-.1114548563374379d+04,
     6      0.9100830514620623d+03,-.3068840243173244d+03,
     7      0.2355638277026167d+03,-.7500456082243995d-02,
     8      0.5830118703298220d-01,-.3071133009966794d+00/
         data arr1424/
     1      0.1268426732667826d+01,-.4372486597945350d+01,
     2      0.1302599407684776d+02,-.3427386366995552d+02,
     3      0.8108641120185293d+02,-.1740078350814538d+03,
     4      0.3436046996121345d+03,-.6243305146776577d+03,
     5      0.1061665397722472d+04,-.1672431550087996d+04,
     6      0.2503372917759702d+04,-.3469898065018641d+04,
     7      0.4648887895795773d+04,-.5715843341196125d+04,
     8      0.6946821375625088d+04,-.7578672396639627d+04/
         data arr1425/
     1      0.8452233077248842d+04,-.8121680345730002d+04,
     2      0.8393009026761571d+04,-.6942878831508012d+04,
     3      0.6708548183900341d+04,-.4605563272513170d+04,
     4      0.4186162860016669d+04,-.2162207886237978d+04,
     5      0.1861767121058919d+04,-.6221391893224835d+03,
     6      0.5032422035459876d+03,-.5268961199556870d-02,
     7      0.4270255177505474d-01,-.2349926234280731d+00,
     8      0.1013014794577910d+01,-.3645762973575433d+01/
         data arr1426/
     1      0.1134160279260489d+02,-.3113227070553060d+02,
     2      0.7694872192293319d+02,-.1720850757593329d+03,
     3      0.3552082392456280d+03,-.6714948892914456d+03,
     4      0.1194510785789839d+04,-.1953054643852960d+04,
     5      0.3061099916954457d+04,-.4388233841031774d+04,
     6      0.6163581836394033d+04,-.7800378874414831d+04,
     7      0.9952476247967681d+04,-.1110448593185588d+05,
     8      0.1302125457823975d+05,-.1270164452761098d+05/
         data arr1427/
     1      0.1382022197475100d+05,-.1150249916079275d+05,
     2      0.1171706495281749d+05,-.8029531386561975d+04,
     3      0.7699268616823217d+04,-.3932336499056372d+04,
     4      0.3573873936766493d+04,-.1180147632340189d+04,
     5      0.1006789482284330d+04,0.1072471761489294d-13,
     6      -.8311693948021752d-16,0.4389205161230131d-18,
     7      -.1828331659938070d-20,0.6386156437223691d-23,
     8      -.1936973613945851d-25,0.5523539226463906d-28/
         data arr1428/
     1      -.8424242129279326d-28,-.8540849146933158d-28,
     2      -.2987061524490375d-27,-.6218465985398880d-27,
     3      -.8477586726115508d-27,-.3032438267926304d-26,
     4      -.1775218106146581d-26,-.1101576232200547d-25,
     5      -.3095211421837297d-26,-.3106123427117248d-25,
     6      -.3944674014511226d-26,-.6800856539285097d-25,
     7      -.3387225896689954d-26,-.1190304865073307d-24,
     8      -.8855849919996721d-27,-.1576769405664217d-24/
         data arr1429/
     1      0.2267210638562158d-26,-.1637784214985413d-24,
     2      0.3332339282457328d-26,-.1108829663785338d-24,
     3      0.2425558806397209d-26,-.5295286327934618d-25,
     4      0.2048630986628183d-09,-.8289902433932191d-11,
     5      0.2285744911522164d-12,-.4971401772175319d-14,
     6      0.9066637099695962d-16,-.1434809577393025d-17,
     7      0.2014357350014825d-19,-.2568108249793555d-21,
     8      0.1302535009495512d-23,-.7337352756719565d-23/
         data arr1430/
     1      -.9652192062702224d-23,-.1973910879636288d-22,
     2      -.4052515243052503d-22,-.4487292777065633d-22,
     3      -.1399956472571729d-21,-.8575472508545533d-22,
     4      -.3831861279067683d-21,-.1342977859392160d-21,
     5      -.8325128309745142d-21,-.1630411075795959d-21,
     6      -.1476660262959606d-20,-.1480825957338800d-21,
     7      -.1979521330215536d-20,-.8494695649968618d-22,
     8      -.2136133483235417d-20,-.2310889690659537d-22/
         data arr1431/
     1      -.1469481795689484d-20,0.7936382091461873d-23,
     2      -.7643281977527765d-21,0.3712050905016547d-07,
     3      -.3635442430153821d-08,0.2426013875991566d-09,
     4      -.1277032788737989d-10,0.5636728094807869d-12,
     5      -.2158900606767531d-13,0.7335602586505754d-15,
     6      -.2246102437548142d-16,0.6266871936858076d-18,
     7      -.1689545107322733d-19,-.1949170860067383d-20,
     8      -.1968330067949402d-20,-.1140005024220033d-19/
         data arr1432/
     1      -.4006267717483659d-20,-.4161692951897592d-19,
     2      -.6185348073392842d-20,-.1183007673407277d-18,
     3      -.6829614338366155d-20,-.2584464011602935d-18,
     4      -.1188453837249530d-20,-.4528903371597213d-18,
     5      0.9054104494258485d-20,-.5941007349305856d-18,
     6      0.2071777811457712d-19,-.6155483916906239d-18,
     7      0.2013517352005638d-19,-.4099955953321625d-18,
     8      0.1240071797803379d-19,-.1976567063391921d-18/
         data arr1433/
     1      0.1165237496396665d-05,-.2076331798365216d-06,
     2      0.2520993461286459d-07,-.2414456815953949d-08,
     3      0.1939025118332790d-09,-.1351225871725267d-10,
     4      0.8353530327103316d-12,-.4653699129234668d-13,
     5      0.2363693225119330d-14,-.1104937642899399d-15,
     6      0.4745315924599612d-17,-.2723236964498543d-18,
     7      -.1803135922567876d-18,-.1287249610519219d-18,
     8      -.7159766627081375d-18,-.1318734340150403d-18/
         data arr1434/
     1      -.2125937578231571d-17,0.5343210712997431d-19,
     2      -.4809479196752508d-17,0.5656963237575794d-18,
     3      -.8872629387477910d-17,0.1233764126226136d-17,
     4      -.1199231592712613d-16,0.1819372466356368d-17,
     5      -.1315367784958406d-16,0.1490267014784792d-17,
     6      -.8934985457563601d-17,0.9272380051396028d-18,
     7      -.4737800021900707d-17,0.1431166937310755d-04,
     8      -.3992742515439484d-05,0.7590055898245670d-06/
         data arr1435/
     1      -.1138128773915279d-06,0.1431047673586945d-07,
     2      -.1561339420636408d-08,0.1511256329863516d-09,
     3      -.1318150516895401d-10,0.1048232651877164d-11,
     4      -.7669792955531927d-13,0.5201095522659798d-14,
     5      -.3312361827572370d-15,0.1738727584771759d-16,
     6      -.7089513572916997d-17,-.9835424952004335d-17,
     7      -.1280370948563213d-16,-.3432819540062956d-16,
     8      -.2232963647127655d-16,-.8586659121108823d-16/
         data arr1436/
     1      -.2910120087540378d-16,-.1697275513141044d-15,
     2      -.2913715122601211d-16,-.2418056353748303d-15,
     3      -.1719705715530219d-16,-.2736406065795190d-15,
     4      -.5925681679769302d-17,-.1931794357287969d-15,
     5      0.2912397595142482d-17,-.1020205172634635d-15,
     6      0.9751024604879014d-04,-.3882140505936915d-04,
     7      0.1053137088393070d-04,-.2253571409844916d-05,
     8      0.4043654216734656d-06,-.6295891305209950d-07/
         data arr1437/
     1      0.8696370164602789d-08,-.1082442588096369d-08,
     2      0.1228393612974038d-09,-.1282624368325635d-10,
     3      0.1241306390532802d-11,-.1120390697300393d-12,
     4      0.9456437870817870d-14,-.7892196051646467d-15,
     5      -.1203112178839670d-16,-.7513831691175582d-16,
     6      -.1959696195270037d-15,-.1176699685213462d-15,
     7      -.4439629996326516d-15,-.1481409424530631d-15,
     8      -.8151386677217534d-15,-.1404322613204825d-15/
         data arr1438/
     1      -.1128640719688289d-14,-.6315626323594153d-16,
     2      -.1249830319166471d-14,-.6933439801344154d-17,
     3      -.8844204838119820d-15,0.4203186863946992d-16,
     4      -.4644704803916996d-15,0.4428118674010067d-03,
     5      -.2362916626687403d-03,0.8591523956976513d-04,
     6      -.2464136554923693d-04,0.5926190491385397d-05,
     7      -.1236707422486237d-05,0.2289580472980157d-06,
     8      -.3819714602372379d-07,0.5809941322235755d-08/
         data arr1439/
     1      -.8130957203721484d-09,0.1054705228641329d-09,
     2      -.1275771860272720d-10,0.1446302870369444d-11,
     3      -.1544335328595366d-12,0.1533583488077524d-13,
     4      -.1587165934464038d-14,-.6056504000943452d-15,
     5      -.7250154113892594d-16,-.1749690551253487d-14,
     6      0.1526223480892291d-15,-.3262300035051216d-14,
     7      0.4275892742195050d-15,-.4418173553314677d-14,
     8      0.7420611557308967d-15,-.4709977133236471d-14/
         data arr1440/
     1      0.6025353780760067d-15,-.3173480402966715d-14,
     2      0.4093187965831603d-15,-.1571091325165258d-14,
     3      0.1494664842094193d-02,-.1021908161609337d-02,
     4      0.4760719315021889d-03,-.1749468168020362d-03,
     5      0.5390831813234874d-04,-.1441405067615097d-04,
     6      0.3419116443726997d-05,-.7308492338414835d-06,
     7      0.1424319858715792d-06,-.2553973302941204d-07,
     8      0.4244677905244279d-08,-.6578460537247887d-09/
         data arr1441/
     1      0.9555830638653101d-10,-.1306686450555019d-10,
     2      0.1688709716210114d-11,-.2069231532964864d-12,
     3      0.2474583538488331d-13,-.2625673636136869d-14,
     4      0.8719906667524396d-15,0.7343204758522780d-15,
     5      -.2907613066879909d-15,0.1338370459851844d-14,
     6      -.1579767877824627d-14,0.2318447201627701d-14,
     7      -.3106418482067926d-14,0.1683891151226387d-14,
     8      -.2519788077574977d-14,0.1337846779526911d-14/
         data arr1442/
     1      -.1834992135637944d-14,0.4022515586664154d-02,
     2      -.3406565769970278d-02,0.1965750891454990d-02,
     3      -.8947731493261075d-03,0.3415180601052818d-03,
     4      -.1131084186985892d-03,0.3323332325040093d-04,
     5      -.8799108442722900d-05,0.2124072799698477d-05,
     6      -.4717687983773785d-06,0.9711998150682777d-07,
     7      -.1864399837685079d-07,0.3354542562982381d-08,
     8      -.5681754661460481d-09,0.9092646152486503d-10/
         data arr1443/
     1      -.1379457029607811d-10,0.1969924668752134d-11,
     2      -.2651207271323384d-12,-.1122103765293412d-13,
     3      0.1612779619869765d-13,-.8433423244570949d-13,
     4      0.3256397753752455d-13,-.1146293883591425d-12,
     5      0.4058771830090200d-13,-.1186912668742075d-12,
     6      0.3033142591978988d-13,-.8065761305981792d-13,
     7      0.1737974615042638d-13,-.3708451220835972d-13,
     8      0.9054372254616753d-02,-.9251936289926320d-02/
         data arr1444/
     1      0.6441686450681328d-02,-.3537848967141585d-02,
     2      0.1629278271049182d-02,-.6510761198131624d-03,
     3      0.2308159692766474d-03,-.7373709029061284d-04,
     4      0.2147691847710873d-04,-.5755552641583349d-05,
     5      0.1429623418391464d-05,-.3311367309036382d-06,
     6      0.7188810860784022d-07,-.1469133657510990d-07,
     7      0.2836969099460713d-08,-.5193596779443520d-09,
     8      0.9036107762255630d-10,-.1497800196316859d-10/
         data arr1445/
     1      0.2276708150630265d-11,-.3087902330507355d-12,
     2      -.1389364754055316d-12,0.7312804067859130d-13,
     3      -.2675568201058925d-12,0.1048918445764957d-12,
     4      -.2874262101861351d-12,0.7814230106095033d-13,
     5      -.1992743867483900d-12,0.4874208716496782d-13,
     6      -.9470650435648494d-13,0.1763713692420767d-01,
     7      -.2129515369766668d-01,0.1751967848301968d-01,
     8      -.1136957533128812d-01,0.6186978760132841d-02/
         data arr1446/
     1      -.2921416856483940d-02,0.1223787524544607d-02,
     2      -.4619602095882568d-03,0.1589896842886429d-03,
     3      -.5034570345766354d-04,0.1477663145083016d-04,
     4      -.4044264483539126d-05,0.1037451187769950d-05,
     5      -.2505245846522344d-06,0.5716416568592635d-07,
     6      -.1236573716752154d-07,0.2543277011065437d-08,
     7      -.4986016441334670d-09,0.9323845143343814d-10,
     8      -.1663273956327346d-10,0.2540008585369485d-11/
         data arr1447/
     1      -.2986506031753312d-12,-.4078698224951314d-12,
     2      0.2074598949829701d-12,-.5262312031773746d-12,
     3      0.1597932933832953d-12,-.3710043064701639d-12,
     4      0.9984392716622772d-13,-.1834887722645474d-12,
     5      0.3048800006902147d-01,-.4276359494383362d-01,
     6      0.4087070585764453d-01,-.3081220850421332d-01,
     7      0.1947824336618485d-01,-.1068457548231055d-01,
     8      0.5199509073967584d-02,-.2280097753235092d-02/
         data arr1448/
     1      0.9116128157012027d-03,-.3353485760328472d-03,
     2      0.1143410228200665d-03,-.3635454880068554d-04,
     3      0.1083376625753635d-04,-.3039168146379062d-05,
     4      0.8056027927148374d-06,-.2024465649177037d-06,
     5      0.4837125240906693d-07,-.1101743892234413d-07,
     6      0.2397463571614973d-08,-.4995380432866416d-09,
     7      0.9936315664045265d-10,-.1900716407238382d-10,
     8      0.2825081706257795d-11,-.3698754222980940d-12/
         data arr1449/
     1      -.6646706418034356d-12,0.1806177779816787d-12,
     2      -.5346906652966136d-12,0.1372836513989018d-12,
     3      -.2577773914658716d-12,0.4767108797193777d-01,
     4      -.7659070541571110d-01,0.8384742615938498d-01,
     5      -.7240626755525548d-01,0.5242987903215229d-01,
     6      -.3294291872232054d-01,0.1836296806508421d-01,
     7      -.9223797086369915d-02,0.4224180145654542d-02,
     8      -.1779935278114286d-02,0.6951612449471268d-03/
         data arr1450/
     1      -.2531733414884662d-03,0.8642002974761342d-04,
     2      -.2776933069607410d-04,0.8431549494389760d-05,
     3      -.2427015444225486d-05,0.6642413011423591d-06,
     4      -.1732982603915536d-06,0.4319941854290627d-07,
     5      -.1031056751475934d-07,0.2358795626043638d-08,
     6      -.5180418466551938d-09,0.1068393510326223d-09,
     7      -.2068431604176202d-10,0.1181242185297371d-11,
     8      0.4670169408293534d-12,-.2040651301197626d-11/
         data arr1451/
     1      0.6773546353059076d-12,-.9294843868900047d-12,
     2      0.6843181398223992d-01,-.1244553486269435d+00,
     3      0.1542274718411732d+00,-.1507588000650053d+00,
     4      0.1235719427676052d+00,-.8788962292781544d-01,
     5      0.5545655826413279d-01,-.3153220068648027d-01,
     6      0.1634637584047002d-01,-.7796824657794725d-02,
     7      0.3446939148871938d-02,-.1421021161799331d-02,
     8      0.5490747734270835d-03,-.1997179041371744d-03/
         data arr1452/
     1      0.6864256385194944d-04,-.2236624972769902d-04,
     2      0.6929171648582372d-05,-.2046373654203951d-05,
     3      0.5774499691213384d-06,-.1560203338658573d-06,
     4      0.4043861774593053d-07,-.1007168663222432d-07,
     5      0.2412025723389080d-08,-.5561222264311756d-09,
     6      0.1213136614886087d-09,-.2535356100988330d-10,
     7      0.3432753738788442d-11,-.3229661701747923d-12,
     8      -.7060483484487828d-12,0.9125532877888487d-01/
         data arr1453/
     1      -.1859828063673545d+00,0.2582736021378296d+00,
     2      -.2829176235719779d+00,0.2598700638718692d+00,
     3      -.2071252420707648d+00,0.1464560746640389d+00,
     4      -.9331851263490007d-01,0.5421182846675351d-01,
     5      -.2897673119858445d-01,0.1435569723425775d-01,
     6      -.6632087821289115d-02,0.2871707902093356d-02,
     7      -.1170536124666827d-02,0.4508378473756867d-03,
     8      -.1646186710142725d-03,0.5715132562188778d-04/
         data arr1454/
     1      -.1891424533967720d-04,0.5981058702166299d-05,
     2      -.1810945059766154d-05,0.5260117604510535d-06,
     3      -.1468217368042466d-06,0.3943844384544286d-07,
     4      -.1020485699394987d-07,0.2541886276076076d-08,
     5      -.6067817217035200d-09,0.1357767915704773d-09,
     6      -.2670453529787574d-10,0.3531798104298121d-11,
     7      0.1141270559006496d+00,-.2584036584189300d+00,
     8      0.3986588066866622d+00,-.4851508824466008d+00/
         data arr1455/
     1      0.4950722215243335d+00,-.4383699905335844d+00,
     2      0.3443583818491110d+00,-.2437623106781568d+00,
     3      0.1573215754196422d+00,-.9341983691750680d-01,
     4      0.5141732569776736d-01,-.2638948676860405d-01,
     5      0.1269452397754068d-01,-.5748525463858536d-02,
     6      0.2459730281930778d-02,-.9977958410370127d-03,
     7      0.3848437190487775d-03,-.1414954721367569d-03,
     8      0.4970812512200535d-04,-.1672050787622611d-04/
         data arr1456/
     1      0.5395616758487813d-05,-.1673112439685181d-05,
     2      0.4994056500834529d-06,-.1435504281265136d-06,
     3      0.3986419964898021d-07,-.1056717528691701d-07,
     4      0.2741037823095465d-08,-.6072516350503031d-09,
     5      0.1462527529232137d-09,0.1349065117204671d+00,
     6      -.3367994939758952d+00,0.5729313781899545d+00,
     7      -.7687879099852789d+00,0.8650212005230249d+00,
     8      -.8445541150079888d+00,0.7315193158041274d+00/
         data arr1457/
     1      -.5709658997395337d+00,0.4063126779345020d+00,
     2      -.2660355440820551d+00,0.1614501743222252d+00,
     3      -.9136680769575183d-01,0.4846211913888463d-01,
     4      -.2419752305465593d-01,0.1141643253545370d-01,
     5      -.5106379300325348d-02,0.2171622155204978d-02,
     6      -.8803809327530082d-03,0.3410232725557864d-03,
     7      -.1264828233265621d-03,0.4500415392725285d-04,
     8      -.1538620783668994d-04,0.5064068438838734d-05/
         data arr1458/
     1      -.1603874415184523d-05,0.4912420939670852d-06,
     2      -.1428196559405449d-06,0.4094643326246934d-07,
     3      -.9762547206155249d-08,0.2638169645848704d-08,
     4      0.1517031582454262d+00,-.4148614151073876d+00,
     5      0.7730438456625940d+00,-.1136260654167307d+01,
     6      0.1400451521418475d+01,-.1497747885520469d+01,
     7      0.1421042070842443d+01,-.1214957855786697d+01,
     8      0.9470683439616162d+00,-.6792513599241634d+00/
         data arr1459/
     1      0.4515431667888167d+00,-.2799104494650696d+00,
     2      0.1626308628558875d+00,-.8894906285349503d-01,
     3      0.4596960641655699d-01,-.2252284683993852d-01,
     4      0.1049214776161555d-01,-.4659292474077095d-02,
     5      0.1976985274699232d-02,-.8031818105733477d-03,
     6      0.3130446534835478d-03,-.1172170121482964d-03,
     7      0.4226103461577469d-04,-.1464488466094293d-04,
     8      0.4914238897240492d-05,-.1553985603754083d-05/
         data arr1460/
     1      0.4884652397211912d-06,-.1240811643884092d-06,
     2      0.3685664504366262d-07,0.1631623265983608d+00,
     3      -.4859365939192262d+00,0.9861250282747295d+00,
     4      -.1578545543819144d+01,0.2118841748819347d+01,
     5      -.2467859612227524d+01,0.2549998733805533d+01,
     6      -.2374354363166351d+01,0.2015658418961895d+01,
     7      -.1574408502452125d+01,0.1139823162460288d+01,
     8      -.7694999694548850d+00,0.4869044635347042d+00/
         data arr1461/
     1      -.2900236675985329d+00,0.1632353250999335d+00,
     2      -.8709991840381097d-01,0.4418859651048002d-01,
     3      -.2137053016428471d-01,0.9875303867338285d-02,
     4      -.4369151612579236d-02,0.1854572528949975d-02,
     5      -.7560718773595319d-03,0.2968812150664218d-03,
     6      -.1118489663617697d-03,0.4088344432430849d-04,
     7      -.1395364307302944d-04,0.4780531669206292d-05,
     8      -.1283147661930677d-05,0.4158391288125798d-06/
         data arr1462/
     1      0.1686120894928366d+00,-.5440853751117564d+00,
     2      0.1196294358817348d+01,-.2074826642510523d+01,
     3      0.3017462261534256d+01,-.3807872536276765d+01,
     4      0.4263051143767710d+01,-.4300755371784721d+01,
     5      0.3955804018635522d+01,-.3347756657053479d+01,
     6      0.2625986931454816d+01,-.1920800711549675d+01,
     7      0.1316849325347990d+01,-.8498540145131077d+00,
     8      0.5182552196949909d+00,-.2996162524690215d+00/
         data arr1463/
     1      0.1646935538251251d+00,-.8629706955142848d-01,
     2      0.4320667584125150d-01,-.2071025742213981d-01,
     3      0.9524824123166617d-02,-.4205276626239994d-02,
     4      0.1789227739320831d-02,-.7285237009285890d-03,
     5      0.2886131651632165d-03,-.1055439881052226d-03,
     6      0.3921764192425792d-04,-.1103999513265641d-04,
     7      0.3884211399301715d-05,0.1680675375511221d+00,
     8      -.5849125310990653d+00,0.1387045395314078d+01/
         data arr1464/
     1      -.2594556801118144d+01,0.4069602212723980d+01,
     2      -.5538871154728799d+01,0.6687875038972941d+01,
     3      -.7276810974980193d+01,0.7218714526645247d+01,
     4      -.6588821249828639d+01,0.5574105082576839d+01,
     5      -.4397376171518027d+01,0.3251443055655818d+01,
     6      -.2263147921136558d+01,0.1488473491931489d+01,
     7      -.9280900213140668d+00,0.5502125300974331d+00,
     8      -.3109345942199395d+00,0.1679016262041822d+00/
         data arr1465/
     1      -.8678790021685862d-01,0.4304982699041923d-01,
     2      -.2048364829363756d-01,0.9400741416788511d-02,
     3      -.4113684671780926d-02,0.1758456353650711d-02,
     4      -.6842156781139549d-03,0.2745509508134542d-03,
     5      -.8050925747576750d-04,0.3061921229346315d-04,
     6      0.1621226311958027d+00,-.6060347456414564d+00,
     7      0.1543633038558617d+01,-.3101439866496794d+01,
     8      0.5225152075021899d+01,-.7638622160264601d+01/
         data arr1466/
     1      0.9906693063671431d+01,-.1157786393651939d+02,
     2      0.1233655808204350d+02,-.1209452020377734d+02,
     3      0.1099013095645076d+02,-.9312537533180603d+01,
     4      0.7396008349582493d+01,-.5529430346692867d+01,
     5      0.3906209478584147d+01,-.2616060490968657d+01,
     6      0.1665850151446320d+01,-.1011115452455315d+01,
     7      0.5864599956032532d+00,-.3255222318658713d+00,
     8      0.1734451521381271d+00,-.8853609173223972d-01/
         data arr1467/
     1      0.4365267907292431d-01,-.2041829177614242d-01,
     2      0.9380955281675984d-02,-.3857755679906134d-02,
     3      0.1665319937122267d-02,-.5055486797214832d-03,
     4      0.2070537345162105d-03,0.1517760253926443d+00,
     5      -.6071575375420090d+00,0.1654978158869417d+01,
     6      -.3558409303768367d+01,0.6415578237725669d+01,
     7      -.1003682224402332d+02,0.1393010041224822d+02,
     8      -.1742201196992574d+02,0.1986589848641029d+02/
         data arr1468/
     1      -.2084237162914462d+02,0.2026775804986664d+02,
     2      -.1837870626933374d+02,0.1562027678961736d+02,
     3      -.1249725123880743d+02,0.9447882156851588d+01,
     4      -.6771155774071123d+01,0.4614212849002885d+01,
     5      -.2996850748447918d+01,0.1860190361834894d+01,
     6      -.1104465746931169d+01,0.6298229284130394d+00,
     7      -.3434138403892866d+00,0.1812557722857131d+00,
     8      -.9014363426710945d-01,0.4436002138474904d-01/
         data arr1469/
     1      -.1915528979335894d-01,0.8866189573197958d-02,
     2      -.2770663176446191d-02,0.1217952926651167d-02,
     3      0.1382376339394876d+00,-.5898241214437154d+00,
     4      0.1714791915728562d+01,-.3932539408970497d+01,
     5      0.7562249648655439d+01,-.1261855006004144d+02,
     6      0.1867951059417868d+02,-.2491767676026462d+02,
     7      0.3030508355669493d+02,-.3391191181603906d+02,
     8      0.3517296117189188d+02,-.3401851732041095d+02/
         data arr1470/
     1      0.3083809026388080d+02,-.2631524047420568d+02,
     2      0.2121908236628164d+02,-.1621939815422662d+02,
     3      0.1178888736905804d+02,-.8165029681695025d+01,
     4      0.5405904090193925d+01,-.3420871992666542d+01,
     5      0.2080993709615256d+01,-.1206920441141285d+01,
     6      0.6797696227759125d+00,-.3575608303300240d+00,
     7      0.1878976782608293d+00,-.8466503103019853d-01,
     8      0.4189577126406308d-01,-.1340743128435619d-01/
         data arr1471/
     1      0.6307390088420628d-02,0.1227526611126947d+00,
     2      -.5569493739842081d+00,0.1721841551192328d+01,
     3      -.4198976111219229d+01,0.8586375910322328d+01,
     4      -.1523550625370619d+02,0.2398288927938680d+02,
     5      -.3401982089032963d+02,0.4399755757456412d+02,
     6      -.5235443062581721d+02,0.5774293477657860d+02,
     7      -.5938704362776100d+02,0.5724705437965417d+02,
     8      -.5194601181255507d+02,0.4454132188012987d+02/
         data arr1472/
     1      -.3620108005089522d+02,0.2798075255155812d+02,
     2      -.2060078961159746d+02,0.1450511731472415d+02,
     3      -.9748773648231905d+01,0.6307955156667536d+01,
     4      -.3875054360646686d+01,0.2322525621294617d+01,
     5      -.1285277878101212d+01,0.7193463111244336d+00,
     6      -.3361807522362782d+00,0.1773997985704003d+00,
     7      -.5786166584547393d-01,0.2905645217243347d-01,
     8      0.1064654743513640d+00,-.5122637105742293d+00/
         data arr1473/
     1      0.1679465335771872d+01,-.4343314178345214d+01,
     2      0.9418629964297558d+01,-.1772289435153114d+02,
     3      0.2958552513494902d+02,-.4450506797126140d+02,
     4      0.6103882169433874d+02,-.7702462937031916d+02,
     5      0.9008978893401388d+02,-.9825686358155666d+02,
     6      0.1004445434664878d+03,-.9665052444207458d+02,
     7      0.8788649983989058d+02,-.7573626785008952d+02,
     8      0.6208185291416045d+02,-.4844229302808923d+02/
         data arr1474/
     1      0.3617690370180777d+02,-.2573535193713365d+02,
     2      0.1766671048693450d+02,-.1144630891640918d+02,
     3      0.7282738846921731d+01,-.4217574481761392d+01,
     4      0.2508336200221400d+01,-.1208728674043693d+01,
     5      0.6786892676958285d+00,-.2246316936192660d+00,
     6      0.1201455272032250d+00,0.9033180420432674d-01,
     7      -.4597741704407065d+00,0.1594560843465108d+01,
     8      -.4362247854185386d+01,0.1000681616835909d+02/
         data arr1475/
     1      -.1991873152730890d+02,0.3517430254565514d+02,
     2      -.5597237961094017d+02,0.8120634130524435d+02,
     3      -.1083998633435208d+03,0.1341205362327821d+03,
     4      -.1547349282587574d+03,0.1673307921300128d+03,
     5      -.1703049237728047d+03,0.1638248428044355d+03,
     6      -.1492910049095671d+03,0.1294667838864120d+03,
     7      -.1067545626702294d+03,0.8435936306168901d+02,
     8      -.6329810989276005d+02,0.4599675876262361d+02/
         data arr1476/
     1      -.3129176578709583d+02,0.2109135045144452d+02,
     2      -.1271339109269432d+02,0.8019157811027704d+01,
     3      -.3962105572831545d+01,0.2362764261263703d+01,
     4      -.7903672370429681d+00,0.4493929094072584d+00,
     5      0.7507710722019184d-01,-.4033168962981743d+00,
     6      0.1476311099488259d+01,-.4262672451704187d+01,
     7      0.1032054364612841d+02,-.2168216005324908d+02,
     8      0.4041119320844560d+02,-.6787066230289035d+02/
         data arr1477/
     1      0.1039284531371116d+03,-.1464193821081094d+03,
     2      0.1912071156213968d+03,-.2328099318373389d+03,
     3      0.2657269765582723d+03,-.2853831316324055d+03,
     4      0.2897666496275342d+03,-.2785270901035145d+03,
     5      0.2549831607520917d+03,-.2215306320893142d+03,
     6      0.1848500952303786d+03,-.1457669863178855d+03,
     7      0.1119110553234641d+03,-.7956986791623218d+02,
     8      0.5671741912931263d+02,-.3539119088367814d+02/
         data arr1478/
     1      0.2363820416105469d+02,-.1190971130814159d+02,
     2      0.7531395265644313d+01,-.2536680765409056d+01,
     3      0.1530850144507983d+01,0.6119244043669426d-01,
     4      -.3462387406925816d+00,0.1334891352895528d+01,
     5      -.4059648564996098d+01,0.1035256944969320d+02,
     6      -.2290787207158114d+02,0.4497009746545012d+02,
     7      -.7954913797169627d+02,0.1283010367056077d+03,
     8      -.1903749005530765d+03,0.2618568407637628d+03/
         data arr1479/
     1      -.3357634481087039d+03,0.4036756319003252d+03,
     2      -.4564363272107592d+03,0.4882077826339341d+03,
     3      -.4937270331870685d+03,0.4762363663115469d+03,
     4      -.4346203840527725d+03,0.3822677438039952d+03,
     5      -.3155761648166724d+03,0.2555698144341845d+03,
     6      -.1889848966043816d+03,0.1422619008798294d+03,
     7      -.9139073557968769d+02,0.6455426830450907d+02,
     8      -.3299309121878414d+02,0.2209736992652800d+02/
         data arr1480/
     1      -.7467818574967711d+01,0.4777166893327880d+01,
     2      0.4895652789477795d-01,-.2912143956154471d+00,
     3      0.1180338983713811d+01,-.3773739018486798d+01,
     4      0.1011710542981568d+02,-.2353479717465030d+02,
     5      0.4857095695660824d+02,-.9032182890174818d+02,
     6      0.1531512094460330d+03,-.2388744545738389d+03,
     7      0.3454389828025918d+03,-.4655061898852792d+03,
     8      0.5884429958147507d+03,-.6989245366226208d+03/
         data arr1481/
     1      0.7861497864848953d+03,-.8342665729376491d+03,
     2      0.8465079861708600d+03,-.8088092405201545d+03,
     3      0.7487791507806896d+03,-.6443995538720218d+03,
     4      0.5498244258837024d+03,-.4206609608689142d+03,
     5      0.3340755505915230d+03,-.2197322249402536d+03,
     6      0.1639903505832057d+03,-.8459207205973178d+02,
     7      0.5995049439881990d+02,-.2026175291655402d+02,
     8      0.1372579044588433d+02,0.3847286431110274d-01/
         data arr1482/
     1      -.2401834229711501d+00,0.1021694511121719d+01,
     2      -.3428208937357272d+01,0.9645820743674095d+01,
     3      -.2354840498032582d+02,0.5100605193885899d+02,
     4      -.9953493064117700d+02,0.1771377804154860d+03,
     5      -.2898854385557570d+03,0.4400139429326568d+03,
     6      -.6219108790943287d+03,0.8252907495575679d+03,
     7      -.1027293284906236d+04,0.1213360868465555d+04,
     8      -.1347278865530428d+04,0.1436213027617076d+04/
         data arr1483/
     1      -.1431391034510642d+04,0.1393347400655543d+04,
     2      -.1244268895194267d+04,0.1117611888569385d+04,
     3      -.8798636030380367d+03,0.7367213282735489d+03,
     4      -.4933802735887717d+03,0.3888311069309303d+03,
     5      -.2014450580664630d+03,0.1509781797400950d+03,
     6      -.5087016676628446d+02,0.3646885800175590d+02,
     7      0.2971256532802498d-01,-.1943795784657442d+00,
     8      0.8664517037904770d+00,-.3046479554392376d+01/
         data arr1484/
     1      0.8982477829622313d+01,-.2297705469592540d+02,
     2      0.5215515589919234d+02,-.1066254361834024d+03,
     3      0.1988705605116987d+03,-.3408432423303123d+03,
     4      0.5422877082812115d+03,-.8021979532180541d+03,
     5      0.1116107679849291d+04,-.1452220350482368d+04,
     6      0.1799159220512304d+04,-.2083444083651379d+04,
     7      0.2331301826167618d+04,-.2413443944126303d+04,
     8      0.2468697222212484d+04,-.2275935172058077d+04/
         data arr1485/
     1      0.2151212515264534d+04,-.1732714213092355d+04,
     2      0.1529320287765800d+04,-.1037038618965649d+04,
     3      0.8628821744536347d+03,-.4468410393520806d+03,
     4      0.3540920121038057d+03,-.1185779598347510d+03,
     5      0.8993562321138933d+02,0.2255623229732692d-01,
     6      -.1544212330353855d+00,0.7203003417734863d+00,
     7      -.2650088725886963d+01,0.8177133317071114d+01,
     8      -.2188359740920929d+02,0.5198823723096415d+02/
         data arr1486/
     1      -.1111609426363613d+03,0.2170261642479818d+03,
     2      -.3887934871224590d+03,0.6476798676894250d+03,
     3      -.1000391306812874d+04,0.1457974285449136d+04,
     4      -.1976972966013106d+04,0.2567411376252273d+04,
     5      -.3088701598628711d+04,0.3626499288940606d+04,
     6      -.3880827520360036d+04,0.4171109228158652d+04,
     7      -.3947672838813569d+04,0.3927128788878234d+04,
     8      -.3216756116869393d+04,0.2993587791838117d+04/
         data arr1487/
     1      -.2044002948152627d+04,0.1796112070500304d+04,
     2      -.9253068598577735d+03,0.7754490866327174d+03,
     3      -.2573147096543311d+03,0.2064953357083442d+03,
     4      0.1682993577854222d-01,-.1204295463740331d+00,
     5      0.5870923281031665d+00,-.2257216508678076d+01,
     6      0.7280540374161076d+01,-.2035359430348723d+02,
     7      0.5055592463396515d+02,-.1128536897664268d+03,
     8      0.2304386562976153d+03,-.4305288748363323d+03/
         data arr1488/
     1      0.7504696552287129d+03,-.1206841642103419d+04,
     2      0.1841730050601899d+04,-.2592923171736351d+04,
     3      0.3529584160459309d+04,-.4390942193509693d+04,
     4      0.5411152170864625d+04,-.5952462503312585d+04,
     5      0.6726303618712493d+04,-.6495054911502495d+04,
     6      0.6805599291512647d+04,-.5633213424830579d+04,
     7      0.5532331342291300d+04,-.3782070893119959d+04,
     8      0.3512657638770731d+04,-.1791696841592692d+04/
         data arr1489/
     1      0.1589164232297464d+04,-.5209055671229884d+03,
     2      0.4425811996756725d+03,0.1232665746116756d-01,
     3      -.9210620388201385d-01,0.4687621038231886d+00,
     4      -.1881080591383378d+01,0.6337377474129129d+01,
     5      -.1847757278710364d+02,0.4796232384744934d+02,
     6      -.1115372892636278d+03,0.2381473254670838d+03,
     7      -.4627148033728484d+03,0.8440945499674076d+03,
     8      -.1408115221787570d+04,0.2251296210063239d+04/
         data arr1490/
     1      -.3275661061239017d+04,0.4678123008118007d+04,
     2      -.5984604165579199d+04,0.7750764438389568d+04,
     3      -.8708177389994109d+04,0.1036195388201717d+05,
     4      -.1013961631734758d+05,0.1120986098341411d+05,
     5      -.9313618332109354d+04,0.9669681968363073d+04,
     6      -.6579787917587071d+04,0.6469979278037932d+04,
     7      -.3251099743135356d+04,0.3056808764039496d+04,
     8      -.9864843759347337d+03,0.8886494999359643d+03/
         data arr1491/
     1      -.2221393646944217d-16,0.1602711117556913d-18,
     2      -.7916908287484922d-21,0.3097746531959548d-23,
     3      -.1020126214894808d-25,0.2924728519722253d-28,
     4      -.2518098332200042d-31,-.6308836975894871d-32,
     5      -.2714364531070296d-30,0.2496209904481931d-31,
     6      -.1619849480330530d-29,-.7903476739414663d-31,
     7      -.7495021841725060d-29,-.4842153673131737d-30,
     8      -.2110518598078847d-28,-.2708957845890660d-29/
         data arr1492/
     1      -.4699641603556086d-28,-.6340967035595083d-29,
     2      -.7845332954004927d-28,-.1342552520647782d-28,
     3      -.1009125083599587d-27,-.1708382019942394d-28,
     4      -.9704093217865190d-28,-.2044057578910407d-28,
     5      -.6267352625914342d-28,-.1310652272577270d-28,
     6      -.2548391277715551d-28,-.8879004091834142d-29,
     7      -.2215569619825529d-11,0.8346360324956272d-13,
     8      -.2152680113480133d-14,0.4397964999776592d-16/
         data arr1493/
     1      -.7562108035016589d-18,0.1131979058728485d-19,
     2      -.1507602464433303d-21,0.1811168320890639d-23,
     3      -.3447896675285970d-25,-.9365344760272102d-26,
     4      -.1054978084567595d-24,-.2589612140963915d-25,
     5      -.5408551360697337d-24,-.8079363534589399d-25,
     6      -.1570572149416776d-23,-.2635380366207566d-24,
     7      -.3560572181041115d-23,-.5425322458403066d-24,
     8      -.6193052458673308d-23,-.1055060947534336d-23/
         data arr1494/
     1      -.8156488969146552d-23,-.1272746012469442d-23,
     2      -.8541375394056022d-23,-.1558309814448994d-23,
     3      -.5721099278644975d-23,-.9824270918458029d-24,
     4      -.2949421302413221d-23,-.7560512523312928d-24,
     5      -.9716128587840299d-09,0.8858550164674293d-10,
     6      -.5529714182551643d-11,0.2734214743417107d-12,
     7      -.1137840524138401d-13,0.4122252767305862d-15,
     8      -.1328797916649511d-16,0.3870022852880084d-18/
         data arr1495/
     1      -.1030951779929865d-19,0.2476536125988745d-21,
     2      -.6336949518773150d-22,-.1691088663173572d-22,
     3      -.2726325246731417d-21,-.5355301038748089d-22,
     4      -.7806055001766630d-21,-.1903148089200054d-21,
     5      -.1733441768503280d-20,-.4248145430595481d-21,
     6      -.2922593882344497d-20,-.8603424943073363d-21,
     7      -.3757914636723750d-20,-.1134452654420489d-20,
     8      -.3689023091666319d-20,-.1349389647183056d-20/
         data arr1496/
     1      -.2389977101842627d-20,-.9059001697617304d-21,
     2      -.1044007142139041d-20,-.5816796501223663d-21,
     3      -.5549230150533444d-07,0.9205366573797416d-08,
     4      -.1045490469477922d-08,0.9405653380759653d-10,
     5      -.7121585646014359d-11,0.4694278792681563d-12,
     6      -.2753164951577661d-13,0.1458906605348191d-14,
     7      -.7065226056936942d-16,0.3154395671776339d-17,
     8      -.1324406436397159d-18,0.2996868057274932d-20/
         data arr1497/
     1      -.9928280813864107d-20,-.5274856941984741d-20,
     2      -.2915709374817177d-19,-.1644141574312558d-19,
     3      -.6699742906782537d-19,-.3170611879193189d-19,
     4      -.1178863840569399d-18,-.6271255142993436d-19,
     5      -.1540353617735570d-18,-.7721868522318092d-19,
     6      -.1638465677486912d-18,-.9529045422768854d-19,
     7      -.1082520120236098d-18,-.6118676768615136d-19,
     8      -.6021974985824431d-19,-.4293411891628590d-19/
         data arr1498/
     1      -.1067105323312893d-05,0.2771496552129523d-06,
     2      -.4928242154942936d-07,0.6941600839411823d-08,
     3      -.8228981282875654d-09,0.8492527417213757d-10,
     4      -.7798283512834438d-11,0.6469832507439002d-12,
     5      -.4905571246897110d-13,0.3429710092124467d-14,
     6      -.2228253833066975d-15,0.1354753811671257d-16,
     7      -.1350982944754991d-17,0.2068968294045536d-18,
     8      -.1715830459024416d-17,0.4147236339393109d-18/
         data arr1499/
     1      -.3867583857861609d-17,0.8603336553302989d-18,
     2      -.6759556111170834d-17,0.1189510498473727d-17,
     3      -.8914033308918657d-17,0.1397095999766136d-17,
     4      -.9102635705781521d-17,0.8337550931666128d-18,
     5      -.6076758571497286d-17,0.4166150387629811d-18,
     6      -.2825937784932294d-17,-.2484201413838350d-18,
     7      -.1037545692895227d-04,0.3845512929721324d-05,
     8      -.9758250450839640d-06,0.1961460405773616d-06/
         data arr1500/
     1      -.3318226070876135d-07,0.4886938145159976d-08,
     2      -.6403816704032984d-09,0.7581810036937547d-10,
     3      -.8203690054925137d-11,0.8184964154315672d-12,
     4      -.7584168799732210d-13,0.6565136812706526d-14,
     5      -.5368338423187907d-15,0.4128562030731292d-16,
     6      -.1266424144472925d-16,-.3090079136391962d-19,
     7      -.2181590006318483d-16,-.1317853096961597d-17,
     8      -.3815237675609533d-16,-.5551330600363399d-17/
         data arr1501/
     1      -.5096344326339756d-16,-.7819998217432506d-17,
     2      -.5286000765735247d-16,-.1347142581669541d-16,
     3      -.3608383516668424d-16,-.9516646650996751d-17,
     4      -.1695369517176435d-16,-.9092026449235248d-17,
     5      -.6315160321839913d-04,0.3137180983054728d-04,
     6      -.1067002427478873d-04,0.2874624629825464d-05,
     7      -.6518020423816828d-06,0.1286633151285372d-06,
     8      -.2259773633333839d-07,0.3585973638249007d-08/
         data arr1502/
     1      -.5200577611777529d-09,0.6954521185433398d-10,
     2      -.8636994512392701d-11,0.1002067852106396d-11,
     3      -.1091679737945785d-12,0.1120720123180311d-13,
     4      -.1142063973348628d-14,0.8388461201719075d-16,
     5      -.1201400689475552d-15,-.4768236149472535d-16,
     6      -.1805031815918237d-15,-.1117402548057592d-15,
     7      -.2192472482992359d-15,-.1608628183954335d-15,
     8      -.2097607165212724d-15,-.1989327159158381d-15/
         data arr1503/
     1      -.1302802885695631d-15,-.1378267338363930d-15,
     2      -.6093815177604469d-16,-.8660066100042013d-16,
     3      -.2731164443921538d-03,0.1738368905858690d-03,
     4      -.7575419383089225d-04,0.2614937526577458d-04,
     5      -.7596871740952124d-05,0.1921377569604056d-05,
     6      -.4323762376698192d-06,0.8791093024156900d-07,
     7      -.1633526809591521d-07,0.2798857693200688d-08,
     8      -.4453638166670188d-09,0.6620458552300994d-10/
         data arr1504/
     1      -.9239588999470343d-11,0.1215608174180916d-11,
     2      -.1514740531330903d-12,0.1753187604537020d-13,
     3      -.2214113750507102d-14,-.5480196347664994d-15,
     4      -.3024366190199537d-15,-.1354211267324180d-14,
     5      -.2809109763791238d-15,-.1727370971449000d-14,
     6      -.2317816539691800d-15,-.1819732146061304d-14,
     7      -.1096116945597964d-15,-.1186455604024137d-14,
     8      -.5990332581011357d-16,-.6246956374126325d-15/
         data arr1505/
     1      -.9104429983386096d-03,0.7177907371238580d-03,
     2      -.3874481389703056d-03,0.1656605923376652d-03,
     3      -.5961337093791582d-04,0.1867551541682842d-04,
     4      -.5205622756696962d-05,0.1311006194266196d-05,
     5      -.3017443372344155d-06,0.6403901963625146d-07,
     6      -.1262204655962668d-07,0.2324096546284889d-08,
     7      -.4017614177094826d-09,0.6547968889771499d-10,
     8      -.1010010810312791d-10,0.1478862849114605d-11/
         data arr1506/
     1      -.2096503373355349d-12,0.2786270638382715d-13,
     2      -.9388231790871503d-14,0.2463632378576720d-15,
     3      -.7363643785208378d-14,-.1019238444169209d-14,
     4      -.6897056014165922d-14,-.2389047441240579d-14,
     5      -.4341794469304629d-14,-.2061401188407411d-14,
     6      -.1737879207114517d-14,-.1775926073412337d-14,
     7      -.2472683982940334d-02,0.2352171318275705d-02,
     8      -.1531933540148569d-02,0.7903160476540665d-03/
         data arr1507/
     1      -.3431472447923699d-03,0.1297073771466154d-03,
     2      -.4362345091324817d-04,0.1325584187163307d-04,
     3      -.3681263838610195d-05,0.9426657669809030d-06,
     4      -.2241806271733827d-06,0.4980554520365097d-07,
     5      -.1038834691971924d-07,0.2042861630653836d-08,
     6      -.3801440340699323d-09,0.6715082331424683d-10,
     7      -.1130427709459803d-10,0.1813646203355080d-11,
     8      -.2988921965314944d-12,0.3956327361032502d-13/
         data arr1508/
     1      -.3198680583004563d-13,-.3978896645232832d-14,
     2      -.2481383886776313d-13,-.1117170060633269d-13,
     3      -.1569147116739081d-13,-.9448594304687125d-14,
     4      -.5995485271595806d-14,-.8280505290383379d-14,
     5      -.5691369223954348d-02,0.6397282070258523d-02,
     6      -.4923170533568183d-02,0.3001125521350701d-02,
     7      -.1539721876883052d-02,0.6877092191275314d-03,
     8      -.2732993456540098d-03,0.9813056358069789d-04/
         data arr1509/
     1      -.3220122012772633d-04,0.9743422241953565d-05,
     2      -.2737980000311064d-05,0.7187672709576159d-06,
     3      -.1771476424076019d-06,0.4116292099528663d-07,
     4      -.9050825893582114d-08,0.1889153437615652d-08,
     5      -.3754112882074975d-09,0.7118143059735398d-10,
     6      -.1296523847436414d-10,0.2231201577621892d-11,
     7      -.4422658834698964d-12,0.3721860589125557d-13,
     8      -.7533283232016049d-13,-.3297447085107951d-13/
         data arr1510/
     1      -.4334946912436137d-13,-.2639059738683567d-13,
     2      -.1801625382336238d-13,-.2060151263535692d-13,
     3      -.1142905149332885d-01,0.1492387169292697d-01,
     4      -.1334207765567582d-01,0.9448335858854989d-02,
     5      -.5631265726015518d-02,0.2921871855521237d-02,
     6      -.1348924022140110d-02,0.5626596453249899d-03,
     7      -.2144896699158787d-03,0.7539423775806182d-04,
     8      -.2461214588478551d-04,0.7505853446061602d-05/
         data arr1511/
     1      -.2149016405288601d-05,0.5801003387132014d-06,
     2      -.1481757276311492d-06,0.3592934440083397d-07,
     3      -.8293675161904470d-08,0.1827059177247397d-08,
     4      -.3850414637777986d-09,0.7770932803525274d-10,
     5      -.1512437625287204d-10,0.2739265669643513d-11,
     6      -.5429613745481852d-12,-.2110973711202154d-14,
     7      -.3642293471505419d-13,-.6065944623085011d-13,
     8      -.8510065718220005d-14,-.3877816560071814d-13/
         data arr1512/
     1      -.2046972704835162d-01,0.3061675113082931d-01,
     2      -.3135283354803209d-01,0.2543222696328493d-01,
     3      -.1736244265605603d-01,0.1031909720897168d-01,
     4      -.5456871946608142d-02,0.2607220589272706d-02,
     5      -.1138450429082346d-02,0.4583757507865675d-03,
     6      -.1713991624525312d-03,0.5987355295884766d-04,
     7      -.1963588210820910d-04,0.6071409680700021d-05,
     8      -.1776393632187336d-05,0.4933864422806916d-06/
         data arr1513/
     1      -.1304547382634709d-06,0.3291889036228494d-07,
     2      -.7945875582940183d-08,0.1837904242427595d-08,
     3      -.4086295120100192d-09,0.8682605772325405d-10,
     4      -.1818240934933162d-10,0.3024683522088746d-11,
     5      -.8068063436458018d-12,-.2796455113745252d-12,
     6      -.3562850043624984d-13,-.2496426713759865d-12,
     7      -.3326209103668071d-01,0.5631591020960238d-01,
     8      -.6528047535017689d-01,0.5994119675219042d-01/
         data arr1514/
     1      -.4632189852420859d-01,0.3116389537760476d-01,
     2      -.1865470149979171d-01,0.1008920220769745d-01,
     3      -.4986865807023236d-02,0.2272844367757204d-02,
     4      -.9620358743716944d-03,0.3804101619204254d-03,
     5      -.1412218844171580d-03,0.4942829534562442d-04,
     6      -.1637041879703149d-04,0.5146859775284572d-05,
     7      -.1540454665301766d-05,0.4400179680845440d-06,
     8      -.1202227082162848d-06,0.3148255727436729d-07/
         data arr1515/
     1      -.7916689586167804d-08,0.1913852783026683d-08,
     2      -.4458890237277415d-09,0.9919673967602374d-10,
     3      -.2152330802171709d-10,0.3816172040304873d-11,
     4      -.7466079942587521d-12,-.2249093296449517d-12,
     5      -.4970599580409711d-01,0.9430818526600261d-01,
     6      -.1225069245958281d+00,0.1260554967387917d+00,
     7      -.1091645876428906d+00,0.8230120893017398d-01,
     8      -.5520797659882497d-01,0.3346026695996766d-01/
         data arr1516/
     1      -.1853357954755426d-01,0.9465866438286777d-02,
     2      -.4489944680328702d-02,0.1989577596525814d-02,
     3      -.8276940316936072d-03,0.3246403545465553d-03,
     4      -.1204885308076815d-03,0.4245094051341310d-04,
     5      -.1423812904489847d-04,0.4557574694513776d-05,
     6      -.1395431343336276d-05,0.4095052864499921d-06,
     7      -.1153941417287181d-06,0.3127506630930255d-07,
     8      -.8163340371777179d-08,0.2053912777079088d-08/
         data arr1517/
     1      -.4967248983148297d-09,0.1151287313435321d-09,
     2      -.2408372241396140d-10,0.4321448384412337d-11,
     3      -.6906128266375705d-01,0.1455696141135844d+00,
     4      -.2100764944335970d+00,0.2401453013710612d+00,
     5      -.2310412713254288d+00,0.1935127047234667d+00,
     6      -.1442117278084676d+00,0.9710098443426519d-01,
     7      -.5975152845792402d-01,0.3390358055936647d-01,
     8      -.1786576699902903d-01,0.8795024202919149d-02/
         data arr1518/
     1      -.4064821337922281d-02,0.1771208238805957d-02,
     2      -.7303117775594777d-03,0.2858547395785622d-03,
     3      -.1065139268155850d-03,0.3787763245446234d-04,
     4      -.1288402603666444d-04,0.4200487803521122d-05,
     5      -.1314921208766307d-05,0.3959493071061079d-06,
     6      -.1147554114274126d-06,0.3211415210054849d-07,
     7      -.8581651607402036d-08,0.2243504342372415d-08,
     8      -.5042681694912039d-09,0.1229743934721278d-09/
         data arr1519/
     1      -.9001345103547387d-01,0.2092049598247745d+00,
     2      -.3328949300847978d+00,0.4195969150770630d+00,
     3      -.4451191017821709d+00,0.4110783672480586d+00,
     4      -.3377879816288464d+00,0.2507816293494589d+00,
     5      -.1701569057232600d+00,0.1064570923745029d+00,
     6      -.6185562122067635d-01,0.3357554103686774d-01,
     7      -.1711023264698897d-01,0.8220770997809606d-02,
     8      -.3737486972766725d-02,0.1613040447850495d-02/
         data arr1520/
     1      -.6627267493319023d-03,0.2598600069671440d-03,
     2      -.9746167577805570d-04,0.3503571014144391d-04,
     3      -.1209226527624772d-04,0.4014951449851515d-05,
     4      -.1282167644940605d-05,0.3956713691864126d-06,
     5      -.1159719774467108d-06,0.3345305496212179d-07,
     6      -.8086846870961127d-08,0.2188330280330185d-08,
     7      -.1108763770231465d+00,0.2822757014732968d+00,
     8      -.4920152959148011d+00,0.6793187701606258d+00/
         data arr1521/
     1      -.7893824464909481d+00,0.7985567047270090d+00,
     2      -.7187787607939740d+00,0.5845432724653156d+00,
     3      -.4344506295671984d+00,0.2977387470763391d+00,
     4      -.1895002701321481d+00,0.1126739669418971d+00,
     5      -.6289648562702946d-01,0.3310189992710293d-01,
     6      -.1648503625238459d-01,0.7793371759436875d-02,
     7      -.3507388809639570d-02,0.1506464404224669d-02,
     8      -.6188948047329048d-03,0.2437051401430975d-03/
         data arr1522/
     1      -.9212382023700681d-04,0.3350587059300228d-04,
     2      -.1170835127038328d-04,0.3958126674741963d-05,
     3      -.1262310492504690d-05,0.3989937453529116d-06,
     4      -.1028878222870040d-06,0.3052456511534220d-07,
     5      -.1298720175815421d+00,0.3600819483376573d+00,
     6      -.6835302709889941d+00,0.1027789215805921d+01,
     7      -.1300676220029591d+01,0.1432975580179924d+01,
     8      -.1404686984586742d+01,0.1244091385700345d+01/
         data arr1523/
     1      -.1006995061715742d+01,0.7515771364564797d+00,
     2      -.5209539422957249d+00,0.3373373077582117d+00,
     3      -.2050777033245957d+00,0.1175428685240155d+00,
     4      -.6375061678562471d-01,0.3282246616151476d-01,
     5      -.1608716113372433d-01,0.7524990593226775d-02,
     6      -.3366677673299685d-02,0.1443785427394258d-02,
     7      -.5942296804281474d-03,0.2353782663192926d-03,
     8      -.8943350322332347d-04,0.3293035602277249d-04/
         data arr1524/
     1      -.1134067798353848d-04,0.3905377669670938d-05,
     2      -.1065767483767112d-05,0.3445004328351403d-06,
     3      -.1454129330587145d+00,0.4368249371602632d+00,
     4      -.8984262904308673d+00,0.1463684191249123d+01,
     5      -.2006925042370466d+01,0.2395627929177612d+01,
     6      -.2544361190731558d+01,0.2441575247473868d+01,
     7      -.2141232352787665d+01,0.1731524506054355d+01,
     8      -.1300388231815065d+01,0.9123399754785433d+00/
         data arr1525/
     1      -.6009375493824888d+00,0.3731864127673596d+00,
     2      -.2192966847462897d+00,0.1223313078642687d+00,
     3      -.6496217937368574d-01,0.3292353619267883d-01,
     4      -.1595852937284581d-01,0.7415094137820467d-02,
     5      -.3305239752064917d-02,0.1418581111632539d-02,
     6      -.5826359949510318d-03,0.2324812383720579d-03,
     7      -.8583725546918980d-04,0.3204340741471204d-04,
     8      -.9186779375710596d-05,0.3219009187323263d-05/
         data arr1526/
     1      -.1563244494713245d+00,0.5064773675311742d+00,
     2      -.1123476050660051d+01,0.1974047032620826d+01,
     3      -.2919241419171235d+01,0.3758261322657566d+01,
     4      -.4305019429652144d+01,0.4455487335500337d+01,
     5      -.4214224234431830d+01,0.3675456048622668d+01,
     6      -.2977037764995430d+01,0.2252665832649976d+01,
     7      -.1600287349315369d+01,0.1071823435563393d+01,
     8      -.6792927017387164d+00,0.4086876715941316d+00/
         data arr1527/
     1      -.2340639522767450d+00,0.1279413131172449d+00,
     2      -.6687629933389093d-01,0.3351450184870751d-01,
     3      -.1610067108608618d-01,0.7453471996956382d-02,
     4      -.3290828539269995d-02,0.1416560551317142d-02,
     5      -.5569194158574229d-03,0.2243702837736034d-03,
     6      -.6713189109943272d-04,0.2538532396035437d-04,
     7      -.1619695987596537d+00,0.5636550904836062d+00,
     8      -.1342962856311662d+01,0.2534571048821349d+01/
         data arr1528/
     1      -.4025907368491048d+01,0.5567080897694917d+01,
     2      -.6849556678036608d+01,0.7614288955989485d+01,
     3      -.7735681137392374d+01,0.7246677756423607d+01,
     4      -.6304617883619946d+01,0.5124104927682735d+01,
     5      -.3909898470323102d+01,0.2812792458027734d+01,
     6      -.1914762836087148d+01,0.1237362916569891d+01,
     7      -.7611465213028972d+00,0.4468840748158446d+00,
     8      -.2508442511367571d+00,0.1350288267674926d+00/
         data arr1529/
     1      -.6959881549132699d-01,0.3461144553776008d-01,
     2      -.1634026912704478d-01,0.7557758519613988d-02,
     3      -.3143145253813112d-02,0.1361253538920915d-02,
     4      -.4224884947691122d-03,0.1717305030250887d-03,
     5      -.1622696775037715d+00,0.6043125798454146d+00,
     6      -.1540836426831387d+01,0.3112012555510869d+01,
     7      -.5289869792545888d+01,0.7828040638726206d+01,
     8      -.1030700128810226d+02,0.1226149874367738d+02/
         data arr1530/
     1      -.1333082582913607d+02,0.1336416391980939d+02,
     2      -.1244244402391287d+02,0.1082204542783979d+02,
     3      -.8836895951629671d+01,0.6803253706028726d+01,
     4      -.4955994956466744d+01,0.3427354448452280d+01,
     5      -.2255987770066186d+01,0.1417473753585371d+01,
     6      -.8511265350013755d+00,0.4903293417359357d+00,
     7      -.2700025736928990d+00,0.1437205873123526d+00,
     8      -.7217655469402916d-01,0.3574312488055087d-01/
         data arr1531/
     1      -.1562534428112815d-01,0.7249212418741435d-02,
     2      -.2321059367570231d-02,0.1010588453494110d-02,
     3      -.1576371271170813d+00,0.6261534756900009d+00,
     4      -.1702839513477852d+01,0.3668229889218379d+01,
     5      -.6650559820570542d+01,0.1049697874594494d+02,
     6      -.1474149641695295d+02,0.1870470363909224d+02,
     7      -.2169013245618103d+02,0.2319236390250239d+02,
     8      -.2303065090011562d+02,0.2136525686270650d+02/
         data arr1532/
     1      -.1860771161077683d+02,0.1527949124527677d+02,
     2      -.1187147392234445d+02,0.8756583845012043d+01,
     3      -.6146633531667411d+01,0.4119344598604854d+01,
     4      -.2636390596903608d+01,0.1620124960855355d+01,
     5      -.9491400957226438d+00,0.5390326530270051d+00,
     6      -.2864836220565447d+00,0.1514227123935403d+00,
     7      -.6915824082668072d-01,0.3426487658034549d-01,
     8      -.1126113097382062d-01,0.5235690108974733d-02/
         data arr1533/
     1      -.1488509809308456d+00,0.6287276382105235d+00,
     2      -.1818209984642374d+01,0.4165004089913087d+01,
     3      -.8029816814425949d+01,0.1347722024847892d+02,
     4      -.2012639766584360d+02,0.2715588199758884d+02,
     5      -.3348601009024768d+02,0.3807456416770497d+02,
     6      -.4020524670881371d+02,0.3966192856957770d+02,
     7      -.3673150657949177d+02,0.3207344536348594d+02,
     8      -.2649691571654637d+02,0.2078367208193751d+02/
         data arr1534/
     1      -.1550879473857649d+02,0.1105311937980739d+02,
     2      -.7514038349785786d+01,0.4911107130035190d+01,
     3      -.3048423305244830d+01,0.1841831743834843d+01,
     4      -.1030660370500510d+01,0.5798178971031982d+00,
     5      -.2750466886908206d+00,0.1451337680154778d+00,
     6      -.4873557274200581d-01,0.2412931097737925d-01,
     7      -.1369082335231264d+00,0.6132540303667957d+00,
     8      -.1880710178731151d+01,0.4568706579671563d+01/
         data arr1535/
     1      -.9340785340943830d+01,0.1662562962915690d+02,
     2      -.2632955413241745d+02,0.3767397811913057d+02,
     3      -.4926513456778173d+02,0.5940344950703029d+02,
     4      -.6652033284962670d+02,0.6959004619809163d+02,
     5      -.6834280338871547d+02,0.6328563546169340d+02,
     6      -.5543517952537616d+02,0.4611364666325552d+02,
     7      -.3647075520448013d+02,0.2756776125560249d+02,
     8      -.1983959162307081d+02,0.1375517603698501d+02/
         data arr1536/
     1      -.9008786589974417d+01,0.5776067443512042d+01,
     2      -.3385654944693195d+01,0.2022269192613980d+01,
     3      -.9907348310268158d+00,0.5554329165016760d+00,
     4      -.1897715763897735d+00,0.9981180109866550d-01,
     5      -.1228798080195158d+00,0.5822512858962779d+00,
     6      -.1888908613551844d+01,0.4854018693937255d+01,
     7      -.1049809270539111d+02,0.1976625067797272d+02,
     8      -.3311370942208230d+02,0.5012163934184930d+02/
         data arr1537/
     1      -.6933284768302568d+02,0.8843646807065151d+02,
     2      -.1047565166052141d+03,0.1159302689884446d+03,
     3      -.1204259679796610d+03,0.1179678500613045d+03,
     4      -.1092773124179998d+03,0.9616711899292501d+02,
     5      -.8038046476242828d+02,0.6428562828812024d+02,
     6      -.4881052029963396d+02,0.3581508995693533d+02,
     7      -.2464376694520980d+02,0.1673029802688421d+02,
     8      -.1021899932559468d+02,0.6466910158084907d+01/
         data arr1538/
     1      -.3254298790223646d+01,0.1934336598832886d+01,
     2      -.6698566165090695d+00,0.3734752567428501d+00,
     3      -.1077909464453682d+00,0.5390725569457475d+00,
     4      -.1845790889408259d+01,0.5006198481962109d+01,
     5      -.1142749950512151d+02,0.2270912633383483d+02,
     6      -.4015283530861989d+02,0.6414602211597500d+02,
     7      -.9365036861685697d+02,0.1260782493765246d+03,
     8      -.1576147493246746d+03,0.1841013716004303d+03/
         data arr1539/
     1      -.2018041708774024d+03,0.2086575237511597d+03,
     2      -.2038876181308097d+03,0.1894024794152228d+03,
     3      -.1668283561945522d+03,0.1408693344838472d+03,
     4      -.1124496710675558d+03,0.8714672261760828d+02,
     5      -.6271791019824589d+02,0.4499790604341366d+02,
     6      -.2849231208085456d+02,0.1906825941488952d+02,
     7      -.9805042391603116d+01,0.6167932882244180d+01,
     8      -.2157252206971928d+01,0.1272664003542264d+01/
         data arr1540/
     1      -.9253610258380369d-01,0.4874332730479914d+00,
     2      -.1757877960702286d+01,0.5021731917365095d+01,
     3      -.1207350090882545d+02,0.2527099923416958d+02,
     4      -.4706193357038793d+02,0.7918907181205887d+02,
     5      -.1217648862069746d+03,0.1726632890418283d+03,
     6      -.2273183510928289d+03,0.2796756405620401d+03,
     7      -.3227745955078287d+03,0.3515551130146202d+03,
     8      -.3614578950663481d+03,0.3537580327319382d+03/
         data arr1541/
     1      -.3273857958849342d+03,0.2913320039843820d+03,
     2      -.2435871640987979d+03,0.1990396856748623d+03,
     3      -.1491227555537806d+03,0.1128900881450400d+03,
     4      -.7371425586915821d+02,0.5209076024698417d+02,
     5      -.2723382237657512d+02,0.1810311804928121d+02,
     6      -.6373855105789283d+01,0.3972600247516915d+01,
     7      -.7783003678950369d-01,0.4309984339431556d+00,
     8      -.1634072488829489d+01,0.4907510746800098d+01/
         data arr1542/
     1      -.1240390213068932d+02,0.2729447439619294d+02,
     2      -.5343518821480718d+02,0.9452680569870337d+02,
     3      -.1527866218812404d+03,0.2277755954700995d+03,
     4      -.3151652132578166d+03,0.4076877646772918d+03,
     5      -.4942897592787045d+03,0.5661076678490407d+03,
     6      -.6108793641588967d+03,0.6288245409257838d+03,
     7      -.6094935336142166d+03,0.5706993657182994d+03,
     8      -.4977981511199985d+03,0.4282724075779858d+03/
         data arr1543/
     1      -.3323916289673323d+03,0.2651651830978200d+03,
     2      -.1776248350764890d+03,0.1323728959478500d+03,
     3      -.7002929709231906d+02,0.4912960175144170d+02,
     4      -.1736008564453290d+02,0.1141657014586626d+02,
     5      -.6419091910253813d-01,0.3730688172969569d+00,
     6      -.1484445282013671d+01,0.4678891295564679d+01,
     7      -.1241102407603086d+02,0.2866277922908318d+02,
     8      -.5888582118999216d+02,0.1093312301746603d+03/
         data arr1544/
     1      -.1854166966394704d+03,0.2901358153915805d+03,
     2      -.4210792685210531d+03,0.5717837342275726d+03,
     3      -.7266128390102185d+03,0.8737580824266770d+03,
     4      -.9868187185628125d+03,0.1066935711191625d+04,
     5      -.1079286660470488d+04,0.1062078367761403d+04,
     6      -.9622355906224446d+03,0.8706958227414334d+03,
     7      -.6964362347724318d+03,0.5849100929353681d+03,
     8      -.3998607443771338d+03,0.3139682470747037d+03/
         data arr1545/
     1      -.1673037180768943d+03,0.1237606317073670d+03,
     2      -.4376226602435550d+02,0.3033721445928617d+02,
     3      -.5194803371603777d-01,0.3163798987178467d+00,
     4      -.1319130394636693d+01,0.4357087749416578d+01,
     5      -.1210976191112854d+02,0.2930823811480773d+02,
     6      -.6308074976181243d+02,0.1227437694764901d+03,
     7      -.2180171469391274d+03,0.3575705096424213d+03,
     8      -.5432000482331420d+03,0.7732716596901281d+03/
         data arr1546/
     1      -.1027398356993648d+04,0.1295628996680177d+04,
     2      -.1526734302233101d+04,0.1731990405252638d+04,
     3      -.1821297863249569d+04,0.1881994117755650d+04,
     4      -.1762562654861233d+04,0.1676287789987145d+04,
     5      -.1374386144549107d+04,0.1214509937335037d+04,
     6      -.8429627822604849d+03,0.6969623256360132d+03,
     7      -.3724288869419112d+03,0.2903160676098501d+03,
     8      -.1024472942990625d+03,0.7481535662402206d+02/
         data arr1547/
     1      -.4126571158223923d-01,0.2630073505457024d+00,
     2      -.1147437604494624d+01,0.3966349337938761d+01,
     3      -.1153312371884445d+02,0.2921370165703471d+02,
     4      -.6576404469283416d+02,0.1339462563029016d+03,
     5      -.2487025101632086d+03,0.4270551995953476d+03,
     6      -.6775221484003963d+03,0.1010122963044850d+04,
     7      -.1399158619475962d+04,0.1848914418513887d+04,
     8      -.2264964069510173d+04,0.2694429742747875d+04/
         data arr1548/
     1      -.2932075689011581d+04,0.3180250087973343d+04,
     2      -.3062816760929027d+04,0.3060791706864940d+04,
     3      -.2558026284769594d+04,0.2377952599352651d+04,
     4      -.1667112447834735d+04,0.1451108680391768d+04,
     5      -.7742289481105647d+03,0.6358412256266791d+03,
     6      -.2233173327542044d+03,0.1717555115372123d+03,
     7      -.3217454800238998d-01,0.2143536373065169d+00,
     8      -.9772065517830127d+00,0.3531226491380828d+01/
         data arr1549/
     1      -.1072595522500458d+02,0.2840701365393327d+02,
     2      -.6676498451952872d+02,0.1422158636092866d+03,
     3      -.2754275754495274d+03,0.4948064779943531d+03,
     4      -.8175812415899504d+03,0.1275967515258256d+04,
     5      -.1836144830030192d+04,0.2541848815147880d+04,
     6      -.3223185077925708d+04,0.4020680500237736d+04,
     7      -.4504359171716649d+04,0.5129113350958562d+04,
     8      -.5050882949613984d+04,0.5305291417768255d+04/
         data arr1550/
     1      -.4493251617125989d+04,0.4395448517231160d+04,
     2      -.3096582138113494d+04,0.2838363002606838d+04,
     3      -.1505585670519362d+04,0.1302982235225208d+04,
     4      -.4542386149727511d+03,0.3680036129910141d+03,
     5      -.2459164021810211d-01,0.1711171727470437d+00,
     6      -.8140999413448752d+00,0.3073252570421285d+01,
     7      -.9735470039312581d+01,0.2694540443501455d+02,
     8      -.6598369944846920d+02,0.1469525542552415d+03/
         data arr1551/
     1      -.2960665506828587d+03,0.5564698400439989d+03,
     2      -.9543839895005723d+03,0.1559594712869570d+04,
     3      -.2321647100802103d+04,0.3368861005372869d+04,
     4      -.4399348791311821d+04,0.5759282073496819d+04,
     5      -.6603454719057950d+04,0.7902098687304921d+04,
     6      -.7907849744767968d+04,0.8739704949780988d+04,
     7      -.7455625617072908d+04,0.7683183448409850d+04,
     8      -.5410766752144063d+04,0.5227942333430540d+04/
         data arr1552/
     1      -.2744816143197377d+04,0.2505635820699019d+04,
     2      -.8645689602840448d+03,0.7384806763170329d+03,
     3      0.4006777793892191d-19,-.2715477139963836d-21,
     4      0.1264649725963479d-23,-.4680671678080583d-26,
     5      0.1462308968293466d-28,-.3986111118110886d-31,
     6      0.1710106138791524d-33,-.3225872113693487d-34,
     7      0.8784023726162615d-33,-.8305168963066050d-34,
     8      0.3975660118017794d-32,-.5555881878375577d-34/
         data arr1553/
     1      0.1586049430871956d-31,-.3410010460466796d-33,
     2      0.4536553253057477d-31,0.4434226164496801d-33,
     3      0.1020966642825020d-30,-.8422105060289962d-33,
     4      0.1793272743968887d-30,0.1574170379232745d-32,
     5      0.2377103864601478d-30,-.1106247949041246d-32,
     6      0.2429291749680614d-30,0.1751441230132904d-32,
     7      0.1621698443780385d-30,-.1128247154417978d-32,
     8      0.7351660535541313d-31,0.2086590081239056d-13/
         data arr1554/
     1      -.7383631874519005d-15,0.1795461692677250d-16,
     2      -.3469733137436552d-18,0.5659895845212552d-20,
     3      -.8058813515860016d-22,0.1023404887835577d-23,
     4      -.1177940040023249d-25,0.3664598321611618d-27,
     5      -.2819250967411743d-28,0.1080971484639001d-26,
     6      0.8380335367004057d-28,0.4617942995727139d-26,
     7      0.6818894859793180d-28,0.1355571612722365d-25,
     8      0.7857047296463473d-27,0.3141705392819217d-25/
         data arr1555/
     1      0.7199679079277788d-27,0.5733274602356582d-25,
     2      0.2445212263271981d-26,0.7790611813210814d-25,
     3      0.1793480642646872d-26,0.8387396408942696d-25,
     4      0.2641502456235049d-26,0.5725486491159460d-25,
     5      0.6922190920135013d-27,0.2902239911890161d-25,
     6      0.2214637541168569d-10,-.1896676317099891d-11,
     7      0.1116238494760363d-12,-.5220770377828053d-14,
     8      0.2061126387639502d-15,-.7102724967877675d-17/
         data arr1556/
     1      0.2182996931946593d-18,-.6075194197177157d-20,
     2      0.1552936023848720d-21,-.3884999769588052d-23,
     3      0.2387596252925698d-23,-.7702994491266888d-24,
     4      0.9454971583130585d-23,-.2193233282006513d-23,
     5      0.2709264876309391d-22,-.4369437857694677d-23,
     6      0.6092109868420734d-22,-.8030868789037528d-23,
     7      0.1064888681094256d-21,-.9571405232455454d-23,
     8      0.1404508079786071d-21,-.1024238927035200d-22/
         data arr1557/
     1      0.1430119273568532d-21,-.5871707955785713d-23,
     2      0.9494281152303137d-22,-.2954863787794404d-23,
     3      0.4324108757364186d-22,0.2301341643449347d-08,
     4      -.3586002725908665d-09,0.3839841913390344d-10,
     5      -.3267607594622680d-11,0.2347139396611398d-12,
     6      -.1471628579380680d-13,0.8229344219965966d-15,
     7      -.4166834434581928d-16,0.1932037675884826d-17,
     8      -.8274709176622154d-19,0.3406998371877343d-20/
         data arr1558/
     1      -.1165891296105307d-21,0.4507982804397084d-21,
     2      -.4724670364510972d-22,0.1233975171846393d-20,
     3      -.1063640129247221d-21,0.2671801584055548d-20,
     4      -.3586769052053983d-21,0.4654298486606051d-20,
     5      -.4179651294789077d-21,0.5830583906717308d-20,
     6      -.5870369529902838d-21,0.6055451474803442d-20,
     7      -.2829771449813340d-21,0.3732769047476448d-20,
     8      -.2018675445245116d-21,0.1964925851719302d-20/
         data arr1559/
     1      0.6928741380323795d-07,-.1690373113624743d-07,
     2      0.2833896675772346d-08,-.3775715560039476d-09,
     3      0.4246263708672589d-10,-.4168357873811109d-11,
     4      0.3649477734996590d-12,-.2893146793268786d-13,
     5      0.2100258779529737d-14,-.1408432947636119d-15,
     6      0.8792726983912274d-17,-.5147339036426702d-18,
     7      0.5603237584460321d-19,-.8933061978757662d-20,
     8      0.8465800909349828d-19,-.1783047284521336d-19/
         data arr1560/
     1      0.1971098492068822d-18,-.4358039471845947d-19,
     2      0.3620639605798052d-18,-.6284619343966245d-19,
     3      0.4914184500459700d-18,-.8538721046237431d-19,
     4      0.5276856069642271d-18,-.5987642320287293d-19,
     5      0.3593164994163166d-18,-.4069522931745901d-19,
     6      0.1798243315922059d-18,0.9613782324303294d-06,
     7      -.3347052291570490d-06,0.8007628574696284d-07,
     8      -.1522506538397353d-07,0.2443469072580891d-08/
         data arr1561/
     1      -.3422984010739051d-09,0.4276717645053705d-10,
     2      -.4838272376638388d-11,0.5012246120563228d-12,
     3      -.4796602377521447d-13,0.4270185776454566d-14,
     4      -.3556482321265766d-15,0.2813570581449384d-16,
     5      -.2014059318127374d-17,0.9244094877729104d-18,
     6      0.8259964560895846d-19,0.1753049252846094d-17,
     7      0.5222286467045944d-19,0.3074572252513660d-17,
     8      0.6256988505160455d-19,0.4085359250805862d-17/
         data arr1562/
     1      -.8754341954431755d-19,0.4269880014131250d-17,
     2      -.4927171928508281d-19,0.2874628678646880d-17,
     3      -.1079909172736687d-18,0.1391713473402190d-17,
     4      0.7842952457636795d-05,-.3659788133124979d-05,
     5      0.1173560590851539d-05,-.2990672877826652d-06,
     6      0.6433165756427038d-07,-.1207899815382752d-07,
     7      0.2022761934197180d-08,-.3067133341645487d-09,
     8      0.4258757061094509d-10,-.5462512359874057d-11/
         data arr1563/
     1      0.6517887820920605d-12,-.7276624657202582d-13,
     2      0.7639768261386243d-14,-.7573625132108259d-15,
     3      0.7711368649575868d-16,-.7705390153181267d-17,
     4      0.1435997343519313d-16,-.3421218477282915d-17,
     5      0.2417222369289707d-16,-.4597881911086730d-17,
     6      0.3129365405158319d-16,-.6147422257674550d-17,
     7      0.3214333979695031d-16,-.3815903564719981d-17,
     8      0.2068825279678670d-16,-.2728335339821708d-17/
         data arr1564/
     1      0.1030605919763684d-16,0.4345922264646720d-04,
     2      -.2598347412121875d-04,0.1067543774895043d-04,
     3      -.3485683811142195d-05,0.9606887848022562d-06,
     4      -.2311148205067614d-06,0.4958845246514877d-07,
     5      -.9634015529745690d-08,0.1713943307766806d-08,
     6      -.2816728058381216d-09,0.4306237606510568d-10,
     7      -.6159701807331502d-11,0.8283885421000195d-12,
     8      -.1051801124963552d-12,0.1267328482489393d-13/
         data arr1565/
     1      -.1462495758215741d-14,0.2049658489004626d-15,
     2      -.4584061547190251d-16,0.7662501299074044d-16,
     3      -.3394454434267568d-16,0.8780710871808354d-16,
     4      -.3635832160539174d-16,0.7966243338968852d-16,
     5      -.1912578675474359d-16,0.4465067354304838d-16,
     6      -.1110775283593735d-16,0.1876946006965978d-16,
     7      0.1794476842809642d-03,-.1328936152990108d-03,
     8      0.6763065361908240d-04,-.2735249048443959d-04/
         data arr1566/
     1      0.9337757708414226d-05,-.2782522405764356d-05,
     2      0.7395072281208141d-06,-.1779591013469614d-06,
     3      0.3921573042042550d-07,-.7982883077284309d-08,
     4      0.1511693762947734d-08,-.2678405583717436d-09,
     5      0.4461681051937695d-10,-.7016527327199882d-11,
     6      0.1045735811627225d-11,-.1482241970300888d-12,
     7      0.2071981389864956d-13,-.2976916171711707d-14,
     8      0.1605326836549530d-14,-.6177822083920655d-15/
         data arr1567/
     1      0.1692128128280937d-14,-.6872060093581704d-15,
     2      0.1686852014543013d-14,-.4902192530117869d-15,
     3      0.1112527671872568d-14,-.2775157695536744d-15,
     4      0.4828597356048530d-15,0.5880428295689247d-03,
     5      -.5254488693356686d-03,0.3226451753809282d-03,
     6      -.1574467539794054d-03,0.6485368857330690d-04,
     7      -.2331771533516078d-04,0.7477303251349038d-05,
     8      -.2171090965906902d-05,0.5772625317386121d-06/
         data arr1568/
     1      -.1417842775449344d-06,0.3239569982043193d-07,
     2      -.6925563402155722d-08,0.1391975520039141d-08,
     3      -.2641236630689719d-09,0.4748349264739130d-10,
     4      -.8113318930313531d-11,0.1324559863271798d-11,
     5      -.2075697385013777d-12,0.3713231232360453d-13,
     6      -.7536578976161183d-14,0.9352459454959912d-14,
     7      -.4006730430760010d-14,0.8882455772532875d-14,
     8      -.2844496654320354d-14,0.5939271438332603d-14/
         data arr1569/
     1      -.1675870125945957d-14,0.2625178215245388d-14,
     2      0.1599320517564627d-02,-.1688633561844468d-02,
     3      0.1225204363558890d-02,-.7064728486833702d-03,
     4      0.3438546095637707d-03,-.1460846450666927d-03,
     5      0.5535310312423900d-04,-.1899124354473810d-04,
     6      0.5966603210262805d-05,-.1731650597020725d-05,
     7      0.4675175967842780d-06,-.1180984249471340d-06,
     8      0.2804780339795491d-07,-.6288579271390106d-08/
         data arr1570/
     1      0.1335836784322175d-08,-.2696814512470179d-09,
     2      0.5189257266605314d-10,-.9538034902343784d-11,
     3      0.1691690371476993d-11,-.2862207926097934d-12,
     4      0.6373034928525211d-13,-.1146142252712952d-13,
     5      0.1897109775627996d-13,-.3580922967024649d-14,
     6      0.1194945895737835d-13,-.2374305051723338d-14,
     7      0.5304017447525452d-14,0.3730967923231733d-02,
     8      -.4576294881619762d-02,0.3857266962105954d-02/
         data arr1571/
     1      -.2583801918307985d-02,0.1460935927760614d-02,
     2      -.7210302188053901d-03,0.3173828441932210d-03,
     3      -.1264991060297066d-03,0.4616935301307155d-04,
     4      -.1556608781951595d-04,0.4882134602981596d-05,
     5      -.1432677600533638d-05,0.3952717525335677d-06,
     6      -.1029537207848790d-06,0.2540588743994151d-07,
     7      -.5958331901482639d-08,0.1331703882981776d-08,
     8      -.2843400656497028d-09,0.5813227550669278d-10/
         data arr1572/
     1      -.1139588352146969d-10,0.2153913363384079d-11,
     2      -.3863450384113453d-12,0.7318222405093664d-13,
     3      -.8755479539025168d-14,0.4541407195480469d-14,
     4      0.5841028345537676d-15,0.1317318636231672d-14,
     5      0.7654187782707315d-02,-.1075393318739219d-01,
     6      0.1038266318045001d-01,-.7966435047449297d-02,
     7      0.5159548604485834d-02,-.2916820746815166d-02,
     8      0.1470670756180904d-02,-.6714214329965756d-03/
         data arr1573/
     1      0.2806966749731008d-03,-.1084023484747892d-03,
     2      0.3894437146421583d-04,-.1309058805574457d-04,
     3      0.4136968373219497d-05,-.1234253055731678d-05,
     4      0.3488769578630493d-06,-.9372136679984863d-07,
     5      0.2399371873371273d-07,-.5868304771219466d-08,
     6      0.1374251177356398d-08,-.3087833534573359d-09,
     7      0.6681202676804389d-10,-.1396820209961774d-10,
     8      0.2939425672139891d-11,-.6239628465380776d-12/
         data arr1574/
     1      0.2090520187455030d-12,-.6313222756499296d-13,
     2      0.4307631644810130d-13,0.1407897755240056d-01,
     3      -.2239101831997151d-01,0.2447089110243975d-01,
     4      -.2125394468841800d-01,0.1558194768880248d-01,
     5      -.9971357380679970d-02,0.5691077579361125d-02,
     6      -.2941092998677968d-02,0.1391827241443379d-02,
     7      -.6084449107598956d-03,0.2474353687462037d-03,
     8      -.9414792294086866d-04,0.3367970618465012d-04/
         data arr1575/
     1      -.1137430340389661d-04,0.3639379600290481d-05,
     2      -.1106695318268340d-05,0.3207158021916443d-06,
     3      -.8879043169154112d-07,0.2353526451077853d-07,
     4      -.5984609673191525d-08,0.1462585515261174d-08,
     5      -.3440523097468206d-09,0.7807722660608629d-10,
     6      -.1706202117490770d-10,0.3630992586068911d-11,
     7      -.7117519007772483d-12,0.1315239057055506d-12,
     8      0.2357704631650062d-01,-.4201952847668906d-01/
         data arr1576/
     1      0.5146194104718471d-01,-.5008814797354208d-01,
     2      0.4115060446508710d-01,-.2950990477854840d-01,
     3      0.1887413604913333d-01,-.1093050889217395d-01,
     4      0.5796635686787938d-02,-.2839690351588587d-02,
     5      0.1294108085189430d-02,-.5517960210871166d-03,
     6      0.2212051147885693d-03,-.8371643522214696d-04,
     7      0.3001734824920178d-04,-.1022897368477837d-04,
     8      0.3321875730176529d-05,-.1030594180292425d-05/
         data arr1577/
     1      0.3061253609731147d-06,-.8722973169233625d-07,
     2      0.2388923057099592d-07,-.6295018243179255d-08,
     3      0.1600717216342453d-08,-.3899728951267325d-09,
     4      0.9302358056824411d-10,-.1950907565569633d-10,
     5      0.4499978214966209d-11,0.3639240352839600d-01,
     6      -.7205564313412004d-01,0.9803890874766467d-01,
     7      -.1060090056310215d+00,0.9675635236173320d-01,
     8      -.7708441094485481d-01,0.5477234216061991d-01/
         data arr1578/
     1      -.3523952895631753d-01,0.2076161820594377d-01,
     2      -.1129930317251910d-01,0.5720667517628384d-02,
     3      -.2709880891797001d-02,0.1206874980665136d-02,
     4      -.5074267089282161d-03,0.2021298250487972d-03,
     5      -.7652186324633084d-04,0.2760783238110857d-04,
     6      -.9515482950747073d-05,0.3140055462619429d-05,
     7      -.9939860995405282d-06,0.3024140590436283d-06,
     8      -.8848777945523320d-07,0.2498784559948125d-07/
         data arr1579/
     1      -.6732140383719915d-08,0.1776226081799323d-08,
     2      -.4022919944218835d-09,0.1001522977845206d-09,
     3      0.5230123995619354d-01,-.1141820190213143d+00,
     4      0.1712997232641212d+00,-.2042346507903220d+00,
     5      0.2055391836240286d+00,-.1805552709464192d+00,
     6      0.1414599171198446d+00,-.1003530681323125d+00,
     7      0.6519138895448116d-01,-.3912092982801983d-01,
     8      0.2183899697903603d-01,-.1140682176342268d-01/
         data arr1580/
     1      0.5601511230019085d-02,-.2596837093592567d-02,
     2      0.1140591842637307d-02,-.4761169473631186d-03,
     3      0.1894039094442402d-03,-.7198021510778448d-04,
     4      0.2619078972339675d-04,-.9140891999442531d-05,
     5      0.3066498907629538d-05,-.9886891105531786d-06,
     6      0.3078620638986276d-06,-.9098438776703146d-07,
     7      0.2647257731650194d-07,-.6453589274652923d-08,
     8      0.1769581391060935d-08,0.7056892536832424d-01/
         data arr1581/
     1      -.1687598542357207d+00,0.2773307265980878d+00,
     2      -.3621935065324919d+00,0.3992783523635001d+00,
     3      -.3842034085399150d+00,0.3297268746933937d+00,
     4      -.2562250027030803d+00,0.1823270017486390d+00,
     5      -.1198504941618014d+00,0.7328806469762600d-01,
     6      -.4193099040167916d-01,0.2255514286170008d-01,
     7      -.1145394054066878d-01,0.5510746080870673d-02,
     8      -.2519782453424573d-02,0.1098015337223570d-02/
         data arr1582/
     1      -.4570840898132029d-03,0.1821808697746296d-03,
     2      -.6963907433300864d-04,0.2559098038626070d-04,
     3      -.9028486405189356d-05,0.3079901502933084d-05,
     4      -.9903825082141305d-06,0.3158173793539523d-06,
     5      -.8214532094154381d-07,0.2469688639911757d-07,
     6      0.9002048708441336d-01,-.2344489487533533d+00,
     7      0.4195931903099482d+00,-.5967911790917971d+00,
     8      0.7164877900899043d+00,-.7508367759948799d+00/
         data arr1583/
     1      0.7017621855608354d+00,-.5938932869335448d+00,
     2      0.4602451216716870d+00,-.3294802026751756d+00,
     3      0.2194189049287114d+00,-.1367184686783618d+00,
     4      0.8009196461329368d-01,-.4429445944594522d-01,
     5      0.2320898921553855d-01,-.1155735707145880d-01,
     6      0.5484734305910070d-02,-.2486456021559242d-02,
     7      0.1079298707117866d-02,-.4491955274395026d-03,
     8      0.1797790918772676d-03,-.6896434113523997d-04/
         data arr1584/
     1      0.2562645500628000d-04,-.8898124294702057d-05,
     2      0.3092597773177858d-05,-.8513160329474667d-06,
     3      0.2791817474267350d-06,0.1092062342900564d+00,
     4      -.3081576753272155d+00,0.5975465688563016d+00,
     5      -.9208403628336098d+00,0.1197813964588166d+01,
     6      -.1360018263387974d+01,0.1377234181971509d+01,
     7      -.1262829946531656d+01,0.1060337879311231d+01,
     8      -.8224377303376128d+00,0.5934257311015738d+00/
         data arr1585/
     1      -.4006250308075928d+00,0.2542836801125727d+00,
     2      -.1523691601784828d+00,0.8650130631475211d-01,
     3      -.4667020045113312d-01,0.2399696682216849d-01,
     4      -.1178615249471692d-01,0.5543161877476192d-02,
     5      -.2498527250778057d-02,0.1083524790535723d-02,
     6      -.4492925554991531d-03,0.1809450157760385d-03,
     7      -.6735413062528875d-04,0.2538881610732353d-04,
     8      -.7342260515054498d-05,0.2613513697991530d-05/
         data arr1586/
     1      0.1266193418827082d+00,-.3853491062573378d+00,
     2      0.8059013263614704d+00,-.1339439825017597d+01,
     3      0.1879130661322778d+01,-.2301129678197729d+01,
     4      0.2513233807647292d+01,-.2485413857667816d+01,
     5      0.2250747973443454d+01,-.1882843997764272d+01,
     6      0.1465232159079983d+01,-.1066858214480799d+01,
     7      0.7303245893431389d+00,-.4719781955848934d+00,
     8      0.2889859064272978d+00,-.1681564463755902d+00/
         data arr1587/
     1      0.9325266079162137d-01,-.4939139598144666d-01,
     2      0.2505401508555553d-01,-.1217096780068238d-01,
     3      0.5693286361881544d-02,-.2537743976454637d-02,
     4      0.1102779987879415d-02,-.4370352275331054d-03,
     5      0.1778979117832979d-03,-.5368597649110989d-04,
     6      0.2065292276181782d-04,0.1409137726202295d+00,
     7      -.4606324594977186d+00,0.1034734297730695d+01,
     8      -.1847212986643023d+01,0.2783540448799264d+01/
         data arr1588/
     1      -.3661242046764055d+01,0.4295038227111585d+01,
     2      -.4562255825002696d+01,0.4437665713494648d+01,
     3      -.3987390414876851d+01,0.3332941478287676d+01,
     4      -.2606598843217107d+01,0.1916595177323302d+01,
     5      -.1330392915634869d+01,0.8749483540136926d+00,
     6      -.5468233442636655d+00,0.3257215512011939d+00,
     7      -.1852605587131322d+00,0.1009433866076048d+00,
     8      -.5261177033872924d-01,0.2643964987739703d-01/
         data arr1589/
     1      -.1260132797549676d-01,0.5885431153930809d-02,
     2      -.2466787941471229d-02,0.1080217977855902d-02,
     3      -.3380969179339822d-03,0.1400334589052171d-03,
     4      0.1510781449567793d+00,-.5285025341790637d+00,
     5      0.1270473805622266d+01,-.2427158719592736d+01,
     6      0.3914020319028134d+01,-.5509323917243893d+01,
     7      0.6916418084603324d+01,-.7862092076678543d+01,
     8      0.8183845644727294d+01,-.7869292277538765d+01/
         data arr1590/
     1      0.7039130841957859d+01,-.5891263082033536d+01,
     2      0.4635637244571970d+01,-.3443464903228163d+01,
     3      0.2423509928743287d+01,-.1620746458730688d+01,
     4      0.1033163530399678d+01,-.6285972098553877d+00,
     5      0.3665653047425924d+00,-.2041026859792985d+00,
     6      0.1098003444103884d+00,-.5566377638368139d-01,
     7      0.2784551675675473d-01,-.1226446889626181d-01,
     8      0.5758413049306021d-02,-.1858821987456147d-02/
         data arr1591/
     1      0.8261086966461495d-03,0.1565383688952690d+00,
     2      -.5840691340330560d+00,0.1497548580899892d+01,
     3      -.3051486115454074d+01,0.5248489370930611d+01,
     4      -.7879661212084948d+01,0.1055087582009439d+02,
     5      -.1279214182221783d+02,0.1420236457229463d+02,
     6      -.1456586099432340d+02,0.1389689693573569d+02,
     7      -.1240513604083216d+02,0.1041122565598260d+02,
     8      -.8248389309300348d+01,0.6191865563005249d+01/
         data arr1592/
     1      -.4415854652517882d+01,0.3002526814689896d+01,
     2      -.1947094921679693d+01,0.1211246786802432d+01,
     3      -.7174812024899304d+00,0.4118819321757270d+00,
     4      -.2209538595458078d+00,0.1180287461764218d+00,
     5      -.5429056248423232d-01,0.2725093254021016d-01,
     6      -.9025931384905999d-02,0.4291533641459788d-02,
     7      0.1571819094091530d+00,-.6236408770303103d+00,
     8      0.1700355797349902d+01,-.3684332593145619d+01/
         data arr1593/
     1      0.6738610113201007d+01,-.1075801173017050d+02,
     2      0.1531798337898609d+02,-.1974896925752165d+02,
     3      0.2331581463087812d+02,-.2542802276582410d+02,
     4      0.2579785727606848d+02,-.2448764564649845d+02,
     5      0.2185440737233177d+02,-.1841022847336101d+02,
     6      0.1469641003725394d+02,-.1114175911584541d+02,
     7      0.8056612213055455d+01,-.5549438531613758d+01,
     8      0.3671956283999024d+01,-.2304380733081044d+01/
         data arr1594/
     1      0.1407711179424454d+01,-.7949678969283296d+00,
     2      0.4522624048102015d+00,-.2159526684729789d+00,
     3      0.1155871467341640d+00,-.3909763911669311d-01,
     4      0.1983632668516089d-01,0.1533135069160579d+00,
     5      -.6450782574412530d+00,0.1865166640666980d+01,
     6      -.4285846062148016d+01,0.8312814761137476d+01,
     7      -.1407373714305585d+02,0.2125098993719974d+02,
     8      -.2905498193539047d+02,0.3637703983040684d+02/
         data arr1595/
     1      -.4207111665760475d+02,0.4526444105543457d+02,
     2      -.4556175393466511d+02,0.4312206981007631d+02,
     3      -.3851659942327763d+02,0.3260790033888718d+02,
     4      -.2620096181020967d+02,0.2009485710409859d+02,
     5      -.1465228379214825d+02,0.1028580339396896d+02,
     6      -.6809934930019546d+01,0.4416167328739765d+01,
     7      -.2611662241778486d+01,0.1578775861634940d+01,
     8      -.7780239445067409d+00,0.4430763581147827d+00/
         data arr1596/
     1      -.1523944792262218d+00,0.8231582078774391d-01,
     2      0.1455628186064692d+00,-.6478902610102385d+00,
     3      0.1981644790396639d+01,-.4816854533738862d+01,
     4      0.9883125105308032d+01,-.1770001599856050d+02,
     5      0.2827241851762754d+02,-.4089024489317259d+02,
     6      0.5415607512327711d+02,-.6625369201326703d+02,
     7      0.7540626627721832d+02,-.8028350823434161d+02,
     8      0.8038228725347619d+02,-.7592585844974930d+02/
         data arr1597/
     1      0.6800306139401980d+02,-.5774536829149993d+02,
     2      0.4686240849097072d+02,-.3604797430905096d+02,
     3      0.2678681712158574d+02,-.1862858212012887d+02,
     4      0.1279743785749069d+02,-.7883739323224019d+01,
     5      0.5054227136958346d+01,-.2556167030246618d+01,
     6      0.1545933084800993d+01,-.5385133415346144d+00,
     7      0.3090734713170695d+00,0.1347681281857438d+00,
     8      -.6331008744438564d+00,0.2043771803679554d+01/
         data arr1598/
     1      -.5243293607730739d+01,0.1135456223712904d+02,
     2      -.2146257031102952d+02,0.3618323966564122d+02,
     3      -.5523183400069526d+02,0.7720691884588939d+02,
     4      -.9968377562168291d+02,0.1197481744559872d+03,
     5      -.1345343622369235d+03,0.1421789777324215d+03,
     6      -.1416593304346954d+03,0.1339378369123815d+03,
     7      -.1198467776246752d+03,0.1027004991594394d+03,
     8      -.8304569778976149d+02,0.6519734547614584d+02/
         data arr1599/
     1      -.4740867728449177d+02,0.3444203805681435d+02,
     2      -.2198424978426446d+02,0.1492289718968266d+02,
     3      -.7703567817361493d+01,0.4939979538755580d+01,
     4      -.1736358983333008d+01,0.1057139933979606d+01,
     5      0.1218582793459759d+00,-.6029465692598843d+00,
     6      0.2050112871830678d+01,-.5539692830794477d+01,
     7      0.1263549622840466d+02,-.2515558393671973d+02,
     8      0.4466867121198732d+02,-.7181253669792673d+02/
         data arr1600/
     1      0.1057344923742080d+03,-.1437668940534623d+03,
     2      0.1819153458392201d+03,-.2151770900214242d+03,
     3      0.2395542917905782d+03,-.2511319797100535d+03,
     4      0.2501796916729048d+03,-.2351793750286838d+03,
     5      0.2124306517815149d+03,-.1798870290911456d+03,
     6      0.1489696924844588d+03,-.1127197743547823d+03,
     7      0.8648030657475084d+02,-.5688625234545467d+02,
     8      0.4083283118651484d+02,-.2140315266312438d+02/
         data arr1601/
     1      0.1453420458283507d+02,-.5137095299175935d+01,
     2      0.3313148601842791d+01,0.1077494825371889d+00,
     3      -.5604803917407607d+00,0.2003480914204845d+01,
     4      -.5691271718391683d+01,0.1364722581949522d+02,
     5      -.2856206733684478d+02,0.5332033896314783d+02,
     6      -.9010714911883974d+02,0.1394842887996997d+03,
     7      -.1993221656114670d+03,0.2651845848624060d+03,
     8      -.3295077489384358d+03,0.3857687498647412d+03/
         data arr1602/
     1      -.4244061806917568d+03,0.4447577612856172d+03,
     2      -.4378048742491634d+03,0.4162456295238258d+03,
     3      -.3676019645937106d+03,0.3207239791431665d+03,
     4      -.2512413290758663d+03,0.2033522328710256d+03,
     5      -.1371022632169192d+03,0.1039663754085169d+03,
     6      -.5505462357340520d+02,0.3955219993765525d+02,
     7      -.1401211289503888d+02,0.9562848572406082d+01,
     8      0.9326682784019921d-01,-.5091552389329206d+00/
         data arr1603/
     1      0.1910143446928677d+01,-.5694485394046054d+01,
     2      0.1433135423011835d+02,-.3147509675789817d+02,
     3      0.6167120495698860d+02,-.1093485123534543d+03,
     4      0.1776734524134838d+03,-.2662970320421463d+03,
     5      0.3719325682164474d+03,-.4843540734271075d+03,
     6      0.5954578967095641d+03,-.6855389943216485d+03,
     7      0.7547660265521758d+03,-.7751825632717154d+03,
     8      0.7749427587927214d+03,-.7105168359759788d+03/
         data arr1604/
     1      0.6525685835674142d+03,-.5263808633878164d+03,
     2      0.4491787896202866d+03,-.3087092126761275d+03,
     3      0.2471611279384564d+03,-.1315785933772486d+03,
     4      0.9994247285605368d+02,-.3537981893691633d+02,
     5      0.2553071693912580d+02,0.7909393069110848d-01,
     6      -.4524439130248751d+00,0.1778756971767972d+01,
     7      -.5556118375164782d+01,0.1465401667574941d+02,
     8      -.3371620635621206d+02,0.6923698420209817d+02/
         data arr1605/
     1      -.1285679827428903d+03,0.2189723483237608d+03,
     2      -.3435043631581936d+03,0.5030221822518356d+03,
     3      -.6847852180417814d+03,0.8830724339128577d+03,
     4      -.1060486398410125d+04,0.1225596967313064d+04,
     5      -.1307915218136362d+04,0.1373982886260221d+04,
     6      -.1301340030565577d+04,0.1257700303987895d+04,
     7      -.1038712952142651d+04,0.9342827413545834d+03,
     8      -.6509770697285529d+03,0.5501477256864072d+03/
         data arr1606/
     1      -.2930303340912536d+03,0.2352587031028366d+03,
     2      -.8297331257767941d+02,0.6328176610920056d+02,
     3      0.6574914156802059d-01,-.3935329273598613d+00,
     4      0.1619211685207293d+01,-.5291209065585629d+01,
     5      0.1460657403488476d+02,-.3514767912931910d+02,
     6      0.7555616484763411d+02,-.1466479095164946d+03,
     7      0.2615315519130786d+03,-.4283882126605362d+03,
     8      0.6571595261156003d+03,-.9324025663608755d+03/
         data arr1607/
     1      0.1260453025514542d+04,-.1572952587498675d+04,
     2      0.1907513028003728d+04,-.2105086524455060d+04,
     3      0.2323703586960015d+04,-.2260993232997888d+04,
     4      0.2299752611763876d+04,-.1933065854016233d+04,
     5      0.1833170837648758d+04,-.1287826580505417d+04,
     6      0.1149061472999718d+04,-.6094755506005874d+03,
     7      0.5172701371614062d+03,-.1812316272458355d+03,
     8      0.1460773078185077d+03,0.5358190180766988d-01/
         data arr1608/
     1      -.3350980448559945d+00,0.1441510048418262d+01,
     2      -.4920122980257490d+01,0.1420280476747529d+02,
     3      -.3567643460252187d+02,0.8022090652640708d+02,
     4      -.1623707972831058d+03,0.3030390766371995d+03,
     5      -.5168146612449614d+03,0.8302506602043823d+03,
     6      -.1223226256055583d+04,0.1733456279510853d+04,
     7      -.2237687232435289d+04,0.2848384061429370d+04,
     8      -.3232758010508122d+04,0.3751958260099931d+04/
         data arr1609/
     1      -.3727758806916582d+04,0.3993556323282218d+04,
     2      -.3394995543512682d+04,0.3397281312567286d+04,
     3      -.2392939248961662d+04,0.2255851937228077d+04,
     4      -.1185887669321784d+04,0.1064669266693113d+04,
     5      -.3694695492039481d+03,0.3148598866417203d+03,
     6      0.4276453686060009d-01,-.2790572457991414d+00,
     7      0.1254402570267259d+01,-.4464132405088126d+01,
     8      0.1347102174231883d+02,-.3524568523596625d+02/
         data arr1610/
     1      0.8289227834429322d+02,-.1744618382261591d+03,
     2      0.3408361408586953d+03,-.6030103744872271d+03,
     3      0.1015091340768690d+04,-.1545839883944578d+04,
     4      0.2298731907147325d+04,-.3052676491193166d+04,
     5      0.4084183110834701d+04,-.4736778661199038d+04,
     6      0.5789452287916758d+04,-.5834432861566778d+04,
     7      0.6594468264587551d+04,-.5632146800030992d+04,
     8      0.5957253436594791d+04,-.4183017162447069d+04/
         data arr1611/
     1      0.4172926075608557d+04,-.2163436658402391d+04,
     2      0.2057577846095914d+04,-.7050408367420467d+03,
     3      0.6359870592984978d+03,-.6400440999855198d-22,
     4      0.4103065856370160d-24,-.1812956892076959d-26,
     5      0.7026638953103929d-29,-.1776692285213613d-29,
     6      0.6350555946152743d-29,-.1292459760968912d-28,
     7      0.4025261695246131d-28,-.6593869024984491d-28,
     8      0.1843034184747275d-27,-.2439703103557532d-27/
         data arr1612/
     1      0.6288287798907505d-27,-.6967502727580611d-27,
     2      0.1680345576831006d-26,-.1518544912483235d-26,
     3      0.3473948091511921d-26,-.2631389297520666d-26,
     4      0.5749013177450622d-26,-.3421818746567292d-26,
     5      0.7205260088996539d-26,-.3487763781168650d-26,
     6      0.7099474657049413d-26,-.2308558177530076d-26,
     7      0.4578982820224677d-26,-.1093468810243279d-26,
     8      0.2112878674064531d-26,-.1740338722752498d-15/
         data arr1613/
     1      0.5825246947439893d-17,-.1343821865719902d-18,
     2      0.2470181055421047d-20,-.3841888963500142d-22,
     3      0.5227005475521111d-24,-.6354291108271445d-26,
     4      0.6992105000126096d-28,0.2105740245406212d-29,
     5      -.8246289737049545d-30,0.1239901747364239d-28,
     6      -.2056906996842705d-29,0.3482222204873475d-28,
     7      -.4236544765879531d-29,0.8012784477505993d-28,
     8      -.1128736913002429d-28,0.1495860059039199d-27/
         data arr1614/
     1      -.1675461222201574d-28,0.2043895172563890d-27,
     2      -.2772565633981861d-28,0.2354302324726652d-27,
     3      -.2513511164240614d-28,0.1617809028973655d-27,
     4      -.2117585642132081d-28,0.9747704859532237d-28,
     5      -.8663505345539841d-29,-.4470508951790852d-12,
     6      0.3621555898817911d-13,-.2021995672771737d-14,
     7      0.8995493035733173d-16,-.3386091270490318d-17,
     8      0.1114974053995311d-18,-.3280939380680732d-20/
         data arr1615/
     1      0.8757775828729220d-22,-.2136665673112890d-23,
     2      0.4880848091795151d-25,0.3115647931880648d-25,
     3      0.4244954912093969d-26,0.8312483039729662d-25,
     4      0.2403600317200193d-25,0.1789865151956621d-24,
     5      0.5792628976831980d-25,0.2960664293919869d-24,
     6      0.1339681074704165d-24,0.3705381630829466d-24,
     7      0.1887851144782875d-24,0.3648315442470877d-24,
     8      0.2358129191455275d-24,0.2236659089791781d-24/
         data arr1616/
     1      0.1675639146740033d-24,0.1078653545656003d-24,
     2      0.9688394950480580d-25,-.8452289482811518d-10,
     3      0.1245809224215317d-10,-.1265538979591925d-11,
     4      0.1024375614426123d-12,-.7015713979369446d-14,
     5      0.4203169796072574d-15,-.2250347879556959d-16,
     6      0.1092910516741340d-17,-.4868493515997425d-19,
     7      0.2006556713657056d-20,-.7116290572029569d-22,
     8      0.3018208010052452d-23,0.1684705105460789d-22/
         data arr1617/
     1      0.2894144865638599d-23,0.3785075243806217d-22,
     2      0.6084472755842161d-23,0.7030002990755729d-22,
     3      0.1557314508685802d-22,0.9281387818729297d-22,
     4      0.2070118579281902d-22,0.1069006104871122d-21,
     5      0.2626104147798609d-22,0.7115239332151591d-22,
     6      0.1787912613806060d-22,0.4515013083434882d-22,
     7      0.9561368965719933d-23,-.3984247637931574d-08,
     8      0.9194374921630725d-09,-.1462328348405019d-09/
         data arr1618/
     1      0.1853221415783636d-10,-.1987186645628481d-11,
     2      0.1863985053052960d-12,-.1562477832078337d-13,
     3      0.1188085030923282d-14,-.8286439298498549d-16,
     4      0.5347062521335426d-17,-.3209325251413910d-18,
     5      0.1800457235560676d-19,0.5459429915695985d-21,
     6      -.5569683987629426d-22,0.3491548414097697d-20,
     7      -.1064469592218121d-21,0.6402444307615598d-20,
     8      0.5273363030827630d-21,0.8639631183853685d-20/
         data arr1619/
     1      0.1046587428555738d-20,0.9296285156540353d-20,
     2      0.2267819474453305d-20,0.6255494946265580d-20,
     3      0.1774620771563536d-20,0.3191346051179418d-20,
     4      0.1541994566433031d-20,-.7889077907851540d-07,
     5      0.2598017774549077d-07,-.5896642467705056d-08,
     6      0.1066417331750705d-08,-.1631843598916251d-09,
     7      0.2184350295261027d-10,-.2612965725487761d-11,
     8      0.2835354478178495d-12,-.2822073665465240d-13/
         data arr1620/
     1      0.2598710714464658d-14,-.2229252283260107d-15,
     2      0.1791885754470072d-16,-.1337727821451631d-17,
     3      0.1047228978948136d-18,0.3336882830576913d-19,
     4      0.1935763019209080d-19,0.7171803890717715d-19,
     5      0.4386394075306631d-19,0.9537990316718427d-19,
     6      0.6300200436431071d-19,0.1024137366029735d-18,
     7      0.8333968838809324d-19,0.6798084503377801d-19,
     8      0.6055102576228850d-19,0.3491186705227724d-19/
         data arr1621/
     1      0.3963545187684526d-19,-.8626203355462417d-06,
     2      0.3807533336619894d-06,-.1158282624977701d-06,
     3      0.2807663717811499d-07,-.5758436427620089d-08,
     4      0.1033133583992210d-08,-.1656441322724039d-09,
     5      0.2409116791979221d-10,-.3213860396626510d-11,
     6      0.3966657511488961d-12,-.4560851004366493d-13,
     7      0.4913093711326714d-14,-.4980243963600999d-15,
     8      0.4788846360788568d-16,-.3990374569089250d-17/
         data arr1622/
     1      0.7108628332742163d-18,0.5612361184135605d-18,
     2      0.7185972903732266d-18,0.6961158786119588d-18,
     3      0.9892600026144600d-18,0.7701922120001082d-18,
     4      0.1178082925035595d-17,0.4628344707578611d-18,
     5      0.7958166080230398d-18,0.3328122366892328d-18,
     6      0.4521885874300042d-18,-.6124363583299641d-05,
     7      0.3463569365655470d-05,-.1349999535069865d-05,
     8      0.4192789595858458d-06,-.1101796675866823d-06/
         data arr1623/
     1      0.2532749640669567d-07,-.5202963044197918d-08,
     2      0.9695527481196506d-09,-.1657217454478844d-09,
     3      0.2620692638327254d-10,-.3860795229225480d-11,
     4      0.5328703586837039d-12,-.6923189161297682d-13,
     5      0.8503243046090573d-14,-.9892989265412304d-15,
     6      0.1136877380000113d-15,-.1048602662563274d-16,
     7      0.9105363919327525d-17,0.5283524374369153d-18,
     8      0.1075342027363830d-16,0.6761241220104977d-18/
         data arr1624/
     1      0.1213133840688221d-16,-.1153490357837157d-18,
     2      0.8206590966929700d-17,0.5002406125503662d-18,
     3      0.4309378728132557d-17,-.3132332551810892d-04,
     4      0.2194228148417983d-04,-.1059357401235322d-04,
     5      0.4075331573330033d-05,-.1326515508816978d-05,
     6      0.3777062144883473d-06,-.9610889922852412d-07,
     7      0.2218376712420068d-07,-.4696716525187398d-08,
     8      0.9199875090578708d-09,-.1678779361689842d-09/
         data arr1625/
     1      0.2870047129865243d-10,-.4618779271436600d-11,
     2      0.7025392426348278d-12,-.1013195343285923d-12,
     3      0.1392775377871859d-13,-.1772600822584940d-14,
     4      0.2729568701268119d-15,0.3364478157109318d-16,
     5      0.7456341588021055d-16,0.5502698343870126d-16,
     6      0.9602490623101689d-16,0.3436479454729039d-16,
     7      0.7359544196711882d-16,0.1093830845133028d-16,
     8      0.4806166598048304d-16,-.1238494862246850d-03/
         data arr1626/
     1      0.1046799177425568d-03,-.6097886560766553d-04,
     2      0.2830447018897823d-04,-.1111628461937676d-04,
     3      0.3819061935103654d-05,-.1172523131887959d-05,
     4      0.3265490005602148d-06,-.8341855358768342d-07,
     5      0.1971539498971077d-07,-.4340826504477925d-08,
     6      0.8954123081248714d-09,-.1738671785451966d-09,
     7      0.3190891660106492d-10,-.5554022729942580d-11,
     8      0.9199018996070440d-12,-.1450775116261110d-12/
         data arr1627/
     1      0.2233265144598066d-13,-.2939265235783403d-14,
     2      0.1038941965355970d-14,0.1105894808492152d-15,
     3      0.7779835646159102d-15,0.8378489614397405d-16,
     4      0.5762039855531022d-15,-.7883058345937786d-17,
     5      0.3570028094342285d-15,-.3980147475064716d-03,
     6      0.3975087860642697d-03,-.2736157577498413d-03,
     7      0.1500704548938531d-03,-.6964312196715511d-04,
     8      0.2827181431935867d-04,-.1025644374613614d-04/
         data arr1628/
     1      0.3375220472465025d-05,-.1018813867466050d-05,
     2      0.2845221484775503d-06,-.7402210512946773d-07,
     3      0.1804224021456663d-07,-.4139649362952655d-08,
     4      0.8977089016003714d-09,-.1846374711024279d-09,
     5      0.3612846384224125d-10,-.6742603245949878d-11,
     6      0.1204739607492436d-11,-.2050602018320843d-12,
     7      0.3569151840412712d-13,-.4756478365194084d-14,
     8      0.3248030109284700d-14,0.2147494887615063d-15/
         data arr1629/
     1      0.1832346139075872d-14,-.8066979896172344d-17,
     2      0.1170044498223142d-14,-.1078643047834207d-02,
     3      0.1251462656547137d-02,-.1000702179950563d-02,
     4      0.6376047118517680d-03,-.3437376696732512d-03,
     5      0.1621045313221634d-03,-.6831732539657690d-04,
     6      0.2611733007884077d-04,-.9158282947173279d-05,
     7      0.2971172500968358d-05,-.8979782089152475d-06,
     8      0.2542654802699103d-06,-.6777243625066790d-07/
         data arr1630/
     1      0.1707330256679760d-07,-.4079391824620126d-08,
     2      0.9272790943351432d-09,-.2010602836313041d-09,
     3      0.4168857327851725d-10,-.8281294679389422d-11,
     4      0.1584017176361105d-11,-.2897566951522247d-12,
     5      0.5644164054809497d-13,-.8868337843034288d-14,
     6      0.5223867848246575d-14,-.4415744015356602d-15,
     7      0.2196589247176888d-14,-.2534726360410692d-02,
     8      0.3368580752509298d-02,-.3085387026741425d-02/
         data arr1631/
     1      0.2251811622081921d-02,-.1390539730811815d-02,
     2      0.7511508514769187d-03,-.3626090172168654d-03,
     3      0.1587860178637119d-03,-.6377834886763885d-04,
     4      0.2370078970830939d-04,-.8204960282494193d-05,
     5      0.2661177383344927d-05,-.8124848175799604d-06,
     6      0.2344528008857135d-06,-.6416660655109934d-07,
     7      0.1670704239286083d-07,-.4149465753704442d-08,
     8      0.9854633848380547d-09,-.2242488574577685d-09/
         data arr1632/
     1      0.4904068057182437d-10,-.1029912434634234d-10,
     2      0.2138616898780572d-11,-.4110161213945247d-12,
     3      0.1170923585676448d-12,-.1945348140322867d-13,
     4      0.2540073211918718d-13,-.5277613630574687d-02,
     5      0.7939405461947832d-02,-.8231617381945656d-02,
     6      0.6800519500836166d-02,-.4753658113238103d-02,
     7      0.2906740173891506d-02,-.1588371757860992d-02,
     8      0.7873363845315996d-03,-.3579775930273087d-03/
         data arr1633/
     1      0.1505843699846028d-03,-.5901033363617909d-04,
     2      0.2166506109894694d-04,-.7487483130735483d-05,
     3      0.2445741351731787d-05,-.7577024673211424d-06,
     4      0.2233178165094207d-06,-.6278428377721182d-07,
     5      0.1687802675882200d-07,-.4347676006389038d-08,
     6      0.1075352089751433d-08,-.2557311366226827d-09,
     7      0.5871458847080203d-10,-.1291685461977247d-10,
     8      0.2841420990233297d-11,-.5457272927335649d-12/
         data arr1634/
     1      0.1512531868483780d-12,-.9904097842709353d-02,
     2      0.1669645842164368d-01,-.1939905629439016d-01,
     3      0.1795959617661426d-01,-.1406829510927279d-01,
     4      0.9640038944552166d-02,-.5903149485984634d-02,
     5      0.3279072321754875d-02,-.1670727290225798d-02,
     6      0.7875691001115836d-03,-.3458564595707049d-03,
     7      0.1422940657666010d-03,-.5510890421698884d-04,
     8      0.2017230345349532d-04,-.7003299438952694d-05/
         data arr1635/
     1      0.2313057159207501d-05,-.7287399564114256d-06,
     2      0.2195335689179685d-06,-.6337067636813350d-07,
     3      0.1756335739838628d-07,-.4679417077932188d-08,
     4      0.1202006046505452d-08,-.2955375122052784d-09,
     5      0.7105759646254517d-10,-.1499458460936174d-10,
     6      0.3531114735056936d-11,-.1698367796096471d-01,
     7      0.3180802220631067d-01,-.4105711133569549d-01,
     8      0.4222793415861541d-01,-.3674855102497671d-01/
         data arr1636/
     1      0.2797518838150826d-01,-.1903152079166588d-01,
     2      0.1174454481746190d-01,-.6647927003882923d-02,
     3      0.3481487381541519d-02,-.1698507737273579d-02,
     4      0.7763434768266972d-03,-.3340291531732390d-03,
     5      0.1358355891752362d-03,-.5239093965305914d-04,
     6      0.1922362683167113d-04,-.6728465187040133d-05,
     7      0.2251850243111027d-05,-.7221179620259680d-06,
     8      0.2223389400180187d-06,-.6578541550395727d-07/
         data arr1637/
     1      0.1876737659850243d-07,-.5107953360682941d-08,
     2      0.1358867745336980d-08,-.3119747167017289d-09,
     3      0.7793343407273183d-10,-.2691295997984757d-01,
     4      0.5557696909442424d-01,-.7909974012294116d-01,
     5      0.8970465402252735d-01,-.8607634806926631d-01,
     6      0.7225120697331514d-01,-.5419685107137150d-01,
     7      0.3687781856374659d-01,-.2301673668338020d-01,
     8      0.1329079030969284d-01,-.7149603913810857d-02/
         data arr1638/
     1      0.3603270242332125d-02,-.1709447461747670d-02,
     2      0.7665022471091636d-03,-.3259750181849951d-03,
     3      0.1318839552014218d-03,-.5089775383599926d-04,
     4      0.1878239069036822d-04,-.6640783871658370d-05,
     5      0.2254537287390830d-05,-.7350738576746420d-06,
     6      0.2312287472619142d-06,-.6905652441055928d-07,
     7      0.2025605791769729d-07,-.5012319620700555d-08,
     8      0.1377971202664837d-08,-.3977707910737732d-01/
         data arr1639/
     1      0.8997796918393770d-01,-.1402769418904882d+00,
     2      0.1742593593393302d+00,-.1831617883518836d+00,
     3      0.1684092932696515d+00,-.1383773169156045d+00,
     4      0.1031397274639386d+00,-.7051384713946147d-01,
     5      0.4460169581256320d-01,-.2628163915782940d-01,
     6      0.1450899083484333d-01,-.7539906894178197d-02,
     7      0.3703339885133428d-02,-.1725177544186913d-02,
     8      0.7645597671192693d-03,-.3232081152773445d-03/
         data arr1640/
     1      0.1306487201812893d-03,-.5059284286884416d-04,
     2      0.1881492302409056d-04,-.6713094205953580d-05,
     3      0.2313290346838033d-05,-.7519828566684889d-06,
     4      0.2416752147644174d-06,-.6388769669828386d-07,
     5      0.1923944185688647d-07,-.5526014716851961d-01,
     6      0.1361340072577388d+00,-.2311362297786884d+00,
     7      0.3127009078665054d+00,-.3579473882723864d+00,
     8      0.3584277860988611d+00,-.3207390329485568d+00/
         data arr1641/
     1      0.2603539572340754d+00,-.1938491519968528d+00,
     2      0.1335340930877251d+00,-.8569283588581124d-01,
     3      0.5152055955361190d-01,-.2915818495663312d-01,
     4      0.1559693999060900d-01,-.7912786755574941d-02,
     5      0.3819079055305831d-02,-.1758200392139563d-02,
     6      0.7740058259117304d-03,-.3263480225863929d-03,
     7      0.1321769833922798d-03,-.5128455255748475d-04,
     8      0.1924817715967357d-04,-.6759430081627148d-05/
         data arr1642/
     1      0.2366706037649526d-05,-.6630581066398740d-06,
     2      0.2175469122124053d-06,-.7263346063287122d-01,
     3      0.1938697071833329d+00,-.3566399389778754d+00,
     4      0.5227688724949372d+00,-.6483632674350686d+00,
     5      0.7034277550716951d+00,-.6820061193400736d+00,
     6      0.5998176838514793d+00,-.4838799285783999d+00,
     7      0.3611473991049004d+00,-.2511050332248526d+00,
     8      0.1635724328523299d+00,-.1003016818142427d+00/
         data arr1643/
     1      0.5813073941081824d-01,-.3195295523645175d-01,
     2      0.1670934600862686d-01,-.8334173957597753d-02,
     3      0.3975213924001966d-02,-.1815289513761155d-02,
     4      0.7966314566735314d-03,-.3341719571178299d-03,
     5      0.1359124570384333d-03,-.5119564396999971d-04,
     6      0.1943105591363514d-04,-.5727670025898194d-05,
     7      0.2037225599600505d-05,-.9082765538640351d-01,
     8      0.2614689169067795d+00,-.5187628135611766d+00/
         data arr1644/
     1      0.8201198567799445d+00,-.1097020530746004d+01,
     2      0.1283644015241383d+01,-.1342276896685782d+01,
     3      0.1273215323831693d+01,-.1107768275400216d+01,
     4      0.8917118956281829d+00,-.6686888267756824d+00,
     5      0.4697940909535987d+00,-.3106942651123785d+00,
     6      0.1942047556133382d+00,-.1151292994386098d+00,
     7      0.6493284531056825d-01,-.3492588449193184d-01,
     8      0.1796722314572409d-01,-.8843285187473616d-02/
         data arr1645/
     1      0.4185859751955068d-02,-.1887989184246843d-02,
     2      0.8283563179271453d-03,-.3324288868414849d-03,
     3      0.1361641945873127d-03,-.4195228662329681d-04,
     4      0.1610473998928628d-04,-.1085721119162668d+00,
     5      0.3357121365390489d+00,-.7154225134675728d+00,
     6      0.1214836648219918d+01,-.1745428662057610d+01,
     7      0.2193707604330291d+01,-.2463899762407824d+01,
     8      0.2510322814982290d+01,-.2345974876527150d+01/
         data arr1646/
     1      0.2028363593778798d+01,-.1633772666833512d+01,
     2      0.1232883449234618d+01,-.8757731364945160d+00,
     3      0.5879841971970607d+00,-.3743876068814989d+00,
     4      0.2268035756565236d+00,-.1310054513308103d+00,
     5      0.7239068733483275d-01,-.3823082544695322d-01,
     6      0.1943935881416835d-01,-.9378204381461632d-02,
     7      0.4421069310720227d-02,-.1877975852986180d-02,
     8      0.8268887652283230d-03,-.2646928833780761d-03/
         data arr1647/
     1      0.1092377409952910d-03,-.1245692419374882d+00,
     2      0.4121961324996489d+00,-.9400345302712967d+00,
     3      0.1708218512525083d+01,-.2626467130871939d+01,
     4      0.3532587637726451d+01,-.4246015084468934d+01,
     5      0.4629482200925658d+01,-.4629886088834727d+01,
     6      0.4283878633787479d+01,-.3692546925175212d+01,
     7      0.2981955006011483d+01,-.2266774263881771d+01,
     8      0.1628651343079561d+01,-.1109669611024221d+01/
         data arr1648/
     1      0.7194040045532636d+00,-.4445257283990594d+00,
     2      0.2628803918018118d+00,-.1483350958374935d+00,
     3      0.8073029783485886d-01,-.4144555600224993d-01,
     4      0.2091851442572362d-01,-.9346531394154261d-02,
     5      0.4408462502436539d-02,-.1458156313714669d-02,
     6      0.6446986759818668d-03,-.1376664151544226d+00,
     7      0.4858689179183622d+00,-.1181835492313886d+01,
     8      0.2290628553694958d+01,-.3756481130593067d+01/
         data arr1649/
     1      0.5388901163667841d+01,-.6908546594896696d+01,
     2      0.8034070631576457d+01,-.8569803966629980d+01,
     3      0.8457382273186251d+01,-.7775343495218765d+01,
     4      0.6697203985315463d+01,-.5429799314005370d+01,
     5      0.4161069840519786d+01,-.3023440701521082d+01,
     6      0.2090698243246699d+01,-.1377025530845800d+01,
     7      0.8686456767559837d+00,-.5215557838559609d+00,
     8      0.3028410254955268d+00,-.1646148993549741d+00/
         data arr1650/
     1      0.8867398334400267d-01,-.4142304470565216d-01,
     2      0.2086501066068092d-01,-.7095473881608824d-02,
     3      0.3350580471485676d-02,-.1469935645568372d+00,
     4      0.5516682672399971d+00,-.1426935885485026d+01,
     5      0.2940970557376379d+01,-.5128681051229462d+01,
     6      0.7823720005795224d+01,-.1066566442153569d+02,
     7      0.1318941644441122d+02,-.1496055059925241d+02,
     8      0.1570007649344964d+02,-.1534850726534379d+02/
         data arr1651/
     1      0.1405823344302029d+02,-.1211931342621573d+02,
     2      0.9876318021184099d+01,-.7628783818621478d+01,
     3      0.5609937827323243d+01,-.3925122439856631d+01,
     4      0.2633372775155505d+01,-.1675638455207850d+01,
     5      0.1035064748131971d+01,-.5927206476808763d+00,
     6      0.3398117514232175d+00,-.1649942262532217d+00,
     7      0.8851213151515092d-01,-.3080487269239850d-01,
     8      0.1549405853381003d-01,-.1520464040959449d+00/
         data arr1652/
     1      0.6051399637188732d+00,-.1659901075992347d+01,
     2      0.3628009765138404d+01,-.6709391752315489d+01,
     3      0.1085402623145647d+02,-.1569149239081279d+02,
     4      0.2057796079947507d+02,-.2475253488576804d+02,
     5      0.2754706337201326d+02,-.2855761440291246d+02,
     6      0.2773903836806036d+02,-.2535567422304080d+02,
     7      0.2191327058173466d+02,-.1794093135245759d+02,
     8      0.1399240183752095d+02,-.1036541081685825d+02/
         data arr1653/
     1      0.7376663336610329d+01,-.4954017979430019d+01,
     2      0.3247240833087193d+01,-.1949087541533901d+01,
     3      0.1186354077898044d+01,-.5953544755904784d+00,
     4      0.3393355699653968d+00,-.1203572365263031d+00,
     5      0.6432669744419250d-01,-.1527092015346087d+00,
     6      0.6429304573073804d+00,-.1865559866694830d+01,
     7      0.4313349271118687d+01,-.8438154731512759d+01,
     8      0.1444024781949217d+02,-.2208329017432290d+02/
         data arr1654/
     1      0.3063529989318530d+02,-.3898049032374946d+02,
     2      0.4589079664122077d+02,-.5032142283271464d+02,
     3      0.5170735105992834d+02,-.4998421734429778d+02,
     4      0.4569974112736459d+02,-.3954479238758120d+02,
     5      0.3263130852689305d+02,-.2550811453857992d+02,
     6      0.1921109973581512d+02,-.1355966501803663d+02,
     7      0.9410437418315023d+01,-.5890488164971263d+01,
     8      0.3798396661676666d+01,-.1959418119271666d+01/
         data arr1655/
     1      0.1184127723035695d+01,-.4263692679956089d+00,
     2      0.2416464042948983d+00,-.1492233155078122d+00,
     3      0.6630870896659598d+00,-.2030719318726563d+01,
     4      0.4955536631985538d+01,-.1023189011583530d+02,
     5      0.1848072830270087d+02,-.2982871949310420d+02,
     6      0.4367481656332073d+02,-.5864962768534298d+02,
     7      0.7287642189536717d+02,-.8432767498403472d+02,
     8      0.9145920924482560d+02,-.9326473095821470d+02/
         data arr1656/
     1      0.9000981841603428d+02,-.8208633425791903d+02,
     2      0.7151312512327834d+02,-.5878743830510571d+02,
     3      0.4675983477508883d+02,-.3453519573862556d+02,
     4      0.2532767608839253d+02,-.1644884350807337d+02,
     5      0.1121643426026293d+02,-.5916567490793439d+01,
     6      0.3784312376853794d+01,-.1378367818808497d+01,
     7      0.8269274960651050d+00,-.1421158939731758d+00,
     8      0.6651442892041274d+00,-.2145515159760247d+01/
         data arr1657/
     1      0.5514580429943239d+01,-.1199248982317684d+02,
     2      0.2281468646537840d+02,-.3878358847199497d+02,
     3      0.5981240879037558d+02,-.8458772982684391d+02,
     4      0.1107101171898369d+03,-.1348816890110111d+03,
     5      0.1540976289608191d+03,-.1653579435436745d+03,
     6      0.1681281086236975d+03,-.1611229407822362d+03,
     7      0.1479224630746764d+03,-.1274112753076580d+03,
     8      0.1068452100606233d+03,-.8219292164659561d+02/
         data arr1658/
     1      0.6359802304585399d+02,-.4263280743769862d+02,
     2      0.3069513031869226d+02,-.1647334603444017d+02,
     3      0.1113527123962194d+02,-.4089083942613442d+01,
     4      0.2592966306364850d+01,-.1321065606230086d+00,
     5      0.6500145119121976d+00,-.2204223862027382d+01,
     6      0.5956130040223569d+01,-.1361653572942316d+02,
     7      0.2723352735073035d+02,-.4866456051683993d+02,
     8      0.7890402581564618d+02,-.1172789027423570d+03/
         data arr1659/
     1      0.1613859089308547d+03,-.2065664786465556d+03,
     2      0.2481523002382335d+03,-.2795052307429243d+03,
     3      0.2988913521087325d+03,-.3000620109743496d+03,
     4      0.2898476267294291d+03,-.2605653730977889d+03,
     5      0.2300400510679498d+03,-.1834280941049952d+03,
     6      0.1495520869035957d+03,-.1029459876065537d+03,
     7      0.7816462727725131d+02,-.4247279246837974d+02,
     8      0.3030523742614764d+02,-.1118504618528127d+02/
         data arr1660/
     1      0.7488034565556916d+01,-.1200091940050798d+00,
     2      0.6197307219838338d+00,-.2205474434011378d+01,
     3      0.6254691735324015d+01,-.1500544364243886d+02,
     4      0.3149866121102427d+02,-.5905803217716181d+02,
     5      0.1005065675216808d+03,-.1566973327165466d+03,
     6      0.2263495409738597d+03,-.3036850137715353d+03,
     7      0.3830360760594361d+03,-.4516248538268326d+03,
     8      0.5072268913228619d+03,-.5316022655467144d+03/
         data arr1661/
     1      0.5396222825849308d+03,-.5041453449929412d+03,
     2      0.4680703630994417d+03,-.3848930014175960d+03,
     3      0.3303487398516544d+03,-.2323077975038765d+03,
     4      0.1858444525410718d+03,-.1017658201229264d+03,
     5      0.7658075419854330d+02,-.2832396972545103d+02,
     6      0.2000187412473980d+02,-.1066423640837294d+00,
     7      0.5771002162943556d+00,-.2151897937910851d+01,
     8      0.6395466756366975d+01,-.1607426186297148d+02/
         data arr1662/
     1      0.3536260585083304d+02,-.6944236445212083d+02,
     2      0.1238671670725869d+03,-.2021554379959805d+03,
     3      0.3061240279115303d+03,-.4294647015324624d+03,
     4      0.5680384914040555d+03,-.6989791176785931d+03,
     5      0.8236324117005195d+03,-.8976776359863637d+03,
     6      0.9567413026036215d+03,-.9245893126585532d+03,
     7      0.9021284691627673d+03,-.7609197462901806d+03,
     8      0.6871124441644123d+03,-.4910833444224413d+03/
         data arr1663/
     1      0.4137040055008493d+03,-.2272557618169901d+03,
     2      0.1802672113190575d+03,-.6662461290169770d+02,
     3      0.4960378203372358d+02,-.9275711437235151d-01,
     4      0.5253288607036155d+00,-.2049323525563751d+01,
     5      0.6374639067145847d+01,-.1675757008463517d+02,
     6      0.3858931109247473d+02,-.7921676215536088d+02,
     7      0.1479377779364102d+03,-.2521703103385680d+03,
     8      0.3999158606652172d+03,-.5850063065861187d+03/
         data arr1664/
     1      0.8107576700080230d+03,-.1037514703871882d+04,
     2      0.1281855852673920d+04,-.1446449009225965d+04,
     3      0.1617976391920738d+04,-.1609130008502006d+04,
     4      0.1649544925795847d+04,-.1419201227611840d+04,
     5      0.1348110220708563d+04,-.9742080985779445d+03,
     6      0.8641234996994045d+03,-.4740548281214290d+03,
     7      0.3963340144836934d+03,-.1459671047480184d+03,
     8      0.1145638849571038d+03,-.7898391375673663d-01/
         data arr1665/
     1      0.4676554406378965d+00,-.1905642507346410d+01,
     2      0.6198120233326899d+01,-.1701136285922508d+02,
     3      0.4096970062258745d+02,-.8772839583843313d+02,
     4      0.1714060989554413d+03,-.3043457284885906d+03,
     5      0.5052179301073871d+03,-.7679841910267222d+03,
     6      0.1114911233602857d+04,-.1477542619605489d+04,
     7      0.1913973922852414d+04,-.2224664476219372d+04,
     8      0.2612165729075508d+04,-.2658602655006853d+04/
         data arr1666/
     1      0.2864232578510221d+04,-.2498921344908541d+04,
     2      0.2497990266446473d+04,-.1815779877124705d+04,
     3      0.1696430694996228d+04,-.9252683708348296d+03,
     4      0.8156297678862674d+03,-.2984993700692173d+03,
     5      0.2470644002941744d+03,-.6577408567060188d-01,
     6      0.4069057042569934d+00,-.1729088434108571d+01,
     7      0.5878053045844354d+01,-.1680905278023564d+02,
     8      0.4232898334525289d+02,-.9429566809249297d+02/
         data arr1667/
     1      0.1927581448783480d+03,-.3553402704515375d+03,
     2      0.6176088802431875d+03,-.9715066957485556d+03,
     3      0.1478223005024583d+04,-.2018690405779077d+04,
     4      0.2743911990003734d+04,-.3266132829714739d+04,
     5      0.4029808902876504d+04,-.4171800417075181d+04,
     6      0.4728777219880139d+04,-.4157949848487278d+04,
     7      0.4379119129747722d+04,-.3184904646920248d+04,
     8      0.3137729951071665d+04,-.1693564934298434d+04/
         data arr1668/
     1      0.1575856806401192d+04,-.5713923854290126d+03,
     2      0.4993065930567565d+03,0.9175236875972036d-25,
     3      -.5875954552105583d-27,0.1597795280769024d-27,
     4      -.4805793840634662d-27,0.1938139198000371d-26,
     5      -.4166513677408373d-26,0.1405818411165291d-25,
     6      -.2400632173825972d-25,0.7120429463385175d-25,
     7      -.9664355688877777d-25,0.2616126667999964d-24,
     8      -.2982946581891342d-24,0.7457062987285798d-24/
         data arr1669/
     1      -.6887548845256258d-24,0.1621208082899845d-23,
     2      -.1270947683715491d-23,0.2816570146755456d-23,
     3      -.1730665251600766d-23,0.3665520708345812d-23,
     4      -.1878653158014024d-23,0.3764503180027723d-23,
     5      -.1293232531707869d-23,0.2498890132387071d-23,
     6      -.6715697349008332d-24,0.1205678930700327d-23,
     7      0.1302564816019851d-17,-.4147124312656497d-19,
     8      0.9121748073096811d-21,-.1602178451081429d-22/
         data arr1670/
     1      0.2385792272894477d-24,-.3113400202869276d-26,
     2      0.3636429065103568d-28,-.3862627261919460d-30,
     3      -.1286275489031193d-31,-.5394085661593051d-32,
     4      -.8730655485217984d-31,-.2724811480643099d-31,
     5      -.2895527887163816d-30,-.6180404149532588d-31,
     6      -.7068556973035429d-30,-.1310606862789504d-30,
     7      -.1394528718476775d-29,-.1795459590890654d-30,
     8      -.1949266676264442d-29,-.1958144319022787d-30/
         data arr1671/
     1      -.2246097940045715d-29,-.1404660724600770d-30,
     2      -.1557737602825618d-29,-.5778625219556621d-31,
     3      -.8856258783569850d-30,0.8098045174072133d-14,
     4      -.6240014118350288d-15,0.3321805949588676d-16,
     5      -.1412097674473142d-17,0.5089137042018004d-19,
     6      -.1607326717594417d-20,0.4544191783695777d-22,
     7      -.1167175950056304d-23,0.2745373421280020d-25,
     8      -.5943957790140551d-27,-.4874662895434127d-27/
         data arr1672/
     1      0.2885065538415234d-28,-.1717220539422679d-26,
     2      0.7245113524179730d-28,-.4258704864177402d-26,
     3      0.1424486206129685d-27,-.8258694946097354d-26,
     4      0.2337191622174380d-27,-.1143498978294126d-25,
     5      0.2288864222172434d-27,-.1244190960124501d-25,
     6      0.1668974052074805d-27,-.8431587739304206d-26,
     7      0.2903029661497091d-28,-.4122176448472587d-26,
     8      0.2785714112341710d-11,-.3905538081172794d-12/
         data arr1673/
     1      0.3782757651077812d-13,-.2925754979209501d-14,
     2      0.1918475759415879d-15,-.1102440830109950d-16,
     3      0.5670834403443393d-18,-.2650147061586662d-19,
     4      0.1137610199328009d-20,-.4523774518193859d-22,
     5      0.1558029953777100d-23,-.4464327766962814d-25,
     6      -.4681281895274548d-24,0.2905437379949827d-25,
     7      -.1205607000533945d-23,0.6481582005928644d-25,
     8      -.2571719881645599d-23,0.1003583586544799d-24/
         data arr1674/
     1      -.3648393936656681d-23,0.1218740629548151d-24,
     2      -.4418936570678762d-23,0.8519749007137065d-25,
     3      -.3057033365380245d-23,0.4677510687269692d-25,
     4      -.1854500437204810d-23,0.2055924733538551d-09,
     5      -.4512843258068523d-10,0.6843473615509167d-11,
     6      -.8287141180716063d-12,0.8507888837193374d-13,
     7      -.7654546860222291d-14,0.6164670548665745d-15,
     8      -.4510572319819635d-16,0.3031515637492547d-17/
         data arr1675/
     1      -.1887504187910760d-18,0.1094166060603234d-19,
     2      -.5884506494126496d-21,-.4044998713946148d-22,
     3      0.2279254910197806d-22,-.1792447027457949d-21,
     4      0.5488699609514591d-22,-.3600410780302577d-21,
     5      0.8597706002569557d-22,-.5116520084049390d-21,
     6      0.1105242961860008d-21,-.5898520180682109d-21,
     7      0.8378626146831071d-22,-.4140249525745756d-21,
     8      0.5176210117584915d-22,-.2276674521166673d-21/
         data arr1676/
     1      0.5809344350644442d-08,-.1819743372591239d-08,
     2      0.3938006981141886d-09,-.6805258237218254d-10,
     3      0.9970149418479226d-11,-.1280086548782913d-11,
     4      0.1471193198256275d-12,-.1536142409125480d-13,
     5      0.1473330355162017d-14,-.1309098350951035d-15,
     6      0.1084912248168840d-16,-.8431045426999680d-18,
     7      0.6082469801546105d-19,-.3598308619053697d-20,
     8      -.2289742328033776d-20,0.1379640827346172d-20/
         data arr1677/
     1      -.5392869288879119d-20,0.2115682084057654d-20,
     2      -.7863695880556735d-20,0.2579027874884532d-20,
     3      -.9273261800123448d-20,0.1930480796696742d-20,
     4      -.6562642969207928d-20,0.1117675745710279d-20,
     5      -.3657135059270539d-20,0.8513903367278654d-07,
     6      -.3574537784738887d-07,0.1036798539581978d-07,
     7      -.2401433995180344d-08,0.4715588073913732d-09,
     8      -.8114872059300698d-10,0.1250029322990888d-10/
         data arr1678/
     1      -.1749404024976951d-11,0.2248883375626774d-12,
     2      -.2678227557464146d-13,0.2975000527337447d-14,
     3      -.3099584625352630d-15,0.3041739626040950d-16,
     4      -.2813756812897594d-17,0.2100124627275599d-18,
     5      0.2820086189922884d-20,-.7731927215776450d-19,
     6      0.3273321395019967d-19,-.1085794546156638d-18,
     7      0.3409199511194786d-19,-.1262827205187128d-18,
     8      0.2309029636806184d-19,-.8526747809888581d-19/
         data arr1679/
     1      0.1129697458770525d-19,-.5051705375950638d-19,
     2      0.7744776546391440d-06,-.4166189014170927d-06,
     3      0.1548290168150550d-06,-.4594809765568217d-07,
     4      0.1156036758923745d-07,-.2548920921781145d-08,
     5      0.5030762183990407d-09,-.9020749239485619d-10,
     6      0.1485793062040794d-10,-.2267137147011924d-11,
     7      0.3226687296996397d-12,-.4307434785599393d-13,
     8      0.5418622238901312d-14,-.6447560186414123d-15/
         data arr1680/
     1      0.7272249556648069d-16,-.7536962210259891d-17,
     2      0.4689951100823535d-18,0.3261613467515230d-18,
     3      -.4391951934229848d-18,0.4321886873798714d-18,
     4      -.5802998127556272d-18,0.2833181280804185d-18,
     5      -.3708264685137738d-18,0.1390433384795794d-18,
     6      -.2688294302946295d-18,0.4906443298006096d-05,
     7      -.3269247916354916d-05,0.1504915918789027d-05,
     8      -.5531952081172020d-06,0.1723985114876622d-06/
         data arr1681/
     1      -.4708355257020624d-07,0.1151059155521836d-07,
     2      -.2556568656850866d-08,0.5215838908754236d-09,
     3      -.9858132102881682d-10,0.1737899716874264d-10,
     4      -.2873677967443041d-11,0.4477768113841670d-12,
     5      -.6600975704490777d-13,0.9234262710881366d-14,
     6      -.1225957882871470d-14,0.1481716602379921d-15,
     7      -.1135562051352158d-16,-.9660158854627030d-17,
     8      0.8521843603061004d-17,-.1256633271590452d-16/
         data arr1682/
     1      0.6429993191301477d-17,-.8751010465946028d-17,
     2      0.3294447214665496d-17,-.3958123314945490d-17,
     3      0.2340714119514429d-04,-.1881848648030193d-04,
     4      0.1045211831082416d-04,-.4635811147802097d-05,
     5      0.1743155308638178d-05,-.5744166769476743d-06,
     6      0.1694379564648319d-06,-.4540730919629950d-07,
     7      0.1117757831393376d-07,-.2549021104530365d-08,
     8      0.5421990652030677d-09,-.1081751511613305d-09/
         data arr1683/
     1      0.2033796916888349d-10,-.3617618692802745d-11,
     2      0.6108608465997281d-12,-.9818655085115729d-13,
     3      0.1501221664005635d-13,-.2154230035151216d-14,
     4      0.2195425169549322d-15,0.2843632618279934d-16,
     5      -.9142469741049324d-16,0.5064203691337380d-16,
     6      -.6622619494182169d-16,0.2745449847556508d-16,
     7      -.3044024375021685d-16,0.8888566672931268d-04,
     8      -.8443965604643341d-04,0.5541718813449308d-04/
         data arr1684/
     1      -.2904318954017374d-04,0.1290425870359277d-04,
     2      -.5024610750720741d-05,0.1751315908155434d-05,
     3      -.5545720262682711d-06,0.1613088958551380d-06,
     4      -.4346727685877575d-07,0.1092511894803344d-07,
     5      -.2575569949513529d-08,0.5721792121683226d-09,
     6      -.1202617701566082d-09,0.2399642704906578d-10,
     7      -.4559111547567969d-11,0.8267706605667611d-12,
     8      -.1433410494605479d-12,0.2355539869359194d-13/
         data arr1685/
     1      -.3562674982402435d-14,0.2125622894562011d-15,
     2      0.1072414258532365d-15,-.2611617643344272d-15,
     3      0.1148830419464209d-15,-.1335100219808779d-15,
     4      0.2798355571341863d-03,-.3088233973614794d-03,
     5      0.2354511439118457d-03,-.1433485175625247d-03,
     6      0.7399025706579511d-04,-.3346851756266070d-04,
     7      0.1355161715176591d-04,-.4985137809034190d-05,
     8      0.1684496472808296d-05,-.5273109609952871d-06/
         data arr1686/
     1      0.1539653941863594d-06,-.4216604566554637d-07,
     2      0.1088213747471005d-07,-.2657066884340577d-08,
     3      0.6159080617453642d-09,-.1359416003290103d-09,
     4      0.2864539325158850d-10,-.5775931855295759d-11,
     5      0.1116553235610674d-11,-.2070722553356436d-12,
     6      0.3659285459061650d-13,-.6093409371002177d-14,
     7      0.6869366362484717d-15,0.1210886952900912d-16,
     8      -.2221922996777639d-15,0.7532375550308181d-03/
         data arr1687/
     1      -.9521711083115607d-03,0.8315365498999586d-03,
     2      -.5798951543866159d-03,0.3428518878692690d-03,
     3      -.1776414136626917d-03,0.8239001906572377d-04,
     4      -.3471653585846605d-04,0.1343708473771760d-04,
     5      -.4818118578336177d-05,0.1611422928074941d-05,
     6      -.5055045052545866d-06,0.1494349211376076d-06,
     7      -.4179420964960062d-07,0.1109699197347042d-07,
     8      -.2805548516818104d-08,0.6771701501536179d-09/
         data arr1688/
     1      -.1564052142073080d-09,0.3464001031972437d-10,
     2      -.7365934695412166d-11,0.1505947620948611d-11,
     3      -.2929379907442672d-12,0.5403549770557775d-13,
     4      -.7771868832998075d-14,0.1094343592083862d-14,
     5      0.1775305031384847d-02,-.2540332275280801d-02,
     6      0.2511258254375850d-02,-.1982412472219009d-02,
     7      0.1326739301705720d-02,-.7781400657214059d-03,
     8      0.4085287899114164d-03,-.1948583205036777d-03/
         data arr1689/
     1      0.8537331306626299d-04,-.3465206107122482d-04,
     2      0.1311884597825346d-04,-.4658494991492681d-05,
     3      0.1558860348338614d-05,-.4935211220748513d-06,
     4      0.1483301586055741d-06,-.4244991048544282d-07,
     5      0.1159825918157703d-07,-.3032420335455165d-08,
     6      0.7603094193005499d-09,-.1831042687049716d-09,
     7      0.4245426819503668d-10,-.9439453951100535d-11,
     8      0.2039193908696438d-11,-.3943315097262735d-12/
         data arr1690/
     1      0.8144921278245852d-13,0.3733441601429412d-02,
     2      -.5986678744655219d-02,0.6632020412298508d-02,
     3      -.5866884622984049d-02,0.4400055654299607d-02,
     4      -.2891940823207083d-02,0.1701427082447895d-02,
     5      -.9094287467549404d-03,0.4465097098209900d-03,
     6      -.2030939061105504d-03,0.8616333571100356d-04,
     7      -.3428716297556457d-04,0.1285737108279570d-04,
     8      -.4561521684593149d-05,0.1536358297307964d-05/
         data arr1691/
     1      -.4927181358214590d-06,0.1508598308655210d-06,
     2      -.4420013260371663d-07,0.1241889570322678d-07,
     3      -.3350978008445511d-08,0.8706224071880212d-09,
     4      -.2164644855173763d-09,0.5235320540937028d-10,
     5      -.1119366719198406d-10,0.2540788050974993d-11,
     6      0.7112489988313354d-02,-.1267049963772880d-01,
     7      0.1559369812968317d-01,-.1532520516883913d-01,
     8      0.1276886810584053d-01,-.9323502993750982d-02/
         data arr1692/
     1      0.6093945074308453d-02,-.3618673112627474d-02,
     2      0.1973817815184956d-02,-.9973980863733009d-03,
     3      0.4700993205282644d-03,-.2078232580752916d-03,
     4      0.8657854006426594d-04,-.3412425998881276d-04,
     5      0.1276854775831482d-04,-.4549274022577278d-05,
     6      0.1547436470701481d-05,-.5036689356978874d-06,
     7      0.1572179431131741d-06,-.4711262191927023d-07,
     8      0.1359893722857695d-07,-.3743703716986936d-08/
         data arr1693/
     1      0.1006064565464422d-08,-.2346181375801308d-09,
     2      0.5903237595880064d-10,0.1242738808785377d-01,
     3      -.2441070976420144d-01,0.3312563883425437d-01,
     4      -.3589631856367319d-01,0.3297801322188572d-01,
     5      -.2655092615811099d-01,0.1913496046725779d-01,
     6      -.1252872453757233d-01,0.7535169833099428d-02,
     7      -.4198391980579931d-02,0.2181888485808812d-02,
     8      -.1063568669349731d-02,0.4885512421075128d-03/
         data arr1694/
     1      -.2123202354856695d-03,0.8759880212520345d-04,
     2      -.3441318784564438d-04,0.1290697702455524d-04,
     3      -.4631891468500997d-05,0.1594218249628817d-05,
     4      -.5264530553761059d-06,0.1675643693722808d-06,
     5      -.5062713994991446d-07,0.1500653586763740d-07,
     6      -.3776431546650670d-08,0.1048276471920032d-08,
     7      0.2011968555726670d-01,-.4329040411228047d-01,
     8      0.6434953307454702d-01,-.7638374595170017d-01/
         data arr1695/
     1      0.7686797401445954d-01,-.6779076368397603d-01,
     2      0.5351657675275091d-01,-.3838287673429570d-01,
     3      0.2528678468278469d-01,-.1543310992866818d-01,
     4      0.8785630261400609d-02,-.4691111597860118d-02,
     5      0.2360425339512571d-02,-.1123675483068950d-02,
     6      0.5078292500108717d-03,-.2185289586566231d-03,
     7      0.8977998266992282d-04,-.3528838701415501d-04,
     8      0.1330450367317761d-04,-.4808203822921925d-05/
         data arr1696/
     1      0.1676544938841924d-05,-.5514868506611512d-06,
     2      0.1791374251142023d-06,-.4821946088051396d-07,
     3      0.1467037257210017d-07,0.3044048942777638d-01,
     4      -.7133018910492303d-01,0.1154724629396734d+00,
     5      -.1492743798580271d+00,0.1635991530698271d+00,
     6      -.1571293942666034d+00,0.1350910350291714d+00,
     7      -.1055181132470410d+00,0.7570671472588761d-01,
     8      -.5032056606236280d-01,0.3119724825893969d-01/
         data arr1697/
     1      -.1814137830694207d-01,0.9941138303734691d-02,
     2      -.5153908140218873d-02,0.2536676520810720d-02,
     3      -.1188765219823744d-02,0.5318878216968832d-03,
     4      -.2276304829697579d-03,0.9346787294389389d-04,
     5      -.3673622010487531d-04,0.1395210570856974d-04,
     6      -.4959380323926791d-05,0.1755359418776194d-05,
     7      -.5014120731423103d-06,0.1662436355546679d-06,
     8      0.4335058440400202d-01,-.1100614746291622d+00/
         data arr1698/
     1      0.1930451998593557d+00,-.2703861736134585d+00,
     2      0.3210693741973947d+00,-.3341133987987262d+00,
     3      0.3112301138628415d+00,-.2633908718428827d+00,
     4      0.2047513300322888d+00,-.1474539543818809d+00,
     5      0.9904802886932243d-01,-.6240480671155404d-01,
     6      0.3705122878583583d-01,-.2081222399237826d-01,
     7      0.1109855148854304d-01,-.5634978729637880d-02,
     8      0.2731739588366294d-02,-.1266213593443363d-02/
         data arr1699/
     1      0.5633544389230579d-03,-.2394132346753081d-03,
     2      0.9853814851449282d-04,-.3758286415659998d-04,
     3      0.1442284597666203d-04,-.4340613680151965d-05,
     4      0.1560475090302878d-05,0.5846622722077851d-01,
     5      -.1600936799368033d+00,0.3028493278620288d+00,
     6      -.4574891863774104d+00,0.5859006525297785d+00,
     7      -.6575786983437683d+00,0.6606389927652353d+00,
     8      -.6029926757241527d+00,0.5055531292888833d+00/
         data arr1700/
     1      -.3926676137180381d+00,0.2844744677280503d+00,
     2      -.1933050295635045d+00,0.1237817937926577d+00,
     3      -.7498836554794384d-01,0.4312928000989998d-01,
     4      -.2361462380379950d-01,0.1234711583137567d-01,
     5      -.6168706307550510d-02,0.2960317999384298d-02,
     6      -.1352938229626628d-02,0.6007546374741587d-03,
     7      -.2442038803137291d-03,0.1011640986488156d-03,
     8      -.3186820686325270d-04,0.1236778953832632d-04/
         data arr1701/
     1      0.7506751581806244d-01,-.2207841809347886d+00,
     2      0.4486081630054209d+00,-.7278940696623395d+00,
     3      0.1001285950082091d+01,-.1207059440953129d+01,
     4      0.1302542554829328d+01,-.1276986997754987d+01,
     5      0.1149974098239427d+01,-.9593844465887208d+00,
     6      0.7465481474658967d+00,-.5448811203741937d+00,
     7      0.3747683622732324d+00,-.2438544625558213d+00,
     8      0.1506467125198983d+00,-.8857888967346558d-01/
         data arr1702/
     1      0.4974826585172221d-01,-.2667013762079328d-01,
     2      0.1374936467522639d-01,-.6722603522563310d-02,
     3      0.3207697904563350d-02,-.1380722015587654d-02,
     4      0.6150432816590043d-03,-.2015940222606933d-03,
     5      0.8412656725249532d-04,0.9216985723828053d-01,
     6      -.2901009542142095d+00,0.6308014910654464d+00,
     7      -.1095312510714424d+01,0.1612398283194516d+01,
     8      -.2080114091343375d+01,0.2402120396185436d+01/
         data arr1703/
     1      -.2520190904765023d+01,0.2428731118479464d+01,
     2      -.2168338863661232d+01,0.1805664406092229d+01,
     3      -.1410324142738425d+01,0.1038069002337004d+01,
     4      -.7227788410613475d+00,0.4778445856196287d+00,
     5      -.3005734914874398d+00,0.1806643237948901d+00,
     6      -.1034912772701703d+00,0.5710968371799080d-01,
     7      -.2972244390718546d-01,0.1518614686185196d-01,
     8      -.6878647388927274d-02,0.3283495438072936d-02/
         data arr1704/
     1      -.1113738082811144d-02,0.4980162258475113d-03,
     2      0.1086435928919129d+00,-.3647223511999272d+00,
     3      0.8458706529774997d+00,-.1566560929452273d+01,
     4      0.2459685627305646d+01,-.3384482869941417d+01,
     5      0.4168674754390203d+01,-.4664811146711229d+01,
     6      0.4794886368208267d+01,-.4565842505167682d+01,
     7      0.4055364193234527d+01,-.3378279830148636d+01,
     8      0.2652192011108856d+01,-.1969328061757353d+01/
         data arr1705/
     1      0.1388714840880699d+01,-.9311461971506156d+00,
     2      0.5970204352907759d+00,-.3639427411974189d+00,
     3      0.2142871789350298d+00,-.1181205794886055d+00,
     4      0.6442322023255864d-01,-.3052204155419455d-01,
     5      0.1556551110243043d-01,-.5436512687128992d-02,
     6      0.2596807132081741d-02,0.1233567748128991d+00,
     7      -.4403619749082457d+00,0.1086025358290643d+01,
     8      -.2138807876337108d+01,0.3571023385319311d+01/
         data arr1706/
     1      -.5225087440017380d+01,0.6843653183782349d+01,
     2      -.8143495816539691d+01,0.8901113586193739d+01,
     3      -.9012971469476607d+01,0.8512713340285403d+01,
     4      -.7540364729575538d+01,0.6295046666345782d+01,
     5      -.4969137951777789d+01,0.3726443262736600d+01,
     6      -.2654395192111960d+01,0.1810139227330609d+01,
     7      -.1169548654502131d+01,0.7326657651362314d+00,
     8      -.4256283380293230d+00,0.2471203026281694d+00/
         data arr1707/
     1      -.1217450074695494d+00,0.6615413521311964d-01,
     2      -.2368327699846262d-01,0.1205110745195936d-01,
     3      0.1353134101941869d+00,-.5122565943833938d+00,
     4      0.1339731420652530d+01,-.2798009900182147d+01,
     5      0.4954163015620790d+01,-.7687231327854067d+01,
     6      0.1067738438788764d+02,-.1347358896365722d+02,
     7      0.1561774900976457d+02,-.1676968639580841d+02,
     8      0.1679696297214195d+02,-.1577591492766097d+02/
         data arr1708/
     1      0.1396751139114014d+02,-.1168657226133772d+02,
     2      0.9295122761786521d+01,-.7010630674484347d+01,
     3      0.5071586514734927d+01,-.3458959910896883d+01,
     4      0.2299714643224529d+01,-.1400955317977092d+01,
     5      0.8638113970386296d+00,-.4400181371412311d+00,
     6      0.2541650889822522d+00,-.9287722995970725d-01,
     7      0.5022350761255434d-01,0.1437636237107273d+00,
     8      -.5757242778281700d+00,0.1592809890429255d+01/
         data arr1709/
     1      -.3518954249004623d+01,0.6591043356888703d+01,
     2      -.1081856404505040d+02,0.1589589679095290d+02,
     3      -.2121835309181559d+02,0.2601777078905940d+02,
     4      -.2955006624105953d+02,0.3131094859592373d+02,
     5      -.3110012268745190d+02,0.2913003073686718d+02,
     6      -.2576083167298051d+02,0.2167917846576940d+02,
     7      -.1725594654898928d+02,0.1321190350562360d+02,
     8      -.9472060661057020d+01,0.6669184360552313d+01/
         data arr1710/
     1      -.4238971686830295d+01,0.2769919836750542d+01,
     2      -.1450931626776440d+01,0.8890971925673190d+00,
     3      -.3303528767380760d+00,0.1894370952484214d+00,
     4      0.1482707919446841d+00,-.6266935989516658d+00,
     5      0.1829953599671382d+01,-.4266994807984162d+01,
     6      0.8435267907349317d+01,-.1461304810061293d+02,
     7      0.2266182638386546d+02,-.3192503603188138d+02,
     8      0.4131756007813086d+02,-.4952003337707865d+02/
         data arr1711/
     1      0.5538355876584347d+02,-.5803165069031770d+02,
     2      0.5737802736511282d+02,-.5347968926473041d+02,
     3      0.4751925211633137d+02,-.3978135540332516d+02,
     4      0.3217203344768284d+02,-.2414004912996402d+02,
     5      0.1796655723011226d+02,-.1185444898713555d+02,
     6      0.8194624419136922d+01,-.4390749134567287d+01,
     7      0.2849330616322392d+01,-.1072664150076616d+01,
     8      0.6510874724004125d+00,0.1487308229088018d+00/
         data arr1712/
     1      -.6621203822993872d+00,0.2036395232720232d+01,
     2      -.5001219348619221d+01,0.1041346004045896d+02,
     3      -.1900006439918718d+02,0.3103540143515048d+02,
     4      -.4604446073324655d+02,0.6276851668325273d+02,
     5      -.7920894780397154d+02,0.9331859428418436d+02,
     6      -.1028976061971792d+03,0.1071881899986642d+03,
     7      -.1049909609431629d+03,0.9831936549909852d+02,
     8      -.8625791079854304d+02,0.7355947154115798d+02/
         data arr1713/
     1      -.5750193512005944d+02,0.4516957024710447d+02,
     2      -.3077976400763754d+02,0.2247573022968599d+02,
     3      -.1225566926050328d+02,0.8410317460728344d+01,
     4      -.3197387801853506d+01,0.2051060045565805d+01,
     5      0.1453477838277584d+00,-.6802383104174886d+00,
     6      0.2199451354546234d+01,-.5678503829596340d+01,
     7      0.1243043663277118d+02,-.2384085984187621d+02,
     8      0.4094213614402523d+02,-.6384076657131089d+02/
         data arr1714/
     1      0.9150288240609734d+02,-.1213112295392993d+03,
     2      0.1502887033525801d+03,-.1739508668483614d+03,
     3      0.1905931765871636d+03,-.1955802778347048d+03,
     4      0.1927358789839581d+03,-.1765167315702869d+03,
     5      0.1585177423089764d+03,-.1284686810612457d+03,
     6      0.1063846554740973d+03,-.7448428194244211d+02,
     7      0.5738593843544025d+02,-.3168876980960385d+02,
     8      0.2296919978167766d+02,-.8791391398205510d+01/
         data arr1715/
     1      0.5952319946956457d+01,0.1385763492565256d+00,
     2      -.6806242550214860d+00,0.2309711257333811d+01,
     3      -.6257745815832120d+01,0.1437736599444091d+02,
     4      -.2893293698838876d+02,0.5215278134838950d+02,
     5      -.8530142146883676d+02,0.1283447894676054d+03,
     6      -.1783614393481023d+03,0.2320134344800246d+03,
     7      -.2811308130907459d+03,0.3235497062354897d+03,
     8      -.3466426286022545d+03,0.3590584812066608d+03/
         data arr1716/
     1      -.3418299882319040d+03,0.3229396476432271d+03,
     2      -.2699539458355382d+03,0.2354625214192928d+03,
     3      -.1685131781246583d+03,0.1368659259565852d+03,
     4      -.7617410374981368d+02,0.5826890524994705d+02,
     5      -.2238844019363488d+02,0.1598304718370058d+02,
     6      0.1290444547415067d+00,-.6640900149278475d+00,
     7      0.2361718140442375d+01,-.6703539083985602d+01,
     8      0.1614145006926109d+02,-.3402101902381937d+02/
         data arr1717/
     1      0.6427825401874675d+02,-.1100555257030331d+03,
     2      0.1736013064213751d+03,-.2522721369650801d+03,
     3      0.3441646100549997d+03,-.4352572605035739d+03,
     4      0.5256585691810085d+03,-.5857097057742772d+03,
     5      0.6372095337837851d+03,-.6276616908768925d+03,
     6      0.6234421991834840d+03,-.5346487722971501d+03,
     7      0.4909613073279043d+03,-.3573118738883075d+03,
     8      0.3057777008227990d+03,-.1707361806550315d+03/
         data arr1718/
     1      0.1377555430175833d+03,-.5298808570484478d+02,
     2      0.3985801670444008d+02,0.1174693765457951d+00,
     3      -.6324339249432945d+00,0.2354079602642489d+01,
     4      -.6988641306330587d+01,0.1761529225709264d+02,
     5      -.3881131417068530d+02,0.7677810299233226d+02,
     6      -.1373027261001311d+03,0.2268453326638737d+03,
     7      -.3437252087044320d+03,0.4914442445638778d+03,
     8      -.6464157289581426d+03,0.8187816849902290d+03/
         data arr1719/
     1      -.9446014722609400d+03,0.1079060778823889d+04,
     2      -.1094115993026709d+04,0.1142439698688046d+04,
     3      -.9994185894424201d+03,0.9661731451441443d+03,
     4      -.7113861865889442d+03,0.6413644746853649d+03,
     5      -.3576581020019792d+03,0.3043208064347261d+03,
     6      -.1168767744258482d+03,0.9260038018554900d+02,
     7      0.1045761150397200d+00,-.5880896162141687d+00,
     8      0.2289010448662689d+01,-.7094767425892984d+01/
         data arr1720/
     1      0.1870413508266858d+02,-.4298495250612696d+02,
     2      0.8897799823066735d+02,-.1657513317806706d+03,
     3      0.2867005119406738d+03,-.4514213036104557d+03,
     4      0.6763039752008440d+03,-.9213301202009790d+03,
     5      0.1224063114234555d+04,-.1454619190754546d+04,
     6      0.1745368563651260d+04,-.1811500110086223d+04,
     7      0.1989256398510116d+04,-.1764667719694947d+04,
     8      0.1796830117248824d+04,-.1331554159956489d+04/
         data arr1721/
     1      0.1265169082321209d+04,-.7014530906916148d+03,
     2      0.6296020902211319d+03,-.2407939117011065d+03,
     3      0.2009585116062070d+03,0.9099784021412885d-01,
     4      -.5335937260489324d+00,0.2171049587891406d+01,
     5      -.7010925775772083d+01,0.1932940248798018d+02,
     6      -.4620953371857141d+02,0.1001043169674142d+03,
     7      -.1936039710863111d+03,0.3507425309143812d+03,
     8      -.5714276379052278d+03,0.8977334668445135d+03/
         data arr1722/
     1      -.1260305641288937d+04,0.1758039420288658d+04,
     2      -.2139274299465267d+04,0.2699468293523701d+04,
     3      -.2850347153268268d+04,0.3295930189655845d+04,
     4      -.2946356993110697d+04,0.3163851306790780d+04,
     5      -.2347340335911916d+04,0.2353009830433135d+04,
     6      -.1291061908899232d+04,0.1223640836594894d+04,
     7      -.4647656790994136d+03,0.4088746474106132d+03,
     8      -.1832465973041534d-27,0.3988396307842559d-27/
         data arr1723/
     1      -.1551755027420022d-26,0.5631701951316374d-26,
     2      -.1473436806175146d-25,0.4212774365881199d-25,
     3      -.8646845128356489d-25,0.2115120407785014d-24,
     4      -.3482982293553920d-24,0.7642223942120840d-24,
     5      -.1058164314971840d-23,0.2126257181703971d-23,
     6      -.2406189134225931d-23,0.4526312185436730d-23,
     7      -.4338382397866929d-23,0.7689646617621201d-23,
     8      -.5799018847604444d-23,0.9836741401629391d-23/
         data arr1724/
     1      -.6131785809337667d-23,0.9936077619336799d-23,
     2      -.4143877689954587d-23,0.6521650602224387d-23,
     3      -.2080740101718166d-23,0.3125810392717700d-23,
     4      -.8841698742739399d-20,0.2689856758893763d-21,
     5      -.5664556225934785d-23,0.9543168785072546d-25,
     6      -.1365207193696102d-26,0.1712052040124113d-28,
     7      0.4661585294593423d-30,-.1221093936891226d-30,
     8      0.2710163548111392d-29,-.4599379610326014d-30/
         data arr1725/
     1      0.8421385089910525d-29,-.1314137009421190d-29,
     2      0.1945916552855549d-28,-.2855799752619758d-29,
     3      0.3578068710524619d-28,-.4966875683007589d-29,
     4      0.4844281414922689d-28,-.6462417542063829d-29,
     5      0.5225431368325756d-28,-.6682724538881483d-29,
     6      0.3566100243583808d-28,-.4446269835221347d-29,
     7      0.1844562316796551d-28,-.2203043211431388d-29,
     8      -.1330375480101411d-15,0.9795471343484655d-17/
         data arr1726/
     1      -.4992519206590288d-18,0.2035654816734286d-19,
     2      -.7048593939847847d-21,0.2142153718603959d-22,
     3      -.5835943053727358d-24,0.1446363895381218d-25,
     4      -.3309900293494219d-27,0.6586294915799215d-29,
     5      -.3302490282027513d-29,-.1195560314897312d-29,
     6      -.8723998664328342d-29,-.4778043605996662d-29,
     7      -.1420284054355269d-28,-.8955112695298740d-29,
     8      -.1885303960513576d-28,-.1632664131342077d-28/
         data arr1727/
     1      -.1631468978325600d-28,-.1775431152858909d-28,
     2      -.8963499659573449d-29,-.1549012465939698d-28,
     3      -.1873596174556882d-29,-.7700477946331000d-29,
     4      -.8326635166601579d-13,0.1115474375469538d-13,
     5      -.1034410592944551d-14,0.7673903037678914d-16,
     6      -.4834522854346912d-17,0.2673257002830925d-18,
     7      -.1325073759342725d-19,0.5975111642150287d-21,
     8      -.2478065285460629d-22,0.9529418127644241d-24/
         data arr1728/
     1      -.3750766255439747d-25,0.5095753679187491d-27,
     2      -.9515115562383914d-26,-.2725784415833409d-26,
     3      -.1971786277181567d-25,-.5439846207670474d-26,
     4      -.2928321756920081d-25,-.9649828490428157d-26,
     5      -.3640213550341364d-25,-.1067042592314994d-25,
     6      -.2614526171817472d-25,-.8791986034795355d-26,
     7      -.1703866789055774d-25,-.4471889489876372d-26,
     8      -.9621414154207962d-11,0.2018030273530163d-11/
         data arr1729/
     1      -.2929946862767389d-12,0.3403155534876750d-13,
     2      -.3356740853997694d-14,0.2906053569973503d-15,
     3      -.2255286192036580d-16,0.1592231922750971d-17,
     4      -.1033841804515494d-18,0.6225882112201158d-20,
     5      -.3505889898324363d-21,0.1827379242734096d-22,
     6      -.2329466002470461d-23,-.6596737142195170d-24,
     7      -.2679164958619132d-23,-.1658011363092455d-23,
     8      -.3965718892668499d-23,-.2763888011605248d-23/
         data arr1730/
     1      -.4275101640008403d-23,-.3680214903080898d-23,
     2      -.3037471149353193d-23,-.2928329806684148d-23,
     3      -.1371707695393177d-23,-.1961418313604245d-23,
     4      -.3879705906198265d-09,0.1161254905302388d-09,
     5      -.2406022123631301d-10,0.3988059767391729d-11,
     6      -.5613550865112143d-12,0.6935271246743285d-13,
     7      -.7680712059118467d-14,0.7738310266637089d-15,
     8      -.7170232055643116d-16,0.6162025939765334d-17/
         data arr1731/
     1      -.4944812462035398d-18,0.3724385560122244d-19,
     2      -.2675838364939301d-20,0.1442869452490059d-21,
     3      -.6277275311569487d-22,-.6792272826163458d-22,
     4      -.7535216706087542d-22,-.1115354019668703d-21,
     5      -.7232926439907740d-22,-.1370074828535015d-21,
     6      -.4868724142660880d-22,-.1089624807499255d-21,
     7      -.1376260963703420d-22,-.6726178923801944d-22,
     8      -.7620940163465270d-08,0.3057352096290132d-08/
         data arr1732/
     1      -.8490351312819651d-09,0.1886235229565359d-09,
     2      -.3558606807634477d-10,0.5892694739917182d-11,
     3      -.8747020127742768d-12,0.1181171419102827d-12,
     4      -.1466925755346707d-13,0.1689689226642812d-14,
     5      -.1817327193928406d-15,0.1835156572839364d-16,
     6      -.1748621865914882d-17,0.1568228013146591d-18,
     7      -.1463578093104428d-19,-.7278952069551917d-21,
     8      -.1776169273119654d-20,-.2815124801232694d-20/
         data arr1733/
     1      -.1925640229961387d-20,-.3432665527249042d-20,
     2      -.1367777271509289d-20,-.2580814173409441d-20,
     3      -.7641487833781743d-21,-.1547879604716574d-20,
     4      -.8882344822941151d-07,0.4565658621750218d-07,
     5      -.1624510571747733d-07,0.4624147035694916d-08,
     6      -.1117775767514220d-08,0.2371524036560792d-09,
     7      -.4510374620082734d-10,0.7803767477526432d-11,
     8      -.1241762168896071d-11,0.1832635283431504d-12/
         data arr1734/
     1      -.2525461684341037d-13,0.3267581432790469d-14,
     2      -.3987846990906451d-15,0.4607269275842165d-16,
     3      -.5063024941820454d-17,0.5023705978392976d-18,
     4      -.5820793603216114d-19,-.3169808129208913d-19,
     5      -.6622065328998292d-20,-.4437256895068158d-19,
     6      -.5413483497214252d-20,-.3002073031255488d-19,
     7      -.3555925361021270d-20,-.1941127875738770d-19,
     8      -.6970059977109538d-06,0.4437754938297956d-06/
         data arr1735/
     1      -.1955840414897879d-06,0.6895940459506449d-07,
     2      -.2064750367958638d-07,0.5426144896121866d-08,
     3      -.1278284328462534d-08,0.2739492806437276d-09,
     4      -.5399521344540098d-10,0.9870607393807807d-11,
     5      -.1684843660582011d-11,0.2700205573126773d-12,
     6      -.4081855807858594d-13,0.5842780648707644d-14,
     7      -.7946803218100898d-15,0.1023532773486700d-15,
     8      -.1268073319949083d-16,0.5186431358748463d-18/
         data arr1736/
     1      0.3173442974975219d-19,-.1182254470777811d-17,
     2      0.1575150369882296d-18,-.9034139518143362d-18,
     3      0.1796415365900093d-18,-.5240131956427148d-18,
     4      -.4012114798328736d-05,0.3082161539420664d-05,
     5      -.1639006749455532d-05,0.6972621234552752d-06,
     6      -.2518983764703698d-06,0.7987381867120792d-07,
     7      -.2270365459843285d-07,0.5870751746063064d-08,
     8      -.1396156359819633d-08,0.3079483778684673d-09/
         data arr1737/
     1      -.6342330891819207d-10,0.1226426445707479d-10,
     2      -.2236956081131699d-11,0.3863619399656270d-12,
     3      -.6340550399111103d-13,0.9909415662717771d-14,
     4      -.1481025207972306d-14,0.2023974959826303d-15,
     5      -.2742360996775028d-16,-.7957388958585189d-17,
     6      0.9359866102140849d-18,-.8670132455038652d-17,
     7      0.1493912348982174d-17,-.5218730260739775d-17,
     8      -.1800259515792092d-04,0.1634163724630721d-04/
         data arr1738/
     1      -.1026831813557154d-04,0.5161703481437094d-05,
     2      -.2203437576408110d-05,0.8255782364379500d-06,
     3      -.2772860131351183d-06,0.8472358281404270d-07,
     4      -.2380800805330447d-07,0.6205050603294373d-08,
     5      -.1510061751046743d-08,0.3450370696034968d-09,
     6      -.7436354073437568d-10,0.1517673470295978d-10,
     7      -.2942984643385853d-11,0.5438047643930845d-12,
     8      -.9601611118413151d-13,0.1619030763317577d-13/
         data arr1739/
     1      -.2629290916822849d-14,0.3561485705030680d-15,
     2      -.5790820024626941d-16,-.3243599451164000d-16,
     3      0.5987349365294828d-17,-.2617417606324825d-16,
     4      -.6584136954484066d-04,0.6943075447454136d-04,
     5      -.5068135442075014d-04,0.2959610282631780d-04,
     6      -.1467691586132540d-04,0.6388293589371746d-05,
     7      -.2492568904520080d-05,0.8847408920355135d-06,
     8      -.2888201081679314d-06,0.8744646769291189d-07/
         data arr1740/
     1      -.2472203567703095d-07,0.6562175810813774d-08,
     2      -.1642989273741204d-08,0.3895344934817549d-09,
     3      -.8775010330641264d-10,0.1883717611430063d-10,
     4      -.3863516913814128d-11,0.7586856566305907d-12,
     5      -.1430018895143812d-12,0.2574612034005677d-13,
     6      -.4508812333323587d-14,0.6399202808379149d-15,
     7      -.1043170090122680d-15,-.5283393981969933d-16,
     8      -.2030035623851399d-03,0.2452067510630881d-03/
         data arr1741/
     1      -.2050238980219986d-03,0.1371407551477076d-03,
     2      -.7790091320695424d-04,0.3883902745564602d-04,
     3      -.1735826792925715d-04,0.7057502659792212d-05,
     4      -.2638992230194975d-05,0.9152267220634851d-06,
     5      -.2963782876381816d-06,0.9011264826035485d-07,
     6      -.2584332274010569d-07,0.7018354590860181d-08,
     7      -.1810975755867866d-08,0.4453053589035527d-09,
     8      -.1046155796226043d-09,0.2353458306877881d-10/
         data arr1742/
     1      -.5079907508746782d-11,0.1052693615326768d-11,
     2      -.2096228489523392d-12,0.3916398156430529d-13,
     3      -.6678092812292970d-14,0.5128514173000606d-15,
     4      -.5416006608711427d-03,0.7405296588706144d-03,
     5      -.7008886511074252d-03,0.5306957206822880d-03,
     6      -.3412369923925350d-03,0.1925823184375309d-03,
     7      -.9742916025188594d-04,0.4484026080056468d-04,
     8      -.1897971551295002d-04,0.7451003824921678d-05/
         data arr1743/
     1      -.2731284791290314d-05,0.9400281589496849d-06,
     2      -.3051672784400113d-06,0.9381222852763648d-07,
     3      -.2740130234927593d-07,0.7626966356476809d-08,
     4      -.2028256814719074d-08,0.5165255450314510d-09,
     5      -.1261999769294942d-09,0.2964733999709033d-10,
     6      -.6677453045704501d-11,0.1455507527514724d-11,
     7      -.2860361255409431d-12,0.5740007223778239d-13,
     8      -.1276364196951395d-02,0.1955676125697000d-02/
         data arr1744/
     1      -.2074256950675560d-02,0.1760022261719844d-02,
     2      -.1268199945177623d-02,0.8020604184622546d-03,
     3      -.4547143733778828d-03,0.2345183889353964d-03,
     4      -.1112391136705350d-03,0.4893748619573288d-04,
     5      -.2010263120501500d-04,0.7753286487259321d-05,
     6      -.2820603005701050d-05,0.9716783072108876d-06,
     7      -.3180482299935931d-06,0.9920481765545044d-07,
     8      -.2956358508249517d-07,0.8436981124175025d-08/
         data arr1745/
     1      -.2309572087793112d-08,0.6080687395182973d-09,
     2      -.1531116953732349d-09,0.3744455713770597d-10,
     3      -.8120082857918674d-11,0.1852370181927167d-11,
     4      -.2701359599347276d-02,0.4598330711858892d-02,
     5      -.5418278248980708d-02,0.5107547242336225d-02,
     6      -.4088626534351939d-02,0.2872713257481359d-02,
     7      -.1809336556320395d-02,0.1036699905708814d-02,
     8      -.5462974307504191d-03,0.2669984723708291d-03/
         data arr1746/
     1      -.1218471857432019d-03,0.5220882407656783d-04,
     2      -.2110063214628770d-04,0.8075538724189102d-05,
     3      -.2936544472450316d-05,0.1017588100840108d-05,
     4      -.3368830382819779d-06,0.1068087664712851d-06,
     5      -.3247145120897844d-07,0.9498221890726167d-08,
     6      -.2648096565797158d-08,0.7198366058261375d-09,
     7      -.1702260488229183d-09,0.4329928170584220d-10,
     8      -.5204380808476647d-02,0.9768217977206178d-02/
         data arr1747/
     1      -.1269126513800411d-01,0.1319120528875449d-01,
     2      -.1164335135351348d-01,0.9020306869424738d-02,
     3      -.6264362268909114d-02,0.3957665087127981d-02,
     4      -.2299553993589810d-02,0.1239229386616573d-02,
     5      -.6235724083983443d-03,0.2946074842624146d-03,
     6      -.1312875743692347d-03,0.5540234812105718d-04,
     7      -.2221363065151177d-04,0.8487578765653721d-05,
     8      -.3098087691216347d-05,0.1083062260896948d-05/
         data arr1748/
     1      -.3628575170306789d-06,0.1170387246122746d-06,
     2      -.3581564862788438d-07,0.1073860521654050d-07,
     3      -.2741766906519177d-08,0.7697740572779564d-09,
     4      -.9229545168062295d-02,0.1897564206833093d-01,
     5      -.2700573236745625d-01,0.3074718960578730d-01,
     6      -.2972821646219177d-01,0.2522795621853276d-01,
     7      -.1919143836900027d-01,0.1328126998110523d-01,
     8      -.8453062449079812d-02,0.4989902679768629d-02/
         data arr1749/
     1      -.2750408006695845d-02,0.1423390043153396d-02,
     2      -.6948213888299590d-03,0.3211794365368828d-03,
     3      -.1410600388231326d-03,0.5903900135642927d-04,
     4      -.2360313844166915d-04,0.9038699825539157d-05,
     5      -.3314200530040457d-05,0.1171060838454235d-05,
     6      -.3902144781978013d-06,0.1282119023939703d-06,
     7      -.3503572408903713d-07,0.1078461526129331d-07,
     8      -.1520764741495386d-01,0.3405097163569849d-01/
         data arr1750/
     1      -.5277646312772476d-01,0.6543966122797645d-01,
     2      -.6890579765764492d-01,0.6368252463142808d-01,
     3      -.5275905664608093d-01,0.3976311462142579d-01,
     4      -.2756170924454887d-01,0.1771884636441727d-01,
     5      -.1063632627211964d-01,0.5994732051840123d-02,
     6      -.3186904431778282d-02,0.1604335340260951d-02,
     7      -.7673471213663462d-03,0.3497679276037057d-03,
     8      -.1522555268937338d-03,0.6349984933581604d-04/
         data arr1751/
     1      -.2532326894687684d-04,0.9746069047992297d-05,
     2      -.3509914157483405d-05,0.1256630112010789d-05,
     3      -.3646401379841131d-06,0.1223635620290300d-06,
     4      -.2346518523412321d-01,0.5692592378714983d-01,
     5      -.9559594845269097d-01,0.1284277496794468d+00,
     6      -.1465184179116936d+00,0.1467152826848418d+00,
     7      -.1316954361476620d+00,0.1075406671302994d+00,
     8      -.8076385806773072d-01,0.5625550037091461d-01/
         data arr1752/
     1      -.3658806545397939d-01,0.2234273269972869d-01,
     2      -.1286918602028595d-01,0.7019342936600992d-02,
     3      -.3637387956198662d-02,0.1796388043259147d-02,
     4      -.8469497511388918d-03,0.3827342538205675d-03,
     5      -.1650502004623925d-03,0.6883852446615312d-04,
     6      -.2660624967010552d-04,0.1032802539936185d-04,
     7      -.3159632827784114d-05,0.1150178514709417d-05,
     8      -.3413208724678879d-01,0.8930539464031062d-01/
         data arr1753/
     1      -.1617468530212216d+00,0.2343602610162967d+00,
     2      -.2883673355593661d+00,0.3114282078323076d+00,
     3      -.3014963397657949d+00,0.2655295125763273d+00,
     4      -.2150729185402833d+00,0.1615706424530033d+00,
     5      -.1133351562311335d+00,0.7464324006970557d-01,
     6      -.4636891871782882d-01,0.2727737605447016d-01,
     7      -.1524338346810153d-01,0.8119479224898541d-02,
     8      -.4126272384766757d-02,0.2011234742403879d-02/
         data arr1754/
     1      -.9328367687671990d-03,0.4197375197692310d-03,
     2      -.1729407632936507d-03,0.7246823522133287d-04,
     3      -.2322167918455860d-04,0.9129905585516379d-05,
     4      -.4707134553708622d-01,0.1322873302008021d+00,
     5      -.2573494164488748d+00,0.4005143800661895d+00,
     6      -.5293305827016327d+00,0.6140244491099546d+00,
     7      -.6384935125461384d+00,0.6039959904776926d+00,
     8      -.5254765665716069d+00,0.4240108704178595d+00/
         data arr1755/
     1      -.3194651373723397d+00,0.2259939029212261d+00,
     2      -.1507873232198227d+00,0.9527753663616562d-01,
     3      -.5717893403822469d-01,0.3271477425864740d-01,
     4      -.1784060916945121d-01,0.9341596620021587d-02,
     5      -.4636033758246456d-02,0.2241550338005445d-02,
     6      -.9782062979082462d-03,0.4407740350730431d-03,
     7      -.1470611822768790d-03,0.6220727398574197d-04,
     8      -.6184973126483696d-01,0.1860132115734240d+00/
         data arr1756/
     1      -.3872514527095383d+00,0.6449593134961015d+00,
     2      -.9121903815092172d+00,0.1132370415804841d+01,
     3      -.1260095537314583d+01,0.1275632102174724d+01,
     4      -.1187648504130062d+01,0.1025548569940432d+01,
     5      -.8268774606001059d+00,0.6259796820322925d+00,
     6      -.4469322005436444d+00,0.3022167326791626d+00,
     7      -.1940287412332994d+00,0.1188076220189483d+00,
     8      -.6923399448550478d-01,0.3880342359368062d-01/
         data arr1757/
     1      -.2050224495895180d-01,0.1061459577177348d-01,
     2      -.4875696752742023d-02,0.2354367559142520d-02,
     3      -.8134314793850876d-03,0.3689412385991520d-03,
     4      -.7775906660443004d-01,0.2494336474384208d+00,
     5      -.5538629324511914d+00,0.9838742521668998d+00,
     6      -.1484193970166672d+01,0.1965132133703297d+01,
     7      -.2332406035665558d+01,0.2518397839986972d+01,
     8      -.2500817087056372d+01,0.2303292680718525d+01/
         data arr1758/
     1      -.1980701049032304d+01,0.1599335027186312d+01,
     2      -.1217750388974405d+01,0.8783079429812167d+00,
     3      -.6011035395855369d+00,0.3926189244161367d+00,
     4      -.2434974091924670d+00,0.1456093286385761d+00,
     5      -.8150450871141060d-01,0.4504347608756948d-01,
     6      -.2164650809221487d-01,0.1116790593128811d-01,
     7      -.3975647961487539d-02,0.1927681571474577d-02,
     8      -.9388548877462985d-01,0.3202514064003875d+00/
         data arr1759/
     1      -.7561827970228319d+00,0.1428409360374308d+01,
     2      -.2291352654835953d+01,0.3226129092958724d+01,
     3      -.4071750135969834d+01,0.4675094616140020d+01,
     4      -.4936618138672239d+01,0.4834899355406158d+01,
     5      -.4420973815972301d+01,0.3796071961491857d+01,
     6      -.3072759267480920d+01,0.2356849115329088d+01,
     7      -.1713652593308269d+01,0.1190448772017526d+01,
     8      -.7826077426830468d+00,0.4979051060528867d+00/
         data arr1760/
     1      -.2938069010585594d+00,0.1728507635871915d+00,
     2      -.8639683470208376d-01,0.4749890716477057d-01,
     3      -.1734242809448827d-01,0.8965726422306475d-02,
     4      -.1092134739880582d+00,0.3950652421169627d+00,
     5      -.9892459750745767d+00,0.1981665234085429d+01,
     6      -.3371074941202746d+01,0.5033367460669004d+01,
     7      -.6736804070301571d+01,0.8202846967965039d+01,
     8      -.9185179994295288d+01,0.9540048050993787d+01/
         data arr1761/
     1      -.9249636065730025d+01,0.8422800706739720d+01,
     2      -.7226821417596132d+01,0.5878935764423185d+01,
     3      -.4526413980702628d+01,0.3335563189502876d+01,
     4      -.2315047480772047d+01,0.1563083604799926d+01,
     5      -.9675466826667452d+00,0.6045089001464157d+00,
     6      -.3124793818243639d+00,0.1826474390844637d+00,
     7      -.6810636473145704d-01,0.3745545664597683d-01,
     8      -.1227448325340307d+00,0.4696940089141469d+00/
         data arr1762/
     1      -.1244138545238792d+01,0.2636417453703757d+01,
     2      -.4744258011137648d+01,0.7493398350393481d+01,
     3      -.1060921369624113d+02,0.1366521642401898d+02,
     4      -.1618540974462804d+02,0.1778348242880157d+02,
     5      -.1823478621572296d+02,0.1756638135744775d+02,
     6      -.1593093536831597d+02,0.1371188868289655d+02,
     7      -.1114283686706269d+02,0.8690239866526749d+01,
     8      -.6341276324582104d+01,0.4533925670350468d+01/
         data arr1763/
     1      -.2929335747922726d+01,0.1939669235282038d+01,
     2      -.1031176080254034d+01,0.6395526442237891d+00,
     3      -.2426025216751942d+00,0.1416497242177299d+00,
     4      -.1336115376742780d+00,0.5396238631161558d+00,
     5      -.1508611666054114d+01,0.3374107560707396d+01,
     6      -.6408258810611178d+01,0.1068288999381974d+02,
     7      -.1596264843922864d+02,0.2170109712750999d+02,
     8      -.2712384108857437d+02,0.3145596769152097d+02/
         data arr1764/
     1      -.3402661814680093d+02,0.3460143779229695d+02,
     2      -.3307534185425747d+02,0.3005675564838093d+02,
     3      -.2569348311547682d+02,0.2116441657884067d+02,
     4      -.1616675319746991d+02,0.1221779183149920d+02,
     5      -.8197832290599385d+01,0.5742897157683617d+01,
     6      -.3123123142969786d+01,0.2051935313303165d+01,
     7      -.7889452210126014d+00,0.4882401955621765d+00,
     8      -.1411645795406832d+00,0.6005001389563964d+00/
         data arr1765/
     1      -.1768201820076063d+01,0.4165385304413331d+01,
     2      -.8332121354410537d+01,0.1463023664068560d+02,
     3      -.2302264756144277d+02,0.3296781549864993d+02,
     4      -.4338644615751039d+02,0.5300215290320872d+02,
     5      -.6033724980193594d+02,0.6464102322188039d+02,
     6      -.6494114584157818d+02,0.6219285686933042d+02,
     7      -.5572667814413095d+02,0.4840115800728513d+02,
     8      -.3852645564650789d+02,0.3072845380076894d+02/
         data arr1766/
     1      -.2130307196853301d+02,0.1576637508084394d+02,
     2      -.8725279908449101d+01,0.6064545874434497d+01,
     3      -.2355429117383784d+01,0.1542858676294477d+01,
     4      -.1450273999984474d+00,0.6485826237436249d+00,
     5      -.2007665209653915d+01,0.4972178431502749d+01,
     6      -.1045502931297198d+02,0.1930033079007628d+02,
     7      -.3192160482897518d+02,0.4806021650073172d+02,
     8      -.6645049375393913d+02,0.8536060830181850d+02/
         data arr1767/
     1      -.1020118054230371d+03,0.1149451056382209d+03,
     2      -.1209960269761023d+03,0.1219295355988207d+03,
     3      -.1140810905428187d+03,0.1043329958357845d+03,
     4      -.8612103473869443d+02,0.7240863243578596d+02,
     5      -.5160030077429946d+02,0.4030183868897485d+02,
     6      -.2258206727426012d+02,0.1658732061898761d+02,
     7      -.6487069175914171d+01,0.4492716509817985d+01,
     8      -.1451098242398104d+00,0.6810960368162201d+00/
         data arr1768/
     1      -.2212476353997288d+01,0.5750956437115317d+01,
     2      -.1268824995842770d+02,0.2458511366694790d+02,
     3      -.4265399662421549d+02,0.6741156190937278d+02,
     4      -.9770757265386463d+02,0.1317815896553533d+03,
     5      -.1648926776682221d+03,0.1951462723849923d+03,
     6      -.2145059875552366d+03,0.2271847306862813d+03,
     7      -.2210307157205896d+03,0.2126377561921073d+03,
     8      -.1810852169379440d+03,0.1603650193164485d+03/
         data arr1769/
     1      -.1168646788760244d+03,0.9625280336144763d+02,
     2      -.5433775352376224d+02,0.4215031615641249d+02,
     3      -.1654833973438392d+02,0.1210856614273951d+02,
     4      -.1415849641562058d+00,0.6964306676117857d+00,
     5      -.2370130197758483d+01,0.6456604120885711d+01,
     6      -.1491997063071757d+02,0.3030118388106429d+02,
     7      -.5503590498132306d+02,0.9118405711273330d+02,
     8      -.1382120859894913d+03,0.1954905384221345d+03/
         data arr1770/
     1      -.2553547423202301d+03,0.3170886388423174d+03,
     2      -.3625708936818544d+03,0.4032692319772483d+03,
     3      -.4061079576762264d+03,0.4107262031577656d+03,
     4      -.3589134679705797d+03,0.3346440750573846d+03,
     5      -.2480893878057818d+03,0.2153941670012778d+03,
     6      -.1219187936644581d+03,0.9984075040772228d+02,
     7      -.3923478015418190d+02,0.3031882474578752d+02,
     8      -.1348361864042258d+00,0.6941744328732333d+00/
         data arr1771/
     1      -.2471018098235262d+01,0.7046168675504116d+01,
     2      -.1702158215318474d+02,0.3619377438692783d+02,
     3      -.6866997782363283d+02,0.1191552925552925d+03,
     4      -.1883499771522377d+03,0.2791665171783355d+03,
     5      -.3793698295509321d+03,0.4940083189164635d+03,
     6      -.5850074902748074d+03,0.6831241114733319d+03,
     7      -.7084632352780874d+03,0.7531901241185792d+03,
     8      -.6714921640260143d+03,0.6592103359241856d+03/
         data arr1772/
     1      -.4945655497034801d+03,0.4526594364872867d+03,
     2      -.2556653924659234d+03,0.2210455407640355d+03,
     3      -.8669739262483175d+02,0.7075369626320949d+02,
     4      -.1253820050619230d+00,0.6749769616875876d+00,
     5      -.2508710223533996d+01,0.7481751622286442d+01,
     6      -.1885356868892173d+02,0.4194494649289634d+02,
     7      -.8291494487232181d+02,0.1506059597637831d+03,
     8      -.2474293108558309d+03,0.3842181274104815d+03/
         data arr1773/
     1      -.5409782301188179d+03,0.7387609039428339d+03,
     2      -.9014028817487625d+03,0.1105444762594018d+04,
     3      -.1174081782506440d+04,0.1312726826508584d+04,
     4      -.1186773761927242d+04,0.1227470564636945d+04,
     5      -.9269929652847197d+03,0.8949611199818007d+03,
     6      -.5019501859699964d+03,0.4584635498212156d+03,
     7      -.1789497566728349d+03,0.1543084158583754d+03,
     8      -.1137620614698978d+00,0.6401690452665004d+00/
         data arr1774/
     1      -.2479362906523344d+01,0.7731914221040970d+01,
     2      -.2027047697771666d+02,0.4718975658099579d+02,
     3      -.9687847276553556d+02,0.1842688623554308d+03,
     4      -.3133223631391273d+03,0.5100996788933006d+03,
     5      -.7405028825711927d+03,0.1061512736873204d+04,
     6      -.1326627679902402d+04,0.1710791017682062d+04,
     7      -.1849406012894815d+04,0.2177692370358110d+04,
     8      -.1983499528063257d+04,0.2164613449952577d+04/
         data arr1775/
     1      -.1636548090143893d+04,0.1668980381977462d+04,
     2      -.9248171413334782d+03,0.8936142571216930d+03,
     3      -.3460621981491333d+03,0.3157013984162735d+03,
     4      0.8231789285402152d-20,-.5707217782158789d-22,
     5      0.3236582986877890d-20,-.1281139201215119d-21,
     6      0.2492054174833362d-19,-.7536794249220014d-21,
     7      0.1229723886639441d-18,-.2984186856840967d-20,
     8      0.4360616390268617d-18,-.9013650174310735d-20/
         data arr1776/
     1      0.1209761632754393d-17,-.2054311448995925d-19,
     2      0.2584737319509839d-17,-.3779279287527436d-19,
     3      0.4470030307141189d-17,-.5146103858326228d-19,
     4      0.5796555636761476d-17,-.5643938849273890d-19,
     5      0.6021734205945040d-17,-.3900469313721427d-19,
     6      0.4003402780263523d-17,-.2080402498671952d-19,
     7      0.2012134518943259d-17,0.5492332839074279d-22,
     8      -.1689586450665966d-23,0.5233346279894809d-24/
         data arr1777/
     1      -.1264385541187200d-23,0.5185556561927993d-23,
     2      -.1035957316112662d-22,0.3485781162938106d-22,
     3      -.5096286915259790d-22,0.1522435203902696d-21,
     4      -.1914748201767291d-21,0.5144795672124082d-21,
     5      -.4974764461453958d-21,0.1244938196415394d-20,
     6      -.1058545702845944d-20,0.2462267318874936d-20,
     7      -.1560049207447801d-20,0.3453737827987430d-20,
     8      -.1924699242193256d-20,0.4017348513307992d-20/
         data arr1778/
     1      -.1394678004833608d-20,0.2808019648444446d-20,
     2      -.8567749443637858d-21,0.1627226698008880d-20,
     3      0.1999492215132689d-17,-.1412097674473548d-18,
     4      0.6914775595289858d-20,-.2713005071861937d-21,
     5      0.9052251571502459d-23,-.2654529704913491d-24,
     6      0.6986131354895279d-26,-.1673314897622403d-27,
     7      0.1829367946845473d-29,0.3999189486038896d-30,
     8      -.5658370726422285d-29,0.1148273890184408d-29/
         data arr1779/
     1      -.1273788551990508d-28,0.2232282845944504d-29,
     2      -.2320424056812665d-28,0.3121152526949097d-29,
     3      -.3101255679361106d-28,0.3570085858208250d-29,
     4      -.3368888422717917d-28,0.2499140975744999d-29,
     5      -.2285322638939240d-28,0.1406823605312667d-29,
     6      -.1225065190813591d-28,0.2276952534208426d-14,
     7      -.2925754979209130d-15,0.2606695251544407d-16,
     8      -.1860808714207461d-17,0.1129657265026704d-18/
         data arr1780/
     1      -.6027214925895818d-20,0.2886253095651854d-21,
     2      -.1258804974500980d-22,0.5054934595468036d-24,
     3      -.1884099448067792d-25,0.7534489057658660d-27,
     4      -.1429350627895461d-28,0.2498382806058023d-27,
     5      0.1334849058084847d-28,0.6037413134126128d-27,
     6      0.1401267797794451d-28,0.8497299673808280d-27,
     7      0.2548619549432017d-28,0.1227934003553826d-26,
     8      0.1186318830879795d-28,0.8495609373117109d-27/
         data arr1781/
     1      0.1267073480856003d-28,0.6792508453125419d-27,
     2      0.4119287046365059d-12,-.8287141180716317d-13,
     3      0.1155994456728811d-13,-.1292010157098818d-14,
     4      0.1228031769589557d-15,-.1025836829320054d-16,
     5      0.7691210910627067d-18,-.5251913190900283d-19,
     6      0.3301804064934071d-20,-.1927206317547386d-21,
     7      0.1054040491109478d-22,-.5437206049336699d-24,
     8      0.9781175264761558d-25,-.1474784561915020d-25/
         data arr1782/
     1      0.1538767677904795d-24,-.2320948983697552d-25,
     2      0.2228443769731813d-24,-.3263113970721214d-25,
     3      0.2782667571529623d-24,-.2678724230293860d-25,
     4      0.1973150753728477d-24,-.1748579230618557d-25,
     5      0.1223692889796159d-24,0.2370401649412377d-10,
     6      -.6805258237218201d-11,0.1354676545624080d-11,
     7      -.2160656735386785d-12,0.2930687000950714d-13,
     8      -.3493639671161541d-14,0.3737958983167817d-15/
         data arr1783/
     1      -.3642481360121821d-16,0.3267909882349363d-17,
     2      -.2721977262370435d-18,0.2119140013324143d-19,
     3      -.1550312447941290d-20,0.1098167479801801d-21,
     4      -.7261474740555030d-23,0.6745877976222622d-23,
     5      -.5909836600044744d-24,0.8948804360371556d-23,
     6      -.7116311753649000d-24,0.1207172197656032d-22,
     7      -.7294765833397312d-24,0.8340320716604791d-23,
     8      -.2990699912225970d-24,0.5871545236842029d-23/
         data arr1784/
     1      0.6240793833282779d-09,-.2401433995180360d-09,
     2      0.6407222494293906d-10,-.1369708398884908d-10,
     3      0.2490118015630283d-11,-.3978659307590914d-12,
     4      0.5705600012735464d-13,-.7451990256750626d-14,
     5      0.8960930796180497d-15,-.1000404691238129d-15,
     6      0.1043850672003567d-16,-.1023547297348714d-17,
     7      0.9482705216177682d-19,-.8316620824101584d-20,
     8      0.8723307276475935d-21,-.6128406555759992d-22/
         data arr1785/
     1      0.2570181652904522d-21,-.1418535472570553d-22,
     2      0.3496494301507053d-21,-.1005242023801787d-22,
     3      0.2442499348355572d-21,-.1444364729142791d-22,
     4      0.1864068734377252d-21,0.9319611635855621d-08,
     5      -.4594809765568226d-08,0.1570744647307547d-08,
     6      -.4302320935119657d-09,0.1002151814845660d-09,
     7      -.2051583705180126d-10,0.3769577818760726d-11,
     8      -.6308158125188070d-12,0.9719016371802198d-13/
         data arr1786/
     1      -.1390220901445000d-13,0.1858592336129762d-14,
     2      -.2335034509153842d-15,0.2769501876103651d-16,
     3      -.3112803263085644d-17,0.3343894104477074d-18,
     4      -.3369385799479014d-19,0.5592619340631874d-20,
     5      -.2008943695025844d-21,0.3718932014193209d-20,
     6      0.1712002268780089d-21,0.2440246231448211d-20,
     7      -.6605684626465495d-22,0.2277834500674027d-20,
     8      0.9058529335288539d-07,-.5531952081172012d-07/
         data arr1787/
     1      0.2342434503338300d-07,-.7947227871668354d-08,
     2      0.2292964722865854d-08,-.5814389091272587d-09,
     3      0.1323300745082676d-09,-.2742959585898019d-10,
     4      0.5234680084880530d-11,-.9274759134670748d-12,
     5      0.1535868084539077d-12,-.2390090496265351d-13,
     6      0.3511275519328749d-14,-.4888674328827268d-15,
     7      0.6474507537801920d-16,-.8189023929184563d-17,
     8      0.1024812335201914d-17,-.1344913342414670d-18/
         data arr1788/
     1      0.5409361267501806d-19,-.1832565753560583d-19,
     2      0.2696321262802716d-19,-.6216876269300033d-20,
     3      0.1174631083779643d-19,0.6291435897009780d-06,
     4      -.4635811147802110d-06,0.2368481667501903d-06,
     5      -.9695573030906314d-07,0.3375284884569769d-07,
     6      -.1032695767989691d-07,0.2835842511219164d-08,
     7      -.7092481400170219d-09,0.1633142898643938d-09,
     8      -.3491338248325318d-10,0.6975870899531665d-11/
         data arr1789/
     1      -.1309827332168153d-11,0.2321765623009625d-12,
     2      -.3900254988167070d-13,0.6230161907076046d-14,
     3      -.9491564942740883d-15,0.1385438361578531d-15,
     4      -.1952581485866741d-16,0.2936324310261711d-17,
     5      -.5041953226127981d-18,0.2714876240645794d-18,
     6      -.1064269590408014d-18,0.9995013496083893d-19,
     7      0.3335722734592756d-05,-.2904318954017380d-05,
     8      0.1753343492728628d-05,-.8481035185878368d-06/
         data arr1790/
     1      0.3488704795684286d-06,-.1261259904416966d-06,
     2      0.4092537859500316d-07,-.1209448018545467d-07,
     3      0.3290725020244776d-08,-.8312616353189232d-09,
     4      0.1962558666446882d-09,-.4354283036870171d-10,
     5      0.9120091317508455d-11,-.1810302858128237d-11,
     6      0.3416816439258338d-12,-.6150044341564723d-13,
     7      0.1058523897899645d-13,-.1747334640583282d-14,
     8      0.2789430809906902d-15,-.4387119771997770d-16/
         data arr1791/
     1      0.8040164379646093d-17,-.1953948793150864d-17,
     2      0.8702029741455525d-18,0.1417249340992386d-04,
     3      -.1433485175625250d-04,0.1005329625912649d-04,
     4      -.5649147548939792d-05,0.2699546753756329d-05,
     5      -.1133766966001417d-05,0.4273704529755659d-06,
     6      -.1467207616701304d-06,0.4637549272564943d-07,
     7      -.1360903274054258d-07,0.3732542376768897d-08,
     8      -.9620360103342944d-09,0.2340811297044561d-09/
         data arr1792/
     1      -.5397725556917321d-10,0.1183510332502134d-10,
     2      -.2474630199907500d-11,0.4946994301008003d-12,
     3      -.9475906323898671d-13,0.1743601450022743d-13,
     4      -.3078600722235347d-14,0.5293856766199350d-15,
     5      -.8386810434766656d-16,0.1727899215243729d-16,
     6      0.5005261846585192d-04,-.5798951543866174d-04,
     7      0.4658439824969898d-04,-.2998407547343518d-04,
     8      0.1641248465182939d-04,-.7895561374253864d-05/
         data arr1793/
     1      0.3409097664348447d-05,-.1340609393554176d-05,
     2      0.4853722661500416d-06,-.1631508777564896d-06,
     3      0.5125575535052635d-07,-.1513230040700525d-07,
     4      0.4217506522155300d-08,-.1113976107866776d-08,
     5      0.2797774630240936d-09,-.6700795873962899d-10,
     6      0.1534364457181748d-10,-.3366452687218757d-11,
     7      0.7092099177278791d-12,-.1434134539379983d-12,
     8      0.2796359952902351d-13,-.5030264560461869d-14/
         data arr1794/
     1      0.8697416855032289d-15,0.1511599836358582d-03,
     2      -.1982412472219013d-03,0.1802683729942109d-03,
     3      -.1313421796101935d-03,0.8138088290648320d-04,
     4      -.4431651346470361d-04,0.2165990375529403d-04,
     5      -.9641705122340179d-05,0.3951491498509882d-05,
     6      -.1503522793958416d-05,0.5346846884245209d-06,
     7      -.1786876622204641d-06,0.5637413403925986d-07,
     8      -.1685521908393258d-07,0.4791878351297864d-08/
         data arr1795/
     1      -.1299126587824659d-08,0.3367354510044959d-09,
     2      -.8362233058176195d-10,0.1994288094854108d-10,
     3      -.4556722614417571d-11,0.1007221196976464d-11,
     4      -.2020198439417806d-12,0.4148055404754726d-13,
     5      0.3992007175083959d-03,-.5866884622984087d-03,
     6      0.5978498359585841d-03,-.4881303864897347d-03,
     7      0.3389323876063736d-03,-.2068308461072200d-03,
     8      0.1132831442658758d-03,-.5650952625543319d-04/
         data arr1796/
     1      0.2595302125808176d-04,-.1106613427602315d-04,
     2      0.4410041902038646d-05,-.1651576023844828d-05,
     3      0.5839059999870620d-06,-.1956393589957265d-06,
     4      0.6232850265768939d-07,-.1893591526415227d-07,
     5      0.5500260163734837d-08,-.1530393211105719d-08,
     6      0.4090085987079703d-09,-.1044948056821507d-09,
     7      0.2588768174578682d-10,-.5732296461857835d-11,
     8      0.1320778172739324d-11,0.9386303260519369d-03/
         data arr1797/
     1      -.1532520516883963d-02,0.1734947532991780d-02,
     2      -.1573713086816451d-02,0.1213942916087947d-02,
     3      -.8229927021190095d-03,0.5007736302142980d-03,
     4      -.2775193723708623d-03,0.1415973227950614d-03,
     5      -.6707466833372661d-04,0.2969619430295132d-04,
     6      -.1235526546728940d-04,0.4852794928749400d-05,
     7      -.1806342000422838d-05,0.6393313601757964d-06,
     8      -.2157794296147024d-06,0.6963113891997627d-07/
         data arr1798/
     1      -.2151754692844719d-07,0.6388869387794361d-08,
     2      -.1807760830549376d-08,0.4976136137604520d-09,
     3      -.1203486318593178d-09,0.3081388274202198d-10,
     4      0.1993929145036409d-02,-.3589631856368265d-02,
     5      0.4480829640343464d-02,-.4481528025489860d-02,
     6      0.3811775364830663d-02,-.2849400468307743d-02,
     7      0.1911733860469946d-02,-.1168174597506726d-02,
     8      0.6572006272465448d-03,-.3432653160358984d-03/
         data arr1799/
     1      0.1675716946489248d-03,-.7687413978320631d-04,
     2      0.3329266992253196d-04,-.1366417218374924d-04,
     3      0.5332587965161969d-05,-.1984395327611820d-05,
     4      0.7060771050513134d-06,-.2404705891978052d-06,
     5      0.7872818151444401d-07,-.2446064594580207d-07,
     6      0.7425108756656381d-08,-.1942881566109903d-08,
     7      0.5483073938900550d-09,0.3873386717425284d-02,
     8      -.7638374595184347d-02,0.1044430099654383d-01/
         data arr1800/
     1      -.1144239585146276d-01,0.1066075726818282d-01,
     2      -.8729395130288991d-02,0.6415462899513777d-02,
     3      -.4294160027304816d-02,0.2646295520142754d-02,
     4      -.1514049819432493d-02,0.8096192297169609d-03,
     5      -.4068458650677040d-03,0.1930048560298464d-03,
     6      -.8676981269006928d-04,0.3709315203000917d-04,
     7      -.1511858423439603d-04,0.5892625764238445d-05,
     8      -.2196644918865497d-05,0.7877928954598648d-06/
         data arr1801/
     1      -.2666538911245586d-06,0.8868045101328742d-07,
     2      -.2489272058255797d-07,0.7692235732624888d-08,
     3      0.6950625479455659d-02,-.1492743798597856d-01,
     4      0.2222874765928737d-01,-.2652185388605664d-01,
     5      0.2691077832317465d-01,-.2399792259549339d-01,
     6      0.1920740916222561d-01,-.1400136240882017d-01,
     7      0.9396837359764791d-02,-.5855105429435170d-02,
     8      0.3409782543047229d-02,-.1866061625198687d-02/
         data arr1802/
     1      0.9640860216001035d-03,-.4720178689669671d-03,
     2      0.2197535301021215d-03,-.9752746618171033d-04,
     3      0.4139836731129385d-04,-.1678746064169106d-04,
     4      0.6557087484775472d-05,-.2400282067183549d-05,
     5      0.8695510502892967d-06,-.2598396370469195d-06,
     6      0.8741230916859246d-07,0.1161995553461145d-01,
     7      -.2703861736312426d-01,0.4362473745371775d-01,
     8      -.5639496536679253d-01,0.6199852270969430d-01/
         data arr1803/
     1      -.5990283170683260d-01,0.5194707753523435d-01,
     2      -.4102808205798469d-01,0.2983398484198291d-01,
     3      -.2014107243713043d-01,0.1270846921175320d-01,
     4      -.7535438649523264d-02,0.4218105260372590d-02,
     5      -.2237484896097587d-02,0.1128647585120196d-02,
     6      -.5425418359701349d-03,0.2495289923734392d-03,
     7      -.1094473301377907d-03,0.4632171387941738d-04,
     8      -.1821185491604483d-04,0.7150562244259652d-05/
         data arr1804/
     1      -.2258876401029530d-05,0.8230466359328021d-06,
     2      0.1822938734574945d-01,-.4574891865285136d-01,
     3      0.7960822238905414d-01,-.1109926393645738d+00,
     4      0.1316024375587214d+00,-.1371382730040102d+00,
     5      0.1282629410916595d+00,-.1092571615508639d+00,
     6      0.8568577726250194d-01,-.6238899537483372d-01,
     7      0.4245682870304580d-01,-.2715098616567538d-01,
     8      0.1639170993059952d-01,-.9376904528713845d-02/
         data arr1805/
     1      0.5101417651885509d-02,-.2643441289548343d-02,
     2      0.1311318658505692d-02,-.6188302974141239d-03,
     3      0.2825090516665177d-03,-.1185136840117470d-03,
     4      0.5020640099133444d-04,-.1666109703510989d-04,
     5      0.6545309446098248d-05,0.2700303820377566d-01,
     6      -.7278940707589338d-01,0.1360479703929294d+00,
     7      -.2037394374253968d+00,0.2594726887156257d+00,
     8      -.2904244228499906d+00,0.2917577891964985d+00/
         data arr1806/
     1      -.2669424334754939d+00,0.2248657570221007d+00,
     2      -.1758601007331336d+00,0.1285446728218053d+00,
     3      -.8829294772109793d-01,0.5725504033838760d-01,
     4      -.3517453560508021d-01,0.2055488080360266d-01,
     5      -.1143087668491969d-01,0.6091178426186354d-02,
     6      -.3077215002510265d-02,0.1509186423646912d-02,
     7      -.6712908008213696d-03,0.3056151014688355d-03,
     8      -.1059266342208204d-03,0.4468632354605664d-04/
         data arr1807/
     1      0.3796978782449082d-01,-.1095312517610245d+00,
     2      0.2190817860932995d+00,-.3511022488275036d+00,
     3      0.4785138433442181d+00,-.5731656607763409d+00,
     4      0.6161888965773678d+00,-.6033264915867708d+00,
     5      0.5438795017626430d+00,-.4551831560998318d+00,
     6      0.3560559781492833d+00,-.2617026077519692d+00,
     7      0.1816121244765861d+00,-.1193668403245522d+00,
     8      0.7465004731512544d-01,-.4436896558634726d-01/
         data arr1808/
     1      0.2530484449920858d-01,-.1361897784756952d-01,
     2      0.7149660267566742d-02,-.3351563027282834d-02,
     3      0.1633972835653884d-02,-.5883995840537341d-03,
     4      0.2655978697513016d-03,0.5091543013540710d-01,
     5      -.1566560967492625d+00,0.3342054690383930d+00,
     6      -.5712665659606655d+00,0.8304199268162972d+00,
     7      -.1060915937892905d+01,0.1216502027726651d+01,
     8      -.1270418844140878d+01,0.1221506823245600d+01/
         data arr1809/
     1      -.1090351700454143d+01,0.9097017138866225d+00,
     2      -.7130744939413336d+00,0.5278119522354210d+00,
     3      -.3698369504519901d+00,0.2467073573578958d+00,
     4      -.1560951715491033d+00,0.9497347189015370d-01,
     5      -.5419549469770214d-01,0.3035703580250798d-01,
     6      -.1490950910836535d-01,0.7759316003042888d-02,
     7      -.2889049258182023d-02,0.1390913791949389d-02,
     8      0.6537104490164540d-01,-.2138808062390066d+00/
         data arr1810/
     1      0.4852065497331162d+00,-.8819422477782772d+00,
     2      0.1363288546098504d+01,-.1852073789568242d+01,
     3      0.2258286800165211d+01,-.2507816832606980d+01,
     4      0.2564099980746712d+01,-.2433723558195291d+01,
     5      0.2159221573514948d+01,-.1799385966217712d+01,
     6      0.1416365993440460d+01,-.1054521516558266d+01,
     7      0.7481052154661076d+00,-.5019220908466208d+00,
     8      0.3248436547114399d+00,-.1956187997755018d+00/
         data arr1811/
     1      0.1165770380438297d+00,-.5964658652228018d-01,
     2      0.3304382237302200d-01,-.1266509837401574d-01,
     3      0.6485008359508965d-02,0.8064235629550591d-01,
     4      -.2798010714424388d+00,0.6731382822897340d+00,
     5      -.1297528232073533d+01,0.2126986805684083d+01,
     6      -.3064304969852528d+01,0.3962358757718922d+01,
     7      -.4666130533272421d+01,0.5059408882525549d+01,
     8      -.5092011681817469d+01,0.4790995590740213d+01/
         data arr1812/
     1      -.4232311506508228d+01,0.3533154158997447d+01,
     2      -.2786129096099376d+01,0.2096457797394955d+01,
     3      -.1485700889330660d+01,0.1020165896909244d+01,
     4      -.6452673730845403d+00,0.4080734861539708d+00,
     5      -.2163128316994021d+00,0.1272485871007590d+00,
     6      -.5000335540386529d-01,0.2716199770295102d-01,
     7      0.9587589406883691d-01,-.3518957463035193d+00,
     8      0.8955467825374157d+00,-.1826069277749078d+01/
         data arr1813/
     1      0.3166542274228303d+01,-.4825735112518188d+01,
     2      0.6600956949688182d+01,-.8222413644250492d+01,
     3      0.9431259714228576d+01,-.1003893607651773d+02,
     4      0.9992267195513994d+01,-.9331068534677097d+01,
     5      0.8241300268160566d+01,-.6861502499073588d+01,
     6      0.5463212168418614d+01,-.4073183919682839d+01,
     7      0.2960618004544847d+01,-.1957641065704420d+01,
     8      0.1310834654914602d+01,-.7160472109606387d+00/
         data arr1814/
     1      0.4463026529786855d+00,-.1791375390017370d+00,
     2      0.1030015987651012d+00,0.1101502823244883d+00,
     3      -.4267006329601067d+00,0.1146128496687275d+01,
     4      -.2466552717237804d+01,0.4514358322381860d+01,
     5      -.7260898937403923d+01,0.1048274090903897d+02,
     6      -.1377971353637260d+02,0.1668259241748251d+02,
     7      -.1873472745891798d+02,0.1968334808119238d+02,
     8      -.1937734961095078d+02,0.1806748571021946d+02/
         data arr1815/
     1      -.1583108563837913d+02,0.1330974542178869d+02,
     2      -.1039682364894654d+02,0.7983485739564247d+01,
     3      -.5492397428421119d+01,0.3886305210478786d+01,
     4      -.2176382602218783d+01,0.1434545837487448d+01,
     5      -.5861274184806954d+00,0.3560426230270224d+00,
     6      0.1225766548585465d+00,-.5001257081567994d+00,
     7      0.1414915003844089d+01,-.3207077271635581d+01,
     8      0.6182449524705371d+01,-.1047254366058814d+02/
         data arr1816/
     1      0.1592536670066906d+02,-.2204295389267008d+02,
     2      0.2811052790549132d+02,-.3322681800848135d+02,
     3      0.3677511920675365d+02,-.3806022077597686d+02,
     4      0.3739273921172394d+02,-.3436649858095961d+02,
     5      0.3045303959566912d+02,-.2481555265464662d+02,
     6      0.2009646682441833d+02,-.1431640758178068d+02,
     7      0.1068646973353173d+02,-.6104752663154085d+01,
     8      0.4248470924353288d+01,-.1761374202260121d+01/
         data arr1817/
     1      0.1128474982366811d+01,0.1323916165825905d+00,
     2      -.5678617299661378d+00,0.1688977633460121d+01,
     3      -.4024271458516200d+01,0.8156024546161220d+01,
     4      -.1452131655655822d+02,0.2321655790878296d+02,
     5      -.3376487211178672d+02,0.4527530461230872d+02,
     6      -.5619306981175070d+02,0.6540433217290543d+02,
     7      -.7095361267436316d+02,0.7333244617192592d+02,
     8      -.7044174433565159d+02,0.6568888033581878d+02/
         data arr1818/
     1      -.5558570871993814d+02,0.4740795660024479d+02,
     2      -.3480416497467389d+02,0.2736804518045449d+02,
     3      -.1587149949407684d+02,0.1164613824173816d+02,
     4      -.4884943057280694d+01,0.3296307681606311d+01,
     5      0.1390288485325463d+00,-.6258060495959387d+00,
     6      0.1953539621889977d+01,-.4884072119997116d+01,
     7      0.1038953326274133d+02,-.1940575437029638d+02,
     8      0.3256659101759914d+02,-.4965801181537326d+02/
         data arr1819/
     1      0.6990531014510097d+02,-.9087596579028565d+02,
     2      0.1110687478002067d+03,-.1258996849364249d+03,
     3      0.1367023286954129d+03,-.1367164553099317d+03,
     4      0.1340022147311310d+03,-.1171837021502237d+03,
     5      0.1051406523836990d+03,-.7916590284690676d+02,
     6      0.6550539226523378d+02,-.3838530886000413d+02,
     7      0.2966654510176700d+02,-.1255454648133173d+02,
     8      0.8912891660217582d+01,0.1421601884769768d+00/
         data arr1820/
     1      -.6704346774213068d+00,0.2193299064315514d+01,
     2      -.5743644735344510d+01,0.1280573779921425d+02,
     3      -.2504456239427156d+02,0.4405614396730472d+02,
     4      -.7027065430461749d+02,0.1037220477816582d+03,
     5      -.1408441525775587d+03,0.1805493836807366d+03,
     6      -.2130787650190010d+03,0.2428257678919802d+03,
     7      -.2517819745369839d+03,0.2591529512630203d+03,
     8      -.2330179521784655d+03,0.2197747919059564d+03/
         data arr1821/
     1      -.1689124390130465d+03,0.1469529110083921d+03,
     2      -.8661865176084439d+02,0.7045708032629365d+02,
     3      -.3000384210941147d+02,0.2239229399160010d+02,
     4      0.1417023902942078d+00,-.6990565555430658d+00,
     5      0.2393714740272430d+01,-.6553903025003412d+01,
     6      0.1529753953048617d+02,-.3126187309103716d+02,
     7      0.5758277216598899d+02,-.9582493926171040d+02,
     8      0.1481697503768631d+03,-.2095076903081097d+03/
         data arr1822/
     1      0.2814697761497699d+03,-.3444407103410363d+03,
     2      0.4117414020646194d+03,-.4405994365255789d+03,
     3      0.4759899286062883d+03,-.4377145693052955d+03,
     4      0.4338114900388705d+03,-.3387178235374238d+03,
     5      0.3096988392176730d+03,-.1828056189897628d+03,
     6      0.1564374024094314d+03,-.6686779624150519d+02,
     7      0.5243824666946279d+02,0.1377896933025472d+00,
     8      -.7099032258279754d+00,0.2542009110262094d+01/
         data arr1823/
     1      -.7261927710382291d+01,0.1773167066614526d+02,
     2      -.3777519742999010d+02,0.7280880316966405d+02,
     3      -.1260186097351231d+03,0.2040412791573997d+03,
     4      -.2993227597215740d+03,0.4213287764635188d+03,
     5      -.5321098434650381d+03,0.6671800249732539d+03,
     6      -.7331189918912534d+03,0.8312707911423797d+03,
     7      -.7774331551554010d+03,0.8097186365084248d+03,
     8      -.6392387416710352d+03,0.6142525008750773d+03/
         data arr1824/
     1      -.3614896513574536d+03,0.3254607864653648d+03,
     2      -.1392918220349601d+03,0.1147768521454853d+03,
     3      0.1306965232734943d+00,-.7019746294636253d+00,
     4      0.2627675459165812d+01,-.7813086040559964d+01,
     5      0.1995584747678206d+02,-.4419470081926845d+02,
     6      0.8913982865894944d+02,-.1598567122092855d+03,
     7      0.2711298120640265d+03,-.4108731320817679d+03,
     8      0.6062479844033908d+03,-.7859399568075289d+03/
         data arr1825/
     1      0.1034379947234108d+04,-.1160821503552298d+04,
     2      0.1382480343431156d+04,-.1307222040385003d+04,
     3      0.1431964411092800d+04,-.1137560354959427d+04,
     4      0.1149563908289140d+04,-.6714533410942682d+03,
     5      0.6364700729313070d+03,-.2720611861532271d+03,
     6      0.2357031778697053d+03,-.7056179669784157d-22,
     7      0.4483570921475377d-24,-.1826368465916187d-22,
     8      0.8156065090838377d-24,-.1408689896628522d-21/
         data arr1826/
     1      0.4959030386554062d-23,-.6463591709416669d-21,
     2      0.1998037019111111d-22,-.2203576659925852d-20,
     3      0.6164383646392540d-22,-.5381749961783137d-20,
     4      0.1416622952746068d-21,-.1078140765586837d-19,
     5      0.2655507737754573d-21,-.1534842595848265d-19,
     6      0.3637679302417025d-21,-.1835727335398966d-19,
     7      0.4090390109923987d-21,-.1306744613778558d-19,
     8      0.2839506472180387d-21,-.7962629049898736d-20/
         data arr1827/
     1      0.1590502766674732d-21,-.3862712831418754d-24,
     2      0.5226008425401034d-24,-.1634094307137887d-23,
     3      0.7109206826029351d-23,-.1672759258054806d-22,
     4      0.5577589590261577d-22,-.9026441089628429d-22,
     5      0.2658209961060821d-21,-.3753638666513071d-21,
     6      0.9706618404454302d-21,-.1017003781609440d-20,
     7      0.2467961669803168d-20,-.2327899464831823d-20,
     8      0.5160044274987392d-20,-.3515586276619365d-20/
         data arr1828/
     1      0.7498995400843988d-20,-.4666421830508781d-20,
     2      0.9172324980008355d-20,-.3424199717523822d-20,
     3      0.6590650697549791d-20,-.2351487079121215d-20,
     4      0.4059373179700008d-20,-.2769351383541908d-19,
     5      0.1881963543756775d-20,-.8880393541367770d-22,
     6      0.3361921178859571d-23,-.1083611829508552d-24,
     7      0.3068768212278761d-26,-.2891700356300234d-28,
     8      -.2047872303499046d-28,0.1902424407515784d-27/
         data arr1829/
     1      -.7642683875482851d-28,0.4985272444187477d-27,
     2      -.1869965081402521d-27,0.1072239111254773d-26,
     3      -.3724014507334787d-27,0.1579159130867784d-26,
     4      -.5264734660924570d-27,0.1978699396841472d-26,
     5      -.6178589777807122d-27,0.1429427627721737d-26,
     6      -.4359376085145358d-27,0.9149165580274566d-27,
     7      -.2565253091542790d-27,-.5737877588837917d-16,
     8      0.7094525868021739d-17,-.6090926276207884d-18/
         data arr1830/
     1      0.4195441757033301d-19,-.2460600189943110d-20,
     2      0.1269782050725865d-21,-.5887521698905506d-23,
     3      0.2488742983321547d-24,-.9693624963405860d-26,
     4      0.3499683776493451d-27,-.7680625487816907d-29,
     5      -.2192107712631820d-29,0.9656334915143625d-29,
     6      -.5191246217029012d-29,0.1451416209038417d-28,
     7      -.7751884929767389d-29,0.2029569481448121d-28,
     8      -.9132403891859674d-29,0.1478724533534811d-28/
         data arr1831/
     1      -.6810801831934102d-29,0.1128103833967864d-28,
     2      -.3795795679004729d-29,-.1625242099706570d-13,
     3      0.3146218404968240d-14,-.4229095959683929d-15,
     4      0.4560795494912689d-16,-.4187961318677264d-17,
     5      0.3383681667651464d-18,-.2456357470955939d-19,
     6      0.1625692011976602d-20,-.9915316754868153d-22,
     7      0.5619742387876788d-23,-.2978829419077877d-24,
     8      0.1518383258101780d-25,-.7228531857015910d-27/
         data arr1832/
     1      0.9869196075917368d-27,-.1308566205267459d-27,
     2      0.1313749717533460d-26,-.2553733639385487d-27,
     3      0.2036419155016053d-26,-.3645838976424815d-27,
     4      0.1440920141671406d-26,-.2298303334545942d-27,
     5      0.1128491395574488d-26,-.1334620944100525d-11,
     6      0.3686962559216794d-12,-.7072409314804340d-13,
     7      0.1088429827464999d-13,-.1426272423254714d-14,
     8      0.1644482702668542d-15,-.1703614661141641d-16/
         data arr1833/
     1      0.1609007443722132d-17,-.1400445668998396d-18,
     2      0.1132671792414005d-19,-.8569108677413848d-21,
     3      0.6099697225311788d-22,-.4061797678991914d-23,
     4      0.3284209347924674d-24,0.3802455789873272d-25,
     5      0.9076295767360716d-25,0.7561239773262701d-25,
     6      0.1512951939003105d-24,0.4603043602963583d-25,
     7      0.1002657479308505d-24,0.4460183654579677d-25,
     8      0.9237351504885703d-25,-.4709599539242202d-10/
         data arr1834/
     1      0.1743825086611394d-10,-.4483423155647718d-11,
     2      0.9248066140263395d-12,-.1624280860664751d-12,
     3      0.2510129343940968d-13,-.3485349298824082d-14,
     4      0.4412057282220874d-15,-.5147039632332100d-16,
     5      0.5579600355729510d-17,-.5657858816667735d-18,
     6      0.5395893931802411d-19,-.4860053105621598d-20,
     7      0.4180242552380716d-21,-.3126489845849480d-22,
     8      0.5748116435781367d-23,0.3794069927867184d-23/
         data arr1835/
     1      0.5610422835534915d-23,0.2991011135134485d-23,
     2      0.3263224404465423d-23,0.2726457457520424d-23,
     3      0.3706279429760944d-23,-.9011163329184255d-09,
     4      0.4275025446790459d-09,-.1408265096369930d-09,
     5      0.3721898403250121d-10,-.8375555403835843d-11,
     6      0.1658393135905957d-11,-.2950370805802827d-12,
     7      0.4785312860174336d-13,-.7152627522824960d-14,
     8      0.9934592549994313d-15,-.1290739124684343d-15/
         data arr1836/
     1      0.1577179691354062d-16,-.1820659324382780d-17,
     2      0.1993588984902468d-18,-.2069766186494402d-19,
     3      0.2086368977006621d-20,-.8771302405181777d-22,
     4      0.8258419471513038d-22,0.7921576415997360d-22,
     5      0.2913638820772082d-22,0.7695533615477626d-22,
     6      0.4994683865459509d-22,-.1084905061929088d-07,
     7      0.6375299210076193d-08,-.2601340949070210d-08,
     8      0.8515857192812279d-09,-.2373714406604058d-09/
         data arr1837/
     1      0.5821747097146545d-10,-.1282901874508938d-10,
     2      0.2577378304953178d-11,-.4771824200011299d-12,
     3      0.8209559964906415d-13,-.1321171973807127d-13,
     4      0.1999645963195958d-14,-.2859316585389011d-15,
     5      0.3877743906854921d-16,-.5004391059411658d-17,
     6      0.6203637339077619d-18,-.7455598982942965d-19,
     7      0.1406970012461547d-19,-.2560523867567505d-20,
     8      0.4551721819057367d-20,-.1282231049555874d-20/
         data arr1838/
     1      0.2977649746168552d-20,-.9091573655374579d-07,
     2      0.6446190611684349d-07,-.3173621237150034d-07,
     3      0.1253549336168127d-07,-.4215962818510733d-08,
     4      0.1247604368774626d-08,-.3317204427669130d-09,
     5      0.8041039774308537d-10,-.1796278708594470d-10,
     6      0.3728759817645285d-11,-.7240342731230026d-12,
     7      0.1322232831851082d-12,-.2281243478967024d-13,
     8      0.3732656686960323d-14,-.5811377233198785d-15/
         data arr1839/
     1      0.8639469857582065d-16,-.1230014587823104d-16,
     2      0.1756011777642220d-17,-.2429109603341863d-18,
     3      0.9081232162496035d-19,-.2282866797693483d-19,
     4      0.4316253074005490d-19,-.5695838084704613d-06,
     5      0.4771996556682677d-06,-.2776070407919385d-06,
     6      0.1295672433668978d-06,-.5149071998088493d-07,
     7      0.1800476610633764d-07,-.5656675140619203d-08,
     8      0.1620240996535093d-08,-.4276805829440463d-09/
         data arr1840/
     1      0.1049031731748292d-09,-.2406920486879169d-10,
     2      0.5193844173275904d-11,-.1058841314122820d-11,
     3      0.2047159973975784d-12,-.3766020178044365d-13,
     4      0.6611418518548483d-14,-.1110384543495404d-14,
     5      0.1793268670945893d-15,-.2778080980915891d-16,
     6      0.4552969692501134d-17,-.7108630285948114d-18,
     7      0.3887936287106762d-18,-.2811295724215047d-05,
     8      0.2736160674210094d-05,-.1849117589642204d-05/
         data arr1841/
     1      0.1002586494727083d-05,-.4628584256544906d-06,
     2      0.1880179319227117d-06,-.6862235271202573d-07,
     3      0.2283371417792370d-07,-.7001789580466631d-08,
     4      0.1995127822022674d-08,-.5317854136809367d-09,
     5      0.1333079849748198d-09,-.3157117017445028d-10,
     6      0.7090937974477585d-11,-.1515395990201420d-11,
     7      0.3090344433244199d-12,-.6028683712949577d-13,
     8      0.1127807589165913d-13,-.2023570447305525d-14/
         data arr1842/
     1      0.3509908514364112d-15,-.5639575554154469d-16,
     2      0.9895368883190357d-17,-.1137267964636639d-04,
     3      0.1267866729848494d-04,-.9814592535734682d-05,
     4      0.6095443775494263d-05,-.3223349433291718d-05,
     5      0.1499803011908277d-05,-.6270126300210460d-06,
     6      0.2389807836817705d-06,-.8394043409929904d-07,
     7      0.2739735366171143d-07,-.8364693774698951d-08,
     8      0.2401848027411786d-08,-.6515620077428873d-09/
         data arr1843/
     1      0.1676271977947751d-09,-.4103382148626597d-10,
     2      0.9585129158407609d-11,-.2141775796865298d-11,
     3      0.4589107064144356d-12,-.9424475428013809d-13,
     4      0.1868892764586844d-13,-.3418413350251545d-14,
     5      0.6377075640139392d-15,-.3887830723013254d-04,
     6      0.4906283673305913d-04,-.4299182000029984d-04,
     7      0.3022410114493283d-04,-.1809214086128550d-04,
     8      0.9529087192063092d-05,-.4509494649016739d-05/
         data arr1844/
     1      0.1945579920578578d-05,-.7735560957146010d-06,
     2      0.2858009877427977d-06,-.9877332178605945d-07,
     3      0.3210477611259501d-07,-.9858578353613356d-08,
     4      0.2871028650429723d-08,-.7955497053697122d-09,
     5      0.2103572686227593d-09,-.5320210237282674d-10,
     6      0.1290343768399339d-10,-.2994895146873532d-11,
     7      0.6718413204897121d-12,-.1371488370249090d-12,
     8      0.2866719780957900d-13,-.1150590737561282d-03/
         data arr1845/
     1      0.1627141156561290d-03,-.1597781746498048d-03,
     2      0.1258763286714444d-03,-.8443833933850678d-04,
     3      0.4983793886144528d-04,-.2642991079222124d-04,
     4      0.1277838432844653d-04,-.5693479115147765d-05,
     5      0.2357266551997772d-05,-.9129429997964824d-06,
     6      0.3325314312301322d-06,-.1144290112845085d-06,
     7      0.3734379694716211d-07,-.1159584524896001d-07,
     8      0.3435993938488742d-08,-.9736771210785822d-09/
         data arr1846/
     1      0.2646408011853042d-09,-.6868410372545818d-10,
     2      0.1726867186241654d-10,-.3894782770981230d-11,
     3      0.9122304554828244d-12,-.3005520007912584d-03,
     4      0.4721929095922661d-03,-.5151185244628001d-03,
     5      0.4508470806612354d-03,-.3359853637053158d-03,
     6      0.2203110244499049d-03,-.1297978012038524d-03,
     7      0.6971770233003550d-04,-.3450963218376453d-04,
     8      0.1587328355909872d-04,-.6829630020384519d-05/
         data arr1847/
     1      0.2763641518897455d-05,-.1056525440229381d-05,
     2      0.3830521367680420d-06,-.1321376984589837d-06,
     3      0.4349845355433085d-07,-.1369035112292901d-07,
     4      0.4133934864086633d-08,-.1188378196500679d-08,
     5      0.3320080716355700d-09,-.8186855681177968d-10,
     6      0.2130903159941764d-10,-.7039847262399177d-03,
     7      0.1219527360353458d-02,-.1466924386134076d-02,
     8      0.1415657830855683d-02,-.1163262870053022d-02/
         data arr1848/
     1      0.8410507659973010d-03,-.5463636390400539d-03,
     2      0.3235832204067778d-03,-.1766085486612209d-03,
     3      0.8957083887890263d-04,-.4249378087029130d-04,
     4      0.1896000348105049d-04,-.7992147043956281d-05,
     5      0.3194994950573097d-05,-.1215195343191620d-05,
     6      0.4410877535158344d-06,-.1530031748988664d-06,
     7      0.5094459615742467d-07,-.1608255729486994d-07,
     8      0.4955805859229840d-08,-.1323604708060423d-08/
         data arr1849/
     1      0.3800342502112281d-09,-.1498008504346293d-02,
     2      0.2842578684621162d-02,-.3745403222930925d-02,
     3      0.3959305852299514d-02,-.3563760639021872d-02,
     4      0.2822427377517944d-02,-.2008409449256187d-02,
     5      0.1302945846025862d-02,-.7789722144235239d-03,
     6      0.4327596889749318d-03,-.2248925327429191d-03,
     7      0.1099152810586687d-03,-.5075153368091981d-04,
     8      0.2222421880380388d-04,-.9258301597686777d-05/
         data arr1850/
     1      0.3681176410484739d-05,-.1397734687484683d-05,
     2      0.5098295270882395d-06,-.1753606706266264d-06,
     3      0.5921688949079711d-07,-.1698645965604499d-07,
     4      0.5345291953216835d-08,-.2927511445337893d-02,
     5      0.6049898820728637d-02,-.8681314500291158d-02,
     6      0.9994412162957926d-02,-.9797110877964451d-02,
     7      0.8450133426033681d-02,-.6548537647331010d-02,
     8      0.4626682903844903d-02,-.3012426999857912d-02/
         data arr1851/
     1      0.1822605533412919d-02,-.1031504609544532d-02,
     2      0.5490422389277166d-03,-.2760830576586422d-03,
     3      0.1316648857084856d-03,-.5972433460099354d-04,
     4      0.2586246527096632d-04,-.1068292634446615d-04,
     5      0.4244169894668655d-05,-.1578962356389231d-05,
     6      0.5810040861909803d-06,-.1776395840242266d-06,
     7      0.6091781554815447d-07,-.5302709136866497d-02,
     8      0.1187314965854402d-01,-.1845958554386740d-01/
         data arr1852/
     1      0.2302567328541159d-01,-.2445522867552948d-01,
     2      0.2285366720733901d-01,-.1918912840932006d-01,
     3      0.1468923891920055d-01,-.1036249738547582d-01,
     4      0.6792963626439774d-02,-.4165372825453081d-02,
     5      0.2402191937662487d-02,-.1308708978759261d-02,
     6      0.6762312331534323d-03,-.3322499115694894d-03,
     7      0.1558918163561931d-03,-.6965784293679136d-04,
     8      0.2998943381224092d-04,-.1198455878913394d-04/
         data arr1853/
     1      0.4781470753296838d-05,-.1547463411193208d-05,
     2      0.5754208048423066d-06,-.8972101114059753d-02,
     3      0.2166661380060527d-01,-.3633086939447423d-01,
     4      0.4887591832534818d-01,-.5598646582913736d-01,
     5      0.5642817123631236d-01,-.5110035923245876d-01,
     6      0.4218876230696421d-01,-.3209888276701189d-01,
     7      0.2269413970253525d-01,-.1500829266294180d-01,
     8      0.9335020737186422d-02,-.5484609245333054d-02/
         data arr1854/
     1      0.3056561661669642d-02,-.1618875414972477d-02,
     2      0.8192881715016922d-03,-.3939325786879491d-03,
     3      0.1829625438063294d-03,-.7802487485118254d-04,
     4      0.3360465851311167d-04,-.1143981583172778d-04,
     5      0.4592213316779916d-05,-.1427517720282100d-01,
     6      0.3702756757548106d-01,-.6668938531432871d-01,
     7      0.9636573759840299d-01,-.1185652764575719d+00,
     8      0.1283563174498407d+00,-.1248508985065486d+00/
         data arr1855/
     1      0.1107162609142578d+00,-.9047934451042064d-01,
     2      0.6871009802684390d-01,-.4880591167426303d-01,
     3      0.3260666233175752d-01,-.2057408772163228d-01,
     4      0.1231593454705674d-01,-.7000721074708410d-02,
     5      0.3806028030562204d-02,-.1959419373056843d-02,
     6      0.9778601912201236d-03,-.4421970014469502d-03,
     7      0.2047989566692802d-03,-.7291329289784843d-04,
     8      0.3147340735557003d-04,-.2148084582336036d-01/
         data arr1856/
     1      0.5962650989562779d-01,-.1149251881405603d+00,
     2      0.1777155815653093d+00,-.2339939158374021d+00,
     3      0.2710869940449568d+00,-.2821801750376888d+00,
     4      0.2677878622338246d+00,-.2341902398402666d+00,
     5      0.1903204729710190d+00,-.1446624980312713d+00,
     6      0.1034286248983858d+00,-.6982109712930118d-01,
     7      0.4473018296626242d-01,-.2717520239636941d-01,
     8      0.1581394547873628d-01,-.8675135010259074d-02/
         data arr1857/
     1      0.4635505009436904d-02,-.2209237939157495d-02,
     2      0.1096517942580116d-02,-.4061286676180765d-03,
     3      0.1878551646228022d-03,-.3072278852381550d-01,
     4      0.9095920839044626d-01,-.1869908779158989d+00,
     5      0.3084102280637211d+00,-.4331171994302012d+00,
     6      0.5351896700749171d+00,-.5941842655136493d+00,
     7      0.6014290238021718d+00,-.5609837592415977d+00,
     8      0.4862592868097657d+00,-.3941719663676309d+00/
         data arr1858/
     1      0.3005949103746621d+00,-.2163374749751338d+00,
     2      0.1478373162668499d+00,-.9561553598967312d-01,
     3      0.5936610735137880d-01,-.3453906026942977d-01,
     4      0.1969883485058287d-01,-.9835668663809975d-02,
     5      0.5215911035314547d-02,-.2000070546127296d-02,
     6      0.9882945034413657d-03,-.4194547849424200d-01,
     7      0.1320565004773266d+00,-.2886833681544573d+00,
     8      0.5063127068574765d+00,-.7561063596776623d+00/
         data arr1859/
     1      0.9935144283462832d+00,-.1172925185561713d+01,
     2      0.1262478937569053d+01,-.1252152476387928d+01,
     3      0.1154169749817642d+01,-.9946736693273001d+00,
     4      0.8066593317133648d+00,-.6168897260649747d+00,
     5      0.4483497197936684d+00,-.3074976461739798d+00,
     6      0.2031220749519645d+00,-.1247494559373440d+00,
     7      0.7573132673397973d-01,-.3938522155302010d-01,
     8      0.2225684134189515d-01,-.8796579216484633d-02/
         data arr1860/
     1      0.4630727105485288d-02,-.5487351087961572d-01,
     2      0.1832050550314998d+00,-.4247158222733938d+00,
     3      0.7899433120672527d+00,-.1250999035688598d+01,
     4      0.1743208727925313d+01,-.2182388238634365d+01,
     5      0.2491096693261023d+01,-.2619871635484232d+01,
     6      0.2560976471778157d+01,-.2339611352158505d+01,
     7      0.2012331602983580d+01,-.1630055492436666d+01,
     8      0.1256679262527989d+01,-.9103982199052461d+00/
         data arr1861/
     1      0.6382091172140214d+00,-.4118380812455831d+00,
     2      0.2654704001959695d+00,-.1429899574179469d+00,
     3      0.8590863766658718d-01,-.3485319550025677d-01,
     4      0.1949957806022290d-01,-.6901245814719979d-01,
     5      0.2437370457735859d+00,-.5977215183711723d+00,
     6      0.1176025313159522d+01,-.1970105161001138d+01,
     7      0.2904047867064864d+01,-.3845703567637714d+01,
     8      0.4643699243491699d+01,-.5165202667693812d+01/
         data arr1862/
     1      0.5341439052866617d+01,-.5158392779141303d+01,
     2      0.4694309364696264d+01,-.4015100990710513d+01,
     3      0.3275801110797234d+01,-.2496692705185290d+01,
     4      0.1853389450134400d+01,-.1250750064387274d+01,
     5      0.8542761559167318d+00,-.4739321291789457d+00,
     6      0.3021219075191239d+00,-.1253431040614956d+00,
     7      0.7437266518796659d-01,-.8368296720084627d-01,
     8      0.3119369896183068d+00,-.8073690090211112d+00/
         data arr1863/
     1      0.1676594590540209d+01,-.2964275112868998d+01,
     2      0.4611845189706542d+01,-.6444948569897230d+01,
     3      0.8214203432614624d+01,-.9639710361742081d+01,
     4      0.1052253618027703d+02,-.1071286463475905d+02,
     5      0.1029294352736969d+02,-.9266216968746338d+01,
     6      0.7984314619809892d+01,-.6375427064511074d+01,
     7      0.5002359088978476d+01,-.3513638954438565d+01,
     8      0.2538298238955072d+01,-.1442596133850432d+01/
         data arr1864/
     1      0.9741135813240516d+00,-.4118310248248714d+00,
     2      0.2586833035781404d+00,-.9808301243350054d-01,
     3      0.3850922278551252d+00,-.1049762712570512d+01,
     4      0.2296118216651335d+01,-.4275482633861516d+01,
     5      0.7006418111372699d+01,-.1030990160959129d+02,
     6      0.1384159526385781d+02,-.1709762522704450d+02,
     7      0.1966187748841094d+02,-.2104398420464954d+02,
     8      0.2130771206955061d+02,-.2012308725503615d+02/
         data arr1865/
     1      0.1828060164061944d+02,-.1522537617774297d+02,
     2      0.1260761245200920d+02,-.9172978250399309d+01,
     3      0.6998500968301649d+01,-.4053271101662191d+01,
     4      0.2895079999925738d+01,-.1243218652961494d+01,
     5      0.8253889557672744d+00,-.1113677332362045d+00,
     6      0.4596851817997228d+00,-.1317252435874733d+01,
     7      0.3029117176306120d+01,-.5928560350876860d+01,
     8      0.1021454295581932d+02,-.1579283523017307d+02/
         data arr1866/
     1      0.2229503139966455d+02,-.2891895065249428d+02,
     2      0.3497550745117211d+02,-.3923755750988236d+02,
     3      0.4180383588615896d+02,-.4126940828924122d+02,
     4      0.3947026747838426d+02,-.3412822587663243d+02,
     5      0.2978919652965419d+02,-.2234241435828388d+02,
     6      0.1798117651284036d+02,-.1055814236815958d+02,
     7      0.7968047905601036d+01,-.3464941001547771d+01,
     8      0.2428358763426383d+01,-.1227331480871982d+00/
         data arr1867/
     1      0.5316971903999846d+00,-.1598687778392211d+01,
     2      0.3858712490099334d+01,-.7923091314621611d+01,
     3      0.1432924488574160d+02,-.2322751962265917d+02,
     4      0.3442802351208658d+02,-.4677750011731361d+02,
     5      0.5941497959353350d+02,-.6964005396433765d+02,
     6      0.7797541387597656d+02,-.8015880311567754d+02,
     7      0.8062603818136600d+02,-.7201287497181747d+02,
     8      0.6620199533886435d+02,-.5093559466687242d+02/
         data arr1868/
     1      0.4320410539348784d+02,-.2559078831335623d+02,
     2      0.2038968516006771d+02,-.8953016392756192d+01,
     3      0.6616961591301262d+01,-.1314895199217102d+00,
     4      0.5969710394123537d+00,-.1880045384596676d+01,
     5      0.4756310707107840d+01,-.1022629306794123d+02,
     6      0.1938727204333098d+02,-.3287150389587778d+02,
     7      0.5109429535988930d+02,-.7252194871648264d+02,
     8      0.9663625807841488d+02,-.1179048994741485d+03/
         data arr1869/
     1      0.1386333458375687d+03,-.1477772435643506d+03,
     2      0.1562139981399272d+03,-.1433599079239121d+03,
     3      0.1387424211398391d+03,-.1089719285142279d+03,
     4      0.9736555752533295d+02,-.5789122026476729d+02,
     5      0.4867432410357033d+02,-.2152258228988276d+02,
     6      0.1676306306834469d+02,-.1371119053889913d+00,
     7      0.6515657171790481d+00,-.2145250285937210d+01,
     8      0.5682341696105512d+01,-.1276720574785487d+02/
         data arr1870/
     1      0.2534636365221602d+02,-.4483091190299874d+02,
     2      0.7301863534628261d+02,-.1079330240019570d+03,
     3      0.1507846038920462d+03,-.1906914939164961d+03,
     4      0.2353787042250494d+03,-.2589593869681369d+03,
     5      0.2876307603189763d+03,-.2696795798161513d+03,
     6      0.2747561992737848d+03,-.2192175076857629d+03,
     7      0.2062970835587646d+03,-.1225260465803295d+03,
     8      0.1087024282384709d+03,-.4827634485977721d+02/
         data arr1871/
     1      0.3961031443825730d+02,-.1392587653210902d+00,
     2      0.6920378069486657d+00,-.2376960024119634d+01,
     3      0.6587733356869152d+01,-.1543208892451232d+02,
     4      0.3206376345517517d+02,-.5896843139726188d+02,
     5      0.1006197227055928d+03,-.1543246357367914d+03,
     6      0.2260137511794804d+03,-.2948041188010303d+03,
     7      0.3821176269984478d+03,-.4316767280461281d+03,
     8      0.5039614554383376d+03,-.4798300425435576d+03/
         data arr1872/
     1      0.5149144674594064d+03,-.4152754657262387d+03,
     2      0.4117425671958953d+03,-.2430838918709247d+03,
     3      0.2276440732574221d+03,-.1012836635255889d+03,
     4      0.8754919356985036d+02,-.1377431328571807d+00,
     5      0.7155934234636634d+00,-.2557242887247674d+01,
     6      0.7416739199171795d+01,-.1806457235191386d+02,
     7      0.3928914846120595d+02,-.7482548697589678d+02,
     8      0.1338503256644904d+03,-.2120863033595613d+03/
         data arr1873/
     1      0.3258767976522118d+03,-.4358700117482239d+03,
     2      0.5939803168024365d+03,-.6851578891317465d+03,
     3      0.8417181598621747d+03,-.8085845977892833d+03,
     4      0.9151727139680379d+03,-.7423207928282653d+03,
     5      0.7762700814287637d+03,-.4532379733829765d+03,
     6      0.4485377646258356d+03,-.1994098044722671d+03,
     7      0.1817203405575315d+03,0.5620556365118349d-24,
     8      -.3253671622669741d-26,0.1034260969017680d-24/
         data arr1874/
     1      -.4140229794949400d-26,0.8287734701325283d-24,
     2      -.2280665636681733d-25,0.3850650726058400d-23,
     3      -.9065430584105744d-25,0.1347583538188171d-22,
     4      -.2389740367366261d-24,0.3300902017362143d-22,
     5      -.5261606557868807d-24,0.6751949666049521d-22,
     6      -.7798015793848169d-24,0.9596274536320562d-22,
     7      -.1011938605660288d-23,0.1176484750932145d-21,
     8      -.7359171486486592d-24,0.8329762586446551d-22/
         data arr1875/
     1      -.4960108706835031d-24,0.5306643271435882d-22,
     2      0.5299676671152183d-24,-.1601950200126862d-25,
     3      0.9801038720310537d-25,-.2040073176611733d-25,
     4      0.7833095458529840d-24,-.1123569692839312d-24,
     5      0.3639417206820159d-23,-.4466085232752462d-24,
     6      0.1273660116689965d-22,-.1177306021987254d-23,
     7      0.3119826990538868d-22,-.2592131486505276d-23,
     8      0.6381563346732271d-22,-.3841693484356579d-23/
         data arr1876/
     1      0.9069857995239179d-22,-.4985315922344798d-23,
     2      0.1111947090137012d-21,-.3625495144293807d-23,
     3      0.7872820762937986d-22,-.2443596819033849d-23,
     4      0.5015540710963707d-22,0.3556576752574231d-21,
     5      -.2332108741154605d-22,0.1063262582831186d-23,
     6      -.3950594130150831d-25,0.2982563491243744d-26,
     7      -.3442546510866145d-26,0.9416779549283214d-26,
     8      -.1856676931713583d-25,0.4633574113743772d-25/
         data arr1877/
     1      -.5229476202558896d-25,0.1255586056657926d-24,
     2      -.1438255468675978d-24,0.3260004189700649d-24,
     3      -.2208034924915000d-24,0.4916017592549471d-24,
     4      -.3437926014628458d-24,0.7351780072481110d-24,
     5      -.2503083168337602d-24,0.5323866629463364d-24,
     6      -.2086101747848713d-24,0.4280046081735676d-24,
     7      0.1340739365478554d-17,-.1599555604280508d-18,
     8      0.1326715174236522d-19,-.8838736801786286d-21/
         data arr1878/
     1      0.5019253808255893d-22,-.2510445516247280d-23,
     2      0.1129013329944902d-24,-.4623669193964678d-26,
     3      0.7498987988483382d-28,0.2574112149215317d-28,
     4      -.2644703876335353d-27,0.8192023670991683d-28,
     5      -.6237124046657894d-27,0.1248779977873679d-27,
     6      -.9236524192826465d-27,0.1840483231667740d-27,
     7      -.1278663977500759d-26,0.1339261583197563d-27,
     8      -.9198832320533593d-27,0.1052993151958353d-27/
         data arr1879/
     1      -.6813399679129356d-27,0.5945793907028747d-15,
     2      -.1110615009375098d-15,0.1442250170615997d-16,
     3      -.1504360115031688d-17,0.1337517618310779d-18,
     4      -.1047394345692373d-19,0.7376457187868192d-21,
     5      -.4740426997111944d-22,0.2809788537730685d-23,
     6      -.1548792603606281d-24,0.7982087467703186d-26,
     7      -.3795375058448931d-27,0.9521778837140881d-30,
     8      0.1613426331544653d-28,-.2676797480404360d-28/
         data arr1880/
     1      0.2037552560604522d-28,-.2220105587121195d-28,
     2      0.1765145740642724d-28,-.1526297223977731d-28,
     3      0.8681978833417609d-29,0.9447777235976955d-30,
     4      0.6967704303495618d-13,-.1857305677701647d-13,
     5      0.3441917328053465d-14,-.5123321787020572d-15,
     6      0.6500388641473798d-16,-.7264237323931926d-17,
     7      0.7300752301635290d-18,-.6695411062289596d-19,
     8      0.5663353731773469d-20,-.4454963233372568d-21/
         data arr1881/
     1      0.3280541724906607d-22,-.2273517888591405d-23,
     2      0.1495659881663892d-24,-.8956527239736459d-26,
     3      0.1463452823871132d-26,-.2057543117816216d-27,
     4      0.2323290795704624d-26,-.3250006398210186d-28,
     5      0.1989754781261743d-26,-.6263478238850930d-27,
     6      0.2204098265527404d-26,0.3295519649406722d-11,
     7      -.1177404603137563d-11,0.2924495295511461d-12,
     8      -.5834589091118847d-13,0.9922157435598016d-14/
         data arr1882/
     1      -.1486157934551369d-14,0.2001938370688158d-15,
     2      -.2460755612587736d-16,0.2789799960575047d-17,
     3      -.2941384152564154d-18,0.2903089987982838d-19,
     4      -.2696668115506885d-20,0.2367763997736675d-21,
     5      -.1966990220257842d-22,0.1492415137871498d-23,
     6      -.2650691296755434d-25,-.9047581307447869d-25,
     7      0.7571663101642126d-25,-.7952811852836211d-25,
     8      0.5740415898894260d-25,-.5423423037477532d-25/
         data arr1883/
     1      0.8079038700485942d-10,-.3698285326503767d-10,
     2      0.1176967617401423d-10,-.3008588315895686d-11,
     3      0.6555374456814479d-12,-.1258042338630977d-12,
     4      0.2171300330009228d-13,-.3419610020319733d-14,
     5      0.4967296248971923d-15,-.6710234075639317d-16,
     6      0.8485659352208535d-17,-.1009942168683531d-17,
     7      0.1136359703411689d-18,-.1213338733233600d-19,
     8      0.1233816375126085d-20,-.1186387882523467d-21/
         data arr1884/
     1      0.1128737681930959d-22,-.6275221526710746d-24,
     2      0.7782698559227408d-24,0.7579337576699428d-24,
     3      -.7497827081286259d-25,0.1204818303106293d-08,
     4      -.6831456013486673d-09,0.2692950495801446d-09,
     5      -.8526633858468136d-10,0.2301247598556490d-10,
     6      -.5470311973184450d-11,0.1169466349946360d-11,
     7      -.2281368320541402d-12,0.4104779961809472d-13,
     8      -.6868445919838462d-14,0.1075864096089822d-14/
         data arr1885/
     1      -.1586059428812190d-15,0.2210504197806476d-16,
     2      -.2923570697563935d-17,0.3682905272698528d-18,
     3      -.4427111998965992d-19,0.5372117363233942d-20,
     4      -.5622364818299625d-21,0.2784569312209910d-21,
     5      -.4947636461599133d-22,0.2183958576205112d-21,
     6      0.1218215518731149d-07,-.8334337677960604d-08,
     7      0.3964071061683365d-08,-.1514418550704494d-08,
     8      0.4931589280129763d-09,-.1414460720553714d-09/
         data arr1886/
     1      0.3648562345993953d-10,-.8587854810625815d-11,
     2      0.1864379905948563d-11,-.3764074932521626d-12,
     3      0.7113976533258239d-13,-.1265405555326721d-13,
     4      0.2127920182545274d-14,-.3395759844670642d-15,
     5      0.5159544393169569d-16,-.7484270234555731d-17,
     6      0.1042811558744973d-17,-.1382313617917033d-18,
     7      0.2051273785009717d-19,-.2371664482268255d-20,
     8      0.2854119252851382d-20,0.9018225818742052d-07/
         data arr1887/
     1      -.7290318052626578d-07,0.4097275991887404d-07,
     2      -.1849601262748553d-07,0.7117008704327953d-08,
     3      -.2412014384341701d-08,0.7351723729003970d-09,
     4      -.2044704273517950d-09,0.5245158656877262d-10,
     5      -.1251298376448077d-10,0.2794431393398086d-11,
     6      -.5873394450142427d-12,0.1167059359821008d-12,
     7      -.2200662111341860d-13,0.3950849013320027d-14,
     8      -.6772073455439251d-15,0.1111378666089686d-15/
         data arr1888/
     1      -.1746600646469589d-16,0.2662997571274155d-17,
     2      -.3741019939016907d-18,0.7576481980027323d-19,
     3      0.5170857636481943d-06,-.4856020692681715d-06,
     4      0.3170456874661977d-06,-.1662636546706235d-06,
     5      0.7432061322877993d-07,-.2926066951242474d-07,
     6      0.1036062898684892d-07,-.3347495689247814d-08,
     7      0.9975639109647257d-09,-.2764620722044561d-09,
     8      0.7172337333558659d-10,-.1751253434076998d-10/
         data arr1889/
     1      0.4042456276254752d-11,-.8855197955787296d-12,
     2      0.1846828985947026d-12,-.3677476206931655d-13,
     3      0.7009465799316987d-14,-.1279933626061847d-14,
     4      0.2250098583585652d-15,-.3686613191149987d-16,
     5      0.6057503751416597d-17,0.2396042901965588d-05,
     6      -.2577438271677960d-05,0.1927548568005787d-05,
     7      -.1157861297008389d-05,0.5928491949013288d-06,
     8      -.2673590837690340d-06,0.1084357636877937d-06/
         data arr1890/
     1      -.4013120332638519d-07,0.1369867683020777d-07,
     2      -.4348597225155362d-08,0.1292260496057772d-08,
     3      -.3614215754946896d-09,0.9556220138347437d-10,
     4      -.2397806269042508d-10,0.5728202396152795d-11,
     5      -.1306476085634686d-11,0.2852418992485609d-12,
     6      -.5960795233360857d-13,0.1200338084443076d-13,
     7      -.2233730418531717d-14,0.4192810181368934d-15,
     8      0.9272004615074213d-05,-.1129020505277331d-04/
         data arr1891/
     1      0.9557699984929066d-05,-.6498888847405091d-05,
     2      0.3766702443657351d-05,-.1922854979148615d-05,
     3      0.8827925042913893d-06,-.3698305506395906d-06,
     4      0.1429004938747617d-06,-.5134980493777556d-07,
     5      0.1727325522392632d-07,-.5468555616266537d-08,
     6      0.1636738183412612d-08,-.4648788573733646d-09,
     7      0.1257125431257957d-09,-.3245369603843671d-10,
     8      0.8020614869281980d-11,-.1894660874208328d-11/
         data arr1892/
     1      0.4318238591681434d-12,-.8993930836816906d-13,
     2      0.1902305050390183d-13,0.3075007748756561d-04,
     3      -.4195980432420814d-04,0.3980559021017226d-04,
     4      -.3033114687909384d-04,0.1970017508630494d-04,
     5      -.1126975182838991d-04,0.5798097411896286d-05,
     6      -.2722003651135136d-05,0.1178633276176923d-05,
     7      -.4746164686554219d-06,0.1789110838547858d-06,
     8      -.6347380477921011d-07,0.2128924114777713d-07/
         data arr1893/
     1      -.6776032235855755d-08,0.2053400800171161d-08,
     2      -.5939634718422079d-09,0.1644994079209536d-09,
     3      -.4345860516002094d-10,0.1110042494674634d-10,
     4      -.2557768318605412d-11,0.6060513503479928d-12,
     5      0.8923607211636794d-04,-.1352767518943722d-03,
     6      0.1425703651327199d-03,-.1206895054505248d-03,
     7      0.8708557886354524d-04,-.5534596840016760d-04,
     8      0.3163389197413471d-04,-.1649875990221210d-04/
         data arr1894/
     1      0.7936641784946039d-05,-.3550555658709134d-05,
     2      0.1486915388466075d-05,-.5860551227767143d-06,
     3      0.2183733575164813d-06,-.7721488409066237d-07,
     4      0.2599534899114905d-07,-.8351711069526163d-08,
     5      0.2569683284179571d-08,-.7520889816515951d-09,
     6      0.2134397996576080d-09,-.5384874173042613d-10,
     7      0.1417213058066832d-10,0.2304690080381820d-03,
     8      -.3852332168368820d-03,0.4476703132958274d-03/
         data arr1895/
     1      -.4178563582402366d-03,0.3324545060519853d-03,
     2      -.2329702385477844d-03,0.1468234938568153d-03,
     3      -.8443503656855598d-04,0.4478541955643737d-04,
     4      -.2209146628760201d-04,0.1020100516085906d-04,
     5      -.4433250504608853d-05,0.1821428253576140d-05,
     6      -.7101054745983092d-06,0.2636014545359066d-06,
     7      -.9334428679612765d-07,0.3166851159775821d-07,
     8      -.1018114463307791d-07,0.3186392921826385d-08/
         data arr1896/
     1      -.8721140975067624d-09,0.2530511987082868d-09,
     2      0.5371968772603499d-03,-.9835910736559798d-03,
     3      0.1252042444651570d-02,-.1280140612082015d-02,
     4      0.1115662380495320d-02,-.8563886678551919d-03,
     5      0.5912020445227145d-03,-.3724199592639738d-03,
     6      0.2163798464529569d-03,-.1169160842919144d-03,
     7      0.5913745746812209d-04,-.2815196192532877d-04,
     8      0.1266976903497071d-04,-.5410193707765196d-05/
         data arr1897/
     1      0.2199942200485721d-05,-.8528129612421855d-06,
     2      0.3169391874032345d-06,-.1110555539409133d-06,
     3      0.3808086536533806d-07,-.1121401291278661d-07,
     4      0.3563956498990885d-08,0.1143323409771968d-02,
     5      -.2279824879222179d-02,0.3160510630963277d-02,
     6      -.3519226119377707d-02,0.3340208520814323d-02,
     7      -.2792305850038776d-02,0.2099323163325344d-02,
     8      -.1440215680221326d-02,0.9113027931136103d-03/
         data arr1898/
     1      -.5362540044360627d-03,0.2953999249902427d-03,
     2      -.1531442674344031d-03,0.7506073487452197d-04,
     3      -.3490128226737227d-04,0.1545602765088679d-04,
     4      -.6519027418593159d-05,0.2638617064548815d-05,
     5      -.1000445311561407d-05,0.3737127453296393d-06,
     6      -.1175247543863513d-06,0.4067658717910445d-07,
     7      0.2243814376870254d-02,-.4847724660567616d-02,
     8      0.7281357224287542d-02,-.8784577494583955d-02/
         data arr1899/
     1      0.9033705168749238d-02,-.8182271999045542d-02,
     2      0.6665133588872332d-02,-.4954222421772454d-02,
     3      0.3396482104102996d-02,-.2165477194154122d-02,
     4      0.1292446124756305d-02,-.7259507031213584d-03,
     5      0.3855133371432538d-03,-.1941644858573382d-03,
     6      0.9316591179759135d-04,-.4251635385389539d-04,
     7      0.1864661617873465d-04,-.7598213537471737d-05,
     8      0.3076399650000480d-05,-.1026197262598089d-05/
         data arr1900/
     1      0.3848511558677398d-06,0.4094605133931755d-02,
     2      -.9540953733398925d-02,0.1545592246588838d-01,
     3      -.2011093246419954d-01,0.2230519326365821d-01,
     4      -.2178926769256738d-01,0.1914283928719641d-01,
     5      -.1534621049456428d-01,0.1134707253204901d-01,
     6      -.7802465238582234d-02,0.5022504122665339d-02,
     7      -.3042395711769980d-02,0.1742528731556008d-02,
     8      -.9461131207782296d-03,0.4896434672811583d-03/
         data arr1901/
     1      -.2405143846051776d-03,0.1137791894107098d-03,
     2      -.4950535908288691d-04,0.2162876810029191d-04,
     3      -.7605715826304789d-05,0.3076849716793207d-05,
     4      0.6997552535974273d-02,-.1751349064584378d-01,
     5      0.3047352193508704d-01,-.4258990644104179d-01,
     6      0.5073729019053615d-01,-.5323661150217795d-01,
     7      0.5023668724037641d-01,-.4325746837133180d-01,
     8      0.3435507004546149d-01,-.2537317073530088d-01/
         data arr1902/
     1      0.1754332631739252d-01,-.1141304902088483d-01,
     2      0.7021323879657525d-02,-.4091777267355688d-02,
     3      0.2274733615103591d-02,-.1196826095531692d-02,
     4      0.6082375473876506d-03,-.2808237065611502d-03,
     5      0.1318691372722610d-03,-.4861028041049614d-04,
     6      0.2112892725014736d-04,0.1126835121699621d-01,
     7      -.3018083334878353d-01,0.5619860143313395d-01,
     8      -.8405310768554773d-01,0.1071565485006406d+00/
         data arr1903/
     1      -.1203220909662872d+00,0.1215067788784757d+00,
     2      -.1119647805256348d+00,0.9516037905079577d-01,
     3      -.7520762472212308d-01,0.5564773961879462d-01,
     4      -.3873356953667342d-01,0.2550122008501242d-01,
     5      -.1588558358482666d-01,0.9451971319036577d-02,
     6      -.5301867848825951d-02,0.2884187113981737d-02,
     7      -.1404544500218436d-02,0.7063986546500759d-03,
     8      -.2715656332903241d-03,0.1263808632723067d-03/
         data arr1904/
     1      0.1718967476276923d-01,-.4910621222869199d-01,
     2      0.9752787792835818d-01,-.1555803567487915d+00,
     3      0.2115523239152591d+00,-.2533613550487301d+00,
     4      0.2728940681111440d+00,-.2682039323352154d+00,
     5      0.2431304890817970d+00,-.2049267607853533d+00,
     6      0.1617300404953081d+00,-.1200235443337446d+00,
     7      0.8428672773792502d-01,-.5590496529209671d-01,
     8      0.3548591364262078d-01,-.2112473283517037d-01/
         data arr1905/
     1      0.1226137006620668d-01,-.6261159885718553d-02,
     2      0.3362187922695603d-02,-.1341636976781330d-02,
     3      0.6664183873315993d-03,0.2495633349109034d-01,
     4      -.7581197594667502d-01,0.1601101385813826d+00,
     5      -.2716017480341838d+00,0.3927212266354072d+00,
     6      -.5001386168517200d+00,0.5728409757947014d+00,
     7      -.5986552233156376d+00,0.5770893135662709d+00,
     8      -.5171382953395264d+00,0.4340137598438029d+00/
         data arr1906/
     1      -.3422930375825623d+00,0.2556327918010076d+00,
     2      -.1798442444110436d+00,0.1214299061756832d+00,
     3      -.7637338507200402d-01,0.4716253325099834d-01,
     4      -.2510909918400318d-01,0.1435672448790105d-01,
     5      -.5920659542338625d-02,0.3130353680596110d-02,
     6      0.3462250426105186d-01,-.1115358800087043d+00,
     7      0.2498020190549658d+00,-.4493735619897535d+00,
     8      0.6890645322460585d+00,-.9305806785939962d+00/
         data arr1907/
     1      0.1130318973344759d+01,-.1252590573011116d+01,
     2      0.1280509048251443d+01,-.1216447465737871d+01,
     3      0.1082730783617494d+01,-.9046527015865992d+00,
     4      0.7165777329361800d+00,-.5326886822591139d+00,
     5      0.3815957847666532d+00,-.2524430323158779d+00,
     6      0.1654326710417657d+00,-.9131560826954468d-01,
     7      0.5545929336248676d-01,-.2354250210578085d-01,
     8      0.1321716016331206d-01,0.4606198566741597d-01/
         data arr1908/
     1      -.1569695213250658d+00,0.3718918960575859d+00,
     2      -.7076884323091800d+00,0.1147929005797330d+01,
     3      -.1639842133722450d+01,0.2107053585961273d+01,
     4      -.2469648279593914d+01,0.2670807436903047d+01,
     5      -.2682283534759601d+01,0.2525839036375797d+01,
     6      -.2229015582583503d+01,0.1868172658793563d+01,
     7      -.1461720486185975d+01,0.1108424426300853d+01,
     8      -.7678355356302220d+00,0.5327919309502939d+00/
         data arr1909/
     1      -.3032474118311939d+00,0.1952155060365192d+00,
     2      -.8498662462445082d-01,0.5055740090743033d-01,
     3      0.5895060233280147d-01,-.2120260617670079d+00,
     4      0.5301858901079209d+00,-.1064820016306780d+01,
     5      0.1823004498200508d+01,-.2748238578622734d+01,
     6      0.3727169269754143d+01,-.4609422025515888d+01,
     7      0.5261605045632448d+01,-.5571388320214174d+01,
     8      0.5538536985142164d+01,-.5146641857852498d+01/
         data arr1910/
     1      0.4554367397217182d+01,-.3735535081420842d+01,
     2      0.2992585454767130d+01,-.2161021942076278d+01,
     3      0.1584664101640784d+01,-.9250636949718737d+00,
     4      0.6300697006974469d+00,-.2803464468586607d+00,
     5      0.1763980034201755d+00,0.7277577426606302d-01,
     6      -.2756830584040243d+00,0.7260967085055841d+00,
     7      -.1535868394391380d+01,0.2769574092692802d+01,
     8      -.4396497366157680d+01,0.6280641673487625d+01/
         data arr1911/
     1      -.8176748274606618d+01,0.9832118192137868d+01,
     2      -.1094697422778153d+02,0.1146638563377296d+02,
     3      -.1118441111681047d+02,0.1043069900256500d+02,
     4      -.8930212742690580d+01,0.7545318718721885d+01,
     5      -.5654265955938557d+01,0.4374483304836018d+01,
     6      -.2605476022973060d+01,0.1874745778204359d+01,
     7      -.8498354013719113d+00,0.5647292141756566d+00,
     8      0.8687292591663995d-01,-.3459330003949302d+00/
         data arr1912/
     1      0.9578918970423225d+00,-.2129814821110644d+01,
     2      0.4037794489953431d+01,-.6735119099641889d+01,
     3      0.1011658118158905d+02,-.1383359528211233d+02,
     4      0.1749154487142359d+02,-.2041907158619376d+02,
     5      0.2249875920701787d+02,-.2295966193625443d+02,
     6      0.2253102305305256d+02,-.2004396167405837d+02,
     7      0.1783713499551043d+02,-.1380812049520005d+02,
     8      0.1125564507529042d+02,-.6805123409693471d+01/
         data arr1913/
     1      0.5166500851558449d+01,-.2378921757380141d+01,
     2      0.1667485698301020d+01,0.1004830850738226d+00,
     3      -.4198512587815681d+00,0.1220233951951214d+01,
     4      -.2846660159223486d+01,0.5664551881632192d+01,
     5      -.9907130259174208d+01,0.1562253990730021d+02,
     6      -.2238560970189470d+02,0.2971873459019211d+02,
     7      -.3626143836880352d+02,0.4197382899925886d+02,
     8      -.4465431115003960d+02,0.4605173370027461d+02/
         data arr1914/
     1      -.4236453820584731d+02,0.3966574831993410d+02,
     2      -.3157577928635050d+02,0.2709090304995210d+02,
     3      -.1654304629212026d+02,0.1323983286256212d+02,
     4      -.6175008224488130d+01,0.4561400614230191d+01,
     5      0.1128217750024552d+00,-.4937628435698309d+00,
     6      0.1504080155832625d+01,-.3674968735479711d+01,
     7      0.7664647029843122d+01,-.1402391511483827d+02,
     8      0.2318651728243174d+02,-.3472880971277107d+02/
         data arr1915/
     1      0.4834903585737146d+02,-.6144466372945053d+02,
     2      0.7464518043159789d+02,-.8246886544690507d+02,
     3      0.8929797320277444d+02,-.8451033796452943d+02,
     4      0.8319501670963830d+02,-.6779224501453567d+02,
     5      0.6117574014456977d+02,-.3754464938003783d+02,
     6      0.3165700563946189d+02,-.1491542536138801d+02,
     7      0.1160434745479656d+02,0.1231467868693329d+00,
     8      -.5634611596088758d+00,0.1796913482412682d+01/
         data arr1916/
     1      -.4589954947743725d+01,0.1002197932090364d+02,
     2      -.1913388757042536d+02,0.3313867053834634d+02,
     3      -.5173967150301431d+02,0.7547130991583462d+02,
     4      -.9949499925588130d+02,0.1267825880161919d+03,
     5      -.1448516673339438d+03,0.1645967895806560d+03,
     6      -.1593707536970947d+03,0.1649123700469428d+03,
     7      -.1369283566569485d+03,0.1299234429670076d+03,
     8      -.7974290344083359d+02,0.7082477116302110d+02/
         data arr1917/
     1      -.3362345997839303d+02,0.2754611470469048d+02,
     2      0.1308126155491151d+00,-.6244174888929499d+00,
     3      0.2083202370078284d+01,-.5552096623597486d+01,
     4      0.1268134244889795d+02,-.2518431055215897d+02,
     5      0.4567135619195044d+02,-.7409379624081285d+02,
     6      0.1131953406598428d+03,-.1540690912297976d+03,
     7      0.2059230992622691d+03,-.2421853844969837d+03,
     8      0.2887932211782886d+03,-.2844052221394958d+03/
         data arr1918/
     1      0.3094159834768445d+03,-.2605827391268360d+03,
     2      0.2600194937303301d+03,-.1588103927917986d+03,
     3      0.1486164597958891d+03,-.7091132033198893d+02,
     4      0.6118893465613269d+02,0.1353012117851391d+00,
     5      -.6719616997129197d+00,0.2345279099552565d+01,
     6      -.6507564506556252d+01,0.1554609109963994d+02,
     7      -.3198942366916542d+02,0.6076711035993334d+02,
     8      -.1020601415698334d+03,0.1633598626667426d+03/
         data arr1919/
     1      -.2282960410479907d+03,0.3203073223263692d+03,
     2      -.3858567807599035d+03,0.4832060976165883d+03,
     3      -.4809560154520542d+03,0.5506940179217709d+03,
     4      -.4682308111745499d+03,0.4917838208018245d+03,
     5      -.2973391500138258d+03,0.2934811857742263d+03,
     6      -.1403817732670354d+03,0.1277088603701366d+03,
     7      -.2830799916765476d-20,0.1539213178761654d-22,
     8      -.3392202048749182d-21,0.1511202581880615d-22/
         data arr1920/
     1      -.2311470655765092d-20,0.8380209993234223d-22,
     2      -.1154079186010821d-19,0.3470691944747234d-21,
     3      -.3295040076455826d-19,0.9173894976177856d-21,
     4      -.8406744060323610d-19,0.2090170671669158d-20,
     5      -.1293526165221780d-18,0.3095457234505043d-20,
     6      -.1918305757456221d-18,0.4168128254768099d-20,
     7      -.1417121291362402d-18,0.3019264466838892d-20,
     8      -.1137509133427950d-18,0.2153619902548321d-20/
         data arr1921/
     1      -.2669133813587554d-20,0.7578109602015121d-22,
     2      -.3218333745233584d-21,0.7446727910383715d-22,
     3      -.2184670694924804d-20,0.4128510133249183d-21,
     4      -.1090770375188144d-19,0.1709836815800347d-20,
     5      -.3114286774025723d-19,0.4519521318337473d-20,
     6      -.7945582673628445d-19,0.1029723039752242d-19,
     7      -.1222568536303775d-18,0.1524977581897640d-19,
     8      -.1813074667359976d-18,0.2053428717675140d-19/
         data arr1922/
     1      -.1339383284184281d-18,0.1487440577887765d-19,
     2      -.1075108915586654d-18,0.1060980520853250d-19,
     3      -.7310261001005867d-23,0.2277562881999272d-22,
     4      -.9320063440784909d-22,0.3436752695557994d-21,
     5      -.6455276788840052d-21,0.2054786657121791d-20,
     6      -.4028555331246462d-20,0.1010847880631086d-19,
     7      -.1206630010425981d-19,0.2849885747052690d-19,
     8      -.3577900852972289d-19,0.7279073012290267d-19/
         data arr1923/
     1      -.5699949627558730d-19,0.1118687864675140d-18,
     2      -.9371414577996900d-19,0.1628986272580869d-18,
     3      -.7009569340008250d-19,0.1195351790463021d-18,
     4      -.6129877216806194d-19,0.9159294353490106d-19,
     5      -.2920375621389453d-19,0.3369859910950939d-20,
     6      -.2706299188907685d-21,0.1747477647901245d-22,
     7      -.9625758448098441d-24,0.4661852787160338d-25,
     8      -.1199660020926223d-26,-.6009658330370372d-27/
         data arr1924/
     1      0.2462992579834904d-26,-.1871972897000592d-26,
     2      0.7280136142613138d-26,-.4868726603234562d-26,
     3      0.1138455482765087d-25,-.7337011200087590d-26,
     4      0.1876381075065387d-25,-.1096664083324552d-25,
     5      0.1382270309018844d-25,-.7902709013041190d-26,
     6      0.1222902048557725d-25,-.6339774899309136d-26,
     7      -.2027696311128447d-16,0.3663319096685242d-17,
     8      -.4606143339022961d-18,0.4656638635820787d-19/
         data arr1925/
     1      -.4016573961103205d-20,0.3054143398019257d-21,
     2      -.2090330134355565d-22,0.1306503286749549d-23,
     3      -.7532618069231794d-25,0.3984412692183412d-26,
     4      -.4491744226436386d-28,-.1616443317816108d-27,
     5      0.2474810656428182d-27,-.2595547543035658d-27,
     6      0.4310942174853044d-27,-.4034503162601352d-27,
     7      0.3168527534957404d-27,-.2911283396092547d-27,
     8      0.2952075591210615d-27,-.2428409791072112d-27/
         data arr1926/
     1      -.3390960719532037d-14,0.8742478755738737d-15,
     2      -.1568690520785415d-15,0.2263144835016916d-16,
     3      -.2785707849096540d-17,0.3022798632685349d-18,
     4      -.2952398764854172d-19,0.2633405907617292d-20,
     5      -.2168072002398841d-21,0.1661164390508436d-22,
     6      -.1192239175105207d-23,0.8054962590580657d-25,
     7      -.5131581821142082d-26,0.2684005822412190d-27,
     8      0.4991892577523196d-28,-.8623627576570247d-28/
         data arr1927/
     1      0.4077023400652490d-28,-.4989448026246019d-28,
     2      0.3979053172957436d-28,-.4294630882062543d-28,
     3      -.2149636868162868d-12,0.7428225478828202d-13,
     4      -.1786470766506218d-13,0.3454451816823961d-14,
     5      -.5699155518511553d-15,0.8288812329442114d-16,
     6      -.1085091231448097d-16,0.1297230630248588d-17,
     7      -.1431466629062411d-18,0.1470037741384573d-19,
     8      -.1414161755685387d-20,0.1281161900744466d-21/
         data arr1928/
     1      -.1098081593269199d-22,0.8911787646336020d-24,
     2      -.6898213493686861d-25,-.4836079423834347d-27,
     3      -.1276576498598954d-26,-.3330147037255347d-26,
     4      0.2502384389706245d-27,-.3880667178510638d-26,
     5      -.6752114324721562d-11,0.2989500737701821d-11,
     6      -.9211882775054560d-12,0.2282288438708089d-12,
     7      -.4824372141092752d-13,0.8990037460427519d-14,
     8      -.1507906282453958d-14,0.2309745838893309d-15/
         data arr1929/
     1      -.3265631126046978d-16,0.4296880684564284d-17,
     2      -.5296183491816722d-18,0.6147718847587052d-19,
     3      -.6750611035247151d-20,0.7038313327884789d-21,
     4      -.6997872433302173d-22,0.6501833291851943d-23,
     5      -.6872212617888943d-24,0.2467041686752602d-25,
     6      -.7593071956900990d-25,-.8238106480697301d-25,
     7      -.1247247519730321d-09,0.6840101099440143d-10,
     8      -.2610737772098146d-10,0.8011915754607649d-11/
         data arr1930/
     1      -.2097768880753375d-11,0.4842050705444689d-12,
     2      -.1005988870853561d-12,0.1908683911910923d-13,
     3      -.3342627176722170d-14,0.5447849479412780d-15,
     4      -.8317365985420917d-16,0.1195881615894841d-16,
     5      -.1626532874521422d-17,0.2100590314942133d-18,
     6      -.2583812108951049d-19,0.3033981512971758d-20,
     7      -.3374192829503454d-21,0.3415907032442843d-22,
     8      -.1229851815687890d-23,0.8772780131999933d-24/
         data arr1931/
     1      -.1521634916028080d-08,0.1006875056543130d-08,
     2      -.4636940882788988d-09,0.1716959004042443d-09,
     3      -.5424209253823954d-10,0.1510648329650137d-10,
     4      -.3786888020750395d-11,0.8669190470718403d-12,
     5      -.1831840754879634d-12,0.3602302026663502d-13,
     6      -.6635842786856951d-14,0.1151207901824301d-14,
     7      -.1889227877397314d-15,0.2943901597286283d-16,
     8      -.4369884816537913d-17,0.6195816772244602d-18/
         data arr1932/
     1      -.8406477067327263d-19,0.1088441585206196d-19,
     2      -.1302523673595445d-20,0.1280747107844777d-21,
     3      -.1331023882936903d-07,0.1040709142649060d-07,
     4      -.5663224151676719d-08,0.2477824385331415d-08,
     5      -.9249652926933006d-09,0.3043902808311395d-09,
     6      -.9016298354021635d-10,0.2438949234756416d-10,
     7      -.6089622027697379d-11,0.1415015339344699d-11,
     8      -.3080034058040429d-12,0.6313811491195849d-13/
         data arr1933/
     1      -.1224335902593310d-13,0.2254336765664752d-14,
     2      -.3954094069794672d-15,0.6625327981825832d-16,
     3      -.1062341846399751d-16,0.1634541552729869d-17,
     4      -.2364386622765569d-18,0.3287700632374292d-19,
     5      -.8865840243645453d-07,0.8052968514613936d-07,
     6      -.5090763958916697d-07,0.2587511628011215d-07,
     7      -.1122095453313260d-07,0.4289707942169293d-08,
     8      -.1476106851439462d-08,0.4638577965818069d-09/
         data arr1934/
     1      -.1345442107363868d-09,0.3631854185734472d-10,
     2      -.9183650536547221d-11,0.2186976038919145d-11,
     3      -.4926578090456132d-12,0.1053795737143346d-12,
     4      -.2147200868590773d-13,0.4179622013494967d-14,
     5      -.7782171041178239d-15,0.1392355343636033d-15,
     6      -.2334496404686293d-16,0.3857761103483519d-17,
     7      -.4705736939917153d-06,0.4895978258715396d-06,
     8      -.3545211713234642d-06,0.2064035963672931d-06/
         data arr1935/
     1      -.1025275283506025d-06,0.4489667155316169d-07,
     2      -.1769619730288022d-07,0.6369755341723651d-08,
     3      -.2116306866059578d-08,0.6543615384543783d-09,
     4      -.1895310765901441d-09,0.5169932126568548d-10,
     5      -.1334016730544025d-10,0.3268497449569649d-11,
     6      -.7628291822474715d-12,0.1700857240700952d-12,
     7      -.3624452985968774d-13,0.7428326772502187d-14,
     8      -.1415423300018087d-14,0.2681046796285811d-15/
         data arr1936/
     1      -.2061299995420912d-05,0.2427658223831419d-05,
     2      -.1989870196401178d-05,0.1311397464149069d-05,
     3      -.7373812238198949d-06,0.3655108219548484d-06,
     4      -.1630799440541772d-06,0.6644737995768159d-07,
     5      -.2499011503145891d-07,0.8746652793679677d-08,
     6      -.2867734939967813d-08,0.8854783136422495d-09,
     7      -.2586349713069848d-09,0.7173131369674787d-10,
     8      -.1894948964309888d-10,0.4782686969585204d-11/
         data arr1937/
     1      -.1152216389530811d-11,0.2673197855882648d-12,
     2      -.5713005106780262d-13,0.1223576845617815d-13,
     3      -.7660777112290460d-05,0.1011063002401894d-04,
     4      -.9286979145910960d-05,0.6858720601886875d-05,
     5      -.4321752542721397d-05,0.2400640400221563d-05,
     6      -.1200290788706550d-05,0.5480533413916296d-06,
     7      -.2309788754021991d-06,0.9059514941736050d-07,
     8      -.3328595052615629d-07,0.1151751908931443d-07/
         data arr1938/
     1      -.3769845302151666d-08,0.1171667772347295d-08,
     2      -.3468218879988866d-09,0.9809328072471005d-10,
     3      -.2643419801383112d-10,0.6873014591506251d-11,
     4      -.1628692163623457d-11,0.3905747743616859d-12,
     5      -.2469804283952379d-04,0.3621290895664146d-04,
     6      -.3695346320814593d-04,0.3031930687237384d-04,
     7      -.2122421001928726d-04,0.1309767561629693d-04,
     8      -.7275269288979182d-05,0.3690463473724037d-05/
         data arr1939/
     1      -.1727928587828796d-05,0.7529288893365634d-06,
     2      -.3073300677888308d-06,0.1181404250764909d-06,
     3      -.4295862936094011d-07,0.1483295437941016d-07,
     4      -.4876919065894890d-08,0.1532401830982324d-08,
     5      -.4575964549994142d-09,0.1321889950930999d-09,
     6      -.3438516808000650d-10,0.9152278713682384d-11,
     7      -.7033364092057360d-04,0.1137083732856486d-03,
     8      -.1279418579395094d-03,0.1157458022541689d-03/
         data arr1940/
     1      -.8934000822243621d-04,0.6079070186318132d-04,
     2      -.3723235175103094d-04,0.2082479721364144d-04,
     3      -.1075112782898413d-04,0.5165480072072891d-05,
     4      -.2324819499350404d-05,0.9853970079742573d-06,
     5      -.3950708170135444d-06,0.1504119475019926d-06,
     6      -.5451255572762932d-07,0.1888645978124776d-07,
     7      -.6196941822652573d-08,0.1974100939982009d-08,
     8      -.5586594890933643d-09,0.1637931715341948d-09/
         data arr1941/
     1      -.1795783394667568d-03,0.3180190989620735d-03,
     2      -.3919614124231126d-03,0.3884237841246771d-03,
     3      -.3284100628176169d-03,0.2447809019828895d-03,
     4      -.1642217705578458d-03,0.1006145868996075d-03,
     5      -.5689889024168306d-04,0.2994542096616808d-04,
     6      -.1476306464588222d-04,0.6854385808778445d-05,
     7      -.3010024952337470d-05,0.1255308988640429d-05,
     8      -.4981088780554076d-06,0.1890367329130431d-06/
         data arr1942/
     1      -.6763058852874802d-07,0.2360341012464721d-07,
     2      -.7209124294751743d-08,0.2312746621358205d-08,
     3      -.4162371711628717d-03,0.8027705030532944d-03,
     4      -.1077538536440308d-02,0.1162911340163332d-02,
     5      -.1070800415952320d-02,0.8692023712737799d-03,
     6      -.6350754784265319d-03,0.4237472186956263d-03,
     7      -.2609757869352822d-03,0.1495816386443930d-03,
     8      -.8031016888344088d-04,0.4060823698727079d-04/
         data arr1943/
     1      -.1941816458390454d-04,0.8819542897941453d-05,
     2      -.3808448112031639d-05,0.1574051963668752d-05,
     3      -.6096551867828714d-06,0.2317720079293093d-06,
     4      -.7585323614003475d-07,0.2647083544273974d-07,
     5      -.8850693829772955d-03,0.1849466584631929d-02,
     6      -.2689716570728819d-02,0.3145132449056021d-02,
     7      -.3137758110959881d-02,0.2759627521690369d-02,
     8      -.2184607336698281d-02,0.1579332399648609d-02/
         data arr1944/
     1      -.1053861665089733d-02,0.6544563334952962d-03,
     2      -.3806982990481502d-03,0.2085661242016974d-03,
     3      -.1080322134271316d-03,0.5316436437504124d-04,
     4      -.2484631655184567d-04,0.1112627724345300d-04,
     5      -.4634133771742211d-05,0.1909360760816035d-05,
     6      -.6652432912302866d-06,0.2512264131288136d-06,
     7      -.1741931859287283d-02,0.3925808233948585d-02,
     8      -.6157690454460817d-02,0.7765671595110265d-02/
         data arr1945/
     1      -.8355803025798523d-02,0.7925888819718389d-02,
     2      -.6767047863853129d-02,0.5276284346899404d-02,
     3      -.3797192229182050d-02,0.2543251221197791d-02,
     4      -.1595502185634314d-02,0.9427363913783184d-03,
     5      -.5264469905344494d-03,0.2794276324290990d-03,
     6      -.1406209399689424d-03,0.6791510999140616d-04,
     7      -.3022501424666346d-04,0.1343619626689697d-04,
     8      -.4954295771169740d-05,0.2015355579260331d-05/
         data arr1946/
     1      -.3197511290775247d-02,0.7740282325956677d-02,
     2      -.1304044315286792d-01,0.1766445770173265d-01,
     3      -.2041531078237310d-01,0.2079996744463644d-01,
     4      -.1907478830651217d-01,0.1597480515247679d-01,
     5      -.1234829835873946d-01,0.8883466985226225d-02,
     6      -.5985469790591808d-02,0.3798748116793190d-02,
     7      -.2277032414558550d-02,0.1298259734478695d-02,
     8      -.7002040945862031d-03,0.3632380120651888d-03/
         data arr1947/
     1      -.1716761854766686d-03,0.8201144934843053d-04,
     2      -.3183135673779990d-04,0.1389058783455980d-04,
     3      -.5510241044210196d-02,0.1427445913454099d-01,
     4      -.2573590814413202d-01,0.3730712573471184d-01,
     5      -.4614142972114486d-01,0.5030860533588644d-01,
     6      -.4937206893498338d-01,0.4424882818053541d-01,
     7      -.3660139452646338d-01,0.2817872665284258d-01,
     8      -.2031472256987151d-01,0.1379756695764824d-01/
         data arr1948/
     1      -.8841624800235832d-02,0.5395335202674543d-02,
     2      -.3104644375139068d-02,0.1723586979536193d-02,
     3      -.8599890184517924d-03,0.4399119431214848d-03,
     4      -.1788487508282347d-03,0.8341576814143575d-04,
     5      -.8965526534747168d-02,0.2477210633610796d-01,
     6      -.4763658916574143d-01,0.7365309026185980d-01,
     7      -.9715972399547364d-01,0.1129889940538496d+00,
     8      -.1182681766217132d+00,0.1130542824174104d+00/
         data arr1949/
     1      -.9973352210435771d-01,0.8189756875155826d-01,
     2      -.6295589213052387d-01,0.4560740953407970d-01,
     3      -.3112349786350109d-01,0.2026050513029697d-01,
     4      -.1238496092733519d-01,0.7333921500761941d-02,
     5      -.3840851195645523d-02,0.2097155049573562d-02,
     6      -.8890688163613904d-03,0.4417373809854300d-03,
     7      -.1384130886927545d-01,0.4066801886143899d-01,
     8      -.8316085277450411d-01,0.1367281133202775d+00/
         data arr1950/
     1      -.1917948019495821d+00,0.2371793066130889d+00,
     2      -.2639889343430664d+00,0.2683458529180388d+00,
     3      -.2516876853259257d+00,0.2197839905407303d+00,
     4      -.1795750513939851d+00,0.1383408790779446d+00,
     5      -.1001603694715685d+00,0.6935281680499597d-01,
     6      -.4484629336863365d-01,0.2824216754124715d-01,
     7      -.1543721899003722d-01,0.8971702824637343d-02,
     8      -.3949770101578685d-02,0.2084434929556366d-02/
         data arr1951/
     1      -.2036356835892970d-01,0.6344979032573125d-01,
     2      -.1375926223172018d+00,0.2399021031953726d+00,
     3      -.3568631808961293d+00,0.4679993942763188d+00,
     4      -.5523709749237202d+00,0.5954472031288047d+00,
     5      -.5920685714565500d+00,0.5483214929114015d+00,
     6      -.4747403570791427d+00,0.3878736661746212d+00,
     7      -.2968281869389814d+00,0.2180458460820193d+00,
     8      -.1485327044505880d+00,0.9921191433995727d-01/
         data arr1952/
     1      -.5628787165392607d-01,0.3473226899396911d-01,
     2      -.1581887976198813d-01,0.8843802088162434d-02,
     3      -.2865856575202147d-01,0.9446069530730331d-01,
     4      -.2166870004320873d+00,0.3996602543216173d+00,
     5      -.6288579615584169d+00,0.8724153068361943d+00,
     6      -.1089135872246231d+01,0.1241996612566842d+01,
     7      -.1305643281765038d+01,0.1279261492407705d+01,
     8      -.1170268736878348d+01,0.1011554002993344d+01/
         data arr1953/
     1      -.8151211873954751d+00,0.6337772400550108d+00,
     2      -.4529280330786900d+00,0.3201125749962846d+00,
     3      -.1874922112560060d+00,0.1225605722044893d+00,
     4      -.5754721292401384d-01,0.3400326916015795d-01,
     5      -.3871042324585697d-01,0.1346675775316656d+00,
     6      -.3260426374468497d+00,0.6346990654435816d+00,
     7      -.1053927946699531d+01,0.1543241945756921d+01,
     8      -.2033018822087879d+01,0.2446970023213575d+01/
         data arr1954/
     1      -.2712397830951922d+01,0.2805526045772748d+01,
     2      -.2703947892579529d+01,0.2467286697128292d+01,
     3      -.2085250386911578d+01,0.1712639337140815d+01,
     4      -.1278756671233388d+01,0.9542657340233637d+00,
     5      -.5739549965137168d+00,0.3966898153646161d+00,
     6      -.1914078053226324d+00,0.1192875626876119d+00,
     7      -.5033239785423776d-01,0.1844295403245084d+00,
     8      -.4702935574116771d+00,0.9642786652546267d+00/
         data arr1955/
     1      -.1686069380682927d+01,0.2600599366486673d+01,
     2      -.3607142601197615d+01,0.4573163848375286d+01,
     3      -.5330886364567833d+01,0.5809687303808487d+01,
     4      -.5882126943647865d+01,0.5654935351359811d+01,
     5      -.4991928476698211d+01,0.4323278778321349d+01,
     6      -.3358750700370827d+01,0.2641522352289639d+01,
     7      -.1623074747838789d+01,0.1184102764689381d+01,
     8      -.5853882902744296d+00,0.3840960057276086d+00/
         data arr1956/
     1      -.6315777111992553d-01,0.2433073217153602d+00,
     2      -.6522188876061819d+00,0.1405899228977187d+01,
     3      -.2583078538164665d+01,0.4189202381455059d+01,
     4      -.6104815910745217d+01,0.8137702768796894d+01,
     5      -.9947759877553690d+01,0.1140390724700023d+02,
     6      -.1209291638582046d+02,0.1222803857185550d+02,
     7      -.1122489226174078d+02,0.1023604795418011d+02,
     8      -.8240548879675034d+01,0.6819082384285409d+01/
         data arr1957/
     1      -.4258750072256232d+01,0.3274895142505556d+01,
     2      -.1654262975367669d+01,0.1141024782765323d+01,
     3      -.7665207196307158d-01,0.3099472193224499d+00,
     4      -.8718926884776137d+00,0.1972503621940441d+01,
     5      -.3800010214101246d+01,0.6469959737992658d+01,
     6      -.9884854483505796d+01,0.1383184582471652d+02,
     7      -.1767742915565324d+02,0.2128787285889020d+02,
     8      -.2356867567700867d+02,0.2503028304192778d+02/
         data arr1958/
     1      -.2378082466889457d+02,0.2280762459397981d+02,
     2      -.1894909619207696d+02,0.1647647477214761d+02,
     3      -.1040720849410775d+02,0.8425939940629060d+01,
     4      -.4337794908375879d+01,0.3141262928434985d+01,
     5      -.9014313903996062d-01,0.3820571719465008d+00,
     6      -.1125985034332766d+01,0.2669491195405770d+01,
     7      -.5380057170433785d+01,0.9604600394548473d+01,
     8      -.1535063405933991d+02,0.2251781868453871d+02/
         data arr1959/
     1      -.2998382421975863d+02,0.3789133794863645d+02,
     2      -.4365238633353180d+02,0.4863383063415188d+02,
     3      -.4758205918478620d+02,0.4795540273926295d+02,
     4      -.4095159515809487d+02,0.3737560797297431d+02,
     5      -.2376029086861404d+02,0.2023648992443999d+02,
     6      -.1059238628500778d+02,0.8045368265198981d+01,
     7      -.1028603301212960d+00,0.4564682098573725d+00,
     8      -.1407274029931895d+01,0.3491811478539429d+01/
         data arr1960/
     1      -.7342806068615785d+01,0.1373222963106849d+02,
     2      -.2290633366660165d+02,0.3518671084155827d+02,
     3      -.4862208638015229d+02,0.6443980127902256d+02,
     4      -.7696992537241006d+02,0.8988509774935298d+02,
     5      -.9007247487510256d+02,0.9535074279722795d+02,
     6      -.8335718545461141d+02,0.7979501299477278d+02,
     7      -.5080847419729159d+02,0.4549784181830178d+02,
     8      -.2415926429816322d+02,0.1923357624376249d+02/
         data arr1961/
     1      -.1139715037565644d+00,0.5292557398389337d+00,
     2      -.1704382986551368d+01,0.4421398163359518d+01,
     3      -.9670036416402862d+01,0.1893741902482438d+02,
     4      -.3288474795998854d+02,0.5286057487510745d+02,
     5      -.7544873476419649d+02,0.1048540887169419d+03,
     6      -.1293515105416871d+03,0.1582646407402225d+03,
     7      -.1615038787202316d+03,0.1795725683419272d+03,
     8      -.1600772620889725d+03,0.1606635537946329d+03/
         data arr1962/
     1      -.1019708235360529d+03,0.9599413068397003d+02,
     2      -.5159975988171190d+02,0.4304441493880358d+02,
     3      -.1226139092626521d+00,0.5959691616796682d+00,
     4      -.2002164080610416d+01,0.5426846351053884d+01,
     5      -.1229417233493647d+02,0.2522232917941814d+02,
     6      -.4546863931512085d+02,0.7647383276446976d+02,
     7      -.1121280374527111d+03,0.1635070801008817d+03,
     8      -.2074772761126880d+03,0.2660160372572579d+03/
         data arr1963/
     1      -.2747401547496635d+03,0.3210582545492133d+03,
     2      -.2907114869080778d+03,0.3059868122862547d+03,
     3      -.1926206317035059d+03,0.1907205397809732d+03,
     4      -.1035688068967000d+03,0.9055431055423671d+02,
     5      0.4830407368065593d-22,-.2492709766209574d-24,
     6      0.4145777052836539d-23,-.1207912004730260d-24,
     7      0.2719458875482710d-22,-.8796106070187518d-24,
     8      0.1468068065124432d-21,-.2531429623479875d-23/
         data arr1964/
     1      0.4085149828751225d-21,-.8128507997227559d-23,
     2      0.1110103055775280d-20,-.1211160630726236d-22,
     3      0.1666855221486365d-20,-.2183189903713871d-22,
     4      0.2637360496042223d-20,-.1517967916868952d-22,
     5      0.1893066994794501d-20,-.1553553490927984d-22,
     6      0.1668192750578637d-20,0.4554479721277109d-22,
     7      -.1227223211209505d-23,0.3937995764953048d-23,
     8      -.5953573722957805d-24,0.2570278527086715d-22/
         data arr1965/
     1      -.4333402061322644d-23,0.1387535037511972d-21,
     2      -.1247109701066190d-22,0.3861054622689998d-21,
     3      -.4004512863865458d-22,0.1049207196344351d-20,
     4      -.5966791580397280d-22,0.1575418569250673d-20,
     5      -.1075549761460052d-21,0.2492685188528145d-20,
     6      -.7478281437621744d-22,0.1789220938550855d-20,
     7      -.7653587302194355d-22,0.1576681300300072d-20,
     8      0.4109526548882875d-22,-.2680458223002021d-23/
         data arr1966/
     1      0.3685460331620088d-23,-.1307763546124218d-23,
     2      0.2347274233252888d-22,-.9496381781702801d-23,
     3      0.1267145007114812d-21,-.2732971491831103d-22,
     4      0.3526056421660274d-21,-.8775672770671620d-22,
     5      0.9581744912477604d-21,-.1307594070153027d-21,
     6      0.1438731983086457d-20,-.2357012758993991d-21,
     7      0.2276410841178354d-20,-.1638831615508791d-21,
     8      0.1633982667461846d-20,-.1677241635433689d-21/
         data arr1967/
     1      0.1439878586521941d-20,0.5957143128823832d-21,
     2      -.6664738827843082d-22,0.5297957963864153d-23,
     3      -.4134985119376861d-24,0.5716382185541644d-24,
     4      -.1496754777134637d-23,0.4743755176606785d-23,
     5      -.3378846757981395d-23,0.1243734131439431d-22,
     6      -.1695798031190697d-22,0.4497708024173098d-22,
     7      -.2285866159480773d-22,0.6623238951906928d-22,
     8      -.5578412446963392d-22,0.1286411300533928d-21/
         data arr1968/
     1      -.3624508020732945d-22,0.9004314561549420d-22,
     2      -.4784307901086618d-22,0.9537524113008203d-22,
     3      0.6475894436943980d-18,-.1133954102453080d-18,
     4      0.1383227789873850d-19,-.1357849821769457d-20,
     5      0.1138211337915010d-21,-.8417519302335397d-23,
     6      0.5602277844942440d-24,-.3386269235567740d-25,
     7      0.4476005057978176d-27,0.1179255301917579d-26,
     8      -.4875576783441502d-26,0.1784367102234137d-26/
         data arr1969/
     1      -.7412620511326122d-26,0.4133645626519008d-26,
     2      -.1346896540703578d-25,0.2745886104372346d-26,
     3      -.9654214346069545d-26,0.3459086584182719d-26,
     4      -.9554525801591551d-26,0.1545466503140547d-15,
     5      -.3861849101772399d-16,0.6722541893376058d-17,
     6      -.9417411364366602d-18,0.1126530537453096d-18,
     7      -.1188912184573855d-19,0.1130251298219778d-20,
     8      -.9819430303209076d-22,0.7879503717769066d-23/
         data arr1970/
     1      -.5887280929090633d-24,0.4091222153296760d-25,
     2      -.2594577849100242d-26,-.3198061512757855d-27,
     3      0.2922847577331738d-27,-.9297243771714608d-27,
     4      0.1980680366309968d-27,-.6540754360854443d-27,
     5      0.2555279647262600d-27,-.6790610569535847d-27,
     6      0.1313137152065528d-13,-.4397987004804793d-14,
     7      0.1026125093627843d-14,-.1926666213931385d-15,
     8      0.3089057970228918d-16,-.4369593302855154d-17/
         data arr1971/
     1      0.5567681924309436d-18,-.6483267125533554d-19,
     2      0.6973001376924232d-20,-.6984051406231881d-21,
     3      0.6556673218674395d-22,-.5800380385336234d-23,
     4      0.4856638344415811d-24,-.3881675027269233d-25,
     5      0.2898765114952844d-26,-.3027232056526118d-27,
     6      -.6357831784162533d-29,-.1683431690861069d-27,
     7      -.6744356294351330d-28,0.5284740609977859d-12,
     8      -.2267808771016586d-12,0.6779406869852605d-13/
         data arr1972/
     1      -.1630935456575152d-13,0.3350389146963262d-14,
     2      -.6072242593035013d-15,0.9913372267008122d-16,
     3      -.1479039649002104d-16,0.2038189464072768d-17,
     4      -.2615598605066328d-18,0.3146198943603876d-19,
     5      -.3566113929502255d-20,0.3825767122722912d-21,
     6      -.3899758133079925d-22,0.3789872123288578d-23,
     7      -.3522541301112743d-24,0.3196197531102446d-25,
     8      -.8197887602767122d-26,0.1775664267894277d-26/
         data arr1973/
     1      0.1209170467853921d-10,-.6427192098472420d-11,
     2      0.2379893609688239d-11,-.7091753180023098d-12,
     3      0.1804525754646079d-12,-.4051053132924168d-13,
     4      0.8192024351408376d-14,-.1513911994469513d-14,
     5      0.2584141908746553d-15,-.4107654380493007d-16,
     6      0.6120120267049450d-17,-.8592509918332563d-18,
     7      0.1141806323628850d-18,-.1441450540459228d-19,
     8      0.1733859902408662d-20,-.1991985670316180d-21/
         data arr1974/
     1      0.2143980150769211d-22,-.2082339984270251d-23,
     2      -.1872103006595612d-24,0.1779920450723088d-09,
     3      -.1141535933691036d-09,0.5100128217732885d-10,
     4      -.1833717411762817d-10,0.5629853925323952d-11,
     5      -.1524955695328882d-11,0.3720795203400668d-12,
     6      -.8296604867994613d-13,0.1708721884383095d-13,
     7      -.3277209176277606d-14,0.5891494519295307d-15,
     8      -.9980236576689112d-16,0.1600183038121696d-16/
         data arr1975/
     1      -.2437450897023106d-17,0.3538545065771594d-18,
     2      -.4908070179266007d-19,0.6515963258734596d-20,
     3      -.8193364276265508d-21,0.9198684557006946d-22,
     4      0.1839731230024970d-08,-.1394189409160106d-08,
     5      0.7360235181190726d-09,-.3126953410383791d-09,
     6      0.1134395599381235d-09,-.3630805941554456d-10,
     7      0.1046791005989104d-10,-.2758055667478566d-11,
     8      0.6712007095950249d-12,-.1521120402530138d-12/
         data arr1976/
     1      0.3231196085752100d-13,-.6467806437639108d-14,
     2      0.1225361972390777d-14,-.2205501138073537d-15,
     3      0.3783434702523005d-16,-.6199261912275580d-17,
     4      0.9736956797162988d-18,-.1444285276115255d-18,
     5      0.2074996566661527d-19,0.1423577161341318d-07,
     6      -.1253259451853814d-07,0.7686054842696619d-08,
     7      -.3793374986316785d-08,0.1598679760385243d-08,
     8      -.5944188308933398d-09,0.1990866241082969d-09/
         data arr1977/
     1      -.6093652795738099d-10,0.1722739703540229d-10,
     2      -.4535481734896693d-11,0.1119220674916628d-11,
     3      -.2602566158518652d-12,0.5727984262428316d-13,
     4      -.1197656708012943d-13,0.2386748674773956d-14,
     5      -.4540774838409795d-15,0.8287137161281375d-16,
     6      -.1420441836798839d-16,0.2392906660253124d-17,
     7      0.8654948568198898d-07,-.8727707912389136d-07,
     8      0.6131100414138792d-07,-.3466063072491672d-07/
         data arr1978/
     1      0.1673200159272561d-07,-.7126145984562383d-08,
     2      0.2733883308067293d-08,-.9584982646575034d-09,
     3      0.3103909312545399d-09,-.9360272808126703d-10,
     4      0.2645797151518857d-10,-.7047218040968381d-11,
     5      0.1776616045072410d-11,-.4254899503140407d-12,
     6      0.9712695702964163d-13,-.2114875137940470d-13,
     7      0.4421405105448906d-14,-.8621922700994763d-15,
     8      0.1663515583185096d-15,0.4291533981186201d-06/
         data arr1979/
     1      -.4898721786608230d-06,0.3895430930979575d-06,
     2      -.2492803514669321d-06,0.1362178407338289d-06,
     3      -.6567125516709809d-07,0.2851905186239812d-07,
     4      -.1131829333214843d-07,0.4148901712344008d-08,
     5      -.1416273397572447d-08,0.4531579949929771d-09,
     6      -.1366292669860561d-09,0.3899010244773948d-10,
     7      -.1056973451699273d-10,0.2731177991927281d-11,
     8      -.6723491755621838d-12,0.1591283387446166d-12/
         data arr1980/
     1      -.3484945443531395d-13,0.7610132059473858d-14,
     2      0.1787323763012983d-05,-.2286296219532091d-05,
     3      0.2037343605578383d-05,-.1461019019731935d-05,
     4      0.8946658540720051d-06,-.4833494587129502d-06,
     5      0.2352231446992145d-06,-.1046128303894559d-06,
     6      0.4297305267848807d-07,-.1643876138172100d-07,
     7      0.5894279144074197d-08,-.1991499296471550d-08,
     8      0.6368694938626362d-09,-.1934556683223772d-09/
         data arr1981/
     1      0.5601807176012812d-10,-.1542604612186510d-10,
     2      0.4091918785671156d-11,-.9951347814410419d-12,
     3      0.2434760267357252d-12,0.6401598372431864d-05,
     4      -.9097313766379936d-05,0.9006176161384567d-05,
     5      -.7175092560055008d-05,0.4881215504234246d-05,
     6      -.2929704627122823d-05,0.1583937837951999d-05,
     7      -.7825975424384778d-06,0.3571455341579651d-06,
     8      -.1517795575839764d-06,0.6046031420813249d-07/
         data arr1982/
     1      -.2269380612218407d-07,0.8062587249090008d-08,
     2      -.2720414963135773d-08,0.8751459578492514d-09,
     3      -.2670606182762851d-09,0.7871619483425950d-10,
     4      -.2104899333598973d-10,0.5720308174008923d-11,
     5      0.2010099045696730d-04,-.3149710810683027d-04,
     6      0.3438162651471431d-04,-.3020243521940215d-04,
     7      0.2265535696144734d-04,-.1499323109825938d-04,
     8      0.8937951735578279d-05,-.4869302047530236d-05/
         data arr1983/
     1      0.2450202404846627d-05,-.1148147610553373d-05,
     2      0.5042935214783382d-06,-.2087048163134373d-06,
     3      0.8175809040252867d-07,-.3040958740187687d-07,
     4      0.1078673205182069d-07,-.3617072492172522d-08,
     5      0.1175870429481797d-08,-.3427163528769130d-09,
     6      0.1026770788936849d-09,0.5621836535528769d-04,
     7      -.9649422935323524d-04,0.1153790566651764d-03,
     8      -.1110228646411723d-03,0.9122445607878976d-04/
         data arr1984/
     1      -.6613106299766840d-04,0.4318353378915782d-04,
     2      -.2577012257841071d-04,0.1420436153879916d-04,
     3      -.7290974908839377d-05,0.3507852673399983d-05,
     4      -.1590115812964768d-05,0.6823421609176629d-06,
     5      -.2778927520916026d-06,0.1079781547229573d-06,
     6      -.3948140384686942d-07,0.1406456546768447d-07,
     7      -.4433156491797532d-08,0.1454631472769924d-08,
     8      0.1419111166053739d-03,-.2652716504528348d-03/
         data arr1985/
     1      0.3454361421169346d-03,-.3619966095802500d-03,
     2      0.3239325981639356d-03,-.2557408713212128d-03,
     3      0.1818712742693850d-03,-.1181987545707055d-03,
     4      0.7095281712182915d-04,-.3966257672911482d-04,
     5      0.2078204873581899d-04,-.1025814676284682d-04,
     6      0.4794059971189575d-05,-.2125010076225593d-05,
     7      0.8992623474328193d-06,-.3559785031926294d-06,
     8      0.1381728349521456d-06,-.4677004430354073d-07/
         data arr1986/
     1      0.1671113804452148d-07,0.3269425908257645d-03,
     2      -.6621624498822905d-03,0.9342435530201491d-03,
     3      -.1060755832355927d-02,0.1028452456308582d-02,
     4      -.8797276669185525d-03,0.6778457043780904d-03,
     5      -.4773053269280719d-03,0.3104360746157706d-03,
     6      -.1880156612552017d-03,0.1067384649542719d-03,
     7      -.5707127796167941d-04,0.2889936191870736d-04,
     8      -.1386642268102051d-04,0.6358183559069328d-05/
         data arr1987/
     1      -.2706588637234362d-05,0.1138984333458030d-05,
     2      -.4113980155549083d-06,0.1592536863770434d-06,
     3      0.6939914053391395d-03,-.1515918631641112d-02,
     4      0.2306748222751115d-02,-.2824776862637068d-02,
     5      0.2953804374301130d-02,-.2725048833468772d-02,
     6      0.2264569438553568d-02,-.1719789248588141d-02,
     7      0.1206371641943411d-02,-.7879811551212120d-03,
     8      0.4824733195857951d-03,-.2781153477368914d-03/
         data arr1988/
     1      0.1518987893913595d-03,-.7850221064440932d-04,
     2      0.3882552694983862d-04,-.1765884760308272d-04,
     3      0.8021251751714795d-05,-.3073840642727169d-05,
     4      0.1283335268115768d-05,0.1368301525251897d-02,
     5      -.3210335430429795d-02,0.5247126039550767d-02,
     6      -.6901633743125805d-02,0.7751690272042360d-02,
     7      -.7681308712758140d-02,0.6856356498382297d-02,
     8      -.5592676379536104d-02,0.4213811621846799d-02/
         data arr1989/
     1      -.2956151894313916d-02,0.1944171553393222d-02,
     2      -.1202954284917632d-02,0.7057889327293034d-03,
     3      -.3910559259566590d-03,0.2077680300633006d-03,
     4      -.1003413761387340d-03,0.4900665277467414d-04,
     5      -.1982015481421248d-04,0.8889102962821526d-05,
     6      0.2523391678519843d-02,-.6335744213255649d-02,
     7      0.1108186919385550d-01,-.1559864398933462d-01,
     8      0.1874891079577047d-01,-.1988190078162072d-01/
         data arr1990/
     1      0.1899155324938505d-01,-.1657715654352073d-01,
     2      0.1336643485930945d-01,-.1003361987901955d-01,
     3      0.7061820261081923d-02,-.4671182848272359d-02,
     4      0.2933434333860801d-02,-.1734908482123766d-02,
     5      0.9866107036355896d-03,-.5028902760090276d-03,
     6      0.2631789449143579d-03,-.1117970848043917d-03,
     7      0.5366923394751512d-04,0.4379130885587907d-02,
     8      -.1172732664295513d-01,0.2187823713270171d-01/
         data arr1991/
     1      -.3284594579889603d-01,0.4210851528336573d-01,
     2      -.4762631048384939d-01,0.4852301269266241d-01,
     3      -.4517032132930726d-01,0.3884797807161341d-01,
     4      -.3109674551376929d-01,0.2334450155945264d-01,
     5      -.1644392541876827d-01,0.1101733728495438d-01,
     6      -.6926210649052801d-02,0.4202289664622902d-02,
     7      -.2247287664963952d-02,0.1256385586342458d-02,
     8      -.5581088360617842d-03,0.2858770828599545d-03/
         data arr1992/
     1      0.7189156864638713d-02,-.2047283234366307d-01,
     2      0.4061435095335895d-01,-.6483829489218590d-01,
     3      0.8839152665738345d-01,-.1063090163410434d+00,
     4      0.1151754804093938d+00,-.1139916828001102d+00,
     5      0.1042556425360857d+00,-.8871112240044425d-01,
     6      0.7082047646668860d-01,-.5292312575835381d-01,
     7      0.3772179697835194d-01,-.2510555827772126d-01,
     8      0.1620403425281698d-01,-.9038495384450567d-02/
         data arr1993/
     1      0.5383805148183839d-02,-.2490849633345930d-02,
     2      0.1357522956107856d-02,0.1121643891451755d-01,
     3      -.3387316788816855d-01,0.7126177923390539d-01,
     4      -.1206409425723637d+00,0.1744131614050647d+00,
     5      -.2224468705255170d+00,0.2555745212795574d+00,
     6      -.2681522864604676d+00,0.2601057941434626d+00,
     7      -.2345715417333230d+00,0.1986072342603594d+00,
     8      -.1568558226186700d+00,0.1186380082581559d+00/
         data arr1994/
     1      -.8325990608560974d-01,0.5702062697708907d-01,
     2      -.3298280430988033d-01,0.2088326633149947d-01,
     3      -.1002547408530029d-01,0.5799037737147641d-02,
     4      0.1669842648448279d-01,-.5334549164052814d-01,
     5      0.1187178030395881d+00,-.2125893588337068d+00,
     6      0.3251303512300197d+00,-.4386312202750225d+00,
     7      0.5331052386461996d+00,-.5913310291123181d+00,
     8      0.6068677408777027d+00,-.5784184589171530d+00/
         data arr1995/
     1      0.5181391590671356d+00,-.4308052419813887d+00,
     2      0.3450021269822529d+00,-.2543115718465136d+00,
     3      0.1843799360375748d+00,-.1099655170369246d+00,
     4      0.7386019717455949d-01,-.3666721850508410d-01,
     5      0.2246054218232452d-01,0.2380599868800073d-01,
     6      -.8026926882217497d-01,0.1885377051367303d+00,
     7      -.3562797558622928d+00,0.5751337242564766d+00,
     8      -.8188436766905869d+00,0.1050403491609092d+01/
         data arr1996/
     1      -.1228437646875748d+01,0.1331016083525166d+01,
     2      -.1337104094299415d+01,0.1264478177401663d+01,
     3      -.1102305783370300d+01,0.9329112630717937d+00,
     4      -.7194934872152606d+00,0.5511342934195034d+00,
     5      -.3369861764542079d+00,0.2396983043284558d+00,
     6      -.1226649371199334d+00,0.7941708589530361d-01,
     7      0.3260251888569086d-01,-.1157888945902946d+00,
     8      0.2864477523093301d+00,-.5699509158446406d+00/
         data arr1997/
     1      0.9691911582790669d+00,-.1453116733265034d+01,
     2      0.1963400339243883d+01,-.2414278809297608d+01,
     3      0.2756631471053717d+01,-.2910814765498293d+01,
     4      0.2900478114633286d+01,-.2639514204606471d+01,
     5      0.2357108757387357d+01,-.1894637181019758d+01,
     6      0.1530703902863804d+01,-.9541142504338485d+00,
     7      0.7176875755733308d+00,-.3774930236403797d+00,
     8      0.2578866652865901d+00,0.4300998694917316d-01/
         data arr1998/
     1      -.1605985242335567d+00,0.4176615028585132d+00,
     2      -.8730981880715579d+00,0.1561239854096841d+01,
     3      -.2460071249142594d+01,0.3494693557859691d+01,
     4      -.4504976410157325d+01,0.5412169859693515d+01,
     5      -.5990536282259923d+01,0.6279262579217726d+01,
     6      -.5937199146830704d+01,0.5587528697154914d+01,
     7      -.4662852850579625d+01,0.3967556974624493d+01,
     8      -.2506949253086588d+01,0.1991929831688617d+01/
         data arr1999/
     1      -.1073960691542878d+01,0.7730782348926013d+00,
     2      0.5478815083387571d-01,-.2147419655182767d+00,
     3      0.5860648610296435d+00,-.1284220393682559d+01,
     4      0.2411260778790518d+01,-.3985495658255527d+01,
     5      0.5942729965907430d+01,-.8004804492165489d+01,
     6      0.1010633610897255d+02,-.1169265791490643d+02,
     7      0.1287484845046395d+02,-.1258368460659454d+02,
     8      0.1246948592009251d+02,-.1076224750357866d+02/
         data arr2000/
     1      0.9633336422909695d+01,-.6135949822722761d+01,
     2      0.5145743702881294d+01,-.2836672767943157d+01,
     3      0.2149133059242106d+01,0.6752944846961936d-01,
     4      -.2774598074695151d+00,0.7933648275172966d+00,
     5      -.1817647301303029d+01,0.3579560683579401d+01,
     6      -.6194873721632582d+01,0.9681970840207422d+01,
     7      -.1357561154789093d+02,0.1799784412909793d+02,
     8      -.2170085084416771d+02,0.2507387755791044d+02/
        do 1200 i=1,16000
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c
c
c
c
        subroutine lot12getb(arr)
        implicit real *8 (a-h,o-z)
        dimension arr(1)
c
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208( 8)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2)
         real *8
     1  arr2205(2),arr2206(2),arr2207(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2))
c
         data arr1001/
     1      -.2519123119514134d+02,0.2627139085610583d+02,
     2      -.2336220715719907d+02,0.2197955224802710d+02,
     3      -.1403385389952377d+02,0.1241565608652264d+02,
     4      -.6981633631525140d+01,0.5562316201586256d+01,
     5      0.8066816744301968d-01,-.3471056388687555d+00,
     6      0.1038299198450767d+01,-.2479395490631379d+01,
     7      0.5118057806839113d+01,-.9257577775093884d+01,
     8      0.1514793192680293d+02,-.2200949051374454d+02/
         data arr1002/
     1      0.3063095472911584d+02,-.3837059184157882d+02,
     2      0.4648806125348159d+02,-.4771708648592905d+02,
     3      0.5237032384041675d+02,-.4780454439235965d+02,
     4      0.4724793310914735d+02,-.3007091081277060d+02,
     5      0.2806193743084356d+02,-.1606109297898530d+02,
     6      0.1344863718958878d+02,0.9349868928943805d-01,
     7      -.4211436635522867d+00,0.1316010265102834d+01,
     8      -.3262059082195543d+01,0.7058430425747078d+01/
         data arr1003/
     1      -.1332088720828492d+02,0.2280095401756742d+02,
     2      -.3414101085505847d+02,0.4989601496426431d+02,
     3      -.6472346640675650d+02,0.8220006950893860d+02,
     4      -.8562460074361745d+02,0.9894812339902030d+02,
     5      -.9237398039785222d+02,0.9590184107035611d+02,
     6      -.6049205030253616d+02,0.5956604874108901d+02,
     7      -.3462782209574145d+02,0.3046863422099993d+02,
     8      0.1052103402226924d+00,-.4963449000173353d+00/
         data arr1004/
     1      0.1618190718561412d+01,-.4140383038450998d+01,
     2      0.9401796435016337d+01,-.1848331985894673d+02,
     3      0.3308559494182715d+02,-.5071092501759134d+02,
     4      0.7792861184505038d+02,-.1043257577927175d+03,
     5      0.1389392664983177d+03,-.1457942293661787d+03,
     6      0.1776314138611343d+03,-.1689935001388827d+03,
     7      0.1843907596954009d+03,-.1145760596980540d+03,
     8      0.1191751530739283d+03,-.7023220219961729d+02/
         data arr1005/
     1      0.6496204937804602d+02,-.2595627368039221d-19,
     2      0.1281580865780061d-21,-.7145072879416564d-21,
     3      0.4058215041118348d-22,-.1016584572398083d-19,
     4      0.3496407534418990d-21,-.2740353672043514d-19,
     5      0.9261556955429988d-21,-.1215414845199727d-18,
     6      0.3309219330185195d-20,-.1709876513338668d-18,
     7      0.4645151662310498d-20,-.3800713368568502d-18,
     8      0.9132992268316461d-20,-.2470595205962359d-18/
         data arr1006/
     1      0.6000899029015131d-20,-.3032376254921390d-18,
     2      0.6760158226455980d-20,-.2447335336586245d-19,
     3      0.6309429172111120d-21,-.6852744297720684d-21,
     4      0.2000659066585557d-21,-.9608183737849634d-20,
     5      0.1722505517925101d-20,-.2590027731594066d-19,
     6      0.4562709658339352d-20,-.1148742277646357d-18,
     7      0.1630288371218578d-19,-.1616080764146187d-18,
     8      0.2288437562388860d-19,-.3592225075521705d-18/
         data arr1007/
     1      0.4499374509538297d-19,-.2335072235327732d-18,
     2      0.2956348618565784d-19,-.2866036362066046d-18,
     3      0.3330395687708953d-19,-.2208141701542049d-19,
     4      0.1377958870915267d-20,-.6710307741869181d-21,
     5      0.4399494874896363d-21,-.8774570796497230d-20,
     6      0.3774766188018396d-20,-.2365303776268410d-19,
     7      0.9998928023744974d-20,-.1049074865947614d-18,
     8      0.3572689485538038d-19,-.1475870246029891d-18/
         data arr1008/
     1      0.5015005085421941d-19,-.3280569171914541d-18,
     2      0.9860157881282971d-19,-.2132492497414350d-18,
     3      0.6478713063342587d-19,-.2617389159707035d-18,
     4      0.7298391604067258d-19,-.5507440835995993d-22,
     5      0.2145257622448086d-21,-.2372070276980517d-21,
     6      0.1338529875255776d-20,-.5386648380076350d-20,
     7      0.1371838073806757d-19,-.1304736098995765d-19,
     8      0.3692432361386442d-19,-.7113659079546189d-19/
         data arr1009/
     1      0.1447462554762512d-18,-.9874806498288481d-19,
     2      0.2116056666739994d-18,-.2483019810161862d-18,
     3      0.4342687595743765d-18,-.1635569199908263d-18,
     4      0.2970187947764738d-18,-.2163821102063113d-18,
     5      0.3337494450691897d-18,-.1944715020826870d-19,
     6      0.3306546477140642d-20,-.3919773315733159d-21,
     7      0.3742404842203897d-22,-.3054111027484442d-23,
     8      0.2195403307839667d-24,-.1295432075335544d-25/
         data arr1010/
     1      -.1629870108000810d-26,-.8058836222867858d-26,
     2      -.4377453389597242d-26,0.1196871434132496d-26,
     3      -.1116173380360968d-25,-.3110424579749571d-25,
     4      -.1039203511367053d-25,-.6045801560094249d-26,
     5      -.1227179896292287d-25,-.3578474316953998d-25,
     6      -.3379455526044228d-26,-.6623016569876471d-17,
     7      0.1606994879677670d-17,-.2718572493153811d-18,
     8      0.3704009589651495d-19,-.4312637635247376d-20/
         data arr1011/
     1      0.4433207610827878d-21,-.4107745677861735d-22,
     2      0.3480107173706094d-23,-.2708425352427646d-24,
     3      0.1677026419780924d-25,0.4327513592231616d-27,
     4      -.3617600800966607d-26,0.6247390695600244d-26,
     5      -.1019024068309028d-25,0.3406714159021482d-26,
     6      -.6036552168256368d-26,0.5926752776995310d-26,
     7      -.8919470296082627d-26,-.7542485487991615d-15,
     8      0.2452908137319835d-15,-.5561806286259155d-16/
         data arr1012/
     1      0.1015676004066051d-16,-.1585018081927939d-17,
     2      0.2183824521390720d-18,-.2712145222250299d-19,
     3      0.3080156717295265d-20,-.3232987159361760d-21,
     4      0.3161905823225285d-22,-.2900151778090719d-23,
     5      0.2507563758940973d-24,-.2047961234096343d-25,
     6      0.1502428325564058d-26,-.8438939168524465d-28,
     7      -.5129554915801883d-28,0.5246038885267624d-28,
     8      -.8074736940566777d-28,-.3889259956031160d-13/
         data arr1013/
     1      0.1620588209033179d-13,-.4708105124422813d-14,
     2      0.1101601165679123d-14,-.2202633893075940d-15,
     3      0.3888344510409590d-16,-.6187266760076647d-17,
     4      0.9003214913235980d-18,-.1210786872635581d-18,
     5      0.1517231847054255d-19,-.1783057416203554d-20,
     6      0.1975615853735030d-21,-.2072877819584954d-22,
     7      0.2067614288723355d-23,-.1966055854983943d-24,
     8      0.1805416072193770d-25,-.1652747662623524d-26/
         data arr1014/
     1      0.4483233650583050d-27,-.1102254351327131d-11,
     2      0.5689033858942933d-12,-.2047212803756342d-12,
     3      0.5933244132604893d-13,-.1469471417935199d-13,
     4      0.3213176309524103d-14,-.6333148247398509d-15,
     5      0.1141482938506830d-15,-.1901474495815583d-16,
     6      0.2951384149303753d-17,-.4296255662730881d-18,
     7      0.5896281413153382d-19,-.7662998911172555d-20,
     8      0.9465884944234324d-21,-.1114850521984696d-21/
         data arr1015/
     1      0.1254670630723203d-22,-.1336412158298228d-23,
     2      0.1172654308081711d-24,-.1957717975173452d-10,
     3      0.1219163831421591d-10,-.5293486206494818d-11,
     4      0.1851084568000683d-11,-.5531595697155701d-12,
     5      0.1459415949865525d-12,-.3470718824523212d-13,
     6      0.7547870613602180d-14,-.1517053063932732d-14,
     7      0.2841130963269110d-15,-.4990118459239291d-16,
     8      0.8263313259338432d-17,-.1295775386315082d-17/
         data arr1016/
     1      0.1931319966952420d-18,-.2743996955899273d-19,
     2      0.3728802797197412d-20,-.4810727336655252d-21,
     3      0.5970718349864944d-22,-.2391015110916283d-09,
     4      0.1759432731997729d-09,-.9026736966142433d-10,
     5      0.3729869754838555d-10,-.1317031739678648d-10,
     6      0.4105852127844421d-11,-.1153777463969708d-11,
     7      0.2964868746588204d-12,-.7041419222053440d-13,
     8      0.1558221123473385d-13,-.3233903286686862d-14/
         data arr1017/
     1      0.6327742640451796d-15,-.1172468599301375d-15,
     2      0.2064926582281208d-16,-.3465660291956157d-17,
     3      0.5565143668397168d-18,-.8454982715372024d-19,
     4      0.1247486082770195d-19,-.2149322228094058d-08,
     5      0.1837318528180830d-08,-.1095053034743544d-08,
     6      0.5256426672657957d-09,-.2156183722164068d-09,
     7      0.7808819855581021d-10,-.2549157854903982d-10,
     8      0.7609790979623296d-11,-.2099520086055283d-11/
         data arr1018/
     1      0.5397361383731496d-12,-.1301283154744296d-12,
     2      0.2957918411253105d-13,-.6366895298930620d-14,
     3      0.1302637094570542d-14,-.2538556068869801d-15,
     4      0.4735662736427200d-16,-.8321173085303050d-17,
     5      0.1426609072899430d-17,-.1496789558511879d-07,
     6      0.1465613324336151d-07,-.1000566223965254d-07,
     7      0.5501448234870339d-08,-.2584924833370114d-08,
     8      0.1072317256607288d-08,-.4009685917849564d-09/
         data arr1019/
     1      0.1371077768709360d-09,-.4332964431987996d-10,
     2      0.1275916698768403d-10,-.3523609625581237d-11,
     3      0.9174406409972273d-12,-.2261975666136445d-12,
     4      0.5301010054399894d-13,-.1182400278800672d-13,
     5      0.2526671004668052d-14,-.5058379823236344d-15,
     6      0.9927857915553522d-16,-.8401238554104255d-07,
     7      0.9311860988787383d-07,-.7196103901135722d-07,
     8      0.4478815013906265d-07,-.2382146797251106d-07/
         data arr1020/
     1      0.1118609245889100d-07,-.4734781800503254d-08,
     2      0.1832678190344865d-08,-.6556072301368134d-09,
     3      0.2185321982195328d-09,-.6831466452358104d-10,
     4      0.2013440553429819d-10,-.5619129137792282d-11,
     5      0.1490640165023586d-11,-.3759312548338455d-12,
     6      0.9093901260429610d-13,-.2048034531553603d-13,
     7      0.4547337178302769d-14,-.3920965668676103d-06,
     8      0.4870182728869940d-06,-.4217598621594482d-06/
         data arr1021/
     1      0.2941643207696130d-06,-.1753292765140953d-06,
     2      0.9226210809791816d-07,-.4376268674920920d-07,
     3      0.1898231914241768d-07,-.7609669318806185d-08,
     4      0.2842474122807804d-08,-.9957507543147741d-09,
     5      0.3288781197054769d-09,-.1028485106869922d-09,
     6      0.3057442856029785d-10,-.8626157298107361d-11,
     7      0.2338579879599102d-11,-.5859725331848822d-12,
     8      0.1456995336927690d-12,-.1560176439562692d-05/
         data arr1022/
     1      0.2152887881777031d-05,-.2071270810314291d-05,
     2      0.1604933771354073d-05,-.1062715566384328d-05,
     3      0.6212715350539939d-06,-.3273840409263573d-06,
     4      0.1577605052562892d-06,-.7026032078644578d-07,
     5      0.2915656162916611d-07,-.1134693173688567d-07,
     6      0.4163505788193356d-08,-.1446345136730414d-08,
     7      0.4776651481100472d-09,-.1493624444141473d-09,
     8      0.4499048192770423d-10,-.1242225839731786d-10/
         data arr1023/
     1      0.3428872248568061d-11,-.5401709477016780d-05,
     2      0.8218780729572732d-05,-.8718692048281383d-05,
     3      0.7449035481327453d-05,-.5438616595924003d-05,
     4      0.3505753120419163d-05,-.2036975201796050d-05,
     5      0.1082318358129913d-05,-.5314898219856248d-06,
     6      0.2431921285947966d-06,-.1043529713954538d-06,
     7      0.4221977444704651d-07,-.1616891879917402d-07,
     8      0.5887818262107815d-08,-.2023402273794430d-08/
         data arr1024/
     1      0.6721380513028851d-09,-.2027690060382480d-09,
     2      0.6166404812166517d-10,-.1654862381803499d-04,
     3      0.2758086989573635d-04,-.3204954033463530d-04,
     4      0.2999441636496655d-04,-.2398825871098006d-04,
     5      0.1693797582847074d-04,-.1078041589171133d-04,
     6      0.6274437199166302d-05,-.3375077229869996d-05,
     7      0.1691640123182185d-05,-.7950665720287362d-06,
     8      0.3523612812038796d-06,-.1477751568137785d-06/
         data arr1025/
     1      0.5894333401021463d-07,-.2209231433442927d-07,
     2      0.8040466932318373d-08,-.2630289081827334d-08,
     3      0.8754644444583063d-09,-.4549371285040322d-04,
     4      0.8257503204510278d-04,-.1044994192548847d-03,
     5      0.1065083817931369d-03,-.9276697554336550d-04,
     6      0.7133578731728805d-04,-.4944608858525975d-04,
     7      0.3134171024455383d-04,-.1836035091573746d-04,
     8      0.1002203935481868d-04,-.5129180751588170d-05/
         data arr1026/
     1      0.2475659348149330d-05,-.1130232881638293d-05,
     2      0.4909509246052172d-06,-.1992654902006898d-06,
     3      0.7900408994028695d-07,-.2783619454511157d-07,
     4      0.1008143274225084d-07,-.1135599245212656d-03,
     5      0.2233269255808874d-03,-.3062138250118088d-03,
     6      0.3381530801842688d-03,-.3191108817241425d-03,
     7      0.2658730099111152d-03,-.1996711630917678d-03,
     8      0.1371277031234165d-03,-.8703583651028637d-04/
         data arr1027/
     1      0.5147436633615637d-04,-.2853673562806790d-04,
     2      0.1492375696804718d-04,-.7377250970040814d-05,
     3      0.3471871479302025d-05,-.1515767569863313d-05,
     4      0.6513812524070489d-06,-.2456886230256529d-06,
     5      0.9632592559024152d-07,-.2599779112245889d-03,
     6      0.5514183039114296d-03,-.8154427740082130d-03,
     7      0.9712048537886446d-03,-.9884801215060720d-03,
     8      0.8882376834524234d-03,-.7194396130136244d-03/
         data arr1028/
     1      0.5328856997814351d-03,-.3647773588911766d-03,
     2      0.2326740401382098d-03,-.1390670904173723d-03,
     3      0.7844194092726165d-04,-.4178207000047026d-04,
     4      0.2120616982318745d-04,-.9895177023779379d-05,
     5      0.4588508626712461d-05,-.1842530236494582d-05,
     6      0.7784686024190599d-06,-.5505680638150699d-03,
     7      0.1254303110480204d-02,-.1992329547912679d-02,
     8      0.2548739723755828d-02,-.2786311069008339d-02/
         data arr1029/
     1      0.2689288034554700d-02,-.2339585411324190d-02,
     2      0.1861349358606485d-02,-.1368528455435105d-02,
     3      0.9376005726670665d-03,-.6015462663390183d-03,
     4      0.3644813924092708d-03,-.2082557382514939d-03,
     5      0.1135232271776528d-03,-.5626618788655757d-04,
     6      0.2804272937693286d-04,-.1192835191021665d-04,
     7      0.5409025779475670d-05,-.1086571683206709d-02,
     8      0.2649073964910178d-02,-.4502937387561964d-02/
         data arr1030/
     1      0.6164601540366881d-02,-.7211972065457070d-02,
     2      0.7449125990536848d-02,-.6934727922714036d-02,
     3      0.5904294167030424d-02,-.4645281144441211d-02,
     4      0.3405772616560234d-02,-.2336031467219391d-02,
     5      0.1514909899798027d-02,-.9246496053972419d-03,
     6      0.5393533697752902d-03,-.2822336702912061d-03,
     7      0.1506533178246607d-03,-.6757303347560044d-04,
     8      0.3276896756868053d-04,-.2011222852477326d-02/
         data arr1031/
     1      0.5229902285800714d-02,-.9481789124578826d-02,
     2      0.1384518011972175d-01,-.1727615427811020d-01,
     3      0.1903244834653124d-01,-.1889612893748621d-01,
     4      0.1716010797864888d-01,-.1439848805435021d-01,
     5      0.1125929158271903d-01,-.8224422152281913d-02,
     6      0.5689861338556706d-02,-.3695341423631832d-02,
     7      0.2298853683076734d-02,-.1262498080079665d-02,
     8      0.7195181066874756d-03,-.3388911845041673d-03/
         data arr1032/
     1      0.1751913346948113d-03,-.3511076561414772d-02,
     2      0.9708704562165217d-02,-.1871710825449386d-01,
     3      0.2906287664539522d-01,-.3856372178997036d-01,
     4      0.4517638130737650d-01,-.4768625414792937d-01,
     5      0.4605210803989677d-01,-.4108281168413210d-01,
     6      0.3416108689359891d-01,-.2647376005918147d-01,
     7      0.1948220960090906d-01,-.1341308277859848d-01,
     8      0.8872383691257871d-02,-.5083691453594700d-02/
         data arr1033/
     1      0.3084824753546257d-02,-.1519902249425377d-02,
     2      0.8352185509889823d-03,-.5809267370232290d-02,
     3      0.1703490869579787d-01,-.3482560470104012d-01,
     4      0.5734631350697181d-01,-.8069623372904099d-01,
     5      0.1002486095467022d+00,-.1121765161371639d+00,
     6      0.1148938308378708d+00,-.1086645505928502d+00,
     7      0.9581723834206413d-01,-.7848207932413591d-01,
     8      0.6127712231060497d-01,-.4456193399696146d-01/
         data arr1034/
     1      0.3125753784723390d-01,-.1857641909550613d-01,
     2      0.1197278532727860d-01,-.6149329062355476d-02,
     3      0.3583085173333223d-02,-.9148951116108570d-02,
     4      0.2837935299863816d-01,-.6136745811341546d-01,
     5      0.1069005290003440d+00,-.1591338963091028d+00,
     6      0.2091185442717764d+00,-.2473723919106538d+00,
     7      0.2680615430996333d+00,-.2680776127563405d+00,
     8      0.2500431463747366d+00,-.2156197548209782d+00/
         data arr1035/
     1      0.1782110324183529d+00,-.1364151682835905d+00,
     2      0.1012225572972907d+00,-.6203092178488599d-01,
     3      0.4237385004619242d-01,-.2261430452600346d-01,
     4      0.1394132656857631d-01,-.1376709271593191d-01,
     5      0.4507059283076948d-01,-.1028422976110603d+00,
     6      0.1890961228038396d+00,-.2971211988262144d+00,
     7      0.4120708839311067d+00,-.5138930538281894d+00,
     8      0.5879119469080493d+00,-.6201528176321678d+00/
         data arr1036/
     1      0.6104700267174554d+00,-.5519439051492052d+00,
     2      0.4819508094241550d+00,-.3870091953458499d+00,
     3      0.3031238827047210d+00,-.1904285771755129d+00,
     4      0.1376194722165961d+00,-.7609155000841547d-01,
     5      0.4953613407977103d-01,-.1986114859417088d-01,
     6      0.6847938860307708d-01,-.1645070740904001d+00,
     7      0.3186436431242831d+00,-.5274261396523595d+00,
     8      0.7703565020928017d+00,-.1009958253148927d+01/
         data arr1037/
     1      0.1217551042972312d+01,-.1351502450102134d+01,
     2      0.1401194825931298d+01,-.1322391420848679d+01,
     3      0.1217878994560056d+01,-.1022536012614158d+01,
     4      0.8437922216678944d+00,-.5402371852733217d+00,
     5      0.4123975857074208d+00,-.2355945801079195d+00,
     6      0.1617007407622165d+00,-.2755352563172837d-01,
     7      0.9985775165718126d-01,-.2519663783566538d+00,
     8      0.5132501125396249d+00,-.8933839826602459d+00/
         data arr1038/
     1      0.1371551879550346d+01,-.1884512099024843d+01,
     2      0.2390255354872855d+01,-.2785778940064314d+01,
     3      0.3036264734252441d+01,-.2976660127643672d+01,
     4      0.2887484705971098d+01,-.2526699316276528d+01,
     5      0.2193094688788950d+01,-.1422635774293439d+01,
     6      0.1145671783301829d+01,-.6745552056278760d+00,
     7      0.4874652450817587d+00,-.3686042695278213d-01,
     8      0.1401503117291310d+00,-.3704992577654307d+00/
         data arr1039/
     1      0.7925606363854270d+00,-.1448666028933066d+01,
     2      0.2333444662496911d+01,-.3348386440531032d+01,
     3      0.4462791524998292d+01,-.5449439756971890d+01,
     4      0.6233683235867564d+01,-.6314599389109071d+01,
     5      0.6445206898446092d+01,-.5859712476252879d+01,
     6      0.5342402416071269d+01,-.3490583762892779d+01,
     7      0.2962654554013566d+01,-.1793692946771470d+01,
     8      0.1363318999633349d+01,-.4767233879564442d-01/
         data arr1040/
     1      0.1898048880408310d+00,-.5240938870333678d+00,
     2      0.1176206759283250d+01,-.2255164466348363d+01,
     3      0.3804740376489069d+01,-.5678062507583257d+01,
     4      0.7945746709620360d+01,-.1014459191861324d+02,
     5      0.1216237570767451d+02,-.1265510555942008d+02,
     6      0.1358222958736518d+02,-.1279124065609491d+02,
     7      0.1223686688747280d+02,-.8005141151706034d+01,
     8      0.7156357681364304d+01,-.4445801270472995d+01/
         data arr1041/
     1      0.3551403360716487d+01,-.5975258954607544d-01,
     2      0.2486128443774070d+00,-.7141528352180059d+00,
     3      0.1680788154628128d+01,-.3378390670148146d+01,
     4      0.5960520383617327d+01,-.9203782058402139d+01,
     5      0.1351812465973786d+02,-.1801083559293013d+02,
     6      0.2260577602686239d+02,-.2400293648820612d+02,
     7      0.2708199511542655d+02,-.2634399168889279d+02,
     8      0.2642566121565372d+02,-.1720385305724911d+02/
         data arr1042/
     1      0.1619475528642775d+02,-.1030333909194011d+02,
     2      0.8646784335049965d+01,-.7275961349977812d-01,
     3      0.3156152765349730d+00,-.9378388617607922d+00,
     4      0.2315674552859713d+01,-.4880000595598824d+01,
     5      0.8990539317260614d+01,-.1427178808633380d+02,
     6      0.2200760221303081d+02,-.3054542547017089d+02,
     7      0.4010469873788941d+02,-.4313839074957183d+02,
     8      0.5118136854475031d+02,-.5128657956059693d+02/
         data arr1043/
     1      0.5392664779152945d+02,-.3472001424215753d+02,
     2      0.3442213045088910d+02,-.2238781351445479d+02,
     3      0.1973871271623827d+02,-.8631865333015899d-01,
     4      0.3892403367330982d+00,-.1186482644200707d+01,
     5      0.3079041848391849d+01,-.6811322592310147d+01,
     6      0.1308784472812305d+02,-.2118506549060153d+02,
     7      0.3434132436602418d+02,-.4958372256991289d+02,
     8      0.6808587917886405d+02,-.7358427554501245d+02/
         data arr1044/
     1      0.9190201704972429d+02,-.9463556724374335d+02,
     2      0.1043402555435686d+03,-.6599360279267252d+02,
     3      0.6897009477253258d+02,-.4578428745095243d+02,
     4      0.4243573974224890d+02,0.7266618221524741d-21,
     5      -.3329095651600719d-23,0.9655672515447074d-23,
     6      -.1249263426174129d-23,0.2172788408540853d-21,
     7      -.2224040137659159d-23,0.4896430483515929d-21,
     8      -.1974252170982317d-22,0.2630721027549241d-20/
         data arr1045/
     1      -.2331917468870477d-22,0.3376458367731100d-20,
     2      -.7554653548888569d-22,0.8492188771011022d-20,
     3      -.4408090966375142d-22,0.5179905330828329d-20,
     4      -.7200817559005105d-22,0.7075149694080136d-20,
     5      0.6851403331100518d-21,-.1638900750523876d-22,
     6      0.9390202897506370d-23,-.6158063932065822d-23,
     7      0.2053597481181317d-21,-.1095670932008079d-22,
     8      0.4627828836722565d-21,-.9726161985820098d-22/
         data arr1046/
     1      0.2486410772563798d-20,-.1148819127323985d-21,
     2      0.3191241098327489d-20,-.3721806231631178d-21,
     3      0.8026349206912124d-20,-.2171649017133791d-21,
     4      0.4895763853664892d-20,-.3547491928692036d-21,
     5      0.6687045650442302d-20,0.6181488878389355d-21,
     6      -.3578571163992546d-22,0.9774497228062378d-23,
     7      -.1353425873202712d-22,0.1875429753703909d-21,
     8      -.2401068846125997d-22,0.4226289885897020d-21/
         data arr1047/
     1      -.2131436105342649d-21,0.2270684670213625d-20,
     2      -.2517563886133039d-21,0.2914367025493730d-20,
     3      -.8156169687393834d-21,0.7329994667061264d-20,
     4      -.4759063857888886d-21,0.4471026216850894d-20,
     5      -.7774204106814069d-21,0.6106904437289561d-20,
     6      0.5359472907524401d-21,-.5644659486736008d-22,
     7      0.1162182063051598d-22,-.2173565625083500d-22,
     8      0.1681095197377176d-21,-.3825489216149073d-22/
         data arr1048/
     1      0.3788087543046029d-21,-.3396003802292473d-21,
     2      0.2035274437613935d-20,-.4011167859472284d-21,
     3      0.2612235245824957d-20,-.1299531364906590d-20,
     4      0.6570137075848136d-20,-.7582638997940621d-21,
     5      0.4007570619574645d-20,-.1238688498076786d-20,
     6      0.5473880588663100d-20,0.5512908069754901d-21,
     7      -.9029692406849767d-22,0.9192648548278932d-23,
     8      -.1339240965945044d-22,0.3448459367478182d-22/
         data arr1049/
     1      0.4866648301002027d-23,0.2188634615281120d-22,
     2      -.1832411781399453d-21,0.4277557317504502d-21,
     3      -.9635516325572845d-22,0.3527273109143093d-21,
     4      -.7553558281196755d-21,0.1561524137111648d-20,
     5      -.3084778104026508d-21,0.7536336595191121d-21,
     6      -.8314353038516556d-21,0.1528716165819929d-20,
     7      0.2678324799551477d-18,-.6320552667322650d-19,
     8      0.1040736814291451d-19,-.1381148397971650d-20/
         data arr1050/
     1      0.1567407827014525d-21,-.1571433102707439d-22,
     2      0.1418026902366444d-23,-.1020528521159725d-24,
     3      0.4436426042141204d-25,0.8340242349392133d-26,
     4      0.7855797693845730d-26,0.6343613263536132d-25,
     5      0.1307794109792930d-24,0.2679921098800879d-25,
     6      0.3882736662796504d-25,0.6896987715959478d-25,
     7      0.1387201288870646d-24,0.4088180228864895d-16,
     8      -.1293093695855747d-16,0.2853803203711488d-17/
         data arr1051/
     1      -.5076120384166800d-18,0.7720985642068867d-19,
     2      -.1037520379979951d-19,0.1257468656102999d-20,
     3      -.1394488152874590d-21,0.1430045557531750d-22,
     4      -.1367065181201257d-23,0.1224697854936534d-24,
     5      -.1042902424084268d-25,0.1503506673300146d-26,
     6      0.4221367087518291d-28,-.4635675402970568d-28,
     7      -.7519356280628012d-28,0.7999238666141147d-27,
     8      0.2700980348388635d-14,-.1094612207343650d-14/
         data arr1052/
     1      0.3095232065390660d-15,-.7054073976133666d-16,
     2      0.1374737385449531d-16,-.2366914322274865d-17,
     3      0.3675547097151043d-18,-.5222500243453141d-19,
     4      0.6861939101980953d-20,-.8405413244325845d-21,
     5      0.9660947679834391d-22,-.1047397970456435d-22,
     6      0.1075661468887206d-23,-.1050464243470733d-24,
     7      0.9712431150215549d-26,-.8010347528723793d-27,
     8      -.8545485978342273d-28,0.9481723098238233d-13/
         data arr1053/
     1      -.4759673088855765d-13,0.1667097681374383d-13,
     2      -.4706074904465790d-14,0.1136029378806482d-14,
     3      -.2422720705759173d-15,0.4660084582418229d-16,
     4      -.8201650721903263d-17,0.1334813705788025d-17,
     5      -.2025274336610788d-18,0.2883338748117510d-19,
     6      -.3872050672150385d-20,0.4926287025949795d-21,
     7      -.5959147087241171d-22,0.6877649695876006d-23,
     8      -.7566576501687560d-24,0.7904011715458954d-25/
         data arr1054/
     1      0.2031939719035986d-11,-.1230710544455996d-11,
     2      0.5201098627281717d-12,-.1771528413163483d-12,
     3      0.5159814573609331d-13,-.1327709700062812d-13,
     4      0.3081405274653343d-14,-.6543521561084126d-15,
     5      0.1284949825716958d-15,-.2352364398499647d-16,
     6      0.4040839969506249d-17,-.6547447881813682d-18,
     7      0.1005093420292983d-18,-.1466747957687492d-19,
     8      0.2042497399109151d-20,-.2706664638880104d-21/
         data arr1055/
     1      0.3448125825119348d-22,0.2932387886662884d-10,
     2      -.2098673715751170d-10,0.1048002927428827d-10,
     3      -.4217877219552414d-11,0.1451637941074660d-11,
     4      -.4413729858442269d-12,0.1210402597242430d-12,
     5      -.3037183053104776d-13,0.7047320198618821d-14,
     6      -.1524476625655988d-14,0.3094327235609255d-15,
     7      -.5924402309590333d-16,0.1074624885354244d-16,
     8      -.1852524485291718d-17,0.3048284258799737d-18/
         data arr1056/
     1      -.4763451883091694d-19,0.7166980248235819d-20,
     2      0.3062197546968061d-09,-.2545946591763317d-09,
     3      0.1476928392369219d-09,-.6905314373942543d-10,
     4      0.2760834736481551d-10,-.9751702116394560d-11,
     5      0.3106684158192924d-11,-.9055882999003329d-12,
     6      0.2441048542778235d-12,-.6134307587998983d-13,
     7      0.1446450698611622d-13,-.3217165259110817d-14,
     8      0.6779180405067951d-15,-.1356985189636721d-15/
         data arr1057/
     1      0.2594009988502171d-16,-.4697320443868360d-17,
     2      0.8201736421225314d-18,0.2442688873893676d-08,
     3      -.2326269218851695d-08,0.1545773507978523d-08,
     4      -.8278384826235101d-09,0.3791214018732102d-09,
     5      -.1533889420063199d-09,0.5597401551449181d-10,
     6      -.1868942337801479d-10,0.5770550490529686d-11,
     7      -.1661045481947979d-11,0.4486373798347405d-12,
     8      -.1142979731747902d-12,0.2758771685881509d-13/
         data arr1058/
     1      -.6320753403628573d-14,0.1384081440578468d-14,
     2      -.2862392217150366d-15,0.5717584609417673d-16,
     3      0.1551976831465096d-07,-.1673060173304173d-07,
     4      0.1258438378413088d-07,-.7628975376729593d-08,
     5      0.3954880916800774d-08,-.1811271966893608d-08,
     6      0.7481877380361052d-09,-.2827838111454052d-09,
     7      0.9883491119015691d-10,-.3220384039936221d-10,
     8      0.9845921790969874d-11,-.2839417743531715d-11/
         data arr1059/
     1      0.7757762973747655d-12,-.2009726512620794d-12,
     2      0.4981906576696290d-13,-.1162228272695231d-13,
     3      0.2624062111876765d-14,0.8116971214804614d-07,
     4      -.9805717617863469d-07,0.8265303873030167d-07,
     5      -.5615030678415849d-07,0.3261958116019331d-07,
     6      -.1674124185528426d-07,0.7749499333134700d-08,
     7      -.3282287992677660d-08,0.1285557525520083d-08,
     8      -.4694013609420726d-09,0.1608247033747548d-09/
         data arr1060/
     1      -.5197280492966735d-10,0.1591234299837678d-10,
     2      -.4611914865466156d-11,0.1281282696730415d-11,
     3      -.3336310566134473d-12,0.8427129942977039d-13,
     4      0.3588146469690469d-06,-.4815606816058069d-06,
     5      0.4509474595866421d-06,-.3403413652073611d-06,
     6      0.2196526582454774d-06,-.1252394610832851d-06,
     7      0.6440545640324360d-07,-.3030548733842432d-07,
     8      0.1318655791879372d-07,-.5348993715857780d-08/
         data arr1061/
     1      0.2035998257376946d-08,-.7309394494819010d-09,
     2      0.2486110758754912d-09,-.7986479020343493d-10,
     3      0.2465358064486467d-10,-.7099560825889340d-11,
     4      0.1988472045211011d-11,0.1369796788397816d-05,
     5      -.2027054723320050d-05,0.2092998281507209d-05,
     6      -.1741751306749974d-05,0.1239470914274534d-05,
     7      -.7792367058024834d-06,0.4418546156714067d-06,
     8      -.2292486090886976d-06,0.1099879262107145d-06/
         data arr1062/
     1      -.4919243878340399d-07,0.2064595878526031d-07,
     2      -.8172272988972711d-08,0.3064690270119209d-08,
     3      -.1082093904373289d-08,0.3683907734767374d-09,
     4      -.1163828025112927d-09,0.3586689562998171d-10,
     5      0.4596811651600214d-05,-.7451366714724009d-05,
     6      0.8427703420718401d-05,-.7682391739926329d-05,
     7      0.5988478987528425d-05,-.4124004244264122d-05,
     8      0.2561528194978436d-05,-.1455783889190064d-05/
         data arr1063/
     1      0.7650755422445141d-06,-.3747976104404562d-06,
     2      0.1723094501942810d-06,-.7470464533487337d-07,
     3      0.3068480857850761d-07,-.1181724247269147d-07,
     4      0.4408109933332499d-08,-.1516940064905545d-08,
     5      0.5109096678857282d-09,0.1376250537240324d-04,
     6      -.2429562074000292d-04,0.2992627152106893d-04,
     7      -.2970921632086041d-04,0.2522101225319783d-04,
     8      -.1891539181598644d-04,0.1279519872254698d-04/
         data arr1064/
     1      -.7919492306458507d-05,0.4532672040549884d-05,
     2      -.2417914438717649d-05,0.1210640079275112d-05,
     3      -.5715376714392143d-06,0.2556313754338667d-06,
     4      -.1066173810861628d-06,0.4332891844533035d-07,
     5      -.1613911831703613d-07,0.5905064467332819d-08,
     6      0.3722115461733045d-04,-.7119326058208286d-04,
     7      0.9501281042168894d-04,-.1021973479359935d-03,
     8      0.9400033521743273d-04,-.7638327606799426d-04/
         data arr1065/
     1      0.5598214004177412d-04,-.3754231934858030d-04,
     2      0.2328054068467951d-04,-.1345229939875353d-04,
     3      0.7298070069251298d-05,-.3732224778390180d-05,
     4      0.1808299467894612d-05,-.8113051735938694d-06,
     5      0.3574074984953975d-06,-.1432822752143713d-06,
     6      0.5664964021578936d-07,0.9190305397810138d-04,
     7      -.1895865274200079d-03,0.2728849805074970d-03,
     8      -.3165676498988227d-03,0.3140397365114919d-03/
         data arr1066/
     1      -.2752175957338501d-03,0.2175495768816174d-03,
     2      -.1573490297932782d-03,0.1052343804289318d-03,
     3      -.6555645080300656d-04,0.3836081302093799d-04,
     4      -.2115189937217576d-04,0.1104990635367411d-04,
     5      -.5298735609708998d-05,0.2519128265275300d-05,
     6      -.1081425567985967d-05,0.4598356812983449d-06,
     7      0.2090505450796891d-03,-.4632067135884741d-03,
     8      0.7161338350814538d-03,-.8923385932852156d-03/
         data arr1067/
     1      0.9508092390630759d-03,-.8949903667558445d-03,
     2      0.7598918822186084d-03,-.5903576426657698d-03,
     3      0.4240744792520698d-03,-.2835686391209656d-03,
     4      0.1782503776596157d-03,-.1055267285496342d-03,
     5      0.5919009035065080d-04,-.3014684109687086d-04,
     6      0.1540660899955710d-04,-.7049826631613486d-05,
     7      0.3210294833343047d-05,0.4415125125519656d-03,
     8      -.1046908448576971d-02,0.1732102083512963d-02/
         data arr1068/
     1      -.2309711319817698d-02,0.2633679935066051d-02,
     2      -.2652795935312447d-02,0.2410412237356502d-02,
     3      -.2004100118320672d-02,0.1540516896469648d-02,
     4      -.1101196589999033d-02,0.7409117042237232d-03,
     5      -.4691424131518022d-03,0.2814535730233723d-03,
     6      -.1513231297269358d-03,0.8283980570490958d-04,
     7      -.4023768437238727d-04,0.1954834107503360d-04,
     8      0.8716515071801260d-03,-.2204452759019590d-02/
         data arr1069/
     1      0.3890151127020504d-02,-.5532978692154467d-02,
     2      0.6729084938135407d-02,-.7228315630647451d-02,
     3      0.7005548795448804d-02,-.6213059015790836d-02,
     4      0.5093408375090171d-02,-.3876921335331438d-02,
     5      0.2783035350192026d-02,-.1878201250979718d-02,
     6      0.1200995880467969d-02,-.6774770723501311d-03,
     7      0.3960492987473140d-03,-.2034376563795564d-03,
     8      0.1050843526588566d-03,0.1618123503758313d-02/
         data arr1070/
     1      -.4351545688181418d-02,0.8165916551605274d-02,
     2      -.1235119505946208d-01,0.1597279201011492d-01,
     3      -.1824054617207401d-01,0.1880049516630274d-01,
     4      -.1773319235582350d-01,0.1545639324360882d-01,
     5      -.1247930577749286d-01,0.9530386752072090d-02,
     6      -.6833168709028040d-02,0.4642211875524287d-02,
     7      -.2730770156661845d-02,0.1700070395948130d-02,
     8      -.9203499515632480d-03,0.5039190568252557d-03/
         data arr1071/
     1      0.2839180804177690d-02,-.8096362157302762d-02,
     2      0.1611269612659504d-01,-.2584766677273732d-01,
     3      0.3544578631555613d-01,-.4290520850468240d-01,
     4      0.4690421996003448d-01,-.4692910213710035d-01,
     5      0.4336604708217464d-01,-.3699435445105973d-01,
     6      0.2998127889140432d-01,-.2276997808096237d-01,
     7      0.1638643069762022d-01,-.9990683007165161d-02,
     8      0.6607703258556460d-02,-.3758302439122225d-02/
         data arr1072/
     1      0.2175253975615051d-02,0.4730020199326436d-02,
     2      -.1426588560589781d-01,0.3003546211520723d-01,
     3      -.5098089383411949d-01,0.7394566597584878d-01,
     4      -.9460053703643126d-01,0.1094312160006420d+00,
     5      -.1158719405218075d+00,0.1132211300877629d+00,
     6      -.1016341281101452d+00,0.8721631037234194d-01,
     7      -.6997176837503462d-01,0.5319582908032075d-01,
     8      -.3340913897118287d-01,0.2342451787643470d-01/
         data arr1073/
     1      -.1395857738580079d-01,0.8519349804821406d-02,
     2      0.7512273406477596d-02,-.2390373933445820d-01,
     3      0.5312746639159237d-01,-.9521974686705036d-01,
     4      0.1457329536724199d+00,-.1964721278386092d+00,
     5      0.2399958148126005d+00,-.2683982540015906d+00,
     6      0.2766276656882450d+00,-.2601516850666754d+00,
     7      0.2359489106512464d+00,-.1994621661062697d+00,
     8      0.1597915208552608d+00,-.1027359821690200d+00/
         data arr1074/
     1      0.7622142900017416d-01,-.4746398649204252d-01,
     2      0.3048121190389351d-01,0.1141507628791073d-01,
     3      -.3822433848175216d-01,0.8951669829144755d-01,
     4      -.1691346992373617d+00,0.2725210981470448d+00,
     5      -.3859573605047414d+00,0.4969946217656969d+00,
     6      -.5860658483080796d+00,0.6356360842270338d+00,
     7      -.6232545091742460d+00,0.5965165495054745d+00,
     8      -.5301242817182312d+00,0.4464809522825158d+00/
         data arr1075/
     1      -.2920333641042649d+00,0.2289041535442959d+00,
     2      -.1486106618231652d+00,0.1002282178662625d+00,
     3      0.1664912839748352d-01,-.5850859629819832d-01,
     4      0.1441623218310702d+00,-.2868202847980390d+00,
     5      0.4854466108989587d+00,-.7196483231766395d+00,
     6      0.9755801586264251d+00,-.1211491987061949d+01,
     7      0.1379589290159853d+01,-.1402811785341078d+01,
     8      0.1415152487841630d+01,-.1319344899836769d+01/
         data arr1076/
     1      0.1165729098582724d+01,-.7707973893955453d+00,
     2      0.6374751511080374d+00,-.4305866550741577d+00,
     3      0.3044758451947603d+00,0.2337748075498461d-01,
     4      -.8592613930942308d-01,0.2225393932922172d+00,
     5      -.4660279653614757d+00,0.8266310207197287d+00,
     6      -.1277192369438612d+01,0.1821163477708992d+01,
     7      -.2379597211973487d+01,0.2838920353882630d+01,
     8      -.2975563803896645d+01,0.3161255114881621d+01/
         data arr1077/
     1      -.3086025002063086d+01,0.2855140645434832d+01,
     2      -.1896286195348947d+01,0.1653044456072934d+01,
     3      -.1159498441801085d+01,0.8584328368082599d+00,
     4      0.3168908879949165d-01,-.1212652261646516d+00,
     5      0.3300488744121681d+00,-.7279314004190333d+00,
     6      0.1349860727830796d+01,-.2161938568729173d+01,
     7      0.3241550701672295d+01,-.4455165560984191d+01,
     8      0.5556695315691426d+01,-.5962493108874530d+01/
         data arr1078/
     1      0.6668360463803268d+01,-.6805129631133838d+01,
     2      0.6581566436916528d+01,-.4362333689995931d+01,
     3      0.4005363316378356d+01,-.2912710455876518d+01,
     4      0.2255199155377598d+01,0.4158301544151087d-01,
     5      -.1645424073046740d+00,0.4710806691164036d+00,
     6      -.1096515509775711d+01,0.2119880274624869d+01,
     7      -.3494841552175243d+01,0.5512343659407234d+01,
     8      -.7971447852684038d+01,0.1037312179423604d+02/
         data arr1079/
     1      -.1130696835060851d+02,0.1331228052155798d+02,
     2      -.1418284515217932d+02,0.1431898961218496d+02,
     3      -.9408801478510222d+01,0.9095552004237355d+01,
     4      -.6847492387856066d+01,0.5539927414557392d+01,
     5      0.5297376760540570d-01,-.2144584899680961d+00,
     6      0.6476590141672340d+00,-.1597714565916166d+01,
     7      0.3209980123125231d+01,-.5397258730023546d+01,
     8      0.8967701278062886d+01,-.1365994077538653d+02/
         data arr1080/
     1      0.1851014670026485d+02,-.2031609998403083d+02,
     2      0.2519522183444479d+02,-.2799551442389782d+02,
     3      0.2947300185188656d+02,-.1906780398373718d+02,
     4      0.1940756844815991d+02,-.1510783787226365d+02,
     5      0.1276556800420706d+02,0.6575331463214064d-01,
     6      -.2677553979637918d+00,0.8579963605095444d+00,
     7      -.2259943715372703d+01,0.4701150946476798d+01,
     8      -.7963567870489803d+01,0.1397784289357968d+02/
         data arr1081/
     1      -.2247758424508362d+02,0.3166593114157046d+02,
     2      -.3464347252517991d+02,0.4532005165621609d+02,
     3      -.5249462381057742d+02,0.5759488543944639d+02,
     4      -.3642055326157482d+02,0.3905454646472836d+02,
     5      -.3140972664346126d+02,0.2771861811523516d+02,
     6      -.1294870626187621d-18,0.5750698047236336d-21,
     7      -.6260854300188232d-20,0.1883119000800058d-21,
     8      0.5779295252465972d-20,0.1526655992152301d-21/
         data arr1082/
     1      -.1167061009212096d-18,0.2858927133008137d-20,
     2      -.4603734387519973d-19,0.2560350824249812d-20,
     3      -.5175541956813112d-18,0.1111850770175556d-19,
     4      -.1833242511160442d-18,0.5532863632741681d-20,
     5      -.5904840115377938d-18,0.1113568560823118d-19,
     6      -.1220858448704506d-18,0.2831006777808387d-20,
     7      -.5962338906494144d-20,0.9283105124901749d-21,
     8      0.5462318723595726d-20,0.7521023204476347d-21/
         data arr1083/
     1      -.1103041106180402d-18,0.1408451901769121d-19,
     2      -.4351153958506479d-19,0.1261355733733763d-19,
     3      -.4891634848048502d-18,0.5477541443317141d-19,
     4      -.1732673734349619d-18,0.2725767402745690d-19,
     5      -.5580930717609124d-18,0.5486008555141241d-19,
     6      -.1101379990928574d-18,0.6181124047116969d-20,
     7      -.5648924297944252d-20,0.2040845994399008d-20,
     8      0.4988456918200818d-20,0.1648136092641965d-20/
         data arr1084/
     1      -.1007339638587794d-18,0.3086548769122119d-19,
     2      -.3973459364135135d-19,0.2764168697835874d-19,
     3      -.4467232481438150d-18,0.1200377894004489d-18,
     4      -.1582321168852877d-18,0.5973369453911556d-19,
     5      -.5096741727881725d-18,0.1202238288073934d-18,
     6      -.9546618467575028d-19,0.9747888667489065d-20,
     7      -.5549676498455304d-20,0.3280139161112442d-20,
     8      0.4470114502441323d-20,0.2625776166846533d-20/
         data arr1085/
     1      -.9029066687186116d-19,0.4917788394960228d-19,
     2      -.3561067757791961d-19,0.4404023555912283d-19,
     3      -.4004112820388431d-18,0.1912572948857188d-18,
     4      -.1418220571346697d-18,0.9517317667019484d-19,
     5      -.4568403736516441d-18,0.1915558733978057d-18,
     6      -.7988822247948783d-19,0.1277102350263445d-19,
     7      -.5784987028696705d-20,0.4466031298418237d-20,
     8      0.3993482196095024d-20,0.3513448482408244d-20/
         data arr1086/
     1      -.8080808609972802d-19,0.6580643559878701d-19,
     2      -.3186226008430647d-19,0.5892831177526635d-19,
     3      -.3583602057232539d-18,0.2559313244046729d-18,
     4      -.1269166305267438d-18,0.1273532245768084d-18,
     5      -.4088711600945868d-18,0.2563368815429679d-18,
     6      -.1023184755076088d-19,0.2291021562772457d-20,
     7      -.6477419833387878d-21,0.7365360590033322d-21,
     8      0.7719916532030698d-21,-.9618037647212395d-21/
         data arr1087/
     1      -.4120134632319719d-20,0.9059381148181764d-20,
     2      0.2190290395524553d-20,0.7365167199157811d-21,
     3      -.1728903143324785d-19,0.3596005521034595d-19,
     4      -.9343498995331464d-21,0.9511976497551674d-20,
     5      -.2137068537524720d-19,0.4057060759242281d-19,
     6      -.2097674969385449d-17,0.6462591652924554d-18,
     7      -.1390152819080886d-18,0.2411630766448152d-19,
     8      -.3579785294452439d-20,0.4697187345364713d-21/
         data arr1088/
     1      -.5562032273487791d-22,0.6031440483359724d-23,
     2      -.6037131386618000d-24,0.5371551968429452d-25,
     3      -.1698355193332890d-26,0.6445830565312887d-26,
     4      0.2176980153247861d-26,-.2363871949753104d-26,
     5      0.4314966311877245d-26,0.6875193725966892d-26,
     6      -.1775695478623686d-15,0.7009320365979781d-16,
     7      -.1931837719517924d-16,0.4293958181862780d-17,
     8      -.8166630278942027d-18,0.1372977403042226d-18/
         data arr1089/
     1      -.2083056962467382d-19,0.2893247187358004d-20,
     2      -.3717932614706583d-21,0.4456255003723281d-22,
     3      -.5013108956885878d-23,0.5308115701425304d-24,
     4      -.5347468914451992d-25,0.4630471094137217d-26,
     5      0.7142300365193886d-27,-.1735860158916903d-26,
     6      -.7721209325920285d-14,0.3775232836591827d-14,
     7      -.1288811691242462d-14,0.3548359634083505d-15,
     8      -.8359180594741045d-16,0.1740745161824569d-16/
         data arr1090/
     1      -.3271326954898890d-17,0.5628068750183157d-18,
     2      -.8958312265013281d-19,0.1329984972721120d-19,
     3      -.1853603882604241d-20,0.2437883807185077d-21,
     4      -.3038538740245758d-22,0.3603339388472390d-23,
     5      -.4073605917534960d-24,0.4395888105373223d-25,
     6      -.1996476135222653d-12,0.1177816905598410d-12,
     7      -.4851530365755710d-13,0.1611655305216521d-13,
     8      -.4581033684057657d-14,0.1151039477630056d-14/
         data arr1091/
     1      -.2609962213300444d-15,0.5417824172658173d-16,
     2      -.1040511611334802d-16,0.1863900478267929d-17,
     3      -.3134356498531875d-18,0.4973929441504172d-19,
     4      -.7478851686282795d-20,0.1070141064355080d-20,
     5      -.1459170704363256d-21,0.1903083393654103d-22,
     6      -.3404498326589139d-11,0.2373259292887883d-11,
     7      -.1155113248970115d-11,0.4534155163160813d-12,
     8      -.1522881481697004d-12,0.4521382450688256d-13/
         data arr1092/
     1      -.1211416963285482d-13,0.2971411101646077d-14,
     2      -.6743154128467423d-15,0.1427306697989454d-15,
     3      -.2836102643908598d-16,0.5318032332085252d-17,
     4      -.9445757024483152d-18,0.1597118203242126d-18,
     5      -.2571828173099862d-19,0.3960527408811301d-20,
     6      -.4130070742386148d-10,0.3344584199510846d-10,
     7      -.1891098224664451d-10,0.8623398935037491d-11,
     8      -.3364656886694887d-11,0.1160482244775271d-11/
         data arr1093/
     1      -.3612047802495791d-12,0.1029236443589641d-12,
     2      -.2713362472056779d-13,0.6671979210312795d-14,
     3      -.1540115212396719d-14,0.3354852511651407d-15,
     4      -.6918894375783770d-16,0.1359114997054136d-16,
     5      -.2540775029002106d-17,0.4541296043328929d-18,
     6      -.3773706986128594d-09,0.3500487686140236d-09,
     7      -.2267129054742138d-09,0.1184176310911903d-09,
     8      -.5292421294733000d-10,0.2090873994082045d-10/
         data arr1094/
     1      -.7454501422442920d-11,0.2433077784668200d-11,
     2      -.7347230181546852d-12,0.2069409608117398d-12,
     3      -.5471715557642224d-13,0.1365263760705719d-13,
     4      -.3222644821955551d-14,0.7251874094002708d-15,
     5      -.1551666449582475d-15,0.3173420838413781d-16,
     6      -.2714061989402207d-08,0.2849801749490289d-08,
     7      -.2089280953405049d-08,0.1235297261499050d-08,
     8      -.6249481971116410d-09,0.2794808031138669d-09/
         data arr1095/
     1      -.1127917373699675d-09,0.4167246133635278d-10,
     2      -.1424457256517776d-10,0.4541583230435130d-11,
     3      -.1359328424406496d-11,0.3839248874376010d-12,
     4      -.1024597039638512d-12,0.2610299540297391d-13,
     5      -.6316617818286039d-14,0.1460538071787976d-14,
     6      -.1590697446799711d-07,0.1871722750985274d-07,
     7      -.1537739486012786d-07,0.1018864541423259d-07,
     8      -.5776277055096649d-08,0.2894776498815150d-08/
         data arr1096/
     1      -.1309180584344488d-08,0.5420387980425149d-09,
     2      -.2076276756810435d-09,0.7418283014971513d-10,
     3      -.2488227186873812d-10,0.7875179587403512d-11,
     4      -.2351023882290116d-11,0.6713496602734198d-12,
     5      -.1818714924557375d-12,0.4705866865193653d-13,
     6      -.7811945803178542d-07,0.1021194903765408d-06,
     7      -.9320632258723820d-07,0.6860796424904470d-07,
     8      -.4321171524897530d-07,0.2405825057454200d-07/
         data arr1097/
     1      -.1208772287067959d-07,0.5559945432463287d-08,
     2      -.2365980190828731d-08,0.9391338192563635d-09,
     3      -.3499679931900762d-09,0.1230483876846528d-09,
     4      -.4070742416896626d-10,0.1291804161176875d-10,
     5      -.3883511709768304d-11,0.1114567063743019d-11,
     6      -.3288316959539175d-06,0.4739707763967276d-06,
     7      -.4769982620328664d-06,0.3871456786476683d-06,
     8      -.2688621242512708d-06,0.1650519818195708d-06/
         data arr1098/
     1      -.9143886246295041d-07,0.4637507866848325d-07,
     2      -.2175872732652882d-07,0.9523223628961232d-08,
     3      -.3913320611440149d-08,0.1517018717409168d-08,
     4      -.5514467413727619d-09,0.1930381796790733d-09,
     5      -.6391091086583954d-10,0.2018929477519007d-10,
     6      -.1208771266978001d-05,0.1908498990811546d-05,
     7      -.2103909968105241d-05,0.1870486715845072d-05,
     8      -.1422915359411738d-05,0.9568423530967488d-06/
         data arr1099/
     1      -.5806615839377794d-06,0.3225858308330668d-06,
     2      -.1657770316975864d-06,0.7947961996979216d-07,
     3      -.3577998827260188d-07,0.1519170969464990d-07,
     4      -.6020700738874643d-08,0.2309994349613609d-08,
     5      -.8366679244520710d-09,0.2889569701346734d-09,
     6      -.3941269734409919d-05,0.6776965773465880d-05,
     7      -.8136208290769874d-05,0.7877722545221833d-05,
     8      -.6526413956509368d-05,0.4779561212774458d-05/
         data arr1100/
     1      -.3158843765139430d-05,0.1911165052407984d-05,
     2      -.1069434801359745d-05,0.5584156390707928d-06,
     3      -.2738281082678476d-06,0.1265960643297318d-06,
     4      -.5430204432222759d-07,0.2270743771382171d-07,
     5      -.8944894602726600d-08,0.3357397992332482d-08,
     6      -.1154906784902538d-04,0.2151616217567521d-04,
     7      -.2798794138741381d-04,0.2936079243421929d-04,
     8      -.2635456454341481d-04,0.2091172469682707d-04/
         data arr1101/
     1      -.1497482077283327d-04,0.9816193476355156d-05,
     2      -.5949556279328921d-05,0.3366225119054572d-05,
     3      -.1789013416317045d-05,0.8959041999369003d-06,
     4      -.4130348833159768d-06,0.1873247713780355d-06,
     5      -.7983939533944441d-07,0.3239646549995494d-07,
     6      -.3075496027355852d-04,0.6179625603371343d-04,
     7      -.8669601642216082d-04,0.9808972749598354d-04,
     8      -.9495760306788219d-04,0.8126379734742962d-04/
         data arr1102/
     1      -.6276595388720176d-04,0.4437312317399539d-04,
     2      -.2899077768889458d-04,0.1769335836433771d-04,
     3      -.1014629818898325d-04,0.5477986922727738d-05,
     4      -.2696106114610468d-05,0.1320488311462625d-05,
     5      -.6061437097599955d-06,0.2646450964546653d-06,
     6      -.7514178324262136d-04,0.1621721917542899d-03,
     7      -.2443799594182952d-03,0.2969844688976131d-03,
     8      -.3087898071641847d-03,0.2838490046310492d-03/
         data arr1103/
     1      -.2355118669698138d-03,0.1788249225976519d-03,
     2      -.1253805207350063d-03,0.8221139564247099d-04,
     3      -.5067196646466667d-04,0.2936960297384983d-04,
     4      -.1532873546835421d-04,0.8077142914841939d-05,
     5      -.3976882432413716d-05,0.1860416665814999d-05,
     6      -.1698292225201883d-03,0.3922425762658547d-03,
     7      -.6325599233060015d-03,0.8226342659201557d-03,
     8      -.9152282293697549d-03,0.9003677153348996d-03/
         data arr1104/
     1      -.7996249975351150d-03,0.6496743571365639d-03,
     2      -.4867654726798830d-03,0.3416918104232183d-03,
     3      -.2255973673604150d-03,0.1398278968857752d-03,
     4      -.7687680948921032d-04,0.4343826045729457d-04,
     5      -.2285706262521010d-04,0.1141373267571720d-04,
     6      -.3575993614123701d-03,0.8809377679718138d-03,
     7      -.1515380433361796d-02,0.2101879435109814d-02,
     8      -.2493583528010874d-02,0.2616716138654286d-02/
         data arr1105/
     1      -.2479681374688849d-02,0.2148397480400124d-02,
     2      -.1713005409515112d-02,0.1283319781842612d-02,
     3      -.9049463882134760d-03,0.5976682545330079d-03,
     4      -.3438131265844621d-03,0.2077228721814053d-03,
     5      -.1164359140052397d-03,0.6185315989618311d-04,
     6      -.7058621934398552d-03,0.1849172609153062d-02,
     7      -.3383086642722094d-02,0.4989422310381739d-02,
     8      -.6291422273838528d-02,0.7021925599104745d-02/
         data arr1106/
     1      -.7080919897293299d-02,0.6521477776721518d-02,
     2      -.5510396615740173d-02,0.4393879906616377d-02,
     3      -.3300956056408936d-02,0.2315355051900776d-02,
     4      -.1384037276139523d-02,0.8919201635768994d-03,
     5      -.5310435071847857d-03,0.2991919862834133d-03,
     6      -.1313165346144260d-02,0.3648596508371513d-02,
     7      -.7081308333530319d-02,0.1107315379820916d-01,
     8      -.1479374334485264d-01,0.1751649775226660d-01/
         data arr1107/
     1      -.1875420431307718d-01,0.1830653852114699d-01,
     2      -.1631970148478590d-01,0.1381885708343506d-01,
     3      -.1103742843652635d-01,0.8196869873670997d-02,
     4      -.5055591856471631d-02,0.3467844058731120d-02,
     5      -.2187526630550185d-02,0.1303558052496160d-02,
     6      -.2313240520678039d-02,0.6800768201722103d-02,
     7      -.1397265847296406d-01,0.2310442474861293d-01,
     8      -.3259877792394390d-01,0.4085857584765216d-01/
         data arr1108/
     1      -.4636665285639864d-01,0.4783387407221510d-01,
     2      -.4477250255571216d-01,0.4018399861457784d-01,
     3      -.3406733456559818d-01,0.2670971699184295d-01,
     4      -.1687389698059831d-01,0.1229871558814008d-01,
     5      -.8200908043140822d-02,0.5156225419440304d-02,
     6      -.3873930370483525d-02,0.1202730938486269d-01,
     7      -.2611864601285625d-01,0.4554998249946716d-01,
     8      -.6763156427365541d-01,0.8957402960725881d-01/
         data arr1109/
     1      -.1076223466636926d+00,0.1170181971136712d+00,
     2      -.1143762084071501d+00,0.1086522703252577d+00,
     3      -.9765275286336536d-01,0.8061105450867823d-01,
     4      -.5177038251203007d-01,0.4003881120679578d-01,
     5      -.2816650871802814d-01,0.1864430778637716d-01,
     6      -.6187666868569928d-02,0.2025803393443618d-01,
     7      -.4646457907498078d-01,0.8523336285147044d-01,
     8      -.1326176917249388d+00,0.1853754654775429d+00/
         data arr1110/
     1      -.2357399513704439d+00,0.2694027645264452d+00,
     2      -.2732537889800051d+00,0.2744854022461229d+00,
     3      -.2613295499429754d+00,0.2265590333402900d+00,
     4      -.1467598795926552d+00,0.1203131960412745d+00,
     5      -.8914013857275367d-01,0.6199953390378576d-01,
     6      -.9449068913512776d-02,0.3260083341212479d-01,
     7      -.7901569263993420d-01,0.1520054257465525d+00,
     8      -.2465313219079225d+00,0.3635002766896864d+00/
         data arr1111/
     1      -.4895850100339759d+00,0.5863814740214941d+00,
     2      -.6126812240929610d+00,0.6505193711854645d+00,
     3      -.6558669434203768d+00,0.5957602475169258d+00,
     4      -.3861045754887298d+00,0.3352937517599406d+00,
     5      -.2612565237822430d+00,0.1906106157430802d+00,
     6      -.1381292223885444d-01,0.5025332289668509d-01,
     7      -.1290186406681157d+00,0.2593725021288441d+00,
     8      -.4353884669597338d+00,0.6774122874654877d+00/
         data arr1112/
     1      -.9681082598750237d+00,0.1211623602373915d+01,
     2      -.1292822173681911d+01,0.1451206032567224d+01,
     3      -.1549693775135706d+01,0.1471722340324954d+01,
     4      -.9462176248486572d+00,0.8701704954806362d+00,
     5      -.7122247496744618d+00,0.5442872126743088d+00,
     6      -.1932137959154771d-01,0.7432969209354590d-01,
     7      -.2032160069743824d+00,0.4250354630531169d+00,
     8      -.7312546028338069d+00,0.1202538685613885d+01/
         data arr1113/
     1      -.1829666176734861d+01,0.2385290809748731d+01,
     2      -.2572452505839341d+01,0.3055724504673809d+01,
     3      -.3458589523721561d+01,0.3427319898480001d+01,
     4      -.2166753624165584d+01,0.2110493584901985d+01,
     5      -.1812919099383578d+01,0.1449415201554870d+01,
     6      -.2578226117123038d-01,0.1055638635089591d+00,
     7      -.3103202244862721d+00,0.6713674100506668d+00,
     8      -.1167693394730913d+01,0.2036585374356553d+01/
         data arr1114/
     1      -.3316139712825486d+01,0.4488318285189363d+01,
     2      -.4832677116086879d+01,0.6086077334896331d+01,
     3      -.7310694568773203d+01,0.7546491808417062d+01,
     4      -.4647754443835987d+01,0.4798110904549127d+01,
     5      -.4323043534015925d+01,0.3612373498189742d+01,
     6      -.3257293631649797d-01,0.1438357049410773d+00,
     7      -.4619605640568044d+00,0.1026035495323648d+01,
     8      -.1769308924887712d+01,0.3292736438979292d+01/
         data arr1115/
     1      -.5780887521796572d+01,0.8095082129591402d+01,
     2      -.8575174739380451d+01,0.1148404239922185d+02,
     3      -.1467014595521784d+02,0.1575189658508987d+02,
     4      -.9357368096638467d+01,0.1025189171696923d+02,
     5      -.9686066344503327d+01,0.8453850961964154d+01,
     6      -.3834408257371848d-01,0.1875262394222252d+00,
     7      -.6749300264469499d+00,0.1524343180108021d+01,
     8      -.2534255645465642d+01,0.5084906110508536d+01/
         data arr1116/
     1      -.9728116887964456d+01,0.1404536826064613d+02,
     2      -.1437890964274002d+02,0.2057652934240150d+02,
     3      -.2803991268036615d+02,0.3128686434406293d+02,
     4      -.1773115553044341d+02,0.2066387628424808d+02,
     5      -.2047951447526399d+02,0.1866582473942708d+02,
     6      0.5186714478399177d-20,-.2424376710298035d-22,
     7      0.2414548868935361d-21,0.5978707327978458d-23,
     8      -.4641833720932740d-21,-.3279684577801460d-22/
         data arr1117/
     1      0.4042045254839817d-20,0.2032516580141311d-22,
     2      -.9796592767012177d-22,-.1493390370301622d-21,
     3      0.1723391506552016d-19,-.6244051751768325d-23,
     4      0.3799795177700982d-20,-.1856000583774705d-21,
     5      0.1991808515677830d-19,0.4890214666091323d-20,
     6      -.1193551553472838d-21,0.2299237629918579d-21,
     7      0.2943217517064821d-22,-.4387219139804031d-21,
     8      -.1615738215156217d-21,0.3820316792502757d-20/
         data arr1118/
     1      0.1001326044964837d-21,-.9260499954978519d-22,
     2      -.7357190955468618d-21,0.1628853828650539d-19,
     3      -.3076020283393852d-22,0.3591336011919375d-20,
     4      -.9143591240510703d-21,0.1882547479078315d-19,
     5      0.4411465482585644d-20,-.2606587996325910d-21,
     6      0.2177534310634234d-21,0.6425751694061311d-22,
     7      -.4006588558621239d-21,-.3540806795077280d-21,
     8      0.3488863263920202d-20,0.2194416943728955d-21/
         data arr1119/
     1      -.8463058740258108d-22,-.1612285239800762d-20,
     2      0.1487532545869178d-19,-.6739667147866250d-22,
     3      0.3279659424776618d-20,-.2003764679195800d-20,
     4      0.1719219201655549d-19,0.3823385535195444d-20,
     5      -.4113466723344844d-21,0.2137318086732688d-21,
     6      0.1013239255689070d-21,-.3590763914066915d-21,
     7      -.5641581084510574d-21,0.3127172565898842d-20,
     8      0.3496638215220030d-21,-.7600694989596569d-22/
         data arr1120/
     1      -.2568827983790507d-20,0.1333318117358526d-19,
     2      -.1073264920657739d-21,0.2939433007703695d-20,
     3      -.3192567154169409d-20,0.1540994923213233d-19,
     4      0.3198768728847587d-20,-.5396792213757878d-21,
     5      0.2224850957198292d-21,0.1327337593840017d-21,
     6      -.3210997624027475d-21,-.7549368448191353d-21,
     7      0.2798760978869270d-20,0.4679739264286748d-21,
     8      -.6830408380956424d-22,-.3437369003536188d-20/
         data arr1121/
     1      0.1193290883521935d-19,-.1434598391339008d-21,
     2      0.2630319611970835d-20,-.4272002965667573d-20,
     3      0.1379174644974238d-19,0.3598231193041733d-21,
     4      -.1538381541436804d-21,0.1749371079744313d-21,
     5      0.3218837158599778d-21,-.4635828685807309d-21,
     6      -.1346174304218053d-20,0.2483299384024981d-20,
     7      0.1540585699489650d-20,-.1337182079364299d-20,
     8      -.5597492233577334d-20,0.1032273567181686d-19/
         data arr1122/
     1      0.1153717663637170d-20,0.3825281446217559d-21,
     2      -.6919171112946443d-20,0.1258148249701088d-19,
     3      0.1021825186031859d-18,-.3070334459203314d-19,
     4      0.6445399468712133d-20,-.1091765477553391d-20,
     5      0.1581834433741761d-21,-.2051510272852917d-22,
     6      0.2971955282620458d-23,0.4636827050628404d-25,
     7      -.5665257416154226d-24,-.7626324589698063d-24,
     8      0.2336403393680119d-23,0.2933475552635059d-24/
         data arr1123/
     1      -.3253653099345459d-24,-.8933067130496754d-24,
     2      0.2789964444805883d-23,0.1108270860315712d-16,
     3      -.4266715749827648d-17,0.1147608596209186d-17,
     4      -.2490798887479669d-18,0.4628305938595229d-19,
     5      -.7606247157876882d-20,0.1128637518196218d-20,
     6      -.1533919199257897d-21,0.1929789292822168d-22,
     7      -.2258891514948052d-23,0.2363720785210123d-24,
     8      -.2737849609716804d-25,0.2069780813166966d-26/
         data arr1124/
     1      0.7464180075077846d-26,-.1637738335713064d-25,
     2      0.5969167230544208d-15,-.2846508837740160d-15,
     3      0.9483390025568463d-16,-.2549526179700004d-16,
     4      0.5868050743499182d-17,-.1194519710776442d-17,
     5      0.2195480062423593d-18,-.3695917439762194d-19,
     6      0.5759004113244391d-20,-.8373728163522896d-21,
     7      0.1143457508345423d-21,-.1473906727376440d-22,
     8      0.1801771672780455d-23,-.2092504776781281d-24/
         data arr1125/
     1      0.2179978886683695d-25,0.1862292044171246d-13,
     2      -.1071523804178088d-13,0.4307329984069811d-14,
     3      -.1397202174910785d-14,0.3880153287513304d-15,
     4      -.9530234529180935d-16,0.2113464760561393d-16,
     5      -.4292823041968020d-17,0.8070925702915133d-18,
     6      -.1415960118002885d-18,0.2332982711715721d-19,
     7      -.3627687857663817d-20,0.5350588218108842d-21,
     8      -.7523857139426992d-22,0.1006433283761553d-22/
         data arr1126/
     1      0.3752452421842990d-12,-.2551218377469852d-12,
     2      0.1211803939932012d-12,-.4644744974459032d-13,
     3      0.1524157713121414d-13,-.4423469330567465d-14,
     4      0.1159131869820456d-14,-.2782012753992754d-15,
     5      0.6180418955171236d-16,-.1281225945601230d-16,
     6      0.2494387018629548d-17,-.4581649006940472d-18,
     7      0.7985255487712884d-19,-.1327798537390112d-19,
     8      0.2097335082925316d-20,0.5288251948329678d-11/
         data arr1127/
     1      -.4176737258262192d-11,0.2304700308915749d-11,
     2      -.1026210729179279d-11,0.3911984847893281d-12,
     3      -.1318933393451783d-12,0.4014997358422479d-13,
     4      -.1119447587758148d-13,0.2889051215915839d-14,
     5      -.6957602834517700d-15,0.1573578859854271d-15,
     6      -.3355868316993357d-16,0.6795056970575463d-17,
     7      -.1313823164623784d-17,0.2408889389544896d-18,
     8      0.5534757004760594d-10,-.5007250427434113d-10/
         data arr1128/
     1      0.3164844315263309d-10,-.1614173357425553d-10,
     2      0.7048334785193686d-11,-.2721999215940988d-11,
     3      0.9491309031656464d-12,-.3031233374303068d-12,
     4      0.8960801606289092d-13,-.2471926332961292d-13,
     5      0.6403778820961225d-14,-.1562980918683574d-14,
     6      0.3625461575026875d-15,-.8038659575307320d-16,
     7      0.1686665691578305d-16,0.4505932204000030d-09,
     8      -.4614449686668086d-09,0.3301470804086869d-09/
         data arr1129/
     1      -.1906074107508270d-09,0.9421295886183141d-10,
     2      -.4118572757233051d-10,0.1625621045512267d-10,
     3      -.5876849655815379d-11,0.1966560364234496d-11,
     4      -.6141117760848241d-12,0.1800840510633287d-12,
     5      -.4968816472215499d-13,0.1304869133309880d-13,
     6      -.3279648220010599d-14,0.7780959523328712d-15,
     7      0.2959453520083859d-08,-.3396298380971946d-08,
     8      0.2723030033665687d-08,-.1761747897575668d-08/
         data arr1130/
     1      0.9758289324489248d-09,-.4780454596006556d-09,
     2      0.2114465744130635d-09,-.8566019504011348d-10,
     3      0.3212199191660565d-10,-.1124173959532700d-10,
     4      0.3694082458122654d-11,-.1139976019345707d-11,
     5      0.3355611560224400d-12,-.9467040649043108d-13,
     6      0.2513868115533657d-13,0.1614650913525206d-07,
     7      -.2058583336178861d-07,0.1833624993050384d-07,
     8      -.1317944727760372d-07,0.8110033847479249d-08/
         data arr1131/
     1      -.4413820246845288d-08,0.2168908018854523d-08,
     2      -.9761172065887571d-09,0.4066534863148568d-09,
     3      -.1581276907810889d-09,0.5772344939543368d-10,
     4      -.1973442943641276d-10,0.6455693659914273d-11,
     5      -.2027385380563148d-11,0.5972595973343568d-12,
     6      0.7494135946974960d-07,-.1053513015319565d-06,
     7      0.1034690392837940d-06,-.8200213278652953d-07,
     8      0.5563899483593341d-07,-.3338891006915390d-07/
         data arr1132/
     1      0.1809072972715127d-07,-.8976731500908132d-08,
     2      0.4123602188611474d-08,-.1768422245375923d-08,
     3      0.7117349469606137d-09,-.2672588135010025d-09,
     4      0.9644570811215555d-10,-.3347405518372550d-10,
     5      0.1085702186760070d-10,0.3017601789632275d-06,
     6      -.4646761262996167d-06,0.4999086783134438d-06,
     7      -.4339843881310146d-06,0.3225512014529579d-06,
     8      -.2120301156787025d-06,0.1258399836024726d-06/
         data arr1133/
     1      -.6839070388010084d-07,0.3441440306008339d-07,
     2      -.1617259013527198d-07,0.7128804976268576d-08,
     3      -.2916811083995235d-08,0.1153734811438131d-08,
     4      -.4398159849580801d-09,0.1560056207845813d-09,
     5      0.1071532274363850d-05,-.1796989688281804d-05,
     6      0.2105410953068065d-05,-.1990528365402735d-05,
     7      0.1611185759635028d-05,-.1153478110043614d-05,
     8      0.7455484644828609d-06,-.4411684476320739d-06/
         data arr1134/
     1      0.2417833863765311d-06,-.1238146969857362d-06,
     2      0.5942372160994893d-07,-.2629381644816426d-07,
     3      0.1133628825609075d-07,-.4721099268338899d-08,
     4      0.1820614632467090d-08,0.3402002826569876d-05,
     5      -.6181521978467012d-05,0.7847013651234590d-05,
     6      -.8037970098903880d-05,0.7049295676376062d-05,
     7      -.5468360544876397d-05,0.3829392846557763d-05,
     8      -.2454110089319319d-05,0.1457417808521414d-05/
         data arr1135/
     1      -.8093615397099824d-06,0.4207245079860975d-06,
     2      -.1998617038229882d-06,0.9346449605701059d-07,
     3      -.4232552833972122d-07,0.1765293515448275d-07,
     4      0.9770835329643838d-05,-.1914812179514175d-04,
     5      0.2621569451037307d-04,-.2896094287335524d-04,
     6      0.2739359005977448d-04,-.2292178865218239d-04,
     7      0.1731112144845194d-04,-.1195635417750793d-04,
     8      0.7659542355550548d-05,-.4593910742279400d-05/
         data arr1136/
     1      0.2574228529373597d-05,-.1303459835157678d-05,
     2      0.6583589383716573d-06,-.3228839631857570d-06,
     3      0.1449733963914146d-06,0.2564158841237920d-04,
     4      -.5397582833025669d-04,0.7937334729782120d-04,
     5      -.9417353597203087d-04,0.9568198685125812d-04,
     6      -.8601872098272234d-04,0.6977000609611667d-04,
     7      -.5169524583542115d-04,0.3558309498792458d-04,
     8      -.2296883725978414d-04,0.1381466859259480d-04/
         data arr1137/
     1      -.7402481021524653d-05,0.4023237057194902d-05,
     2      -.2129456396111918d-05,0.1025052293423972d-05,
     3      0.6201838844536829d-04,-.1397178360154853d-03,
     4      0.2198646454493067d-03,-.2790993535368283d-03,
     5      0.3034893318252097d-03,-.2921260689058731d-03,
     6      0.2535142327302054d-03,-.2006077392626804d-03,
     7      0.1478479291520019d-03,-.1024235392845072d-03,
     8      0.6585968691564327d-04,-.3707195033298185d-04/
         data arr1138/
     1      0.2161103523175899d-04,-.1230755468531017d-04,
     2      0.6328289264997066d-05,0.1392847375183166d-03,
     3      -.3347421117361894d-03,0.5617903186696916d-03,
     4      -.7602884358591463d-03,0.8819432263439908d-03,
     5      -.9062871801633775d-03,0.8385697962732772d-03,
     6      -.7054752491259551d-03,0.5550206721426237d-03,
     7      -.4117540836140098d-03,0.2820235313463866d-03,
     8      -.1654977996001821d-03,0.1031925466462850d-03/
         data arr1139/
     1      -.6307175037011727d-04,0.3452714188522697d-04,
     2      0.2923593060949226d-03,-.7474598491570119d-03,
     3      0.1333694929441733d-02,-.1917587698988777d-02,
     4      0.2366260156622063d-02,-.2589893261681816d-02,
     5      0.2546681935765489d-02,-.2266915548727210d-02,
     6      0.1898915409934949d-02,-.1506343209640560d-02,
     7      0.1095253564544680d-02,-.6647279520156828d-03,
     8      0.4422860323377955d-03,-.2894991179054555d-03/
         data arr1140/
     1      0.1682335779994141d-03,0.5767928839877273d-03,
     2      -.1565210147267914d-02,0.2960483060592279d-02,
     3      -.4506115538553498d-02,0.5900733126281393d-02,
     4      -.6868015545607281d-02,0.7154462822064790d-02,
     5      -.6702775622947092d-02,0.5965606892821514d-02,
     6      -.5056071786500225d-02,0.3890038164593029d-02,
     7      -.2421364962322542d-02,0.1715834391839301d-02,
     8      -.1200644805537933d-02,0.7387350342572546d-03/
         data arr1141/
     1      0.1074848430559231d-02,-.3091133000805392d-02,
     2      0.6179608770866742d-02,-.9917571209173534d-02,
     3      0.1375533296965278d-01,-.1701441633594258d-01,
     4      0.1871813971904290d-01,-.1834442162795613d-01,
     5      0.1731964516863685d-01,-.1568245658710898d-01,
     6      0.1272891575455750d-01,-.8053994838107724d-02,
     7      0.6068868787331179d-02,-.4533622830165409d-02,
     8      0.2946637609050901d-02,0.1899877559707581d-02/
         data arr1142/
     1      -.5788163674712426d-02,0.1219268287061530d-01,
     2      -.2053159349599345d-01,0.3012231294684828d-01,
     3      -.3961865186305415d-01,0.4588379338599050d-01,
     4      -.4669854651590206d-01,0.4672211716662753d-01,
     5      -.4523146121742076d-01,0.3862036456775358d-01,
     6      -.2460586583043868d-01,0.1969324875101525d-01,
     7      -.1568996095657871d-01,0.1075053189269174d-01,
     8      0.3196387911481013d-02,-.1033106699200536d-01/
         data arr1143/
     1      0.2284963492264279d-01,-.4011008090556914d-01,
     2      0.6221943463448070d-01,-.8720706451681629d-01,
     3      0.1059637820208430d+00,-.1110073027684858d+00,
     4      0.1176484726696494d+00,-.1219703287945530d+00,
     5      0.1092610000795870d+00,-.6939077348059229d-01,
     6      0.5894521868433397d-01,-.5005619751031595d-01,
     7      0.3609337882323210d-01,0.5131823887978937d-02,
     8      -.1767530634213636d-01,0.4086406922275340d-01/
         data arr1144/
     1      -.7409092339969822d-01,0.1216122300216273d+00,
     2      -.1824301297927627d+00,0.2317135013309724d+00,
     3      -.2471347539471022d+00,0.2775585080970460d+00,
     4      -.3089561436006082d+00,0.2896411344450517d+00,
     5      -.1813897688594889d+00,0.1634993105097324d+00,
     6      -.1479611906470092d+00,0.1121053015724388d+00,
     7      0.7873608465083382d-02,-.2917058066715096d-01,
     8      0.7007502768512468d-01,-.1294667690850381d+00/
         data arr1145/
     1      0.2254345706366587d+00,-.3645257665414534d+00,
     2      0.4820235056507681d+00,-.5163090787817098d+00,
     3      0.6153332068196493d+00,-.7381069842331879d+00,
     4      0.7225087467328692d+00,-.4410208145024107d+00,
     5      0.4219275985217460d+00,-.4070130955070030d+00,
     6      0.3236343698071669d+00,0.1154030131157783d-01,
     7      -.4678229586750871d-01,0.1158150543531084d+00,
     8      -.2136635501581631d+00,0.3967778168973750d+00/
         data arr1146/
     1      -.6990447401564199d+00,0.9580423763097479d+00,
     2      -.1013145045223067d+01,0.1284693169605081d+01,
     3      -.1668808745362964d+01,0.1702176079085031d+01,
     4      -.1000026534221382d+01,0.1016395035223789d+01,
     5      -.1045958679406272d+01,0.8719750724295929d+00,
     6      0.1610744016243171d-01,-.7353813342477777d-01,
     7      0.1855301436159170d+00,-.3314543863764216d+00,
     8      0.6628808152674575d+00,-.1292160322833133d+01/
         data arr1147/
     1      0.1826543202205527d+01,-.1866602220572379d+01,
     2      0.2529395558185931d+01,-.3580985564866966d+01,
     3      0.3799388205756460d+01,-.2118922162885363d+01,
     4      0.2291835944201145d+01,-.2519602272641170d+01,
     5      0.2200723392657214d+01,0.2123646045150727d-01,
     6      -.1143898968779079d+00,0.2899472203344500d+00,
     7      -.4785195996636048d+00,0.1048933099469078d+01,
     8      -.2311331508008465d+01,0.3352847193697724d+01/
         data arr1148/
     1      -.3222292576250165d+01,0.4698963923922561d+01,
     2      -.7311049622465064d+01,0.8057411417850881d+01,
     3      -.4200407948356959d+01,0.4848315848484765d+01,
     4      -.5706856752042277d+01,0.5220597683936548d+01,
     5      0.2598357725598614d-01,-.1779151406936574d+00,
     6      0.4456671921827278d+00,-.6300916068118149d+00,
     7      0.1565420273214785d+01,-.4018893122501130d+01,
     8      0.5953186599849067d+01,-.5193046409172694d+01/
         data arr1149/
     1      0.8242317184935827d+01,-.1425232462482093d+02,
     2      0.1630125011245377d+02,-.7802006288979921d+01,
     3      0.9653526378119846d+01,-.1220806284476757d+02,
     4      0.1169847705760836d+02,-.4909991777680558d-18,
     5      0.2221773260629551d-20,0.2873330158717626d-19,
     6      -.6314392791068142d-21,-.1219666809013635d-18,
     7      0.2802021357941051d-20,0.1755211746748238d-18,
     8      -.2626387744637318d-20,-.5471762254561006d-18/
         data arr1150/
     1      0.1182851799773434d-19,0.1501104160635062d-18,
     2      -.1078349386951919d-20,-.7097124684611142d-18,
     3      0.1441969696298690d-19,-.4629409248858246d-18,
     4      0.1093803378026835d-19,0.2700401848850397d-19,
     5      -.3108870104028486d-20,-.1152760342958622d-18,
     6      0.1380417167480738d-19,0.1658928674061541d-18,
     7      -.1293894751258228d-19,-.5171596827381302d-18,
     8      0.5827321587905589d-19,0.1418763208789727d-18/
         data arr1151/
     1      -.5312568103854326d-20,-.6707793364530583d-18,
     2      0.7103865197783809d-19,-.4176641317710122d-18,
     3      0.2388705644888000d-19,0.2396638374591492d-19,
     4      -.6791818440691898d-20,-.1052746766232291d-18,
     5      0.3025112540728927d-19,0.1514998628369072d-18,
     6      -.2835541402947562d-19,-.4722863293565883d-18,
     7      0.1277022884408009d-18,0.1295683543880476d-18,
     8      -.1164303746000740d-19,-.6125751543243287d-18/
         data arr1152/
     1      0.1556768514461061d-18,-.3620956752735728d-18,
     2      0.3769436718252347d-19,0.1982478948201428d-19,
     3      -.1072899535147484d-19,-.9436513699178313d-19,
     4      0.4819921546021013d-19,0.1357938079743853d-18,
     5      -.4518030677031563d-19,-.4233138821297094d-18,
     6      0.2034657866861314d-18,0.1161393083498039d-18,
     7      -.1855446393691225d-19,-.5490522738508749d-18,
     8      0.2480365776359843d-18,-.3031343311467407d-18/
         data arr1153/
     1      0.4944918069906800d-19,0.1495704633159124d-19,
     2      -.1410775663907411d-19,-.8447843057598684d-19,
     3      0.6449844417135861d-19,0.1215326717518147d-18,
     4      -.6046192217944777d-19,-.3788383200746525d-18,
     5      0.2722586110708668d-18,0.1039486353544630d-18,
     6      -.2483845426317966d-19,-.4913593440407785d-18,
     7      0.3318973912860181d-18,-.2462590521551783d-18,
     8      0.5741288000950569d-19,0.9870578757772674d-20/
         data arr1154/
     1      -.1645453016301129d-19,-.7665391982765617d-19,
     2      0.7749312906853376d-19,0.1101690809059197d-18,
     3      -.7264657910038497d-19,-.3433877314424017d-18,
     4      0.3270699112961506d-18,0.9423972810166240d-19,
     5      -.2986132250021096d-19,-.4453688202608560d-18,
     6      0.3987117962956950d-18,-.5511273059402537d-20,
     7      0.4157260273773306d-20,0.5588203047876941d-20,
     8      -.1335047293684368d-19,-.2118639185031827d-19/
         data arr1155/
     1      0.4598686467126219d-19,0.3734889709726212d-19,
     2      -.6737753392973347d-19,-.7769894527164420d-19,
     3      0.1654710971626537d-18,0.4287171370310690d-19,
     4      -.6769736066069712d-19,-.8566056177043400d-19,
     5      0.1880399111474367d-18,-.6583685405440017d-18,
     6      0.2474996574471305d-18,-.6503881007155161d-19,
     7      0.1379883251065350d-19,-.2507893558881354d-20,
     8      0.4036107245364549d-21,-.5823641914338625d-22/
         data arr1156/
     1      0.7246117020357300d-23,-.1600170658087230d-23,
     2      0.1303871240477124d-23,0.3875641909117688d-24,
     3      -.5808072807683494d-24,-.6570072770975335d-24,
     4      0.1302416802622121d-23,-.4392258493592500d-16,
     5      0.2045240491657973d-16,-.6657233117292556d-17,
     6      0.1749514713979468d-17,-.3938214864756792d-18,
     7      0.7844336230725045d-19,-.1411401731355559d-19,
     8      0.2326987094677342d-20,-.3552680608925654d-21/
         data arr1157/
     1      0.5063697025263919d-22,-.6778330000369761d-23,
     2      0.8552256722043533d-24,-.1034608626915657d-24,
     3      0.1499500560566375d-25,-.1653397125489437d-14,
     4      0.9289426745694324d-15,-.3648325192462252d-15,
     5      0.1156838201852232d-15,-.3142025281691373d-16,
     6      0.7551299704655988d-17,-.1639348807031985d-17,
     7      0.3261146383812173d-18,-.6007425512025765d-19,
     8      0.1033063692915743d-19,-.1668410883938591d-20/
         data arr1158/
     1      0.2545906113058834d-21,-.3710388879691839d-22,
     2      0.5094991586337196d-23,-.3936615421319015d-13,
     3      0.2613443588442993d-13,-.1212819476233451d-13,
     4      0.4544160339545564d-14,-.1458374660413488d-14,
     5      0.4141517915422280d-15,-.1062398494698066d-15,
     6      0.2497266168749812d-16,-.5435819478154310d-17,
     7      0.1104537761134732d-17,-.2107048169442423d-18,
     8      0.3799429908810033d-19,-.6561098955949696d-20/
         data arr1159/
     1      0.1063205839414540d-20,-.6444845509073750d-12,
     2      0.4970444514396784d-12,-.2679605370242548d-12,
     3      0.1166328538936279d-12,-.4348394757374022d-13,
     4      0.1434537701198936d-13,-.4274958763066767d-14,
     5      0.1167352657462189d-14,-.2951911755815521d-15,
     6      0.6967995905494936d-16,-.1543203054108263d-16,
     7      0.3232985566258666d-17,-.6507910785722076d-18,
     8      0.1223156991457930d-18,-.7726355154214021d-11/
         data arr1160/
     1      0.6825478786657631d-11,-.4214872687121431d-11,
     2      0.2101407421819307d-11,-.8974166705066714d-12,
     3      0.3391195559658287d-12,-.1157569500545493d-12,
     4      0.3620707703090777d-13,-.1048790285926010d-13,
     5      0.2835706589346200d-14,-.7186487674508347d-15,
     6      0.1724819336960189d-15,-.3993531284909170d-16,
     7      0.8581248955017658d-17,-.7120250468123119d-10,
     8      0.7120135056292854d-10,-.4977073542519226d-10/
         data arr1161/
     1      0.2808887703516276d-10,-.1357853773724668d-10,
     2      0.5808260609085811d-11,-.2244249298961498d-11,
     3      0.7946086604073945d-12,-.2605668251907428d-12,
     4      0.7974643234497468d-13,-.2284186260129741d-13,
     5      0.6207271232412356d-14,-.1634894958445460d-14,
     6      0.3967896319751712d-15,-.5240602246345525d-09,
     7      0.5872637630101060d-09,-.4600213629568488d-09,
     8      0.2909359628569763d-09,-.1576071184896801d-09/
         data arr1162/
     1      0.7554880771663317d-10,-.3271167511090919d-10,
     2      0.1297917491871192d-10,-.4770235151230945d-11,
     3      0.1635924049642640d-11,-.5239014778090798d-12,
     4      0.1596013824461364d-12,-.4738008445520776d-13,
     5      0.1285380091539719d-13,-.3176463233711105d-08,
     6      0.3954497445793792d-08,-.3441369517928962d-08,
     7      0.2417944517104966d-08,-.1455198658504335d-08,
     8      0.7749409076466223d-09,-.3727516253828654d-09/
         data arr1163/
     1      0.1643107749963935d-09,-.6710816705955829d-10,
     2      0.2556496094141113d-10,-.9065674698690344d-11,
     3      0.3069794383502884d-11,-.1019234495952107d-11,
     4      0.3063203459544378d-12,-.1625606244184166d-07,
     5      0.2231470878097380d-07,-.2141208022491016d-07,
     6      0.1658833414485506d-07,-.1100810215116180d-07,
     7      0.6463753453594913d-08,-.3427859895092853d-08,
     8      0.1666141689444993d-08,-.7506836843246940d-09/
         data arr1164/
     1      0.3152626548257598d-09,-.1227041069265807d-09,
     2      0.4584707953552484d-10,-.1691394289902904d-10,
     3      0.5587440123785629d-11,-.7170114105898258d-07,
     4      0.1078131107813556d-06,-.1133200311692935d-06,
     5      0.9616603083498425d-07,-.6990590242030280d-07,
     6      0.4496248453533618d-07,-.2611420503903012d-07,
     7      0.1390473965503591d-07,-.6867823426275149d-08,
     8      0.3158426279842337d-08,-.1338125787168985d-08/
         data arr1165/
     1      0.5482101009486605d-09,-.2234869574782011d-09,
     2      0.8059361770320427d-10,-.2772822675434573d-06,
     3      0.4540650533677221d-06,-.5197540962187245d-06,
     4      0.4803606053958679d-06,-.3803113414965067d-06,
     5      0.2663876744114627d-06,-.1684368217704694d-06,
     6      0.9768446218939471d-07,-.5261099708986889d-07,
     7      0.2633725200871757d-07,-.1205009004075512d-07,
     8      0.5383450803240563d-08,-.2413884863597543d-08/
         data arr1166/
     1      0.9445116459720967d-09,-.9538373118109815d-06,
     2      0.1692335602451770d-05,-.2098786914902517d-05,
     3      0.2101669121095775d-05,-.1803084156768718d-05,
     4      0.1368302653639859d-05,-.9367887061729049d-06,
     5      0.5887630706540908d-06,-.3442309246402117d-06,
     6      0.1865720483008222d-06,-.9146873439202192d-07,
     7      0.4435127478894161d-07,-.2178792484402621d-07,
     8      0.9200400189200328d-08,-.2954688111225581d-05/
         data arr1167/
     1      0.5653870918990098d-05,-.7561651954404763d-05,
     2      0.8166953899915714d-05,-.7559028694240575d-05,
     3      0.6185941359776715d-05,-.4562456366610536d-05,
     4      0.3093751024384554d-05,-.1956525442026122d-05,
     5      0.1142477798916705d-05,-.5954869703323835d-06,
     6      0.3120999589120135d-06,-.1674352181805500d-06,
     7      0.7593648232808707d-07,-.8329173608431685d-05,
     8      0.1711849450615197d-04,-.2458625567355524d-04/
         data arr1168/
     1      0.2852492655082125d-04,-.2837424411862820d-04,
     2      0.2493471208421415d-04,-.1971525677336993d-04,
     3      0.1436818554638297d-04,-.9801638595380082d-05,
     4      0.6138291134356050d-05,-.3374185739493512d-05,
     5      0.1904837079144502d-05,-.1113014342049623d-05,
     6      0.5398239259209112d-06,-.2156238362366819d-04,
     7      0.4742004327855101d-04,-.7285096790275540d-04,
     8      0.9046938977265357d-04,-.9640822645847929d-04/
         data arr1169/
     1      0.9062344691957420d-04,-.7643546223257141d-04,
     2      0.5967200611637213d-04,-.4382889652157864d-04,
     3      0.2931145680561276d-04,-.1684971283000798d-04,
     4      0.1021556185192369d-04,-.6487503726287288d-05,
     5      0.3352025739139725d-05,-.5167193844583843d-04,
     6      0.1211762831301201d-03,-.1983697566687986d-03,
     7      0.2628599452753540d-03,-.2993587115632044d-03,
     8      0.2998901355115825d-03,-.2684026107769147d-03/
         data arr1170/
     1      0.2238425451894319d-03,-.1768649554010264d-03,
     2      0.1257991420102970d-03,-.7495078067204233d-04,
     3      0.4868118191702941d-04,-.3354700258420159d-04,
     4      0.1840207679870303d-04,-.1154398335472964d-03,
     5      0.2877283063033368d-03,-.4999151378382850d-03,
     6      0.7050154326226316d-03,-.8567860683812066d-03,
     7      0.9114212775289871d-03,-.8604885855659850d-03,
     8      0.7649633518089329d-03,-.6503140049404204d-03/
         data arr1171/
     1      0.4900202688129436d-03,-.2996933739753804d-03,
     2      0.2081257024417316d-03,-.1554587563214967d-03,
     3      0.9025553031996212d-04,-.2420032297049808d-03,
     4      0.6389498452277234d-03,-.1172900331074259d-02,
     5      0.1756950188095139d-02,-.2277922370228276d-02,
     6      0.2563677529844124d-02,-.2535448304714081d-02,
     7      0.2399025127519096d-02,-.2197245770071728d-02,
     8      0.1747306704478208d-02,-.1085600487750410d-02/
         data arr1172/
     1      0.8049057993430379d-03,-.6512758800315887d-03,
     2      0.3990933005979845d-03,-.4790256546941883d-03,
     3      0.1334854004035106d-02,-.2573931007348233d-02,
     4      0.4090729272435346d-02,-.5666858349935908d-02,
     5      0.6721015495972757d-02,-.6903272433363709d-02,
     6      0.6947018334220176d-02,-.6872870022716710d-02,
     7      0.5746634127800311d-02,-.3586068555504479d-02,
     8      0.2835995427462880d-02,-.2485476968712137d-02/
         data arr1173/
     1      0.1603642085789266d-02,-.9010525327420485d-03,
     2      0.2638193053233162d-02,-.5300584752617481d-02,
     3      0.8938718455058144d-02,-.1328270564903346d-01,
     4      0.1652862736147114d-01,-.1744024583412561d-01,
     5      0.1867008870675844d-01,-.2003236597748715d-01,
     6      0.1754772805809545d-01,-.1086247204400809d-01,
     7      0.9159120500922617d-02,-.8698226574502640d-02,
     8      0.5896277186493422d-02,-.1622175874236222d-02/
         data arr1174/
     1      0.4960174284637635d-02,-.1025900984631206d-01,
     2      0.1839332820763906d-01,-.2953199130842458d-01,
     3      0.3836176080801787d-01,-.4100202476228543d-01,
     4      0.4675812412343586d-01,-.5471740266402152d-01,
     5      0.5003927313488964d-01,-.3030982600146844d-01,
     6      0.2725494556582017d-01,-.2807648294900098d-01,
     7      0.1995806627416126d-01,-.2819184904399276d-02,
     8      0.8924168904437337d-02,-.1864517980459454d-01/
         data arr1175/
     1      0.3571721367101250d-01,-.6269448821283070d-01,
     2      0.8451314046945896d-01,-.8983867985812424d-01,
     3      0.1094655102663575d+00,-.1407476838511795d+00,
     4      0.1339320388341153d+00,-.7819156489380433d-01,
     5      0.7505514743147421d-01,-.8401242019132144d-01,
     6      0.6252325491393762d-01,-.4780100378344393d-02,
     7      0.1546774060402946d-01,-.3167715216802022d-01,
     8      0.6548519960926404d-01,-.1279056636433978d+00/
         data arr1176/
     1      0.1777134826644386d+00,-.1834167755810640d+00,
     2      0.2400512319619917d+00,-.3423606986161801d+00,
     3      0.3379501066076581d+00,-.1869918195965874d+00,
     4      0.1919675553618053d+00,-.2340757529482621d+00,
     5      0.1821314523387649d+00,-.8008954900278063d-02,
     6      0.2603279782273537d-01,-.4976550435524078d-01,
     7      0.1131603071724275d+00,-.2522922087160824d+00,
     8      0.3585881039148533d+00,-.3480465577537035d+00/
         data arr1177/
     1      0.4935490328220106d+00,-.7902444623831228d+00,
     2      0.8069846110619903d+00,-.4152259294250818d+00,
     3      0.4573339050766003d+00,-.6096321891192973d+00,
     4      0.4953963088978622d+00,-.1344277789497741d-01,
     5      0.4294802742994899d-01,-.7058361503708686d-01,
     6      0.1833404017715685d+00,-.4837123858055367d+00,
     7      0.6977986182560496d+00,-.6100789126798335d+00,
     8      0.9508888554386770d+00,-.1735854073397369d+01/
         data arr1178/
     1      0.1829536565230925d+01,-.8564723520362153d+00,
     2      0.1016976439671986d+01,-.1489229862707584d+01,
     3      0.1262859926437441d+01,-.2287186370547594d-01,
     4      0.7019949734153916d-01,-.8520965577018054d-01,
     5      0.2753761245056480d+00,-.9053183697886412d+00,
     6      0.1315682095956409d+01,-.9753275078726286d+00,
     7      0.1712577969161770d+01,-.3637388008129467d+01,
     8      0.3949569536489946d+01,-.1638988194803918d+01/
         data arr1179/
     1      0.2113713023257380d+01,-.3422970054139364d+01,
     2      0.3027626061991777d+01,-.3974251176995162d-01,
     3      0.1150381073980706d+00,-.7107757942258702d-01,
     4      0.3744707264977102d+00,-.1661087511019606d+01,
     5      0.2416795181515747d+01,-.1384382353138421d+01,
     6      0.2870439481017342d+01,-.7297019231599675d+01,
     7      0.8153303532411346d+01,-.2902186846443413d+01,
     8      0.4113418131654766d+01,-.7436870632839970d+01/
         data arr1180/
     1      0.6861344786379092d+01,0.2596702384827456d-19,
     2      -.9309882976145472d-22,-.1632329848725766d-20,
     3      -.6319464852726085d-22,0.6319450429647830d-20,
     4      0.1312139768659792d-21,-.1024849798697664d-19,
     5      -.2755495314973491d-21,0.2592178153365184d-19,
     6      0.1752363853951098d-21,-.1048138917058841d-19,
     7      -.3393948608034226d-21,0.3201824064226556d-19,
     8      0.2448303795845153d-19,-.4582594954300057d-21/
         data arr1181/
     1      -.1535049550022663d-20,-.3114232006352372d-21,
     2      0.5972787555015335d-20,0.6464250446903374d-21,
     3      -.9686304505690219d-20,-.1357492854915942d-20,
     4      0.2449978484801559d-19,0.8633012407838718d-21,
     5      -.9906427205035168d-20,-.1672025703708392d-20,
     6      0.3026179450179865d-19,0.2208810409908142d-19,
     7      -.9999308512199187d-21,-.1366755275284028d-20,
     8      -.6835066184498975d-21,0.5454582006590753d-20/
         data arr1182/
     1      0.1416592000826382d-20,-.8845881827164599d-20,
     2      -.2974838110010962d-20,0.2237396223256691d-19,
     3      0.1891860781215347d-20,-.9046938218879068d-20,
     4      -.3664103954264084d-20,0.2763594018893298d-19,
     5      0.1914833630069616d-19,-.1574212528213612d-20,
     6      -.1141327422524144d-20,-.1093575526126388d-20,
     7      0.4889298490964635d-20,0.2256977958484211d-20,
     8      -.7928748804289249d-20,-.4739637806092262d-20/
         data arr1183/
     1      0.2005394420415874d-19,0.3014212368619427d-20,
     2      -.8109041247210735d-20,-.5837769790320347d-20,
     3      0.2477012403643096d-19,0.1602854459740103d-19,
     4      -.2054971226983796d-20,-.8807190582251562d-21,
     5      -.1475598151986558d-20,0.4376936051359855d-20,
     6      0.3019876300774676d-20,-.7095925853836769d-20,
     7      -.6341802961030053d-20,0.1794695225968979d-19,
     8      0.4033177715436606d-20,-.7257436766401429d-20/
         data arr1184/
     1      -.7811043301443733d-20,0.2216730616688209d-19,
     2      0.1301866934759614d-19,-.2365096711092795d-20,
     3      -.6121234755032007d-21,-.1797008860222941d-20,
     4      0.3971242071812750d-20,0.3627241531566298d-20,
     5      -.6432221873731583d-20,-.7617845569868971d-20,
     6      0.1626749698555547d-19,0.4844813190426812d-20,
     7      -.6578900219054860d-20,-.9382502730802034d-20,
     8      0.2009241495826053d-19,0.1030715850937821d-19/
         data arr1185/
     1      -.2481255256237333d-20,-.3627875002697256d-21,
     2      -.2052650826897221d-20,0.3684341625430703d-20,
     3      0.4063415686176669d-20,-.5954026045642060d-20,
     4      -.8535863792975947d-20,0.1505715834543859d-19,
     5      0.5428850434795957d-20,-.6090293377119142d-20,
     6      -.1051279471257450d-19,0.1859676714355383d-19,
     7      0.3732769600237786d-19,-.1366707163553676d-19,
     8      0.3406887994070601d-20,-.9112115767003465d-21/
         data arr1186/
     1      0.5252816755555869d-21,0.3510518516854971d-21,
     2      -.7150132531645904d-21,-.6422454676801812d-21,
     3      0.1304267760371077d-20,0.4754364037545958d-21,
     4      -.8317937442816539d-21,-.6332470235897495d-21,
     5      0.1302628447762455d-20,0.3083316065554613d-17,
     6      -.1403467941242018d-17,0.4467856378752278d-18,
     7      -.1148896491610053d-18,0.2531784778583171d-19,
     8      -.4938643873274949d-20,0.8700189610004116d-21/
         data arr1187/
     1      -.1410956810533492d-21,0.2221183768174968d-22,
     2      -.2651209532139236d-23,-.3775896569704913d-24,
     3      -.4118394076349875d-24,0.1102526505601178d-23,
     4      0.1400433774227800d-15,-.7691344834720873d-16,
     5      0.2954298222898280d-16,-.9166229850165224d-17,
     6      0.2437171505789782d-17,-.5736525181857950d-18,
     7      0.1220209136308491d-18,-.2379306663377369d-19,
     8      0.4297824623413299d-20,-.7246171052519778d-21/
         data arr1188/
     1      0.1148927236578183d-21,-.1745269903559577d-22,
     2      0.2475487078540616d-23,0.3939914451682635d-14,
     3      -.2556847955305656d-14,0.1160473849490151d-14,
     4      -.4254516220891976d-15,0.1336669168895140d-15,
     5      -.3717618733433851d-16,0.9343912670502417d-17,
     6      -.2152933220974975d-17,0.4595188730942374d-18,
     7      -.9150165782059378d-19,0.1714604483933126d-19,
     8      -.3093994940583427d-20,0.5160957034334838d-21/
         data arr1189/
     1      0.7493227043963342d-13,-.5649104110846689d-13,
     2      0.2978534353217862d-13,-.1268557224956651d-13,
     3      0.4629950666980184d-14,-.1495921843895748d-14,
     4      0.4367831001143925d-15,-.1169168568308244d-15,
     5      0.2898914053246692d-16,-.6700215795997872d-17,
     6      0.1458830867736831d-17,-.3079025698340055d-18,
     7      0.5952687284836351d-19,0.1028979643671324d-11,
     8      -.8885731643104982d-12,0.5366510336933632d-12/
         data arr1190/
     1      -.2618034274699762d-12,0.1094503793904952d-12,
     2      -.4050632533901080d-13,0.1354742297419733d-13,
     3      -.4154128347820830d-14,0.1179773523135508d-14,
     4      -.3119175235458393d-15,0.7781687437133773d-16,
     5      -.1896877945365772d-16,0.4189090854609248d-17,
     6      0.1073400750129644d-10,-.1049259136006770d-10,
     7      0.7173251781170577d-11,-.3961270638677097d-11,
     8      0.1874608839769388d-11,-.7853148022611230d-12/
         data arr1191/
     1      0.2973138725979325d-12,-.1032155419187742d-12,
     2      0.3317937563410657d-13,-.9909119013081896d-14,
     3      0.2799767733887229d-14,-.7801550015243469d-15,
     4      0.1944021549033146d-15,0.8853334459396503d-10,
     5      -.9698098383232769d-10,0.7429833241883961d-10,
     6      -.4597886930566046d-10,0.2438330488015858d-10,
     7      -.1144637999484939d-10,0.4856303139837047d-11,
     8      -.1889864919822682d-11,0.6807013990915066d-12/
         data arr1192/
     1      -.2271051550142365d-12,0.7196095584522451d-13,
     2      -.2273040965448418d-13,0.6323932120809003d-14,
     3      0.5961629559651458d-09,-.7255034747790786d-09,
     4      0.6174870510167934d-09,-.4245289826093475d-09,
     5      0.2501120428429087d-09,-.1304273723752469d-09,
     6      0.6147771830148790d-10,-.2659390174228629d-10,
     7      0.1063906560091329d-10,-.3925611090665821d-11,
     8      0.1383371171321533d-11,-.4919583392740015d-12/
         data arr1193/
     1      0.1514250983407487d-12,0.3364069698164636d-08,
     2      -.4514044309710433d-08,0.4236272415326353d-08,
     3      -.3211472008814237d-08,0.2086188263946668d-08,
     4      -.1199329511162235d-08,0.6233745489446038d-09,
     5      -.2976190895709283d-09,0.1312323575036887d-09,
     6      -.5305242192989323d-10,0.2064518267013452d-10,
     7      -.8220011947945415d-11,0.2776890926230169d-11,
     8      0.1625345136796514d-07,-.2388966675118076d-07/
         data arr1194/
     1      0.2455848633779027d-07,-.2039489003249593d-07,
     2      0.1451193872343636d-07,-.9135355030786941d-08,
     3      0.5202011095095704d-08,-.2724871103030453d-08,
     4      0.1315281660387589d-08,-.5773423333434943d-09,
     5      0.2466118092875263d-09,-.1094434192285362d-09,
     6      0.4029323179512417d-10,0.6845306787553697d-07,
     7      -.1095700347833931d-06,0.1226716133302652d-06,
     8      -.1109640934163271d-06,0.8598123261203092d-07/
         data arr1195/
     1      -.5890594947944170d-07,0.3654094630418697d-07,
     2      -.2089847583332707d-07,0.1097492611813568d-07,
     3      -.5184383905949737d-08,0.2418454402670778d-08,
     4      -.1192077033322446d-08,0.4753223007345158d-09,
     5      0.2551313084074930d-06,-.4424235050772207d-06,
     6      0.5367016984037604d-06,-.5261814233818877d-06,
     7      0.4416745778737607d-06,-.3274415790224735d-06,
     8      0.2201897049535362d-06,-.1369845998298742d-06/
         data arr1196/
     1      0.7782339084803110d-07,-.3920504859633898d-07,
     2      0.1988869237687719d-07,-.1085916958133823d-07,
     3      0.4663389851136918d-08,0.8523733948207285d-06,
     4      -.1593782935877758d-05,0.2085496962969544d-05,
     5      -.2206690223862674d-05,0.1997047719186115d-05,
     6      -.1593263708862209d-05,0.1156568130168727d-05,
     7      -.7806818420646190d-06,0.4772576951819198d-06,
     8      -.2539727551533053d-06,0.1396317211356950d-06/
         data arr1197/
     1      -.8428769834808115d-07,0.3879036438872631d-07,
     2      0.2580876175909570d-05,-.5180535859784464d-05,
     3      0.7283341645375705d-05,-.8289049473831459d-05,
     4      0.8052090256564467d-05,-.6873951365933625d-05,
     5      0.5367845669116845d-05,-.3926235295688974d-05,
     6      0.2569681450624538d-05,-.1429803727480262d-05,
     7      0.8496720141573467d-06,-.5663677884248169d-06,
     8      0.2780780407071366d-06,0.7150018933411895d-05/
         data arr1198/
     1      -.1534034437486200d-04,0.2309480597047659d-04,
     2      -.2820126185862334d-04,0.2928012012255096d-04,
     3      -.2658079226445256d-04,0.2226883113924479d-04,
     4      -.1765301178099565d-04,0.1230761360332510d-04,
     5      -.7080563813902550d-05,0.4539478449186283d-05,
     6      -.3339636856067346d-05,0.1742303305242909d-05,
     7      0.1827535874833282d-04,-.4171446844042977d-04,
     8      0.6707234164371226d-04,-.8777829202764263d-04/
         data arr1199/
     1      0.9698546497058312d-04,-.9294746902014847d-04,
     2      0.8339070904314082d-04,-.7177424518637265d-04,
     3      0.5304038708279591d-04,-.3115837780616091d-04,
     4      0.2152891674986563d-04,-.1748406127599469d-04,
     5      0.9657023058275762d-05,0.4341735561662689d-04,
     6      -.1048395966180842d-03,0.1797345814079901d-03,
     7      -.2522831299456543d-03,0.2952458364300577d-03,
     8      -.2960196794455331d-03,0.2842133334596090d-03/
         data arr1200/
     1      -.2665767852891246d-03,0.2077534873808313d-03,
     2      -.1228762352928671d-03,0.9148983386976152d-04,
     3      -.8209450846396611d-04,0.4784823116424198d-04,
     4      0.9652734888800775d-04,-.2446750308864458d-03,
     5      0.4471452890825215d-03,-.6755033262520504d-03,
     6      0.8328090576198297d-03,-.8633116486856001d-03,
     7      0.8876686807896812d-03,-.9125905522645289d-03,
     8      0.7462024870825852d-03,-.4372597639501820d-03/
         data arr1201/
     1      0.3511753852101114d-03,-.3487537261191822d-03,
     2      0.2138629462166050d-03,0.2021443765453410d-03,
     3      -.5315741097763265d-03,0.1037767245707201d-02,
     4      -.1699921095847429d-02,0.2193356794510141d-02,
     5      -.2313776308995237d-02,0.2554656238043129d-02,
     6      -.2902472733758183d-02,0.2477086062042944d-02,
     7      -.1411662157738247d-02,0.1225762534433348d-02,
     8      -.1350722457565730d-02,0.8691395591985568d-03/
         data arr1202/
     1      0.4014377553514572d-03,-.1074410785272299d-02,
     2      0.2254470505729604d-02,-.4056821443851944d-02,
     3      0.5433331832019184d-02,-.5706505721492654d-02,
     4      0.6803162916421010d-02,-.8635793109248757d-02,
     5      0.7652581117605170d-02,-.4150588685914676d-02,
     6      0.3912591808823130d-02,-.4801119451210642d-02,
     7      0.3233944447970320d-02,0.7617249105159785d-03,
     8      -.2008759892672322d-02,0.4591141135260801d-02/
         data arr1203/
     1      -.9265788308624179d-02,0.1275134763210026d-01,
     2      -.1293082708688378d-01,0.1681127824377757d-01,
     3      -.2417999079477895d-01,0.2213568411133457d-01,
     4      -.1113723605252487d-01,0.1147326510346493d-01,
     5      -.1575329499687942d-01,0.1108405816690376d-01,
     6      0.1393700316932517d-02,-.3421454940112922d-02,
     7      0.8754067603461632d-02,-.2043957119706330d-01,
     8      0.2855649958698984d-01,-.2675590991965810d-01/
         data arr1204/
     1      0.3859389465765237d-01,-.6403087095986815d-01,
     2      0.6026775505098288d-01,-.2726761224800133d-01,
     3      0.3101778609253216d-01,-.4795827588773065d-01,
     4      0.3518070790816197d-01,0.2487139168520882d-02,
     5      -.5114220228674866d-02,0.1554422836333479d-01,
     6      -.4391206106702684d-01,0.6146126988957610d-01,
     7      -.4982122993433755d-01,0.8224089496184755d-01,
     8      -.1610117224663001d+00,0.1551484367371998d+00/
         data arr1205/
     1      -.6069658414847048d-01,0.7749870257533852d-01,
     2      -.1360696302423047d+00,0.1038950612680681d+00,
     3      0.4389483617770160d-02,-.6011901782169023d-02,
     4      0.2537136394199132d-01,-.9249082219229184d-01,
     5      0.1279948601088906d+00,-.8069700529624554d-01,
     6      0.1620429444569667d+00,-.3856921331852977d+00,
     7      0.3790895093740977d+00,-.1216801111450819d+00,
     8      0.1791597281278625d+00,-.3612249363465447d+00/
         data arr1206/
     1      0.2866725032216825d+00,0.7776915162830732d-02,
     2      -.2864146669819270d-02,0.3694954784306995d-01,
     3      -.1917540384224355d+00,0.2594781503980278d+00,
     4      -.1033769293877322d+00,0.2925920357044317d+00,
     5      -.8822520140382447d+00,0.8819832659502466d+00,
     6      -.2149622413578134d+00,0.3830243724647376d+00,
     7      -.9003998123615323d+00,0.7418343991569283d+00,
     8      0.1401026196637795d-01,0.1233562957440755d-01/
         data arr1207/
     1      0.4437074823452880d-01,-.3917174007115518d+00,
     2      0.5145793920305248d+00,-.6401070151218950d-01,
     3      0.4749843358880478d+00,-.1930876936272053d+01,
     4      0.1959385787693302d+01,-.3168640281376442d+00,
     5      0.7550797815354194d+00,-.2114247352641307d+01,
     6      0.1806747726503573d+01,0.2586860168816990d-01,
     7      0.5723610161029226d-01,0.3113592769480328d-01,
     8      -.7885246023232177d+00,0.1003131424087736d+01/
         data arr1208/
     1      0.1755266892014944d+00,0.6629739390986873d+00,
     2      -.4056360719923298d+01,0.4173826437613711d+01,
     3      -.3216189839580610d+00,0.1364497197945746d+01,
     4      -.4699416798668812d+01,0.4163285038510221d+01/
        do 1200 i=1,3320
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine mptoxf1(mpole,nterms,nlambs,numtts,nxtot,mexpup)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer nlambs,numtts(nlambs),nxtot,nterms
      complex *16 mpole(0:nterms,0:nterms)
c
      complex *16 mexpup(nxtot)
      parameter (nnlmbs = 3)
      parameter (nmaxnf = 2)
      parameter (nntrms = 2)
c
      real *8 lambda(nnlmbs),wghts(nnlmbs),dtmp(nnlmbs)
c
      complex *16 mult(0:nntrms,0:nntrms),cd(nmaxnf),eye,
     1        expcfs(nnlmbs,nmaxnf)
c
      SAVE ifinit,cd,dtmp
c
c ... first initializing:
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,wghts,nlambs)
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nmaxnf
            cd(i) = 1.0d0/cd(i)
 102     continue
c
         do 103 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(lambda(i)*1.5d0)/wghts(i)
 103     continue
c
ccc         do 104 i = 1, nxtot
ccc            mexpup(i) = 0.0d0
ccc 104     continue
c
         ifinit = 1
      endif
c
c ... you don't want to mess the input data:
c
      do 106 i=0,nntrms
         do 105 j = 0, i
            mult(i,j)=mpole(i,j)
 105     continue
 106  continue
c
c ... generate mexpup: using vladimir's shceme:
c
      call alota1(mult,expcfs)
c
c the expcfs needs to be normalized back to leslie's notation:
c
      ntot = 0
      do 108 i = 1, nlambs
         mexpup(ntot+1) = expcfs(i,1)*(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j 
            mexpup(ncrrnt) = expcfs(i,j)*cd(j)*dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c-----------end of mpoletoexp-------------------------------------------
      return
      end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine xftota1(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer nlambs,numtts(nlambs),nxtot,nthmax
      real *8  rlams(nlambs),whts(nlambs)
c
      complex *16 local(0:nterms,0:nterms), mexpup(nxtot)
      parameter (nnlmbs = 3)
      parameter (nmaxnf = 2)
      parameter (nntrms = 2)
c
      real *8 dtmp(nnlmbs)
c
      complex *16 expcfs(nnlmbs,nmaxnf),
     1   taylor(0:nntrms,0:nntrms),cd(nmaxnf),eye
      SAVE ifinit,cd,dtmp
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(-rlams(i)*0.5d0)/whts(i)
 102     continue
c
         do 104 i = 1, nlambs
            do 103 j = 1, nmaxnf
              expcfs(i,j) = 0.0d0
 103        continue
 104     continue
c
         ifinit = 1
      endif
c
c ... initialize local expansion
c
      do 106 nm = 0,nterms
         do 105 mth = 0,nm
            local(nm,mth) = 0.0d0
 105     continue
 106  continue
c
      ntot = 0
      do 108 i = 1, nlambs
         expcfs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j
            expcfs(i,j) = mexpup(ncrrnt)*cd(j)/dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c
      call atalo1(expcfs,taylor)
c
      do 110 l=0,nntrms
         do 109 m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
 109     continue
 110  continue
c-----------end of exptolocal-------------------------------------------
      return
      end
c 
c
c 
c
c///////////////////////////////////////////////////////////////////////
        subroutine alota1(mult,expcfs)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        dimension map(2),nsstrd(2),num1s(2),num2s(2)
        real *8  arr(11)
c
        complex *16 mult(0:2,0:2),expcfs(3,2)
c
        SAVE ifinit,arr
c
c       This subroutine transforms a multipole expansion of
c       order 2 into a bessel expansion of order (3,2);
c       the accuracy of the resulting scheme is about 0.08d0.
c
c	 and map=
c	       1      10
c	 and nsstored=
c	       9       2
c	 and num1s=
c	       1       3
c	 and num2s=
c	       3       3
c	 and errs=
c	  0.75183E-01  0.75915E-01
c	 and vals=
c	  0.10000E+01  0.10689E+00
c
c ... initialize "arr" and write "expcfs" to 0 on the first call:
c
        data map/1,10/
        data nsstrd/9,2/
        data num1s/1,3/
        data num2s/3,3/
        data ifinit/0/
        if(ifinit .eq. 0) then
           call lot1get(arr)
c
           do i=1,2
              do j=1,3
                 expcfs(j,i)=0.0d0
	      enddo
	   enddo
c
           ifinit = 1
        endif
c
c ... one wave number m after another, calculate the coefficients of the
c         exponential expansion
c
        do 2000 m=0,1
           numexp=num2s(m+1)-num1s(m+1)+1
           nnmult=2-m+1
c
           iarr=map(m+1)
           num1=num1s(m+1)
           call mtvc34(arr(iarr),numexp,nnmult,
     1         mult(m,m),expcfs(num1,m+1) )
 2000 continue
c
        return
        end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
        subroutine atalo1(expcfs,taylor)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        dimension map(2),nsstrd(2),num1s(2),num2s(2)
        real *8  arr(15)
c
        complex *16 taylor(0:2,0:2),expcfs(3,2)
***        data map/1,10/
c
c
	SAVE ifinit,arr
c
c       this subroutine transforms a bessel expansion of order (3,2)
c       into a local expansion of order 2; the accuracy of the 
c       resulting scheme is about 1 digits.
c
c	 and map=
c	       1      10
c	 and nsstored=
c	       9       6
c	 and errs=
c	  0.16140E-01  0.12299E-01
c	 and vals=
c	  0.78806E+00  0.12278E+00
c
c ... initialize "arr" and write "taylor" to 0 on the first call:
c
        data map/1,14/
        data nsstrd/9,6/
        data num1s/1,3/
        data num2s/3,3/
        data ifinit/0/
        if(ifinit .eq. 0) then
ccc           do i = 1, 2
ccc              map(i) = map(i) + (num1s(i)-1)*(2-(i-1)+1)
ccc           enddo
ccc           print *, map
ccc	      STOP
c
           call lot1geta(arr)
c
           do i=0,2
              do j=0,i
                 taylor(i,j)=0.0d0
	      enddo
	   enddo
c
           ifinit=1
        endif
c
c ... one wave number m after another, calculate the coefficients of the
c         taylor series
c
        do 2000 m=0,1
           numexp=num2s(m+1)-num1s(m+1)+1
           nntylr=2-m+1
c
           iarr=map(m+1)
           num1=num1s(m+1)
           call mtvc34(arr(iarr),nntylr,numexp,
     1         expcfs(num1,m+1),taylor(m,m) )
 2000 continue
c
        return
        end
c
c
c
c
c
        subroutine lot1get(arr)
        implicit real *8(a-h,o-z)
c
c	This is the data TABLE for the 1 digits LOTA map.
c
        real *8 arr(1)
         real *8
     1  arr1001(11)
c
         data arr1001/
     1      0.3883572018012448D+00,0.2026883609043107D+00,
     2      0.6418642191775227D-01,0.7986735770781474D-01,
     3      0.1828712021956250D+00,0.1392941107578361D+00,
     4      0.1166717802425026D-01,0.9411809445490839D-01,
     5      0.1684893727611148D+00,-.2961385166104095D+00,
     6      -.2102690266809543D+00/
        do 1200 i=1,11
           arr(i)=arr1001(i)
 1200 continue
c
        return
        end
c
c
c
c
c
        subroutine lot1geta(arr)
        implicit real *8(a-h,o-z)
c
c	This is the data TABLE for the 1 digits TALO map.
c
        real *8 arr(1)
         real *8
     1  arr1001(15)
c
         data arr1001/
     1      0.8877218598476543D+00,-.2111648741916543D+00,
     2      0.2519813293667095D-01,0.6350605678062444D+00,
     3      -.5646958078265347D+00,0.2629354539417150D+00,
     4      0.4062063680809918D+00,-.6778577540368648D+00,
     5      0.6630395888763366D+00,-.7489547861735793D-01,
     6      0.1027086540102259D-01,-.2087544401720193D+00,
     7      0.1049101331661611D+00,-.2799319247253748D+00,
     8      0.2479139163963066D+00/
        do 1200 i=1,15
           arr(i)=arr1001(i)
 1200 continue
c
        return
        end
c
c
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine mptoxf2(mpole,nterms,nlambs,numtts,nxtot,mexpup)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer nlambs,numtts(nlambs),nxtot,nterms
      complex *16 mpole(0:nterms,0:nterms)
c
      complex *16 mexpup(nxtot)
      parameter (nnlmbs = 5)
      parameter (nmaxnf = 3)
      parameter (nntrms = 3)
c
      real *8 lambda(nnlmbs),wghts(nnlmbs),dtmp(nnlmbs)
c
      complex *16 mult(0:nntrms,0:nntrms),cd(nmaxnf),eye,
     1        expcfs(nnlmbs,nmaxnf)
c
      SAVE ifinit,cd,dtmp
c
c ... first initializing:
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,wghts,nlambs)
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nmaxnf
            cd(i) = 1.0d0/cd(i)
 102     continue
c
         do 103 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(lambda(i)*1.5d0)/wghts(i)
 103     continue
c
ccc         do 104 i = 1, nxtot
ccc            mexpup(i) = 0.0d0
ccc 104     continue
c
         ifinit = 1
      endif
c
c ... you don't want to mess the input data:
c
      do 106 i=0,nntrms
         do 105 j = 0, i
            mult(i,j)=mpole(i,j)
 105     continue
 106  continue
c
c ... generate mexpup: using vladimir's shceme:
c
      call alota2(mult,expcfs)
c
c the expcfs needs to be normalized back to leslie's notation:
c
      ntot = 0
      do 108 i = 1, nlambs
         mexpup(ntot+1) = expcfs(i,1)*(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j 
            mexpup(ncrrnt) = expcfs(i,j)*cd(j)*dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c-----------end of mpoletoexp-------------------------------------------
      return
      end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine xftota2(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer nlambs,numtts(nlambs),nxtot,nthmax
      real *8  rlams(nlambs),whts(nlambs)
c
      complex *16 local(0:nterms,0:nterms), mexpup(nxtot)
      parameter (nnlmbs = 5)
      parameter (nmaxnf = 3)
      parameter (nntrms = 3)
c
      real *8 dtmp(nnlmbs)
c
      complex *16 expcfs(nnlmbs,nmaxnf),
     1   taylor(0:nntrms,0:nntrms),cd(nmaxnf),eye
      SAVE ifinit,cd,dtmp
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(-rlams(i)*0.5d0)/whts(i)
 102     continue
c
         do 104 i = 1, nlambs
            do 103 j = 1, nmaxnf
              expcfs(i,j) = 0.0d0
 103        continue
 104     continue
c
         ifinit = 1
      endif
c
c ... initialize local expansion
c
      do 106 nm = 0,nterms
         do 105 mth = 0,nm
            local(nm,mth) = 0.0d0
 105     continue
 106  continue
c
      ntot = 0
      do 108 i = 1, nlambs
         expcfs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j
            expcfs(i,j) = mexpup(ncrrnt)*cd(j)/dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c
      call atalo2(expcfs,taylor)
c
      do 110 l=0,nntrms
         do 109 m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
 109     continue
 110  continue
c-----------end of exptolocal-------------------------------------------
      return
      end
c 
c
c 
c
c///////////////////////////////////////////////////////////////////////
        subroutine alota2(mult,expcfs)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        dimension map(3),nsstrd(3),num1s(3),num2s(3)
        real *8  arr(31)
c
        complex *16 mult(0:3,0:3),expcfs(5,3)
c
        SAVE ifinit,arr
c
c       This subroutine transforms a multipole expansion of
c       order 3 into a bessel expansion of order (5,3);
c       the accuracy of the resulting scheme is about 0.021d0.
c
c	 and map=
c	       1      21      30
c	 and nsstored=
c	      20       9       2
c	 and num1s=
c	       1       2       4
c	 and num2s=
c	       5       4       4
c	 and errs=
c	  0.20744E-01  0.17750E-01  0.15944E-01
c	 and vals=
c	  0.10000E+01  0.10689E+00  0.24902E-01
c
c ... initialize "arr" and write "expcfs" to 0 on the first call:
c
        data map/1,21,30/
        data nsstrd/20,9,2/
        data num1s/1,2,4/
        data num2s/5,4,4/
        data ifinit/0/
        if(ifinit .eq. 0) then
           call lot2get(arr)
c
           do i=1,3
              do j=1,5
                 expcfs(j,i)=0.0d0
	      enddo
	   enddo
c
           ifinit = 1
        endif
c
c ... one wave number m after another, calculate the coefficients of the
c         exponential expansion
c
        do 2000 m=0,2
           numexp=num2s(m+1)-num1s(m+1)+1
           nnmult=3-m+1
c
           iarr=map(m+1)
           num1=num1s(m+1)
           call mtvc34(arr(iarr),numexp,nnmult,
     1         mult(m,m),expcfs(num1,m+1) )
 2000 continue
c
        return
        end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
        subroutine atalo2(expcfs,taylor)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        dimension map(3),nsstrd(3),num1s(3),num2s(3)
        real *8  arr(45)
c
        complex *16 taylor(0:3,0:3),expcfs(5,3)
***        data map/1,21,36/
c
c
	SAVE ifinit,arr
c
c       this subroutine transforms a bessel expansion of order (5,3)
c       into a local expansion of order 3; the accuracy of the 
c       resulting scheme is about 2 digits.
c
c	 and map=
c	       1      21      36
c	 and nsstored=
c	      20      15      10
c	 and errs=
c	  0.71383E-02  0.51780E-02  0.45251E-02
c	 and vals=
c	  0.84056E+00  0.11981E+00  0.28270E-01
c
c ... initialize "arr" and write "taylor" to 0 on the first call:
c
        data map/1,24,42/
        data nsstrd/20,15,10/
        data num1s/1,2,4/
        data num2s/5,4,4/
        data ifinit/0/
        if(ifinit .eq. 0) then
ccc           do i = 1, 3
ccc              map(i) = map(i) + (num1s(i)-1)*(3-(i-1)+1)
ccc           enddo
ccc           print *, map
ccc	      STOP
c
           call lot2geta(arr)
c
           do i=0,3
              do j=0,i
                 taylor(i,j)=0.0d0
	      enddo
	   enddo
c
           ifinit=1
        endif
c
c ... one wave number m after another, calculate the coefficients of the
c         taylor series
c
        do 2000 m=0,2
           numexp=num2s(m+1)-num1s(m+1)+1
           nntylr=3-m+1
c
           iarr=map(m+1)
           num1=num1s(m+1)
           call mtvc34(arr(iarr),nntylr,numexp,
     1         expcfs(num1,m+1),taylor(m,m) )
 2000 continue
c
        return
        end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
        subroutine mmmtvc34(alota,numexp,nnmult,cw1,cw2)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        complex *16 cw1(1),cw2(1),cd
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        do 1200 j=1,nnmult
        cd=cd+alota(i,j)*cw1(j)
 1200 continue
c
        cw2(i)=cd
 1400 continue
c
        return
        end
c
c
c
c
c
        subroutine lot2get(arr)
        implicit real *8(a-h,o-z)
c
c	This is the data TABLE for the 2 digits LOTA map.
c
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(15)
         real *8
     1  arr2001(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2))
c
         data arr1001/
     1      0.3159223046891704D+00,0.2264496309467716D+00,
     2      0.8615478297566785D-01,0.2617880047563401D-01,
     3      0.5271628434819990D-02,0.5143863462213370D-01,
     4      0.1619060246461520D+00,0.1345691189703289D+00,
     5      0.6521814842562408D-01,0.2863700432870358D-01,
     6      0.5494295334069020D-02,0.5766351997252337D-01,
     7      0.1016922463562318D+00,0.8439855435758661D-01,
     8      0.5670220910235421D-01,0.1034769576763437D-02/
         data arr1002/
     1      0.1190420060375751D-01,0.5156188025955763D-01,
     2      0.6430096860585548D-01,0.5896871406807926D-01,
     3      -.2826640183258880D+00,-.1765950391473583D+00,
     4      -.8424715743124665D-01,-.1016242150025548D+00,
     5      -.1607643045155889D+00,-.1261836442742507D+00,
     6      -.2778416580242924D-01,-.9086037116925938D-01,
     7      -.1115381834552931D+00,0.1088947845776777D+00,
     8      0.8397425876835354D-01/
        do 1200 i=1,31
           arr(i)=arr1001(i)
 1200 continue
c
        return
        end
c
c
c
c
c
        subroutine lot2geta(arr)
        implicit real *8(a-h,o-z)
c
c	This is the data TABLE for the 2 digits TALO map.
c
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(13)
         real *8
     1  arr2001(2),arr2002(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2))
c
         data arr1001/
     1      0.9168198349560914D+00,-.1592368651966619D+00,
     2      0.1383388334670546D-01,-.8006582377634401D-03,
     3      0.6972477801787036D+00,-.5021895697890660D+00,
     4      0.1819471608673075D+00,-.4342126662896519D-01,
     5      0.4743264414285808D+00,-.7039793844697699D+00,
     6      0.5305523017940083D+00,-.2538020879754120D+00,
     7      0.2888322776516123D+00,-.7244508923069248D+00,
     8      0.9003141770964213D+00,-.6623549809903173D+00/
         data arr1002/
     1      0.1453157760984208D+00,-.6337314134864067D+00,
     2      0.1157836843399697D+01,-.1135949113040015D+01,
     3      -.5629867449659364D-01,0.5642920588540518D-02,
     4      -.3464870106115181D-03,-.1774958443230210D+00,
     5      0.7321185509142661D-01,-.1860911762435333D-01,
     6      -.2475641437906641D+00,0.2037660057253516D+00,
     7      -.1052996884965414D+00,-.2474183485220481D+00,
     8      0.3134228531472085D+00,-.2575121686836224D+00/
         data arr1003/
     1      -.1947984436526629D+00,0.3388517653928818D+00,
     2      -.3977859235739673D+00,0.2826518319084993D-02,
     3      -.2192422788130038D-03,0.3773579491437033D-01,
     4      -.1186588328718548D-01,0.1150723008406649D+00,
     5      -.6885750162249422D-01,0.2092221807130368D+00,
     6      -.1767316731340254D+00,0.2877653719981282D+00,
     7      -.2932899514144917D+00/
        do 1200 i=1,45
           arr(i)=arr1001(i)
 1200 continue
c
        return
        end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine mptoxf3(mpole,nterms,nlambs,numtts,nxtot,mexpup)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer nlambs,numtts(nlambs),nxtot,nterms
      complex *16 mpole(0:nterms,0:nterms)
c
      complex *16 mexpup(nxtot)
      parameter (nnlmbs = 8)
      parameter (nmaxnf = 5)
      parameter (nntrms = 7)
c
      real *8 lambda(nnlmbs),wghts(nnlmbs),dtmp(nnlmbs)
c
      complex *16 mult(0:nntrms,0:nntrms),cd(nmaxnf),eye,
     1 expcfs(nnlmbs,nmaxnf)
      save
c
c ... first initializing:
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,wghts,nlambs)
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nmaxnf
            cd(i) = 1.0d0/cd(i)
 102     continue
c
         do 103 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(lambda(i)*1.5d0)/wghts(i)
 103     continue
c
ccc         do 104 i = 1, nxtot
ccc            mexpup(i) = 0.0d0
ccc 104     continue
c
         ifinit = 1
      endif
c
c ... you don't want to mess the input data:
c
      do 106 i=0,nntrms
         do 105 j = 0, i
            mult(i,j)=mpole(i,j)
 105     continue
 106  continue
c
c ... generate mexpup: using vladimir's shceme:
c
      call alota3(mult,expcfs)
c
c the expcfs needs to be normalized back to leslie's notation:
c
      ntot = 0
      do 108 i = 1, nlambs
         mexpup(ntot+1) = expcfs(i,1)*(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j 
            mexpup(ncrrnt) = expcfs(i,j)*cd(j)*dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c-----------end of mpoletoexp-------------------------------------------
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine xftota3(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      integer nlambs,numtts(nlambs),nxtot,nthmax
c
      real *8  rlams(nlambs),whts(nlambs)
c
      complex *16 local(0:nterms,0:nterms), mexpup(nxtot)
      parameter (nnlmbs = 8)
      parameter (nmaxnf = 5)
      parameter (nntrms = 7)
c
c
      real *8 dtmp(nnlmbs)
c
      complex *16 expcfs(nnlmbs,nmaxnf),
     1   taylor(0:nntrms,0:nntrms),cd(nmaxnf),eye
      save
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
c
         cd(1) = 0.50d0
         cd(2) = eye
         do 101 i = 3, nmaxnf
            cd(i) = cd(i-1)*eye
 101     continue
c
         do 102 i = 1, nlambs
            dtmp(i) = 0.5d0*exp(-rlams(i)*0.5d0)/whts(i)
 102     continue
c
         do 104 i = 1, nlambs
            do 103 j = 1, nmaxnf
              expcfs(i,j) = 0.0d0
 103        continue
 104     continue
c
         ifinit = 1
      endif
c
c ... initialize local expansion
c
      do 106 nm = 0,nterms
         do 105 mth = 0,nm
            local(nm,mth) = 0.0d0
 105     continue
 106  continue
c
      ntot = 0
      do 108 i = 1, nlambs
         expcfs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do 107 j = 2, numtts(i)
            ncrrnt = ntot + j
            expcfs(i,j) = mexpup(ncrrnt)*cd(j)/dtmp(i)
 107     continue
         ntot = ntot + numtts(i)
 108  continue
c
      call atalo3(expcfs,taylor)
c
      do 110 l=0,nntrms
         do 109 m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
 109     continue
 110  continue
c-----------end of exptolocal-------------------------------------------
      return
      end
c 
c
c///////////////////////////////////////////////////////////////////////
        subroutine alota3(mult,expcfs)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        complex *16 mult(0:7,0:7),expcfs(8,5)
c
        real *8  arr(199)
        dimension map(5),nsstrd(5),num1s(5),num2s(5)
      save
c
c       this subroutine transforms a multipole expansion of
c       order 7 into a bessel expansion of order (10,8);
c       the accuracy of the resulting scheme is about 3 digits.
c
c ... one wave number m after another, calculate the coefficients of the
c         exponential expansion
c
        data map/1,65,121,163,188/
        data nsstrd/64,56,42,25,12/
        data num1s/1,1,2,3,5/
        data num2s/8,8,8,7,7/
        data ifinit/0/
        if(ifinit .eq. 0) then
          call lot3get(arr)
c
        do 1400 i=1,5
        do 1200 j=1,8
c
        expcfs(j,i)=0
 1200 continue
 1400 continue
c
          ifinit = 1
        endif
c
        do 2000 m=0,4
c
        iarr=map(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
cccc        nnmult=15-m+1
        nnmult=7-m+1
        num1=num1s(m+1)
c
        call mtvc34(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcfs(num1,m+1) )
 2000 continue
        return
        end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
        subroutine atalo3(expcfs,taylor)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
c
        complex *16 taylor(0:7,0:7),expcfs(8,5)
c
        real *8  arr(240)
        dimension map(5),nsstrd(5)
        dimension num1s(5),num2s(5)
c
ccc        data map/1,65,121,169,209/
c
      save
c
c       this subroutine transforms a bessel expansion of order (10,8)
c       into a local expansion of order 7; the accuracy of the 
c       resulting scheme is about 3 digits.
c
c ... one wave number m after another, calculate the coefficients of the
c         taylor series
c
        data map/1,65,127,179,225/
        data nsstrd/64,56,48,40,32/
        data num1s/1,1,2,3,5/
        data num2s/8,8,8,7,7/
        data ifinit/0/
        if(ifinit .eq. 0) then
ccc           do i = 1, 5
ccc              map(i) = map(i) + (num1s(i)-1)*(7-(i-1)+1)
ccc           enddo
ccc           print *, map
           call lot3geta(arr)
c
        do 1400 i=0,7
        do 1200 j=0,i
c
        taylor(i,j)=0
 1200 continue
 1400 continue
          ifinit=1
        endif
c
        ntylr=7
        numexp=8

        do 2000 m=0,4
c
        iarr=map(m+1)
        nntylr=ntylr-m+1
        num1=num1s(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
c
        call mtvc34(arr(iarr),nntylr,numexp,
     1      expcfs(num1,m+1),taylor(m,m) )
 2000 continue
        return
        end
c
c///////////////////////////////////////////////////////////////////////
        subroutine mtvc34(alota,numexp,nnmult,cw1,cw2)
c///////////////////////////////////////////////////////////////////////
        implicit real *8(a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        do 1200 j=1,nnmult
        cd=cd+alota(i,j)*cw1(j)
 1200 continue
c
        cw2(i)=cd
 1400 continue
        return
        end
c
c
c
        subroutine lot3get(arr)
        implicit real *8(a-h,o-z)
c
        real *8 arr(1)
         real *8 
     1  ar1001(16),ar1002(16),ar1003(16),ar1004(16),
     2  ar1005(16),ar1006(16),ar1007(16),ar1008(16),
     3  ar1009(16),ar1010(16),ar1011(16),ar1012(16)
         real *8
     1  ar1013( 7)
         real *8
     1  ar2001(2),ar2002(2),ar2003(2),ar2004(2),
     2  ar2005(2),ar2006(2),ar2007(2),ar2008(2),
     3  ar2009(2),ar2010(2),ar2011(2),ar2012(2)
         equivalence
     1  (ar1001(16),ar2001(1)),(ar1002(1),ar2001(2)),
     2  (ar1002(16),ar2002(1)),(ar1003(1),ar2002(2)),
     3  (ar1003(16),ar2003(1)),(ar1004(1),ar2003(2)),
     4  (ar1004(16),ar2004(1)),(ar1005(1),ar2004(2)),
     5  (ar1005(16),ar2005(1)),(ar1006(1),ar2005(2)),
     6  (ar1006(16),ar2006(1)),(ar1007(1),ar2006(2)),
     7  (ar1007(16),ar2007(1)),(ar1008(1),ar2007(2)),
     8  (ar1008(16),ar2008(1)),(ar1009(1),ar2008(2)),
     9  (ar1009(16),ar2009(1)),(ar1010(1),ar2009(2)),
     a  (ar1010(16),ar2010(1)),(ar1011(1),ar2010(2))
         equivalence
     1  (ar1011(16),ar2011(1)),(ar1012(1),ar2011(2)),
     2  (ar1012(16),ar2012(1)),(ar1013(1),ar2012(2))
c
         data ar1001/
     1      0.2301553062718833d+00,0.2426405607749711d+00,
     2      0.1264171854532939d+00,0.4736712962260299d-01,
     3      0.1461498155513891d-01,0.4174841163597342d-02,
     4      0.1126052436541781d-02,0.2222840736016656d-03,
     5      0.2515355566881463d-01,0.1252684899953265d+00,
     6      0.1432768009894581d+00,0.8934172509024978d-01,
     7      0.4009947944355507d-01,0.1484142719168725d-01,
     8      0.4827692174465899d-02,0.1646981677987988d-02/
         data ar1002/
     1      0.1415589823916361d-02,0.3247513274548099d-01,
     2      0.8116353589282292d-01,0.8390780354632914d-01,
     3      0.5476597294693882d-01,0.2681936735827450d-01,
     4      0.1097050928687432d-01,0.5014356530321760d-02,
     5      0.6046434965966339d-04,0.5569750085501200d-02,
     6      0.3071864311127490d-01,0.5262512382440606d-01,
     7      0.4955041743445177d-01,0.3247328110856605d-01,
     8      0.1683575072046481d-01,0.9226485999467798d-02/
         data ar1003/
     1      0.2595287237740555d-04,0.6658572774027776d-03,
     2      0.8804149639207866d-02,0.2470800103250547d-01,
     3      0.3340073811006389d-01,0.2897524506655710d-01,
     4      0.1846555366898315d-01,0.1162739882648938d-01,
     5      0.8844976340220310d-04,-.1062371866561275d-03,
     6      0.2203895704080417d-02,0.9203782650349941d-02,
     7      0.1839341828117407d-01,0.2147934480414546d-01,
     8      0.1752238184799727d-01,0.1455794482463639d-01/
         data ar1004/
     1      0.1090038831939744d-03,-.2137888544399374d-03,
     2      0.6354598738741718d-03,0.2744027480781307d-02,
     3      0.8307084386652643d-02,0.1273707768127892d-01,
     4      0.1278402298716559d-01,0.1308558690931912d-01,
     5      0.8043891044701048d-04,-.1660637569531730d-03,
     6      0.2881340210968636d-03,0.6716407971331280d-03,
     7      0.3283352534009019d-02,0.6786550838440857d-02,
     8      0.8458921012592834d-02,0.1076979235088333d-01/
         data ar1005/
     1      -.3624292714234110d-01,-.1774788330949875d+00,
     2      -.2025233790702503d+00,-.1262783728575870d+00,
     3      -.5677222106904924d-01,-.2082891145624850d-01,
     4      -.6723668100729904d-02,-.2222074317543085d-02,
     5      -.3928485894321734d-03,-.5368040383401758d-01,
     6      -.1322946492979332d+00,-.1372157859209124d+00,
     7      -.8901717560067866d-01,-.4369504867421081d-01,
     8      -.1777747389312765d-01,-.7207353235880262d-02/
         data ar1006/
     1      -.8767202779086395d-03,-.9138633887774663d-02,
     2      -.5363783167376938d-01,-.9086664560138268d-01,
     3      -.8540773266536289d-01,-.5645591322090977d-01,
     4      -.2880297322156086d-01,-.1437428814285484d-01,
     5      -.2964084087537176d-03,-.9909392314239151d-03,
     6      -.1589849824954515d-01,-.4402449244374805d-01,
     7      -.5939498771885861d-01,-.5149464640529538d-01,
     8      -.3220742541742268d-01,-.1850975024327699d-01/
         data ar1007/
     1      -.2305630797709265d-04,0.1063840734770211d-03,
     2      -.4021023414117024d-02,-.1674939620877440d-01,
     3      -.3282443777069353d-01,-.3870390432434925d-01,
     4      -.3084113917202654d-01,-.2264368936367868d-01,
     5      -.9319694128900668d-04,0.2708354640633611d-03,
     6      -.1130509374670561d-02,-.4968554619025697d-02,
     7      -.1407224410801266d-01,-.2173413061125213d-01,
     8      -.2051111784993455d-01,-.1737700017149464d-01/
         data ar1008/
     1      -.1535268727444879d-03,0.4497834134890709d-03,
     2      -.8174468994777331d-03,-.9979729909203108d-03,
     3      -.5319272967709204d-02,-.1260875819678020d-01,
     4      -.1488690022805801d-01,-.1648855327757846d-01,
     5      0.2652340931591909d-01,0.6631711081362111d-01,
     6      0.6847332080011025d-01,0.4464035907697212d-01,
     7      0.2180712992602309d-01,0.8729298347873490d-02,
     8      0.3518336341952276d-02,0.5980457835044232d-02/
         data ar1009/
     1      0.3371680198876004d-01,0.5756078620917862d-01,
     2      0.5415851135068430d-01,0.3540979441766631d-01,
     3      0.1799418665780010d-01,0.8825225571163794d-02,
     4      0.7983165089383149d-03,0.1112151889896570d-01,
     5      0.3114418288474000d-01,0.4208199132933702d-01,
     6      0.3614152102612082d-01,0.2236676529258801d-01,
     7      0.1248376048533467d-01,-.3720939480091308d-03,
     8      0.3139114384464427d-02,0.1248809516009582d-01/
         data ar1010/
     1      0.2512909410555186d-01,0.2915347263184982d-01,
     2      0.2294656275781094d-01,0.1673155093704645d-01,
     3      -.6068318153411651d-03,0.1074637256312530d-02,
     4      0.3767194081803417d-02,0.1184485804552965d-01,
     5      0.1814635031875968d-01,0.1741184926837963d-01,
     6      0.1551837262084406d-01,-.4956318878073723d-03,
     7      0.5408285309798991d-03,0.7925741287528563d-03,
     8      0.4742461067583494d-02,0.9837795639871144d-02/
         data ar1011/
     1      0.1158536701205089d-01,0.1276605890252985d-01,
     2      -.1463445757608877d-01,-.2306829413699003d-01,
     3      -.2231480582243280d-01,-.1480459916227100d-01,
     4      -.8166981695560301d-02,-.5890779358934118d-02,
     5      -.1662038505599955d-01,-.2284285876734877d-01,
     6      -.1903976623370061d-01,-.1312273931101803d-01,
     7      -.1455592050954492d-02,-.7839942201974948d-02,
     8      -.1593739750224157d-01,-.1761158819677320d-01/
         data ar1012/
     1      -.1642793150118801d-01,-.2177522775017047d-03,
     2      -.2712694503315961d-02,-.8195198395976761d-02,
     3      -.1155571833307886d-01,-.1336562477070393d-01,
     4      -.6664864963835254d-04,-.6634280581057227d-03,
     5      -.3792833225220339d-02,-.7372995874196016d-02,
     6      -.1124790872819141d-01,0.7816149073259566d-02,
     7      0.7496868593806696d-02,0.4990797876008961d-02,
     8      0.7229347463813508d-02,0.8986661737264704d-02/
         data ar1013/
     1      0.7444032811001805d-02,0.4768753544702473d-02,
     2      0.7320441011412844d-02,0.7512249203018180d-02,
     3      0.2502242233874854d-02,0.4548312100969366d-02,
     4      0.5662845247337578d-02/
        do 1200 i=1,199
        arr(i)=ar1001(i)
 1200 continue
        return
        end
c
c
c
c
c
        subroutine lot3geta(arr)
        implicit real *8(a-h,o-z)
        dimension arr(1)
c
         real *8
     1  ar1001(16),ar1002(16),ar1003(16),ar1004(16),
     2  ar1005(16),ar1006(16),ar1007(16),ar1008(16),
     3  ar1009(16),ar1010(16),ar1011(16),ar1012(16)
         real *8
     1  ar1013(16),ar1014(16),ar1015(16)
         real *8
     1  ar2001(2),ar2002(2),ar2003(2),ar2004(2),
     2  ar2005(2),ar2006(2),ar2007(2),ar2008(2),
     3  ar2009(2),ar2010(2),ar2011(2),ar2012(2)
         real *8
     1  ar2013(2),ar2014(2)
         equivalence
     1  (ar1001(16),ar2001(1)),(ar1002(1),ar2001(2)),
     2  (ar1002(16),ar2002(1)),(ar1003(1),ar2002(2)),
     3  (ar1003(16),ar2003(1)),(ar1004(1),ar2003(2)),
     4  (ar1004(16),ar2004(1)),(ar1005(1),ar2004(2)),
     5  (ar1005(16),ar2005(1)),(ar1006(1),ar2005(2)),
     6  (ar1006(16),ar2006(1)),(ar1007(1),ar2006(2)),
     7  (ar1007(16),ar2007(1)),(ar1008(1),ar2007(2)),
     8  (ar1008(16),ar2008(1)),(ar1009(1),ar2008(2)),
     9  (ar1009(16),ar2009(1)),(ar1010(1),ar2009(2)),
     a  (ar1010(16),ar2010(1)),(ar1011(1),ar2010(2))
         equivalence
     1  (ar1011(16),ar2011(1)),(ar1012(1),ar2011(2)),
     2  (ar1012(16),ar2012(1)),(ar1013(1),ar2012(2)),
     3  (ar1013(16),ar2013(1)),(ar1014(1),ar2013(2)),
     4  (ar1014(16),ar2014(1)),(ar1015(1),ar2014(2))
c
         data ar1001/
     1      0.9467940044054348d+00,-.1035295268058131d+00,
     2      0.5660345793687612d-02,-.2063148262628421d-03,
     3      0.5640000860854349d-05,-.1233439626741918d-06,
     4      0.2247797633486835d-08,-.3511191771360389d-10,
     5      0.7719398050417403d+00,-.3996312377645299d+00,
     6      0.1034440308095028d+00,-.1785090194399047d-01,
     7      0.2310320798844593d-02,-.2392103281603350d-03,
     8      0.2062121704988796d-04,-.1524394023927345d-05/
         data ar1002/
     1      0.5674896423204567d+00,-.6430030867361862d+00,
     2      0.3642833562189312d+00,-.1375853993915839d+00,
     3      0.3896537977160863d-01,-.8830831897831036d-02,
     4      0.1660525303003106d-02,-.2682091109802789d-03,
     5      0.3903682192028600d+00,-.7344137069934890d+00,
     6      0.6908796406825563d+00,-.4332434534328214d+00,
     7      0.2034575827284494d+00,-.7660428465373745d-01,
     8      0.2374118378944197d-01,-.6343701714093986d-02/
         data ar1003/
     1      0.2569864064032319d+00,-.6983502653325019d+00,
     2      0.9494133853459433d+00,-.8597885529769185d+00,
     3      0.5803500257865427d+00,-.3163176168251860d+00,
     4      0.1398997340251557d+00,-.5367437665271227d-01,
     5      0.1642558992834314d+00,-.5931846556906132d+00,
     6      0.1074890163252055d+01,-.1293044530978268d+01,
     7      0.1145576101289035d+01,-.8353340911259566d+00,
     8      0.4831544110457749d+00,-.2445510311856089d+00/
         data ar1004/
     1      0.1034096196757153d+00,-.4675513902662374d+00,
     2      0.1074134582130535d+01,-.1620197231753298d+01,
     3      0.1757611459491468d+01,-.1635095338086610d+01,
     4      0.1166769325608763d+01,-.7369872203856632d+00,
     5      0.6606740547817017d-01,-.3514695916071359d+00,
     6      0.9910951416917713d+00,-.1787039462668514d+01,
     7      0.2228107731397494d+01,-.2570902968052708d+01,
     8      0.2170940171582469d+01,-.1646246123322180d+01/
         data ar1005/
     1      -.3660321522871240d-01,0.2310826493703603d-02,
     2      -.8933694036050663d-04,0.2522285049711795d-05,
     3      -.5629855874193866d-07,0.1040464209842537d-08,
     4      -.1642191061903246d-10,-.1412909790814243d+00,
     5      0.4223084763290613d-01,-.7729667197754714d-02,
     6      0.1033205069923450d-02,-.1091836492965430d-03,
     7      0.9532266461116007d-05,-.7126377713950922d-06,
     8      -.2273359069214480d+00,0.1487176307682599d+00/
         data ar1006/
     1      -.5957615438358835d-01,0.1742514326383717d-01,
     2      -.4030344021690524d-02,0.7634641953773042d-03,
     3      -.1251644172770312d-03,-.2596534997066640d+00,
     4      0.2820335335819835d+00,-.1875952547425928d+00,
     5      0.9096040059505928d-01,-.3494136001935829d-01,
     6      0.1078453831569382d-01,-.2948966480435959d-02,
     7      -.2468869832632347d+00,0.3873867445237316d+00,
     8      -.3722162295158157d+00,0.2591711498927121d+00/
         data ar1007/
     1      -.1439618236168936d+00,0.6222998264782999d-01,
     2      -.2479014733349016d-01,-.2095813662412528d+00,
     3      0.4375216614739740d+00,-.5592235679451721d+00,
     4      0.5098979043068991d+00,-.3779001096504012d+00,
     5      0.2081328152884486d+00,-.1118988678939150d+00,
     6      -.1646063365067200d+00,0.4334043341695332d+00,
     7      -.6982198139757338d+00,0.7758652714303041d+00,
     8      -.7299979518498586d+00,0.4801016374134717d+00/
         data ar1008/
     1      -.3331095978085993d+00,-.1218539651111807d+00,
     2      0.3900867753713690d+00,-.7623548086951872d+00,
     3      0.9652795098778769d+00,-.1118825471862053d+01,
     4      0.8382068673175922d+00,-.7328519229946706d+00,
     5      0.1155413246851942d-02,-.5650164214593779d-04,
     6      0.1783524859016171d-05,-.4255771025952278d-07,
     7      0.8226072864963822d-09,-.1340859667492856d-10,
     8      0.2111542384259939d-01,-.4888670776914334d-02/
         data ar1009/
     1      0.7305855450494309d-03,-.8253523586147570d-04,
     2      0.7545802712026610d-05,-.5819867188775439d-06,
     3      0.7435882478080931d-01,-.3767926561930843d-01,
     4      0.1232114515654549d-01,-.3046783654229935d-02,
     5      0.6073710057933981d-03,-.1022956854027472d-03,
     6      0.1410170764301035d+00,-.1186454453803398d+00,
     7      0.6430753700539922d-01,-.2642156810682070d-01,
     8      0.8674549890676782d-02,-.2413993715730270d-02/
         data ar1010/
     1      0.1936958862015233d+00,-.2354056049359987d+00,
     2      0.1831307526985118d+00,-.1089702094775821d+00,
     3      0.5100123647090314d-01,-.2034083759007782d-01,
     4      0.2187641768574074d+00,-.3536361600554759d+00,
     5      0.3598079541484694d+00,-.2868055073857605d+00,
     6      0.1753660678083870d+00,-.9205961145166558d-01,
     7      0.2166493623402711d+00,-.4412910435624832d+00,
     8      0.5460324564534035d+00,-.5570836257885703d+00/
         data ar1011/
     1      0.4200809103086238d+00,-.2745898426382597d+00,
     2      0.1946488541457691d+00,-.4808325496987508d+00,
     3      0.6763212791298492d+00,-.8622099813577961d+00,
     4      0.7704191757402621d+00,-.6038333560566380d+00,
     5      -.2306669881449411d-04,0.9533341281649409d-06,
     6      -.2606116854424520d-07,0.5483859018730235d-09,
     7      -.9481600337971053d-11,-.1995791501523036d-02,
     8      0.3905124575342353d-03,-.5054216218595479d-04/
         data ar1012/
     1      0.5026639261738709d-05,-.4118102752766640d-06,
     2      -.1538250774347440d-01,0.6585177270196063d-02,
     3      -.1865647507804629d-02,0.4034143768885732d-03,
     4      -.7257350960844186d-04,-.4843757988983692d-01,
     5      0.3434397043821354d-01,-.1617212199675365d-01,
     6      0.5724196574803786d-02,-.1722655972946140d-02,
     7      -.9611767965812580d-01,0.9751577075261078d-01,
     8      -.6659493390183736d-01,0.3328297007473923d-01/
         data ar1013/
     1      -.1466306906472581d-01,-.1444819732360316d+00,
     2      0.1900104565796837d+00,-.1745490119819331d+00,
     3      0.1125722300631564d+00,-.6738645323450530d-01,
     4      -.1806852751886575d+00,0.2827469648346207d+00,
     5      -.3360065952967275d+00,0.2636438170560979d+00,
     6      -.2053714992444997d+00,-.1980393702420919d+00,
     7      0.3356125605989649d+00,-.5112453488423272d+00,
     8      0.4694076426641818d+00,-.4649949344710496d+00/
         data ar1014/
     1      0.3370545147806936d-06,-.1228535266128564d-07,
     2      0.3003854896772513d-09,-.5717558245941327d-11,
     3      0.1380672916365240d-03,-.2382579654055464d-04,
     4      0.2757753870976401d-05,-.2482704922050835d-06,
     5      0.2328323509940733d-02,-.8794682783737765d-03,
     6      0.2227038256767536d-03,-.4371186201649119d-04,
     7      0.1214688311017754d-01,-.7623148285628115d-02,
     8      0.3203129927249164d-02,-.1035339062871995d-02/
         data ar1015/
     1      0.3453286780988011d-01,-.3138356466423545d-01,
     2      0.1904542850453686d-01,-.8778145831127279d-02,
     3      0.6752933230640723d-01,-.8218872108621691d-01,
     4      0.6647690385383487d-01,-.4008453966048450d-01,
     5      0.1013582805296036d+00,-.1578269569717093d+00,
     6      0.1620539840608033d+00,-.1209737409061387d+00,
     7      0.1226362089632856d+00,-.2386143930332338d+00,
     8      0.3025963747667361d+00,-.2699409332349813d+00/
        do 1200 i=1,240
        arr(i)=ar1001(i)
 1200 continue
        return
        end
c
c
C
C///////////////////////////////////////////////////////////////////////
      subroutine mptoxf6(mpole,nterms,nlambs,numtets,
     1                      nexptot,mexpup)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 mpole(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
c
      integer *4  nlambs,numtets(nlambs),nexptot
      parameter (nNLAMBS = 17)
      parameter (NMAXNF = 11)
      parameter (nNTERMS = 15)
c
      real *8 lambda(nNLAMBS),weights(nNLAMBS),dtmp(nNLAMBS)
      complex *16 mult(0:nNTERMS,0:nNTERMS),cd(NMAXNF),imag
c
      complex *16 expcoefs(nNLAMBS,NMAXNF)
      save
c
c ... first initializing....
c
      data imag/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,weights,NLAMBS)
c
         cd(1) = 0.5d0
         cd(2) = imag
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*imag
         enddo
c
         do i = 1, NLAMBS
            dtmp(i) = 0.5d0*dexp(lambda(i)*1.5d0)/weights(i)
         enddo
c
         do i = 1, nexptot
            mexpup(i) = 0.0d0
         enddo
c
         ifinit = 1
      endif
c
c you don't want to mess the input data:
c
      do i=0,nNTERMS
         do j = 0, i
            mult(i,j)=mpole(i,j)
         enddo
      enddo
c
c generate MEXPUP: using Vladimir's shceme:
c
      call alota6(mult,expcoefs)
c
c the expcoefs needs to be normalized back to Leslie's notation:
c
      ntot = 0
      do i = 1, NLAMBS
         mexpup(ntot+1) = expcoefs(i,1)*(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j 
            mexpup(ncurrent) = expcoefs(i,j)*dtmp(i)/cd(j)
         enddo
         ntot = ntot + numtets(i)
      enddo
c-----------End of MPOLETOEXP-------------------------------------------
      return
      end
c
c
C///////////////////////////////////////////////////////////////////////
      subroutine xftota6(local,nterms,rlams,whts,nlambs,numtets,
     1                      nthmax,nexptot,mexpup,scale)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 local(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
      real *8     rlams(nlambs)
      real *8     whts(nlambs)
C
      integer *4  nlambs,numtets(nlambs),nexptot,nthmax
      parameter (nNLAMBS = 17)
      parameter (NMAXNF = 11)
      parameter (nNTERMS = 15)
C
      real *8 dtmp(nNLAMBS)
      complex *16 expcoefs(nNLAMBS,NMAXNF)
C
      complex *16 taylor(0:nNTERMS,0:nNTERMS),cd(NMAXNF),imag
      save
C
      data imag/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
C
         cd(1) = 0.5d0
         cd(2) = imag
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*imag
         enddo
C
         do i = 1, nlambs
            dtmp(i) = 0.5d0*dexp(-rlams(i)*0.5d0)/whts(i)
         enddo
C
         do i = 1, nlambs
            do j = 1, NMAXNF
              expcoefs(i,j) = 0.0d0
            enddo
         enddo
C
         ifinit = 1
      endif
C
C     initialize LOCAL expansion
C
         do nm = 0,nterms
            do mth = 0,nm
               local(nm,mth) = 0.0d0
            enddo
         enddo
C
      ntot = 0
      do i = 1, nlambs
         expcoefs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j
            expcoefs(i,j) = mexpup(ncurrent)*cd(j)/dtmp(i)
         enddo
         ntot = ntot + numtets(i)
      enddo
C
      call atalo6(expcoefs,taylor)
C
      do l=0,nNTERMS
         do m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
         enddo
      enddo
C-----------End of EXPTOLOCAL-------------------------------------------
      RETURN
      END
c
c
c 
c
        subroutine alota66(mult,expcoefs,expcoefs1)
        implicit real *8 (a-h,o-z)
        complex *16 mult(0:15,0:15),expcoefs(17,11)
ccc        complex *16 mult1(0:15,0:15),expcoefs1(17,11)
        complex *16 expcoefs1(17,11)
        real *8 arr(1600)
c
        dimension map(11),nsstored(11),num1s(11),num2s(11)
c
c       this subroutine transforms a multipole expansion of
c       order 15 into a Bessel expansion of order (17,10);
c       the accuracy of the resulting scheme is about 6 digits.
c
c ... one wave number m after another, calcolate the coefficients of the
c     exponential expansion
c
        data ifinit/0/
        data map/1,273,513,723,905,1073,1216,1336,1435,1507,1549/
        data nsstored/272,240,210,182,168,143,120,99,72,42,12/
        data num1s/1,1,2,3,3,4,5,6,7,10,11/
        data num2s/17,16,16,16,16,16,16,16,15,15,12/
        if(ifinit .eq. 0) then
           call lot6get(arr)
ccc        if(ifinit .eq. 0) ifinit=1
c
        do 1400 i=1,11
        do 1200 j=1,17
c
        expcoefs(j,i)=0
        expcoefs1(j,i)=0
 1200 continue
 1400 continue
            ifinit = 1
         endif
c
        isgn = -1
        do 2000 m=0,10
c
        isgn = -isgn
        iarr=map(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
        nnmult=15-m+1
        num1=num1s(m+1)
c
ccc        call matvec34(arr(iarr),numexp,nnmult,mult(m,m),
ccc     1      expcoefs(num1,m+1) )
ccc        call matvec34(arr(iarr),numexp,nnmult,mult1(m,m),
ccc     1      expcoefs1(num1,m+1) )
        call matvec344(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcoefs(num1,m+1), expcoefs1(num1,m+1), isgn )
 2000 continue
        return
        end
c
c 
c
        subroutine alota6(mult,expcoefs)
        implicit real *8 (a-h,o-z)
        complex *16 mult(0:15,0:15),expcoefs(17,11)
        real *8 arr(1600)
c
        dimension map(11),nsstored(11),num1s(11),num2s(11)
c
        dimension ms(17),num1s7(1),num2s7(1),ms7(1)
c
c       this subroutine transforms a multipole expansion of
c       order 15 into a Bessel expansion of order (17,10);
c       the accuracy of the resulting scheme is about 6 digits.
c
c ... one wave number m after another, calcolate the coefficients of the
c     exponential expansion
c
        data ifinit/0/
        data map/1,273,513,723,905,1073,1216,1336,1435,1507,1549/
        data nsstored/272,240,210,182,168,143,120,99,72,42,12/
        data num1s/1,1,2,3,3,4,5,6,7,10,11/
        data num2s/17,16,16,16,16,16,16,16,15,15,12/
        data ms/1,2,4,5,6,7,8,8,8,9,10,10,9,9,9,7,0/
        if(ifinit .eq. 0) then
           call lot6get(arr)
ccc        if(ifinit .eq. 0) ifinit=1
c
        do 1400 i=1,11
        do 1200 j=1,17
c
        expcoefs(j,i)=0
 1200 continue
 1400 continue
c
         ifinit=1
	endif
c
        do 2000 m=0,10
c
        iarr=map(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
        nnmult=15-m+1
        num1=num1s(m+1)
c
        call matvec34(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcoefs(num1,m+1) )
 2000 continue
        return
c
c
c
c
       entry get6dat(num1s7,num2s7,ms7)
c
c       this entry returns to the user three parameters describing
c       the translation operator converting a multipole expansion of 
c       order 15 into a Bessel expansion of order (17,10).
c
c    Explanation: the subroutiune converts a multipole  expansion 
c       of order 15 into an expansion of the form
c
c    \sum_{m=0}^{11} \sum_{k=m}^15 \alpha_{m,k} * P_k^m (\theta) * 
c         e^{i * m * \phi}/r^{k+1}                                  (1)
c
c        into an expansion of the form 
c
c     \sum_{m=0}^{10} sum_{k=num1s(m+1)}^{num2s(m+1)} 
c        
c        \beta_{m,k} * e^{-rlams_k *z} *
c                                                                   (2)
c        J_m(\rlams(k) * sqrt(x^2+y^2)) * e^{i * m * \phi}.
c
c        The procedure is supposed to lead to 6-digit accuracy under 
c        normal FMM conditions 
c
c                    input parameters: none
c
c                    output parameters:
c
c  num1s - the list of first non-zero 

        do 3200 i=1,11
        num1s7(i)=num1s(i)
        num2s7(i)=num2s(i)
 3200 continue
c
        do 3400 i=1,17
        ms7(i)=ms(i)
 3400 continue
c
        return
        end
c
c
c
c
c 
c
        subroutine atalo66(expcoefs,expcoefs1,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:15,0:15),expcoefs(17,11)
        complex *16 expcoefs1(17,11)
        real *8 arr(2100)
c
        dimension map(11),nsstored(11),num1s(11),num2s(11)
ccc        data map/1,273,528,766,987,1191,1378,1548,1701,1837,1956/
ccc        data map/1,273,542,792,1011,1224,1418,1593,1749,1900,2016/
ccc        data num1s/1,1,2,3,3,4,5,6,7,10,11/
c
ccc        data ms/2,3,5,6,7,8,9,9,9,10,11,11,10,10,10,8,1/
c
c
c       this subroutine transforms a Bessel expansion of order (17,10)
c       into a local expansion of order 15; the accuracy of the 
c       resulting scheme is about 6 digits.
c
c ...one wave number m after another, calculate the coefficients of the
c    taylor series
c
        data ifinit/0/
        data map/1,273,528,779,999,1202,1418,1593,1749,1900,2016/
        data nsstored/272,255,238,221,204,187,170,153,136,119,102/
        data num1s/1,1,1,2,2,2,5,6,7,10,11/
        data num2s/17,16,16,16,16,16,16,16,15,15,12/
        if (ifinit .eq. 0) then
ccc           do i = 1, 11
ccc              map(i) = map(i) + (num1s(i)-1)*(15-(i-1)+1)
ccc              print *, map(i)
ccc           enddo
ccc           pause 'check'
           call lot6geta(arr)
        do 1400 i=0,15
        do 1200 j=0,i
c
        taylor(j,i)=0
 1200 continue
 1400 continue
c
           ifinit=1
        endif
c
        ntaylor=15
ccc        numexp=17
c
        isgn = -1
        do 2000 m=0,10
c
        mp1 = m+1
        isgn = -isgn
        iarr=map(mp1)
        nntaylor=ntaylor-m+1
        num1=num1s(mp1)
        numexp=num2s(mp1)-num1+1
        call matvec334(arr(iarr),nntaylor,numexp,
     1      expcoefs(num1,mp1),expcoefs1(num1,mp1),taylor(m,m),isgn )
ccc     1      expcoefs(1,mp1),expcoefs1(1,mp1),taylor(m,m),isgn )
 2000 continue
c
        return
        end
c
c
c 
c
        subroutine atalo6(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:15,0:15),expcoefs(17,11)
        real *8 arr(2100)
c
        dimension map(11),nsstored(11),num1s(11),num2s(11)
ccc        data map/1,273,528,766,987,1191,1378,1548,1701,1837,1956/
ccc        data map/1,273,542,792,1011,1224,1418,1593,1749,1900,2016/
ccc        data num1s/1,1,2,3,3,4,5,6,7,10,11/
c
ccc        data ms/2,3,5,6,7,8,9,9,9,10,11,11,10,10,10,8,1/
c
c
c       this subroutine transforms a Bessel expansion of order (17,10)
c       into a local expansion of order 15; the accuracy of the 
c       resulting scheme is about 6 digits.
c
c ...one wave number m after another, calculate the coefficients of the
c    taylor series
c
        data ifinit/0/
        data map/1,273,528,779,999,1202,1418,1593,1749,1900,2016/
        data nsstored/272,255,238,221,204,187,170,153,136,119,102/
        data num1s/1,1,1,2,2,2,5,6,7,10,11/
        data num2s/17,16,16,16,16,16,16,16,15,15,12/
        if (ifinit .eq. 0) then
ccc           do i = 1, 11
ccc              map(i) = map(i) + (num1s(i)-1)*(15-(i-1)+1)
ccc           enddo
ccc           print *, map
           call lot6geta(arr)
c
        do 1400 j=0,15
        do 1200 i=0,j
c
        taylor(j,i)=0
 1200 continue
 1400 continue
           ifinit=1
        endif
c
        do 2000 m=0,10
c
        iarr=map(m+1)
        nntaylor=15-m+1
        num1=num1s(m+1)
        numexp=num2s(m+1)-num1s(m+1)+1
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(num1,m+1),taylor(m,m) )
 2000 continue
c
        return
        end
c
c
c
c 
c
        subroutine atalo6_old(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:15,0:15),expcoefs(17,11)
        real *8 arr(2100)
c
        dimension map(11),nsstored(11)
c
c       this subroutine transforms a Bessel expansion of order (17,10)
c       into a local expansion of order 15; the accuracy of the 
c       resulting scheme is about 6 digits.
c
c  ...one wave number m after another, calculate the coefficients of the
c         taylor series
c
        data ifinit/0/
        data map/1,273,528,766,987,1191,1378,1548,1701,1837,1956/
        data nsstored/272,255,238,221,204,187,170,153,136,119,102/
        if(ifinit .eq. 0) call lot6geta(arr)
        if(ifinit .eq. 0) ifinit=1
c
        ntaylor=15
        numexp=17

        do 1400 i=0,15
        do 1200 j=0,15
c
        taylor(j,i)=0
 1200 continue
 1400 continue
c
        do 2000 m=0,10
c
        nntaylor=ntaylor-m+1
        iarr=map(m+1)
c
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(1,m+1),taylor(m,m) )
 2000 continue
        return
        end
c
c
c
c
c
        subroutine matvec34(alota,numexp,nnmult,cw1,cw2)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        do 1200 j=1,nnmult
        cd=cd+alota(i,j)*cw1(j)
 1200 continue
c
        cw2(i)=cd
 1400 continue
        return
        end
c
        subroutine matvec334(alota,numexp,nnmult,cw1,cw2,cw3,isgn)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        complex *16 cw3(1), cd1
        dimension alota(numexp,nnmult)
c
        iisgn = -isgn
        do 1400 i=1,numexp
c
        cd=0
        cd1=0
        iisgn = -iisgn
        do 1200 j=1,nnmult
        cd=cd+alota(i,j)*cw1(j)
        cd1=cd1+alota(i,j)*cw2(j)
 1200 continue
***        cw3(i)=cd+cd1*iisgn
        if (iisgn .gt. 0) then
           cw3(i)=cd+cd1
        else
           cw3(i)=cd-cd1
        endif
C
 1400 continue
        return
        end
c
c
        subroutine matvec344(alota,numexp,nnmult,cw1,cw2,cw3,isgn)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        complex *16 cw3(1), cd1, tmp
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        cd1=0
ccc        isgnn = -isgn
ccc        do 1200 j=1,nnmult
ccc        isgnn = -isgnn
ccc        tmp=alota(i,j)*cw1(j)
ccc        cd=cd+tmp
ccc        cd1=cd1+isgnn*tmp
ccc 1200 continue
        if (isgn .gt. 0) then
           do j=1,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1+tmp
           enddo
           do j=2,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1-tmp
           enddo
        else
           do j=1,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1-tmp
           enddo
           do j=2,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1+tmp
           enddo
        endif
c
        cw2(i)=cd
        cw3(i)=cd1
 1400 continue
        return
        end
c
c
        subroutine lot6get(arr)
        implicit real *8 (a-h,o-z)
        dimension arr(1)
c         
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16)
         real *8
     1  arr1097(16),arr1098( 8)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2)
         real *8
     1  arr2097(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2))
c
         data arr1001/
     1      0.1309243681616575d+00,0.2023226798962192d+00,
     2      0.1642412739559832d+00,0.9610103816069308d-01,
     3      0.4532965769948588d-01,0.1826130400723258d-01,
     4      0.6512170426630952d-02,0.2106938993281298d-02,
     5      0.6294685213687294d-03,0.1759799435415395d-03,
     6      0.4650509354672851d-04,0.1166914066665504d-04,
     7      0.2779510006391477d-05,0.6457680176385878d-06,
     8      0.1643280577638656d-06,0.4692145621991275d-07/
         data arr1002/
     1      0.3789965253629085d-09,0.7330131808252566d-02,
     2      0.5763244573760799d-01,0.1092780896460362d+00,
     3      0.1121191137580551d+00,0.7998099555646807d-01,
     4      0.4456325885950996d-01,0.2071083571851237d-01,
     5      0.8372243023578238d-02,0.3029365890854726d-02,
     6      0.1001211065897675d-02,0.3067043201430255d-03,
     7      0.8806269347132798d-04,0.2390800341241040d-04,
     8      0.6160880205545737d-05,0.1500094827317372d-05/
         data arr1003/
     1      0.3514187546265127d-06,0.1207564144096615d-06,
     2      0.2054860566306857d-03,0.8207870506099469d-02,
     3      0.3635461868732562d-01,0.6540345630318552d-01,
     4      0.7056047935542530d-01,0.5437367851443470d-01,
     5      0.3293355949058022d-01,0.1663452448906482d-01,
     6      0.7288769897701030d-02,0.2848120104221045d-02,
     7      0.1012331544323381d-02,0.3320659261752894d-03,
     8      0.1016329846075461d-03,0.2930115352607404d-04/
         data arr1004/
     1      0.8042668542905641d-05,0.2145463103590761d-05,
     2      0.6831865265833652d-06,0.3635815816588264d-05,
     3      0.7796662879581106d-03,0.8062725405676886d-02,
     4      0.2543497048027151d-01,0.4149966206075967d-01,
     5      0.4422938963183559d-01,0.3491308599929790d-01,
     6      0.2203364672532009d-01,0.1169161780617619d-01,
     7      0.5401262742849010d-02,0.2227238302604966d-02,
     8      0.8347638359784870d-03,0.2882397050625966d-03/
         data arr1005/
     1      0.9267791057349349d-04,0.2801538937565183d-04,
     2      0.8083866510134265d-05,0.2673757870532821d-05,
     3      0.9508473379219024d-07,0.5538630831087168d-04,
     4      0.1341313526985259d-02,0.7418491022681477d-02,
     5      0.1830590996252086d-01,0.2698313984361895d-01,
     6      0.2775879733919865d-01,0.2188882092054544d-01,
     7      0.1406550055407146d-01,0.7682518771913309d-02,
     8      0.3675186875177637d-02,0.1573977988534027d-02/
         data arr1006/
     1      0.6135769691568846d-03,0.2205690353207652d-03,
     2      0.7391225610854996d-04,0.2348005066531579d-04,
     3      0.8653052423359123d-05,0.4505857860654800d-06,
     4      0.2266328102586232d-05,0.1791991591947367d-03,
     5      0.1730511630193931d-02,0.6460253741596022d-02,
     6      0.1316914527676191d-01,0.1765661235818180d-01,
     7      0.1739589075997576d-01,0.1353705832545017d-01,
     8      0.8741875033217371d-02,0.4851437582303083d-02/
         data arr1007/
     1      0.2373867426718881d-02,0.1044253925606747d-02,
     2      0.4191251688273440d-03,0.1552082985226173d-03,
     3      0.5389351166850460d-04,0.2153006462272692d-04,
     4      0.4715709225242109d-06,-.9021237790388227d-06,
     5      0.2082995543754704d-04,0.3357928291009470d-03,
     6      0.1900287764227017d-02,0.5355753037338697d-02,
     7      0.9359272247083798d-02,0.1152100385176522d-01,
     8      0.1085694694315582d-01,0.8289573912681170d-02/
         data arr1008/
     1      0.5337015788255640d-02,0.2983719164189893d-02,
     2      0.1481283824037963d-02,0.6642396668724822d-03,
     3      0.2724538509377450d-03,0.1040363112200862d-03,
     4      0.4576707514748261d-04,0.8375764119704973d-06,
     5      -.1860333524626542d-05,0.3723631405439418d-05,
     6      0.5467847010344812d-04,0.4799535928226896d-03,
     7      0.1866412381567088d-02,0.4252869222569203d-02,
     8      0.6539991357942698d-02,0.7463389719536067d-02/
         data arr1009/
     1      0.6738167029274222d-02,0.5032316263253742d-02,
     2      0.3214076504302616d-02,0.1800917046463292d-02,
     3      0.9022060318216472d-03,0.4095939602080556d-03,
     4      0.1717909590941692d-03,0.8343845916359495d-04,
     5      0.1591526693105296d-05,-.3506942767500289d-05,
     6      0.3552101064186313d-05,0.5599518970397309d-05,
     7      0.1075974949205760d-03,0.5681072626879477d-03,
     8      0.1691856520432497d-02,0.3248059983782353d-02/
         data arr1010/
     1      0.4488864437010808d-02,0.4792508240872362d-02,
     2      0.4149886450246086d-02,0.3025416276211060d-02,
     3      0.1910321010011061d-02,0.1065420493466511d-02,
     4      0.5316203314453423d-03,0.2419382734124879d-03,
     5      0.1266716266541666d-03,0.2756911686881750d-05,
     6      -.6071799992239127d-05,0.5881687699447312d-05,
     7      -.3400190036006840d-05,0.2412580329527326d-04,
     8      0.1518984138354716d-03,0.5999011375906815d-03/
         data arr1011/
     1      0.1433382520655304d-02,0.2399471026817719d-02,
     2      0.3031975639295932d-02,0.3043635246687379d-02,
     3      0.2534431482903702d-02,0.1808215771935839d-02,
     4      0.1128709150560539d-02,0.6247388831244682d-03,
     5      0.3137099382134880d-03,0.1840979880243298d-03,
     6      0.3135593258044162d-05,-.6910460678603321d-05,
     7      0.6694219668051971d-05,-.4973321238196795d-05,
     8      0.7586763121203033d-05,0.3476341590174580d-04/
         data arr1012/
     1      0.1929431781493344d-03,0.5688028189379686d-03,
     2      0.1153319308068435d-02,0.1724698811627234d-02,
     3      0.2002185171175246d-02,0.1896797198101595d-02,
     4      0.1518716231078916d-02,0.1048760225854814d-02,
     5      0.6326083440820933d-03,0.3414183038911885d-03,
     6      0.2137029660367801d-03,0.4282290927939107d-05,
     7      -.9438573957653503d-05,0.9145188299413393d-05,
     8      -.6957785640122343d-05,0.5971405172183105d-05/
         data arr1013/
     1      0.4347100682579360d-05,0.5901329098120759d-04,
     2      0.2044172874774757d-03,0.5034363671296215d-03,
     3      0.8958731743316242d-03,0.1201808494907761d-02,
     4      0.1299189328156888d-02,0.1177836109475661d-02,
     5      0.9121701412323877d-03,0.6109719340664235d-03,
     6      0.3645700376309876d-03,0.2576206548015495d-03,
     7      0.3379171358217269d-05,-.7445216991086758d-05,
     8      0.7205736941916685d-05,-.5477212074579538d-05/
         data arr1014/
     1      0.4303122186784531d-05,-.1428132559140709d-05,
     2      0.1773811107488773d-04,0.6670096038824156d-04,
     3      0.1994975118289724d-03,0.4193796354709283d-03,
     4      0.6415439687618570d-03,0.7772252608056906d-03,
     5      0.7761552144113374d-03,0.6491994511603359d-03,
     6      0.4607848508305607d-03,0.2863964265218918d-03,
     7      0.2068955165914698d-03,0.4511763920320942d-05,
     8      -.9937883326867318d-05,0.9606338111181427d-05/
         data arr1015/
     1      -.7304482911085248d-05,0.5599053432383191d-05,
     2      -.3847032603018323d-05,0.7771826201305481d-05,
     3      0.1913354788719515d-04,0.7274059785653052d-04,
     4      0.1877739050972929d-03,0.3263305846580785d-03,
     5      0.4502462463406017d-03,0.5127636414666585d-03,
     6      0.4832495188128092d-03,0.3814573237162984d-03,
     7      0.2628428880387983d-03,0.2165070080839337d-03,
     8      0.2772133793177344d-05,-.6104482950993025d-05/
         data arr1016/
     1      0.5894838968694106d-05,-.4477553987253054d-05,
     2      0.3410556787862734d-05,-.2487864951731091d-05,
     3      0.3342762814326262d-05,0.4537457575593029d-05,
     4      0.2257671888939500d-04,0.6955866192053477d-04,
     5      0.1323564769025941d-03,0.1997910504207023d-03,
     6      0.2465937205288799d-03,0.2473629579271229d-03,
     7      0.2046339781101174d-03,0.1462636872547159d-03,
     8      0.1243682087020341d-03,0.2906037152396508d-05/
         data arr1017/
     1      -.6401831773737955d-05,0.6189277500731671d-05,
     2      -.4716726267118683d-05,0.3605744617290282d-05,
     3      -.2699710554880481d-05,0.2870688431577537d-05,
     4      0.4251305949689991d-06,0.6427416697051360d-05,
     5      0.2876103881654718d-04,0.5793409541882306d-04,
     6      0.9840472627731906d-04,0.1399766228203365d-03,
     7      0.1584967388694025d-03,0.1451980476027526d-03,
     8      0.1146503747961734d-03,0.1111964287707487d-03/
         data arr1018/
     1      -.1036775760604102d-01,-.8150274681846181d-01,
     2      -.1545439178321427d+00,-.1585599980950931d+00,
     3      -.1131104308011786d+00,-.6302171044842787d-01,
     4      -.2928960121880842d-01,-.1184017496420564d-01,
     5      -.4284051891991590d-02,-.1415970975510982d-02,
     6      -.4338040005281119d-03,-.1244880403992904d-03,
     7      -.3375630891762729d-04,-.8727471104972446d-05,
     8      -.2165802265006504d-05,-.5667118665857123d-06/
         data arr1019/
     1      -.3359574010866966d-03,-.1340426600490012d-01,
     2      -.5936605043989855d-01,-.1068036001495135d+00,
     3      -.1152246343109442d+00,-.8879202000473405d-01,
     4      -.5378022610918728d-01,-.2716404534551774d-01,
     5      -.1190259431358334d-01,-.4650926100247722d-02,
     6      -.1653066418561809d-02,-.5422699777946092d-03,
     7      -.1659954910360507d-03,-.4783454439491005d-04,
     8      -.1312990477820137d-04,-.4019985014370377d-05/
         data arr1020/
     1      -.8393507300037745d-05,-.1348345753107000d-02,
     2      -.1396634116350135d-01,-.4405417015536139d-01,
     3      -.7187974384299453d-01,-.7660741458690430d-01,
     4      -.6047133591062031d-01,-.3816327264118205d-01,
     5      -.2025057824510017d-01,-.9355325725631731d-02,
     6      -.3857507127855088d-02,-.1445851740993340d-02,
     7      -.4994889261402048d-03,-.1607195804391510d-03,
     8      -.4875321535357975d-04,-.1638994867754920d-04/
         data arr1021/
     1      -.2335144008917895d-04,-.8983802938529421d-04,
     2      -.2402690661855124d-02,-.1326947299925417d-01,
     3      -.3274686627306987d-01,-.4826896978267728d-01,
     4      -.4965644302579358d-01,-.3915560949904244d-01,
     5      -.2516166546047556d-01,-.1374277599880862d-01,
     6      -.6573763644847374d-02,-.2815738876247883d-02,
     7      -.1098152303551876d-02,-.3948025696939291d-03,
     8      -.1327570175969837d-03,-.4990012037813324d-04/
         data arr1022/
     1      -.4572257877821782d-04,0.1470528822675217d-04,
     2      -.3346511546252116d-03,-.3156813155599609d-02,
     3      -.1179539842830803d-01,-.2404345933749374d-01,
     4      -.3223645705290334d-01,-.3175978900547254d-01,
     5      -.2471621364139743d-01,-.1596033271583827d-01,
     6      -.8856308775936326d-02,-.4334490617927270d-02,
     7      -.1908343275601153d-02,-.7666928608353057d-03,
     8      -.2856637564867503d-03,-.1192660126840770d-03/
         data arr1023/
     1      -.8933039927482531d-04,0.3981927224259075d-04,
     2      -.5396737261494723d-04,-.6161330412719195d-03,
     3      -.3520189826979443d-02,-.9916765850983483d-02,
     4      -.1733029124369971d-01,-.2133124189880400d-01,
     5      -.2010536243904306d-01,-.1534916085870369d-01,
     6      -.9879106324492128d-02,-.5524715499956469d-02,
     7      -.2745549228271528d-02,-.1231611011581809d-02,
     8      -.5076371167489873d-03,-.2353069004605393d-03/
         data arr1024/
     1      -.1801032721491749d-03,0.8020540025472736d-04,
     2      -.3776679615387708d-04,-.9108357226016904d-04,
     3      -.9008968392593543d-03,-.3491540175005263d-02,
     4      -.7956833765320682d-02,-.1223225247066431d-01,
     5      -.1396729326939916d-01,-.1260573723445916d-01,
     6      -.9409376254675002d-02,-.6014860472476312d-02,
     7      -.3377061115239732d-02,-.1693887744385921d-02,
     8      -.7750936011921076d-03,-.4042351508563936d-03/
         data arr1025/
     1      -.2783757772293865d-03,0.1239303804944232d-03,
     2      -.5313644007547360d-04,0.5908423197365315d-05,
     3      -.2068975139165175d-03,-.1071365459293997d-02,
     4      -.3190427214053054d-02,-.6120349211757420d-02,
     5      -.8471120023337051d-02,-.9035207534745635d-02,
     6      -.7815435493704802d-02,-.5704176457036038d-02,
     7      -.3607741670578836d-02,-.2010061836526697d-02,
     8      -.1007822364065681d-02,-.5727281447208845d-03/
         data arr1026/
     1      -.4107749009201171d-03,0.1831028473072599d-03,
     2      -.7836623090096449d-04,0.2988546882852901d-04,
     3      -.5116593865815194d-04,-.2886915975537236d-03,
     4      -.1138290567382296d-02,-.2713634497900439d-02,
     5      -.4562943850038520d-02,-.5751283232198557d-02,
     6      -.5763677754270098d-02,-.4813564086563698d-02,
     7      -.3447815895889642d-02,-.2154231109377499d-02,
     8      -.1205023383328381d-02,-.7804029816020699d-03/
         data arr1027/
     1      -.4612060567906364d-03,0.2055842682941907d-03,
     2      -.8796194129061889d-04,0.3556827182612699d-04,
     3      -.2028948285793454d-04,-.6702204444707103d-04,
     4      -.3677857806527826d-03,-.1077793006699737d-02,
     5      -.2210587182540124d-02,-.3285089306788319d-02,
     6      -.3800629243657867d-02,-.3613732237145031d-02,
     7      -.2901229012754378d-02,-.1996325745108590d-02,
     8      -.1210161380302247d-02,-.8423178478195731d-03/
         data arr1028/
     1      -.5833639824736000d-03,0.2601268877624073d-03,
     2      -.1114267414105600d-03,0.4547167474182174d-04,
     3      -.1821268421396940d-04,-.9634381508953589d-05,
     4      -.1124564169016534d-03,-.3830269192107551d-03,
     5      -.9789084749062707d-03,-.1712654992111813d-02,
     6      -.2285664495477428d-02,-.2496102578971537d-02,
     7      -.2280941011496796d-02,-.1766063036307295d-02,
     8      -.1199751095889232d-02,-.9625627796518810d-03/
         data arr1029/
     1      -.4640915672171727d-03,0.2067475485882114d-03,
     2      -.8829097258501384d-04,0.3576357842835096d-04,
     3      -.1329583626279163d-04,0.1337264996046374d-05,
     4      -.3324620921560681d-04,-.1215134576054484d-03,
     5      -.3947316713823682d-03,-.8000856967251730d-03,
     6      -.1213102701466224d-02,-.1486204422782832d-02,
     7      -.1488374100863051d-02,-.1232616337736764d-02,
     8      -.8774176767990819d-03,-.7223014563054900d-03/
         data arr1030/
     1      -.5127897268322162d-03,0.2287053155424498d-03,
     2      -.9803188324708715d-04,0.4009818164148223d-04,
     3      -.1516485446837115d-04,0.5117923431786968d-05,
     4      -.1336877716822922d-04,-.3019112197668336d-04,
     5      -.1534333537296895d-03,-.3581270614170773d-03,
     6      -.6160852670901978d-03,-.8766234609795095d-03,
     7      -.1010696990684831d-02,-.9481772338203435d-03,
     8      -.7619885942971378d-03,-.7335252965603959d-03/
         data arr1031/
     1      -.2797280078169649d-03,0.1247336392413366d-03,
     2      -.5342874407103074d-04,0.2181504249190397d-04,
     3      -.8196248431431689d-05,0.2955817767063804d-05,
     4      -.4975382683087990d-05,-.5322945536370349d-05,
     5      -.5052238441470253d-04,-.1294270895479438d-03,
     6      -.2433678994466383d-03,-.3805748745704684d-03,
     7      -.4712838672234361d-03,-.4648412574954971d-03,
     8      -.3874232486006185d-03,-.3833453416999354d-03/
         data arr1032/
     1      -.2561856253278296d-03,0.1144721857099965d-03,
     2      -.4936236498539337d-04,0.2050264080025374d-04,
     3      -.8078955575563420d-05,0.3369404184193087d-05,
     4      -.4083581621532289d-05,0.2125727380492492d-05,
     5      -.1923259942499824d-04,-.5364831411245447d-04,
     6      -.1072939692978970d-03,-.1983234877799779d-03,
     7      -.2874729779698707d-03,-.3228310701064162d-03,
     8      -.3041968670605542d-03,-.3521065433703375d-03/
         data arr1033/
     1      0.6715998837064140d-02,0.2968080444433083d-01,
     2      0.5340235289302212d-01,0.5761220353364874d-01,
     3      0.4439601604797205d-01,0.2689011097270813d-01,
     4      0.1358202928221862d-01,0.5951281055237017d-02,
     5      0.2325467315619971d-02,0.8265359127834714d-03,
     6      0.2711150094242271d-03,0.8297095424560364d-04,
     7      0.2389509849077031d-04,0.6538374561374648d-05,
     8      0.1939310210756410d-05,0.8557830383362202d-03/
         data arr1034/
     1      0.8831718996525283d-02,0.2786274537178634d-01,
     2      0.4546057437168752d-01,0.4845086248112159d-01,
     3      0.3824538615352766d-01,0.2413661341347389d-01,
     4      0.1280754373344242d-01,0.5916817086202304d-02,
     5      0.2439747358065618d-02,0.9143880601744834d-03,
     6      0.3158039650264897d-03,0.1015910178659011d-03,
     7      0.3078104545305440d-04,0.1009693259087723d-04,
     8      0.6942816505458281d-04,0.1697082161577846d-02/
         data arr1035/
     1      0.9383458048162700d-02,0.2315551643203075d-01,
     2      0.3413114923067609d-01,0.3511251619740128d-01,
     3      0.2768729664145743d-01,0.1779161649639726d-01,
     4      0.9717791980266817d-02,0.4648469172602403d-02,
     5      0.1990577112895063d-02,0.7760357622746029d-03,
     6      0.2789445447303292d-03,0.9355111171447055d-04,
     7      0.3398633283734201d-04,-.7929090563861171d-06,
     8      0.2495285438537192d-03,0.2387196250692173d-02/
         data arr1036/
     1      0.8916598384677404d-02,0.1817470247536897d-01,
     2      0.2436876845905648d-01,0.2400831006173602d-01,
     3      0.1868290853476561d-01,0.1206532580256101d-01,
     4      0.6695045530528827d-02,0.3275734940921341d-02,
     5      0.1441784106817413d-02,0.5793411445831171d-03,
     6      0.2154291589016085d-03,0.8724660821688836d-04,
     7      -.6286191081159674d-05,0.3372484698496474d-04,
     8      0.4896526707887537d-03,0.2782822613711156d-02/
         data arr1037/
     1      0.7839196228731663d-02,0.1370122914168176d-01,
     2      0.1686431856199852d-01,0.1589297725870008d-01,
     3      0.1213531490953148d-01,0.7810826622877942d-02,
     4      0.4365803253101256d-02,0.2168418083788687d-02,
     5      0.9727354059053363d-03,0.3999353594268447d-03,
     6      0.1793254299344033d-03,-.1277319575509096d-04,
     7      0.1216413988085408d-04,0.7970869570398962d-04,
     8      0.7353351016130240d-03,0.2849320081960410d-02/
         data arr1038/
     1      0.6497693767058175d-02,0.9988617768367692d-02,
     2      0.1140062029363827d-01,0.1029431836728166d-01,
     3      0.7684406099326435d-02,0.4907443764889212d-02,
     4      0.2753513745372474d-02,0.1381942633078047d-02,
     5      0.6307433081112703d-03,0.3170511985240604d-03,
     6      -.2170603949681840d-04,0.1583521072284972d-04,
     7      0.2961825790004381d-05,0.1730532621890855d-03,
     8      0.8937403873996248d-03,0.2671046233138926d-02/
         data arr1039/
     1      0.5122126011901937d-02,0.7081753820144947d-02,
     2      0.7562574108192058d-02,0.6541733785553701d-02,
     3      0.4767313484607189d-02,0.3013916941930273d-02,
     4      0.1681987182047309d-02,0.8418857704768581d-03,
     5      0.4615633472037230d-03,-.3592605003631924d-04,
     6      0.2586148552614170d-04,-.1481344196864857d-04,
     7      0.4425431946442842d-04,0.2417825363245664d-03,
     8      0.9736981458847555d-03,0.2316166093800791d-02/
         data arr1040/
     1      0.3882606486888818d-02,0.4909486872999884d-02,
     2      0.4918716757353487d-02,0.4095638460480648d-02,
     3      0.2931097821642536d-02,0.1834102744547867d-02,
     4      0.1021317461139523d-02,0.6321031794014908d-03,
     5      -.4084717448714327d-04,0.2940982716694195d-04,
     6      -.1862625816644124d-04,0.1830078657286315d-04,
     7      0.5297016321168152d-04,0.3219294305691326d-03,
     8      0.9356823184693294d-03,0.1904611538719577d-02/
         data arr1041/
     1      0.2851243582685784d-02,0.3297278476225085d-02,
     2      0.3122541969405718d-02,0.2508137686405620d-02,
     3      0.1733442919014916d-02,0.1049377576432280d-02,
     4      0.7019938705122660d-03,-.5416869381481552d-04,
     5      0.3907076627592986d-04,-.2506879255211135d-04,
     6      0.1740769293608968d-04,0.1574122886395621d-05,
     7      0.1032528592142939d-03,0.3387329006984362d-03,
     8      0.8454974845307008d-03,0.1509227252896533d-02/
         data arr1042/
     1      0.2009220261212797d-02,0.2173931199851266d-02,
     2      0.1984715290125771d-02,0.1541419642081058d-02,
     3      0.1038837422155270d-02,0.7875928334238633d-03,
     4      -.4259255347497593d-04,0.3066600096712464d-04,
     5      -.1964166616052127d-04,0.1295710809325307d-04,
     6      -.6796325684184646d-05,0.3333475940899506d-04,
     7      0.1099962130684451d-03,0.3396728957664537d-03,
     8      0.7168992109341637d-03,0.1083126418608219d-02/
         data arr1043/
     1      0.1313204575303064d-02,0.1320501837325581d-02,
     2      0.1104961641813711d-02,0.7868366711149914d-03,
     3      0.6210479460031928d-03,-.5243309148099461d-04,
     4      0.3784689894464052d-04,-.2433366960504239d-04,
     5      0.1597814274994068d-04,-.1158373717067716d-04,
     6      0.1678291986356587d-04,0.2913717200516037d-04,
     7      0.1252173895383421d-03,0.3272858779047446d-03,
     8      0.5543861362891588d-03,0.7686542373374554d-03/
         data arr1044/
     1      0.8880412594743231d-03,0.8387879633864346d-03,
     2      0.6655373154977227d-03,0.5983952964640164d-03,
     3      -.3110870654846993d-04,0.2245162380213242d-04,
     4      -.1443155787877690d-04,0.9461909478475142d-05,
     5      -.7093244127662978d-05,0.7657299454768301d-05,
     6      0.5739493677418863d-05,0.3911443654059656d-04,
     7      0.1226141004470739d-03,0.2247309231577050d-03,
     8      0.3415716079245666d-03,0.4284471830822054d-03/
         data arr1045/
     1      0.4299101399900369d-03,0.3568083659197377d-03,
     2      0.3339980765318380d-03,-.3130732551520146d-04,
     3      0.2267714862545514d-04,-.1465446919983679d-04,
     4      0.9683662024384513d-05,-.7399391285921146d-05,
     5      0.6738310169717983d-05,-.1238243872639508d-05,
     6      0.1108306539725451d-04,0.5228454243336807d-04,
     7      0.9755923502916810d-04,0.1690514708286553d-03,
     8      0.2480330942485644d-03,0.2812298234811886d-03/
         data arr1046/
     1      0.2587169521229042d-03,0.2752987643486850d-03,
     2      -.3691262914977682d-02,-.1134832394292139d-01,
     3      -.1857064192867050d-01,-.1977343823922116d-01,
     4      -.1561730154339830d-01,-.9853326380380199d-02,
     5      -.5225959422502519d-02,-.2418338725782431d-02,
     6      -.9965783598210331d-03,-.3709396140355536d-03,
     7      -.1284497106106768d-03,-.4308697833102381d-04,
     8      -.1355384614968902d-04,-.2948528370456539d-05/
         data arr1047/
     1      -.9163060382297797d-03,-.5012911277547308d-02,
     2      -.1237818295025025d-01,-.1824337174512354d-01,
     3      -.1876869420919546d-01,-.1479937676860086d-01,
     4      -.9509975453258544d-02,-.5194476978582271d-02,
     5      -.2484607106550520d-02,-.1063910763825347d-02,
     6      -.4147776182370289d-03,-.1489760749414792d-03,
     7      -.4974089453163823d-04,-.1765314141163695d-04,
     8      -.1538358886072315d-03,-.1461506789425973d-02/
         data arr1048/
     1      -.5460114644514094d-02,-.1113001634855432d-01,
     2      -.1492253490893437d-01,-.1470187334358581d-01,
     3      -.1144142499531839d-01,-.7388063494425561d-02,
     4      -.4099505160158387d-02,-.2006365384390634d-02,
     5      -.8830713606061997d-03,-.3541981812203539d-03,
     6      -.1310941188337116d-03,-.5232841831804799d-04,
     7      -.2457241073764892d-04,-.3256143238317439d-03,
     8      -.1854889225065388d-02,-.5226838181077606d-02/
         data arr1049/
     1      -.9133690496771164d-02,-.1124244514638915d-01,
     2      -.1059655996371157d-01,-.8089253876465183d-02,
     3      -.5206132926747458d-02,-.2911122908424191d-02,
     4      -.1445594732345908d-02,-.6465643539539471d-03,
     5      -.2639655538388078d-03,-.1160905716666511d-03,
     6      -.1334971990408168d-04,-.5449782364859988d-04,
     7      -.5192181405847154d-03,-.2016392663057081d-02,
     8      -.4593508490885313d-02,-.7062024837308255d-02/
         data arr1050/
     1      -.8064361289313399d-02,-.7277142021884276d-02,
     2      -.5431641094111203d-02,-.3472294663202051d-02,
     3      -.1948332840631743d-02,-.9745247160108056d-03,
     4      -.4418925974342594d-03,-.2190198658388224d-03,
     5      -.1854525253483544d-04,0.3229258019735718d-06,
     6      -.1262739406692953d-03,-.6629433688190298d-03,
     7      -.1970771871219204d-02,-.3781464682075750d-02,
     8      -.5234863679201255d-02,-.5581402387575377d-02/
         data arr1051/
     1      -.4827223406179882d-02,-.3522640148370779d-02,
     2      -.2224660677573491d-02,-.1233674133503659d-02,
     3      -.6109171868521284d-03,-.3275774180504046d-03,
     4      -.2901407862775685d-04,0.1438866692998903d-04,
     5      -.3089222252285777d-04,-.1894984097610252d-03,
     6      -.7404186000567266d-03,-.1766818797846824d-02,
     7      -.2972901256621058d-02,-.3743975202901622d-02,
     8      -.3751886463543018d-02,-.3134295851608794d-02/
         data arr1052/
     1      -.2242030893656099d-02,-.1394172547715156d-02,
     2      -.7702485917806927d-03,-.4706716020305918d-03,
     3      -.3387746591311298d-04,0.1817432818446109d-04,
     4      -.1091979754577434d-04,-.4724805323720337d-04,
     5      -.2486884450041901d-03,-.7314394476920735d-03,
     6      -.1502767562053560d-02,-.2229218447671457d-02,
     7      -.2579097087640976d-02,-.2453236537368008d-02,
     8      -.1965628716131360d-02,-.1344457410822138d-02/
         data arr1053/
     1      -.8037425395092051d-03,-.5267165174232945d-03,
     2      -.4469398520171018d-04,0.2424709646020200d-04,
     3      -.9075414668593764d-05,-.9026129566442351d-05,
     4      -.7753998211535476d-04,-.2682583760239589d-03,
     5      -.6897749451805984d-03,-.1201213823841293d-02,
     6      -.1604026817417999d-02,-.1754343312247585d-02,
     7      -.1599270295863321d-02,-.1229164454882489d-02,
     8      -.8219779970421958d-03,-.6186756282737563d-03/
         data arr1054/
     1      -.3637207849711570d-04,0.1959248350402281d-04,
     2      -.6622733586607132d-05,-.8313781761682427d-06,
     3      -.2284362558662133d-04,-.8711086248093979d-04,
     4      -.2867256917321580d-03,-.5763881113716782d-03,
     5      -.8749056421615305d-03,-.1073727613907956d-02,
     6      -.1071549705801582d-02,-.8796857221468649d-03,
     7      -.6156522778248416d-03,-.4750090538276338d-03,
     8      -.4140425881571693d-04,0.2251626712632322d-04/
         data arr1055/
     1      -.7756493523570018d-05,0.1690142657167972d-05,
     2      -.8471451570135418d-05,-.2138404447130386d-04,
     3      -.1150920486396630d-03,-.2626758198308774d-03,
     4      -.4539029585326176d-03,-.6493433171060477d-03,
     5      -.7452865925436081d-03,-.6914230868574539d-03,
     6      -.5449481261093408d-03,-.4896306694935932d-03,
     7      -.2380716033716510d-04,0.1293760328287017d-04,
     8      -.4437524240179819d-05,0.1135577176607353d-05/
         data arr1056/
     1      -.3064188634736343d-05,-.3352556694211965d-05,
     2      -.3930687350797912d-04,-.9723472097908574d-04,
     3      -.1843249690276567d-03,-.2914444091305552d-03,
     4      -.3605414707068431d-03,-.3528306832323391d-03,
     5      -.2896373357600819d-03,-.2694409043251815d-03,
     6      -.2175952175450415d-04,0.1201255790511061d-04,
     7      -.4352852876425322d-05,0.1454730716278599d-05,
     8      -.2351650695778826d-05,0.2232837795458132d-05/
         data arr1057/
     1      -.1560104463340826d-04,-.3989777826364266d-04,
     2      -.8147250700196707d-04,-.1535939277832017d-03,
     3      -.2212831920805149d-03,-.2449394890078673d-03,
     4      -.2259025522125339d-03,-.2434911177241253d-03,
     5      0.3225410262281371d-03,0.1772927153174532d-02,
     6      0.4376082147714261d-02,0.6450146544957677d-02,
     7      0.6635654785375738d-02,0.5232402770591055d-02,
     8      0.3362297598347853d-02,0.1836480207930735d-02/
         data arr1058/
     1      0.8784604256741655d-03,0.3761601848408329d-03,
     2      0.1466038468945559d-03,0.5262229276893485d-04,
     3      0.1754919969551853d-04,0.6129365881664919d-05,
     4      0.7223921047745163d-04,0.6890818371164157d-03,
     5      0.2573994375108195d-02,0.5246601245551758d-02,
     6      0.7034633332020678d-02,0.6930616334330464d-02,
     7      0.5393295378262376d-02,0.3482903040945290d-02,
     8      0.1932669185865388d-02,0.9456117038025206d-03/
         data arr1059/
     1      0.4160864945865872d-03,0.1669733008553533d-03,
     2      0.6177382152740199d-04,0.2408493041807342d-04,
     3      0.1171192806046661d-04,0.1790601482028512d-03,
     4      0.1015994698850585d-02,0.2862576490546781d-02,
     5      0.5002879077447411d-02,0.6158029271514300d-02,
     6      0.5803316536356983d-02,0.4430995245255922d-02,
     7      0.2852013952808671d-02,0.1594087127775712d-02,
     8      0.7913578203596695d-03,0.3543151142702219d-03/
         data arr1060/
     1      0.1447553996825026d-03,0.6226696895273152d-04,
     2      0.3884828063940771d-05,0.3454321299750369d-04,
     3      0.3132390842595349d-03,0.1215175085487788d-02,
     4      0.2770409700808161d-02,0.4259272100123048d-02,
     5      0.4861287965853114d-02,0.4389126347671599d-02,
     6      0.3276519093755712d-02,0.2092542844334020d-02,
     7      0.1173426367837237d-02,0.5876713548765196d-03,
     8      0.2664329514898038d-03,0.1282591569792393d-03/
         data arr1061/
     1      0.5375651137367804d-05,0.2361273329290494d-05,
     2      0.8195165913167239d-04,0.4264754398221893d-03,
     3      0.1272971750275362d-02,0.2442091631094249d-02,
     4      0.3376148741297486d-02,0.3604508583514551d-02,
     5      0.3118198513510769d-02,0.2272226860457078d-02,
     6      0.1434763135076845d-02,0.7979503943225917d-03,
     7      0.3958216852471409d-03,0.2066666838084393d-03,
     8      0.8735072233400502d-05,-.5849152380885695d-05/
         data arr1062/
     1      0.2203195616247440d-04,0.1260825279119454d-03,
     2      0.5046071649623158d-03,0.1202148883183197d-02,
     3      0.2014666669572525d-02,0.2546288247286649d-02,
     4      0.2551816342568130d-02,0.2124971747763468d-02,
     5      0.1518625818316142d-02,0.9466772131057538d-03,
     6      0.5221828854409313d-03,0.3071250219317493d-03,
     7      0.1055615212505327d-04,-.8062024375931319d-05,
     8      0.8996126709298442d-05,0.3016435293337937d-04/
         data arr1063/
     1      0.1778068782773043d-03,0.5194471660697643d-03,
     2      0.1056621245030624d-02,0.1580273210894533d-02,
     3      0.1828714241756971d-02,0.1732293597288996d-02,
     4      0.1389110137285539d-02,0.9560730499069090d-03,
     5      0.5731258073033492d-03,0.3640562957435986d-03,
     6      0.1365840655834935d-04,-.1127923267389300d-04,
     7      0.8633650885389681d-05,0.1895116788333644d-05,
     8      0.5950973371465615d-04,0.1988872408752954d-03/
         data arr1064/
     1      0.4951625300596999d-03,0.8821063999662484d-03,
     2      0.1176161225464859d-02,0.1273341175117649d-02,
     3      0.1159880049555650d-02,0.8964044822129912d-03,
     4      0.5976658043407431d-03,0.4290097323019482d-03,
     5      0.1184662906839982d-04,-.9280856188157828d-05,
     6      0.6544959310276929d-05,-.3227383778901960d-05,
     7      0.1950223430217643d-04,0.6786995793784769d-04,
     8      0.2081220014944553d-03,0.4373416568538888d-03/
         data arr1065/
     1      0.6626317566664327d-03,0.8037014584863246d-03,
     2      0.8049113963730582d-03,0.6687942702473072d-03,
     3      0.4699815743204818d-03,0.3496643009343740d-03,
     4      0.1339265953816579d-04,-.1168109737590026d-04,
     5      0.8542882145905908d-05,-.6420564499359159d-05,
     6      0.9758618756965868d-05,0.1909645186823111d-04,
     7      0.7963670031909054d-04,0.2065765428757988d-03,
     8      0.3521858336441644d-03,0.4889019255956842d-03/
         data arr1066/
     1      0.5619937106600497d-03,0.5267301576766463d-03,
     2      0.4121532435895152d-03,0.3483851916921210d-03,
     3      0.8365865512344261d-05,-.7361588201738591d-05,
     4      0.5395574311081917d-05,-.4223734039802148d-05,
     5      0.4596242382914207d-05,0.4072675070134150d-05,
     6      0.2575442549682719d-04,0.8019813207517748d-04,
     7      0.1484895222393362d-03,0.2265054829764052d-03,
     8      0.2831964840473541d-03,0.2825180066497590d-03/
         data arr1067/
     1      0.2316769139971547d-03,0.2043231583013621d-03,
     2      0.7317913327269730d-05,-.7471115380055766d-05,
     3      0.5793370821253021d-05,-.4720410115407613d-05,
     4      0.4277676072399927d-05,-.6098469256830613d-06,
     5      0.7366023264881744d-05,0.3508070915684875d-04,
     6      0.6644839855554326d-04,0.1158407759848512d-03,
     7      0.1696305008334444d-03,0.1915199194526170d-03,
     8      0.1743031072614513d-03,0.1748921886498611d-03/
         data arr1068/
     1      -.2222068816450359d-03,-.8130549090959839d-03,
     2      -.1659423255941233d-02,-.2224413584838902d-02,
     3      -.2191654298624836d-02,-.1705619226232232d-02,
     4      -.1101298775811287d-02,-.6111071425233724d-03,
     5      -.2991194221910542d-03,-.1316276629654120d-03,
     6      -.5272310605468195d-04,-.1942131715479511d-04,
     7      -.7510596088800752d-05,-.7625937234442208d-04,
     8      -.4335944908274118d-03,-.1220386001635722d-02/
         data arr1069/
     1      -.2133395421773433d-02,-.2625621229857366d-02,
     2      -.2474676763066068d-02,-.1889430524127144d-02,
     3      -.1215897017614398d-02,-.6797864750254516d-03,
     4      -.3376568940915861d-03,-.1510552527550339d-03,
     5      -.6144835459243792d-04,-.2605704328377579d-04,
     6      -.1449017063327357d-04,-.1582807920970437d-03,
     7      -.6067532712666989d-03,-.1385755793528267d-02,
     8      -.2129118435758775d-02,-.2431007675436437d-02/
         data arr1070/
     1      -.2194729140901702d-02,-.1637674293551439d-02,
     2      -.1046462687047420d-02,-.5873810343097507d-03,
     3      -.2938418468957940d-03,-.1325463184033023d-03,
     4      -.6292096510555488d-04,0.4078246418225036d-05,
     5      -.4860025633371927d-04,-.2350172051512629d-03,
     6      -.7071240259396045d-03,-.1353671637108035d-02,
     7      -.1873436874829071d-02,-.1999619464171827d-02,
     8      -.1728418116191225d-02,-.1260453245153033d-02/
         data arr1071/
     1      -.7965043367371395d-03,-.4418274307720382d-03,
     2      -.2174970093901096d-03,-.1114606975155285d-03,
     3      0.1282991225166852d-04,-.1852101667697402d-04,
     4      -.7277954116991948d-04,-.3032107310633932d-03,
     5      -.7167769396064377d-03,-.1205320780179756d-02,
     6      -.1522049241987773d-02,-.1523158147902591d-02,
     7      -.1270871748863825d-02,-.9099617560663536d-03,
     8      -.5659272128260122d-03,-.3101632777453187d-03/
         data arr1072/
     1      -.1800349710978571d-03,0.1787141911868597d-04,
     2      -.1304393328557470d-04,-.1550036422830812d-04,
     3      -.1147814262911648d-03,-.3262594682109891d-03,
     4      -.6700842862823527d-03,-.1000293958368927d-02,
     5      -.1154648070172052d-02,-.1097989357935158d-02,
     6      -.8837116824294324d-03,-.6072605376211463d-03,
     7      -.3621491721331814d-03,-.2279428358740140d-03,
     8      0.2485241207288652d-04,-.1554691582690034d-04/
         data arr1073/
     1      0.3381820973992790d-05,-.4232173447766385d-04,
     2      -.1284941800121155d-03,-.3301695894083207d-03,
     3      -.5841187510141547d-03,-.7749038581394330d-03,
     4      -.8452092393921635d-03,-.7736009665253601d-03,
     5      -.5957188971667071d-03,-.3946057319827140d-03,
     6      -.2809989174329990d-03,0.2211731070506174d-04,
     7      -.1349793593261206d-04,0.6539409069227436d-05,
     8      -.1616107497876840d-04,-.4378207445122070d-04/
         data arr1074/
     1      -.1450321198160094d-03,-.3006368500687773d-03,
     2      -.4515140301484127d-03,-.5530876230889906d-03,
     3      -.5563964991822063d-03,-.4592602422619703d-03,
     4      -.3194317773125762d-03,-.2346040109703089d-03,
     5      0.2580582621252904d-04,-.1576889330153389d-04,
     6      0.8937990866455920d-05,-.9635562064929930d-05,
     7      -.1047492012575752d-04,-.5928063233927441d-04,
     8      -.1464719010582599d-03,-.2462505719141187d-03/
         data arr1075/
     1      -.3498292120463228d-03,-.4052275082816399d-03,
     2      -.3768846789175126d-03,-.2928106546481228d-03,
     3      -.2467333086941602d-03,0.1758623965131034d-04,
     4      -.1075786266543905d-04,0.6241199832175620d-05,
     5      -.5368329678512671d-05,-.8313744473680349d-06,
     6      -.2093178202316127d-04,-.5980506879399473d-04,
     7      -.1085706821306946d-03,-.1725165017482439d-03,
     8      -.2195829463682457d-03,-.2188522538610904d-03/
         data arr1076/
     1      -.1798230680878000d-03,-.1605488156863558d-03,
     2      0.1527722111158446d-04,-.9422841157889255d-05,
     3      0.5582464984595900d-05,-.4389204727056950d-05,
     4      0.2086252674671354d-05,-.7523427495813816d-05,
     5      -.2615880532293543d-04,-.4860788788766572d-04,
     6      -.9080947240114150d-04,-.1341665016028009d-03,
     7      -.1495798723313162d-03,-.1358158623448575d-03,
     8      -.1371741101559506d-03,0.1341610517822297d-03/
         data arr1077/
     1      0.3483592704741936d-03,0.6179983113284613d-03,
     2      0.7569421882411370d-03,0.7141652288691252d-03,
     3      0.5464783430067232d-03,0.3504075108497355d-03,
     4      0.1957054148723848d-03,0.9799869509221605d-04,
     5      0.4411529763122775d-04,0.1756956002028384d-04,
     6      0.6950387410421990d-05,0.6421903478674556d-04,
     7      0.2371031189690924d-03,0.5439761103800742d-03,
     8      0.8349923603818026d-03,0.9533445916770538d-03/
         data arr1078/
     1      0.8610717398093101d-03,0.6423757137091339d-03,
     2      0.4102889163493761d-03,0.2303464373714607d-03,
     3      0.1153464572543635d-03,0.5199045074032077d-04,
     4      0.2418393657602205d-04,0.2126827801800576d-04,
     5      0.1094540986273091d-03,0.3268680203988471d-03,
     6      0.6270647558668976d-03,0.8669615188088549d-03,
     7      0.9254238441290962d-03,0.8005349605150815d-03,
     8      0.5833416069952077d-03,0.3680134672034929d-03/
         data arr1079/
     1      0.2040650985326386d-03,0.1004415063136045d-03,
     2      0.5036342029702831d-04,0.6050740014770296d-05,
     3      0.3928826044996991d-04,0.1554759077214078d-03,
     4      0.3711090990850476d-03,0.6218347700507210d-03,
     5      0.7855527479908846d-03,0.7875081470336791d-03,
     6      0.6560190109907336d-03,0.4685619192993665d-03,
     7      0.2914796288194936d-03,0.1598554742330477d-03,
     8      0.9058608493308630d-04,0.2048813119911221d-05/
         data arr1080/
     1      0.1119234968371552d-04,0.6254290885786084d-04,
     2      0.1838088577555872d-03,0.3737438804864294d-03,
     3      0.5586788028959163d-03,0.6471679525143841d-03,
     4      0.6140213557643457d-03,0.4930476488192501d-03,
     5      0.3396360345119145d-03,0.2033068163763180d-03,
     6      0.1253660461395665d-03,0.1692857401009233d-05,
     7      0.1473916890065856d-05,0.2296330996955115d-04,
     8      0.7837198876795765d-04,0.1946930638366295d-03/
         data arr1081/
     1      0.3464986895909885d-03,0.4626776012566030d-03,
     2      0.5019183138102129d-03,0.4579477791614487d-03,
     3      0.3543048543158278d-03,0.2358972222612741d-03,
     4      0.1641482636909450d-03,0.1133559868256304d-05,
     5      -.5398368085479850d-06,0.7792057011974857d-05,
     6      0.2929942666608072d-04,0.8922529466158765d-04,
     7      0.1865417680755670d-03,0.2834437193657283d-03,
     8      0.3441496554139989d-03,0.3437629956749980d-03/
         data arr1082/
     1      0.2842135668242740d-03,0.1978791096257254d-03,
     2      0.1406259989931818d-03,0.1873105980799657d-05,
     3      -.2090056434970753d-05,0.3984020023084917d-05,
     4      0.9046080816762250d-05,0.3661274544392532d-04,
     5      0.9458964867432572d-04,0.1620310212475274d-03,
     6      0.2256536268808766d-03,0.2595140420427195d-03,
     7      0.2429468220189177d-03,0.1891313669080661d-03,
     8      0.1535213342741349d-03,0.1430969339743567d-05/
         data arr1083/
     1      -.1697664840072910d-05,0.2111242349567484d-05,
     2      0.2103615385795142d-05,0.1266684984941138d-04,
     3      0.3996813364225245d-04,0.7447044811452210d-04,
     4      0.1148265313721664d-03,0.1451549234234535d-03,
     5      0.1460417337326773d-03,0.1202341598926526d-03,
     6      0.1030702875252017d-03,0.1847661454787192d-05,
     7      -.2254467333545684d-05,0.2249908046762838d-05,
     8      -.2634524651430375d-06,0.3607879773561546d-05/
         data arr1084/
     1      0.1887176700017751d-04,0.3550249589434216d-04,
     2      0.6275975870577032d-04,0.9385376631711631d-04,
     3      0.1075558763413242d-03,0.9866323008953598d-04,
     4      0.9658935645892868d-04,-.6765211091595533d-04,
     5      -.1433947362636526d-03,-.2208375822861685d-03,
     6      -.2609725576976956d-03,-.2257910757326477d-03,
     7      -.1692452001207634d-03,-.1139894555979498d-03,
     8      -.6344532636855910d-04,-.2793241112562109d-04/
         data arr1085/
     1      -.1125364532146935d-04,-.7780380536157825d-05,
     2      -.4166474563195256d-04,-.1186695043347127d-03,
     3      -.2276675367457250d-03,-.3195705480694268d-03,
     4      -.3360057819696159d-03,-.2909522883802104d-03,
     5      -.2150452725110484d-03,-.1354969030807984d-03,
     6      -.7320257692027953d-04,-.3523156168013967d-04,
     7      -.1866109931446178d-04,-.1710045193368586d-04,
     8      -.6752769678349292d-04,-.1597077723328460d-03/
         data arr1086/
     1      -.2707517054773995d-03,-.3395836312032257d-03,
     2      -.3399536809229192d-03,-.2849486394153857d-03,
     3      -.2038412465223369d-03,-.1256980113657807d-03,
     4      -.6810266950287465d-04,-.3849228419590383d-04,
     5      -.4632671159603678d-05,-.3117585717937515d-04,
     6      -.8786329604881634d-04,-.1826913129835609d-03,
     7      -.2712325976571515d-03,-.3131861050775458d-03,
     8      -.2997952856629176d-03,-.2426800830871160d-03/
         data arr1087/
     1      -.1672366304766470d-03,-.9997760171192814d-04,
     2      -.6226481971835867d-04,0.4581755666307434d-06,
     3      -.1331595067468119d-04,-.3947442522575202d-04,
     4      -.1044996878159543d-03,-.1826180067562471d-03,
     5      -.2420109107060081d-03,-.2658040301313436d-03,
     6      -.2439337589041148d-03,-.1872252167650430d-03,
     7      -.1232248017879941d-03,-.8532719606207131d-04,
     8      0.1727935967128959d-05,-.5745507527096421d-05/
         data arr1088/
     1      -.1460703307180244d-04,-.5193987356578150d-04,
     2      -.1052467182799809d-03,-.1579597441775896d-03,
     3      -.1955246003895140d-03,-.1974030092763860d-03,
     4      -.1623602090078567d-03,-.1121571838889160d-03,
     5      -.7998323669743407d-04,0.2624038091148882d-05,
     6      -.3719503475891803d-05,-.3155674202006107d-05,
     7      -.2407055663718726d-04,-.5576347592962798d-04,
     8      -.9358918398644472d-04,-.1351289879776590d-03/
         data arr1089/
     1      -.1564440672834283d-03,-.1438433924039746d-03,
     2      -.1100959602162770d-03,-.8897066529293158d-04,
     3      0.2355184193993538d-05,-.2604822755699305d-05,
     4      0.6541498774363026d-06,-.1010496833255481d-04,
     5      -.2563945093226599d-04,-.4634662650435278d-04,
     6      -.7705891322069502d-04,-.1000752811218665d-03,
     7      -.1001971359083124d-03,-.8260496752336830d-04,
     8      -.7274105419288987d-04,0.2097132415027746d-05/
         data arr1090/
     1      -.2142397192811542d-05,0.1723760039497801d-05,
     2      -.4389786201623011d-05,-.1158821921068698d-04,
     3      -.2121583242075691d-04,-.4213611481577237d-04,
     4      -.6290008899934927d-04,-.6954025099147655d-04,
     5      -.6268381742748201d-04,-.6164587779894796d-04,
     6      0.2886552513054118d-04,0.5879584099755715d-04,
     7      0.7875135401827072d-04,0.8360019188875026d-04,
     8      0.7376137167023163d-04,0.5372450755146835d-04/
         data arr1091/
     1      0.3291208727761741d-04,0.1784795509963060d-04,
     2      0.1026482713856381d-04,0.2238199214725445d-04,
     3      0.5591010535503626d-04,0.9270141147989854d-04,
     4      0.1155806083199227d-03,0.1171368992522744d-03,
     5      0.9853894027877320d-04,0.6964244497054498d-04,
     6      0.4247693832174047d-04,0.2667229072920468d-04,
     7      0.1166201861295604d-04,0.3657474364338905d-04,
     8      0.7538060198340795d-04,0.1092135143714872d-03/
         data arr1092/
     1      0.1284449731806113d-03,0.1250654971225557d-03,
     2      0.1007434679332398d-03,0.6900642458246490d-04,
     3      0.4920844827040760d-04,0.4543706577839704d-05,
     4      0.1886107805959534d-04,0.4925991218492771d-04,
     5      0.8139540346231201d-04,0.1114302272877541d-03,
     6      0.1251788912838930d-03,0.1133267523218342d-03,
     7      0.8569037349271674d-04,0.6772425032251160d-04,
     8      0.1227273831808555d-05,0.8094549151142759d-05/
         data arr1093/
     1      0.2716772014970376d-04,0.4993163468649279d-04,
     2      0.7881420663307710d-04,0.9942605549585827d-04,
     3      0.9730772666000732d-04,0.7745161445300981d-04,
     4      0.6281416634075817d-04,0.3609633821548048d-08,
     5      0.2693387824417323d-05,0.1421107381956309d-04,
     6      0.2697002208107906d-04,0.5051034591212621d-04,
     7      0.7549660140969927d-04,0.8434931795601240d-04,
     8      0.7565576788346490d-04,0.7096678923435671d-04/
         data arr1094/
     1      -.2529122684264618d-06,0.4723720880543544d-06,
     2      0.7100308332347867d-05,0.1256988689420851d-04,
     3      0.2792592057498929d-04,0.4958561190288689d-04,
     4      0.6255529702668885d-04,0.6218899527216886d-04,
     5      0.6571956013522905d-04,-.1887775946198071d-06,
     6      -.2543811127108641d-06,0.3540402572034653d-05,
     7      0.5141873687277646d-05,0.1354411816825586d-04,
     8      0.2902670218794374d-04,0.4125209833090210d-04/
         data arr1095/
     1      0.4512503055190771d-04,0.5318256646158083d-04,
     2      -.2828006306455360d-04,-.2890258074257810d-04,
     3      -.2393007261210837d-04,-.1596957603187714d-04,
     4      -.9418486390345047d-05,-.5967566962699551d-05,
     5      -.3671659649975123d-04,-.4295640453917300d-04,
     6      -.4184239153099200d-04,-.3333468240807471d-04,
     7      -.2282991138211770d-04,-.1651157444825859d-04,
     8      -.3285574917232209d-04,-.4366108148220160d-04/
         data arr1096/
     1      -.4921004570539665d-04,-.4481154909973281d-04,
     2      -.3382815116934469d-04,-.2622499829776799d-04,
     3      -.2279059656201503d-04,-.3425259023347392d-04,
     4      -.4280281488931029d-04,-.4178702962239427d-04,
     5      -.3258706575946975d-04,-.2460756929756713d-04,
     6      -.1412773075048158d-04,-.2334517385005817d-04,
     7      -.3512883134920851d-04,-.4012267565173018d-04,
     8      -.3528857831970636d-04,-.3051817603853120d-04/
         data arr1097/
     1      -.8008768561310255d-05,-.1347914702809358d-04,
     2      -.2567162366623513d-04,-.3460867234124708d-04,
     3      -.3411067082114653d-04,-.3384548263983446d-04,
     4      -.4173750944518020d-05,-.6309593052181846d-05,
     5      -.1608643363343888d-04,-.2526894343974729d-04,
     6      -.2727523632287352d-04,-.3024172956446678d-04,
     7      0.1051370048075531d-04,0.9794566493392407d-05,
     8      0.1513847702959671d-04,0.1567092744979035d-04/
         data arr1098/
     1      0.1416672547906986d-04,0.1566455355083602d-04,
     2      0.1188250098224377d-04,0.1496123819196180d-04,
     3      0.9480914402563644d-05,0.1387719716543979d-04,
     4      0.5578753658139956d-05,0.9036834100931517d-05/
        do 1200 i=1,1560
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c
c
c
c
        subroutine lot6geta(arr)
        implicit real *8 (a-h,o-z)
        dimension arr(1)
c         
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16)
         real *8
     1  arr1129( 9)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2))
c
         data arr1001/
     1      0.9723932164459568d+00,-.5444432080736553d-01,
     2      0.1524169450198267d-02,-.2844609536857831d-04,
     3      0.3981744049630489d-06,-.4458751096146303d-08,
     4      0.4161434058068001d-10,-.3381695640931225d-12,
     5      0.1808216929316514d-13,-.1226365217737351d-13,
     6      -.5541348616650906d-14,-.1818951585218827d-13,
     7      -.1130571856741345d-13,-.1578287163234073d-13,
     8      -.3103054837191396d-14,-.8312921951822948d-14/
         data arr1002/
     1      0.8672519969516073d+00,-.2470379290237412d+00,
     2      0.3518454762332694d-01,-.3340788993686027d-02,
     3      0.2379070896400341d-03,-.1355363260105530d-04,
     4      0.6434618282834581d-06,-.2618443053636192d-07,
     5      0.9323393743978922d-09,-.2951269668577459d-10,
     6      0.8261805383684108d-12,-.2687315024370654d-13,
     7      -.1509199971036889d-13,-.4556156341962991d-14,
     8      0.2382024484987828d-14,-.6544556021247094d-14/
         data arr1003/
     1      0.7170018663916099d+00,-.4770598236726748d+00,
     2      0.1587067524021621d+00,-.3519870675635640d-01,
     3      0.5854897185694294d-02,-.7791154667628079d-03,
     4      0.8639788928125673d-04,-.8212164683236707d-05,
     5      0.6829992528151621d-06,-.5049290338330525d-07,
     6      0.3359579759218056d-08,-.2032104513957286d-09,
     7      0.1128144467820741d-10,-.5828879317149732d-12,
     8      0.3447918643224049d-13,0.1265244961752565d-13/
         data arr1004/
     1      0.5580316911563870d+00,-.6510438822217178d+00,
     2      0.3797796283755701d+00,-.1476936451010366d+00,
     3      0.4307777031748583d-01,-.1005158641325309d-01,
     4      0.1954495878007216d-02,-.3257527700557810d-03,
     5      0.4750611642487024d-04,-.6158265645764667d-05,
     6      0.7184718636273037d-06,-.7620237847883382d-07,
     7      0.7408378020889187d-08,-.6648834953199186d-09,
     8      0.5510802692956698d-10,-.4289315810087485d-11/
         data arr1005/
     1      0.4138651275631936d+00,-.7302361604809470d+00,
     2      0.6442253944102184d+00,-.3788969297544454d+00,
     3      0.1671343034093664d+00,-.5897936495624898d-01,
     4      0.1734416284652342d-01,-.4371795143528381d-02,
     5      0.9642159490175046d-03,-.1890324238711355d-03,
     6      0.3335340355353440d-04,-.5349978163156572d-05,
     7      0.7864978670685691d-06,-.1067489128850916d-06,
     8      0.1329792592924286d-07,-.1563321702559989d-08/
         data arr1006/
     1      0.2951861333282566d+00,-.7203422259446376d+00,
     2      0.8789249627658396d+00,-.7149463706981258d+00,
     3      0.4361706073174647d+00,-.2128772802375816d+00,
     4      0.8658067832763781d-01,-.3018324054954391d-01,
     5      0.9207012149808765d-02,-.2496428543017546d-02,
     6      0.6091967726367294d-03,-.1351475206377194d-03,
     7      0.2746557008222751d-04,-.5155910993159592d-05,
     8      0.8790461932539650d-06,-.1428550445287170d-06/
         data arr1007/
     1      0.2038928017671235d+00,-.6484447242604885d+00,
     2      0.1031131450264948d+01,-.1093109946172311d+01,
     3      0.8691103537947250d+00,-.5528101212760490d+00,
     4      0.2930190151587515d+00,-.1331278215211485d+00,
     5      0.5292358133584103d-01,-.1870156173672259d-01,
     6      0.5947404000803202d-02,-.1719519361311463d-02,
     7      0.4548826347034493d-03,-.1112952538037193d-03,
     8      0.2435858373038677d-04,-.5155402774350941d-05/
         data arr1008/
     1      0.1371255193622374d+00,-.5448980265898534d+00,
     2      0.1082635335018723d+01,-.1434028852716785d+01,
     3      0.1424606336295318d+01,-.1132196487145125d+01,
     4      0.7498381185319384d+00,-.4256634550882662d+00,
     5      0.2114313429304338d+00,-.9335215363424615d-01,
     6      0.3708868686825872d-01,-.1339832511602998d-01,
     7      0.4417394089908514d-02,-.1350641923483241d-02,
     8      0.3619783751157144d-03,-.9564045607892216d-04/
         data arr1009/
     1      0.9016771248451028d-01,-.4339021387114126d+00,
     2      0.1044005206565381d+01,-.1674642544969268d+01,
     3      0.2014666266850075d+01,-.1938981813969845d+01,
     4      0.1555117869475378d+01,-.1069068785238408d+01,
     5      0.6430409080408911d+00,-.3438264147088717d+00,
     6      0.1653621928840372d+00,-.7234350778372813d-01,
     7      0.2874687057928622d-01,-.1064746698911441d-01,
     8      0.3368813649888732d-02,-.1076832768863112d-02/
         data arr1010/
     1      0.5815404913325365d-01,-.3308567267799356d+00,
     2      0.9411772642979195d+00,-.1784884287072614d+01,
     3      0.2538704120287968d+01,-.2888694077667628d+01,
     4      0.2739119659430211d+01,-.2226237248562410d+01,
     5      0.1582983035285241d+01,-.1000697808340976d+01,
     6      0.5684923021806453d+00,-.2940590157269815d+00,
     7      0.1370363343649737d+00,-.6004212023557368d-01,
     8      0.2177932213770130d-01,-.8222213860483440d-02/
         data arr1011/
     1      0.3687639997190396d-01,-.2433956858149221d+00,
     2      0.8032663072175713d+00,-.1767271921812353d+01,
     3      0.2916228186751785d+01,-.3849598936794026d+01,
     4      0.4234815753524020d+01,-.3992986435544908d+01,
     5      0.3292847132168244d+01,-.2415049936716777d+01,
     6      0.1588606041324672d+01,-.9534482689305053d+00,
     7      0.5089954581310090d+00,-.2589701466987153d+00,
     8      0.1051332000345612d+00,-.4600355113553745d-01/
         data arr1012/
     1      0.2303367008498129d-01,-.1736974437194063d+00,
     2      0.6550563117842262d+00,-.1646661398471988d+01,
     3      0.3104974241369333d+01,-.4683142815035063d+01,
     4      0.5886578745176014d+01,-.6341788245574169d+01,
     5      0.5970799344803064d+01,-.5004285805245347d+01,
     6      0.3747358013016810d+01,-.2570652999574300d+01,
     7      0.1539278925686852d+01,-.8961907601038832d+00,
     8      0.3990779113949378d+00,-.1994081665311247d+00/
         data arr1013/
     1      0.1419792937667138d-01,-.1207499460745623d+00,
     2      0.5140555487920545d+00,-.1457844993018046d+01,
     3      0.3102897924417213d+01,-.5280397822804276d+01,
     4      0.7490121203733228d+01,-.9104965484100452d+01,
     5      0.9655591123953394d+01,-.9134924145033363d+01,
     6      0.7669294926602703d+01,-.5940671990253920d+01,
     7      0.3912475169355638d+01,-.2576392488615208d+01,
     8      0.1237217329930388d+01,-.6976057067524319d+00/
         data arr1014/
     1      0.8669711504250201d-02,-.8206919374409209d-01,
     2      0.3906323065313048d+00,-.1235714271277383d+01,
     3      0.2939425161996374d+01,-.5583137449176644d+01,
     4      0.8844359492032581d+01,-.1200315371198555d+02,
     5      0.1416093805779116d+02,-.1497153048435353d+02,
     6      0.1389018273724296d+02,-.1203040827084697d+02,
     7      0.8553284051969353d+01,-.6311699482714874d+01,
     8      0.3221325904787957d+01,-.2030481543510435d+01/
         data arr1015/
     1      0.5314619970096766d-02,-.5481866715615977d-01,
     2      0.2896878171177806d+00,-.1009623026907892d+01,
     3      0.2662843379975637d+01,-.5587931394574992d+01,
     4      0.9796136210467994d+01,-.1470488073310050d+02,
     5      0.1906263237519080d+02,-.2233673171662602d+02,
     6      0.2257516896266506d+02,-.2169032779436090d+02,
     7      0.1635012680016491d+02,-.1342285647172899d+02,
     8      0.7189705012404868d+01,-.5029500631122966d+01/
         data arr1016/
     1      0.3419327702847340d-02,-.3644986116745823d-01,
     2      0.2127171126840223d+00,-.8015670256135344d+00,
     3      0.2328799382701414d+01,-.5337987719282062d+01,
     4      0.1026682142563793d+02,-.1689463049450455d+02,
     5      0.2374325077639196d+02,-.3062551255509397d+02,
     6      0.3322708530128710d+02,-.3519588510974361d+02,
     7      0.2763710723952594d+02,-.2510536692386389d+02,
     8      0.1395668207246284d+02,-.1077818837771744d+02/
         data arr1017/
     1      0.2572222878671629d-02,-.2499174704230193d-01,
     2      0.1594572685565409d+00,-.6266130211993721d+00,
     3      0.1991382297241854d+01,-.4908379293322215d+01,
     4      0.1025860813796825d+02,-.1833175856845374d+02,
     5      0.2749444912224984d+02,-.3881995465514316d+02,
     6      0.4452765277901264d+02,-.5176193308872716d+02,
     7      0.4160878262616102d+02,-.4167198473079022d+02,
     8      0.2380382041623501d+02,-.2022848209671167d+02/
         data arr1018/
     1      -.1924897421999207d-01,0.6222395724210017d-03,
     2      -.1231752061368760d-04,0.1780690050425607d-06,
     3      -.2035135718438708d-08,0.1926059444659388d-10,
     4      -.1557438887458117d-12,0.1060748022261567d-14,
     5      -.2876635061949931d-15,-.5497406559323595d-16,
     6      -.4850347825203355d-15,-.2106276780068159d-16,
     7      -.4483432210694105d-15,-.2080213023885006d-16,
     8      -.1675450227910319d-15,-.8734109741148427d-01/
         data arr1019/
     1      0.1436403141796777d-01,-.1446604068607746d-02,
     2      0.1063952849512296d-03,-.6186358595960246d-05,
     3      0.2978649465029311d-06,-.1224664475855948d-07,
     4      0.4395060330906352d-09,-.1399732231028216d-10,
     5      0.4010775821640855d-12,-.1148516198324397d-13,
     6      0.6041195382128643d-15,-.1189821251777485d-14,
     7      0.2919313361905927d-16,-.5526644341279606d-15,
     8      -.1686661181753037d+00,0.6479176035325460d-01/
         data arr1020/
     1      -.1524148711568263d-01,0.2618389621696137d-02,
     2      -.3556159300402417d-03,0.3999445123536552d-04,
     3      -.3840888331230590d-05,0.3219689272934741d-06,
     4      -.2395088323394534d-07,0.1601611298375337d-08,
     5      -.9728260315638049d-10,0.5414345839652153d-11,
     6      -.2808019353877419d-12,0.1396669887611573d-13,
     7      -.9108975374113801d-15,-.2301787719844966d+00,
     8      0.1550443840373274d+00,-.6395322431751170d-01/
         data arr1021/
     1      0.1926496454980351d-01,-.4587900514372925d-02,
     2      0.9047557843845643d-03,-.1523569072931484d-03,
     3      0.2239459804081207d-04,-.2921121874903817d-05,
     4      0.3425180084149502d-06,-.3647911737935720d-07,
     5      0.3558854230991190d-08,-.3203453546707206d-09,
     6      0.2660803729979888d-10,-.2079952031599054d-11,
     7      -.2581774704718529d+00,0.2630039159413550d+00,
     8      -.1640671832916356d+00,0.7474473275891463d-01/
         data arr1022/
     1      -.2692027384485025d-01,0.8028787287517641d-02,
     2      -.2044719948920214d-02,0.4545357533664363d-03,
     3      -.8966595140790258d-04,0.1590060207791588d-04,
     4      -.2561106948408982d-05,0.3778078454810450d-06,
     5      -.5143292521050881d-07,0.6413282768143873d-08,
     6      -.7574798181682633d-09,-.2546794363701228d+00,
     7      0.3588196134921917d+00,-.3095808596831346d+00,
     8      0.1950614255284738d+00,-.9716474029985867d-01/
         data arr1023/
     1      0.4007906599769948d-01,-.1411691810079116d-01,
     2      0.4340226640330927d-02,-.1184159990000183d-02,
     3      0.2904220035800989d-03,-.6469692689942325d-04,
     4      0.1319232340500257d-04,-.2484182542947743d-05,
     5      0.4233284177794249d-06,-.6927086769253563d-07,
     6      -.2292598308677842d+00,0.4209576516731953d+00,
     7      -.4733304912017856d+00,0.3886779651933875d+00,
     8      -.2523221441924803d+00,0.1356414409535060d+00/
         data arr1024/
     1      -.6226483592097310d-01,0.2494839139505215d-01,
     2      -.8870927065338164d-02,0.2835258786358570d-02,
     3      -.8231558073452890d-03,0.2184379933258613d-03,
     4      -.5362356268569062d-04,0.1170568286663721d-04,
     5      -.2502696466991430d-05,-.1926505446287761d+00,
     6      0.4419840214135611d+00,-.6209527064797797d+00,
     7      0.6371032980633232d+00,-.5167746196437566d+00,
     8      0.3471074611759558d+00,-.1990858170033977d+00/
         data arr1025/
     1      0.9966912855962629d-01,-.4428073971735787d-01,
     2      0.1768006223965358d-01,-.6413918556529119d-02,
     3      0.2120175533300168d-02,-.6507609802462490d-03,
     4      0.1734498331482267d-03,-.4650062375835366d-04,
     5      -.1534075689917501d+00,0.4262132951235833d+00,
     6      -.7251414658516857d+00,0.9009858159381475d+00,
     7      -.8850198982745188d+00,0.7198777629405930d+00,
     8      -.5000105654189639d+00,0.3031246578841045d+00/
         data arr1026/
     1      -.1630899447089404d+00,0.7881585569494128d-01,
     2      -.3463113033420556d-01,0.1378394074037084d-01,
     3      -.5130178765070319d-02,0.1608223892896448d-02,
     4      -.5246150837099270d-03,-.1169754814183785d+00,
     5      0.3842335890897547d+00,-.7728772714397250d+00,
     6      0.1135339969226377d+01,-.1318500612753014d+01,
     7      0.1267948347350288d+01,-.1041220908292497d+01,
     8      0.7461547818484977d+00,-.4746592417572701d+00/
         data arr1027/
     1      0.2708592964880411d+00,-.1407626073470963d+00,
     2      0.6559794087591470d-01,-.2893023257836372d-01,
     3      0.1034885957071021d-01,-.4015887307621535d-02,
     4      -.8605309269096932d-01,0.3279293069566877d+00,
     5      -.7652489064588762d+00,0.1304156753068572d+01,
     6      -.1757079552245641d+01,0.1960221846151039d+01,
     7      -.1867500629589853d+01,0.1551798614470663d+01,
     8      -.1145456484423057d+01,0.7562992569815116d+00/
         data arr1028/
     1      -.4563716371825745d+00,0.2429981129334862d+00,
     2      -.1247852239182948d+00,0.4967498264478936d-01,
     3      -.2253871275226460d-01,-.6140971396128996d-01,
     4      0.2674114083149651d+00,-.7130120048663473d+00,
     5      0.1388483932462282d+01,-.2137471554702985d+01,
     6      0.2724363507904203d+01,-.2965822904059924d+01,
     7      0.2812322713486425d+01,-.2373152355180183d+01,
     8      0.1781284719191156d+01,-.1230275556655981d+01/
         data arr1029/
     1      0.7318883679831562d+00,-.4318601430038136d+00,
     2      0.1873036012773022d+00,-.9805943287448726d-01,
     3      -.4268418964520913d-01,0.2098042405766526d+00,
     4      -.6312040649971010d+00,0.1387237523334202d+01,
     5      -.2409788563730517d+01,0.3464843183896088d+01,
     6      -.4257186176650001d+01,0.4542263856459334d+01,
     7      -.4330392726216303d+01,0.3635411043057756d+01,
     8      -.2842351706206347d+01,0.1849399881599689d+01/
         data arr1030/
     1      -.1241650329391335d+01,0.5761434300741004d+00,
     2      -.3445453958186215d+00,-.2898815900916375d-01,
     3      0.1592782396783474d+00,-.5348476912029251d+00,
     4      0.1313122654644147d+01,-.2546936098999113d+01,
     5      0.4086033319538528d+01,-.5609169476312552d+01,
     6      0.6644118120538146d+01,-.7091596755626146d+01,
     7      0.6553257929578545d+01,-.5753285927054281d+01,
     8      0.4009986863745184d+01,-.3042253924945349d+01/
         data arr1031/
     1      0.1486533021520934d+01,-.1007910351878454d+01,
     2      -.1929361622561513d-01,0.1176972712549401d+00,
     3      -.4364373300961624d+00,0.1186731869208301d+01,
     4      -.2546051509333170d+01,0.4511531061204139d+01,
     5      -.6862342177939194d+01,0.8897419388234498d+01,
     6      -.1056364465661858d+02,0.1057035257439382d+02,
     7      -.1036450068574591d+02,0.7579511113754052d+01,
     8      -.6470964086432438d+01,0.3283206679443080d+01/
         data arr1032/
     1      -.2510963542127718d+01,-.1264784301985394d-01,
     2      0.8542173465151248d-01,-.3450448663885403d+00,
     3      0.1031114515579640d+01,-.2424155137717795d+01,
     4      0.4695106920916741d+01,-.7859983416417883d+01,
     5      0.1097569745599926d+02,-.1444109848733716d+02,
     6      0.1537705602131775d+02,-.1679505503364490d+02,
     7      0.1261809238077277d+02,-.1210486400898760d+02,
     8      0.6296584827301843d+01,-.5415748530690751d+01/
         data arr1033/
     1      -.8265286851996357d-02,0.6196494883347951d-01,
     2      -.2663977064700859d+00,0.8676547969019621d+00,
     3      -.2210786131653883d+01,0.4623315141940243d+01,
     4      -.8473507450989757d+01,0.1249556960795281d+02,
     5      -.1820914875613401d+02,0.2024768631105468d+02,
     6      -.2464377291694831d+02,0.1860919736458984d+02,
     7      -.2009327329957988d+02,0.1058804152097735d+02,
     8      -.1023660173658842d+02,0.3111197862104953d-03/
         data arr1034/
     1      -.7790284053070875d-05,0.1259138009852221d-06,
     2      -.1538417989758517d-08,0.1522684857194667d-10,
     3      -.1270930497666488d-12,0.9167579383876258d-15,
     4      -.7237560130272629d-17,0.1983574246058201d-17,
     5      -.1928813962086862d-17,0.3135633205172202d-17,
     6      -.2085026813972348d-17,-.1058340845653661d-18,
     7      -.2108354341222109d-17,0.7182015708983871d-02,
     8      -.9149127458533679d-03,0.7523282747537121d-04/
         data arr1035/
     1      -.4676447533114290d-05,0.2354829167207542d-06,
     2      -.9999343348478985d-08,0.3677173562046309d-09,
     3      -.1193679815809385d-10,0.3470124382761559d-12,
     4      -.9139244546470186d-14,0.1939186544266552d-15,
     5      0.4418335611115244d-17,-.1335272629135734d-15,
     6      0.2065630131711500d-16,0.3239588017662735d-01,
     7      -.9639562842733406d-02,0.1851481057290267d-02,
     8      -.2688203751827134d-03,0.3161838991914119d-04/
         data arr1036/
     1      -.3136072189549838d-05,0.2693785326554820d-06,
     2      -.2042538151952629d-07,0.1387034122071257d-08,
     3      -.8531915784714029d-10,0.4797998638886881d-11,
     4      -.2482778298239002d-12,0.1141849395407813d-13,
     5      -.2919324463700364d-15,0.7752219201866396d-01,
     6      -.4044757051100095d-01,0.1362238707248564d-01,
     7      -.3468126800268149d-02,0.7152722512196551d-03,
     8      -.1243988938847803d-03,0.1873666499475962d-04/
         data arr1037/
     1      -.2491141105476420d-05,0.2966292973170538d-06,
     2      -.3199429325048651d-07,0.3154596033179287d-08,
     3      -.2865189941077576d-09,0.2399440758239218d-10,
     4      -.1882125985825430d-11,0.1315019579706707d+00,
     5      -.1037651976979763d+00,0.5285250739170428d-01,
     6      -.2034981423405230d-01,0.6347313669136326d-02,
     7      -.1669506847177289d-02,0.3802918958468763d-03,
     8      -.7646738008559779d-04,0.1377032821235521d-04/
         data arr1038/
     1      -.2246238851783070d-05,0.3348972322400489d-06,
     2      -.4600233500032247d-07,0.5786976076227751d-08,
     3      -.6865169353408463d-09,0.1794098067451485d+00,
     4      -.1957961273179635d+00,0.1379292567259972d+00,
     5      -.7344963972221100d-01,0.3168528372789780d-01,
     6      -.1152641535013676d-01,0.3631294181692144d-02,
     7      -.1009854996244670d-02,0.2515131947284396d-03,
     8      -.5674286717133759d-04,0.1169454728585965d-04/
         data arr1039/
     1      -.2221803464021177d-05,0.3823517258113704d-06,
     2      -.6270797389793144d-07,0.2104788257916342d+00,
     3      -.2993604876175330d+00,0.2748368242658860d+00,
     4      -.1907376123421086d+00,0.1072339730393985d+00,
     5      -.5083902487405600d-01,0.2087332388216794d-01,
     6      -.7565149764343725d-02,0.2455422936878435d-02,
     7      -.7219497422295521d-03,0.1936620637619464d-03,
     8      -.4795512424910203d-04,0.1058710465077820d-04/
         data arr1040/
     1      -.2261643389961029d-05,0.2209920096535736d+00,
     2      -.3927249736654234d+00,0.4505000478821675d+00,
     3      -.3906448884513711d+00,0.2744125049556629d+00,
     4      -.1625528663601189d+00,0.8338922160019778d-01,
     5      -.3776267525917083d-01,0.1531176556758485d-01,
     6      -.5625212405449574d-02,0.1880195018217014d-02,
     7      -.5818452052212333d-03,0.1571611294649049d-03,
     8      -.4192066950363393d-04,0.2131066330038507d+00/
         data arr1041/
     1      -.4586197202518855d+00,0.6370929803916231d+00,
     2      -.6690120734500926d+00,0.5691128165882317d+00,
     3      -.4082565382626571d+00,0.2536128684547231d+00,
     4      -.1390824504667647d+00,0.6826162383888812d-01,
     5      -.3037071273542715d-01,0.1222973478831600d-01,
     6      -.4584983287461958d-02,0.1460520889557554d-02,
     7      -.4714399474735689d-03,0.1921166608284484d+00,
     8      -.4888103832550701d+00,0.8028047619668568d+00/
         data arr1042/
     1      -.9966918502944472d+00,0.1002396289629948d+01,
     2      -.8501491755896233d+00,0.6242826717727270d+00,
     3      -.4047784557667371d+00,0.2346155349585902d+00,
     4      -.1234264040343823d+00,0.5824910186380990d-01,
     5      -.2583674874027492d-01,0.9423951225092637d-02,
     6      -.3594137875121861d-02,0.1639637667144153d+00,
     7      -.4839849642850143d+00,0.9221660003668961d+00,
     8      -.1328220148905025d+01,0.1549658429031435d+01/
         data arr1043/
     1      -.1524775849516856d+01,0.1298355000518943d+01,
     2      -.9767527494795908d+00,0.6552513884091224d+00,
     3      -.4000275269565894d+00,0.2160472414095508d+00,
     4      -.1113069643461930d+00,0.4537553750167645d-01,
     5      -.2006884708893819d-01,0.1337011960650665d+00,
     6      -.4509429494426628d+00,0.9817452505543286d+00,
     7      -.1615735075599570d+01,0.2153627238181192d+01,
     8      -.2421396756552646d+01,0.2353067585787993d+01/
         data arr1044/
     1      -.2023266734642552d+01,0.1543936964819243d+01,
     2      -.1077635891495579d+01,0.6518921127330302d+00,
     3      -.3844835591057406d+00,0.1716701525902824d+00,
     4      -.8676494400329038d-01,0.1048837555210773d+00,
     5      -.3991836135485103d+00,0.9806771908928734d+00,
     6      -.1821437642498776d+01,0.2738484939091176d+01,
     7      -.3475108076347935d+01,0.3800640726163628d+01,
     8      -.3690335747800165d+01,0.3153132402234956d+01/
         data arr1045/
     1      -.2486473157295910d+01,0.1651290074927817d+01,
     2      -.1102283673640870d+01,0.5299055358294492d+00,
     3      -.3025209845011576d+00,0.7957713808163924d-01,
     4      -.3381739541221997d+00,0.9276859949934676d+00,
     5      -.1924579876691034d+01,0.3227816800840451d+01,
     6      -.4576553743797964d+01,0.5559377346671002d+01,
     7      -.6037624739720821d+01,0.5689387511390009d+01,
     8      -.5021476116131877d+01,0.3591656366678895d+01/
         data arr1046/
     1      -.2689526251501968d+01,0.1371883601204333d+01,
     2      -.8767223870080865d+00,0.5867088173448731d-01,
     3      -.2757316613805104d+00,0.8367744932505181d+00,
     4      -.1922330312654974d+01,0.3559355164063327d+01,
     5      -.5592426531015136d+01,0.7443788986393352d+01,
     6      -.8975987412806349d+01,0.9188048305437272d+01,
     7      -.9011704841436508d+01,0.6814598769855443d+01,
     8      -.5686538058423891d+01,0.3038953907654916d+01/
         data arr1047/
     1      -.2159401197683461d+01,0.4226930701550013d-01,
     2      -.2174210298289517d+00,0.7232536184930014d+00,
     3      -.1826166169951298d+01,0.3692971248657471d+01,
     4      -.6388154116343953d+01,0.9176994601759285d+01,
     5      -.1222420949127765d+02,0.1338250568999981d+02,
     6      -.1451344096641101d+02,0.1139368136937806d+02,
     7      -.1054740437544274d+02,0.5839786833303358d+01,
     8      -.4593133176899611d+01,0.3001760677148956d-01/
         data arr1048/
     1      -.1665677601412759d+00,0.6008148761500417d+00,
     2      -.1655994910192040d+01,0.3612242056693052d+01,
     3      -.6847042801435746d+01,0.1042866631791281d+02,
     4      -.1530622334062350d+02,0.1763262895937535d+02,
     5      -.2109091989947093d+02,0.1687833521034052d+02,
     6      -.1729773491210469d+02,0.9821893696623093d+01,
     7      -.8533787667816917d+01,-.3180370146893889d-05,
     8      0.6730375765059568d-07,-.9420847737087500d-09/
         data arr1049/
     1      0.1015123222539891d-10,-.8986684920853244d-13,
     2      0.6784931098615449d-15,-.4474846445065153d-17,
     3      0.4585565007942313d-19,-.6365878596631532d-20,
     4      -.1405851956810212d-19,-.2581547973716744d-19,
     5      0.1918401255886917d-19,-.1732767607418425d-19,
     6      -.3735115644182312d-03,0.4021363780730762d-04,
     7      -.2863727566309651d-05,0.1569886111336562d-06,
     8      -.7070603455971659d-08,0.2715773028306371d-09/
         data arr1050/
     1      -.9116865521394335d-11,0.2722368067516450d-12,
     2      -.7327695460110100d-14,0.1783389074142771d-15,
     3      -.5598755432452917d-17,0.2568756040627327d-17,
     4      0.3192917164454687d-18,-.3935335051364871d-02,
     5      0.9896582534974811d-03,-.1646181879155204d-03,
     6      0.2107892661262795d-04,-.2217537911397363d-05,
     7      0.1989492314609211d-06,-.1560014282817905d-07,
     8      0.1088079032553810d-08,-.6840754906038013d-10/
         data arr1051/
     1      0.3917293481022317d-11,-.2060906635540478d-12,
     2      0.1002850022601026d-13,-.4714759026171623d-15,
     3      -.1651265151453264d-01,0.7281472173608551d-02,
     4      -.2123785255982494d-02,0.4768481674787065d-03,
     5      -.8796330143779149d-04,0.1383794417791513d-04,
     6      -.1902640447045917d-05,0.2326951592355797d-06,
     7      -.2565250387087840d-07,0.2575704278086213d-08,
     8      -.2375703418202853d-09,0.2015773850290572d-10/
         data arr1052/
     1      -.1601541236461628d-11,-.4236196456984328d-01,
     2      0.2825085352734486d-01,-.1246166530845789d-01,
     3      0.4231542445758115d-02,-.1180519612867877d-02,
     4      0.2808641769352997d-03,-.5840292625769438d-04,
     5      0.1080233090637615d-04,-.1800998099175713d-05,
     6      0.2734361908454730d-06,-.3814364008596582d-07,
     7      0.4860448327789968d-08,-.5844192571422208d-09,
     8      -.7993343425695786d-01,0.7372628889218116d-01/
         data arr1053/
     1      -.4497853477659283d-01,0.2112352244318554d-01,
     2      -.8150406455335588d-02,0.2681888253548229d-02,
     3      -.7712894966175537d-03,0.1973027670002871d-03,
     4      -.4549556768415576d-04,0.9547767838045486d-05,
     5      -.1842312577280737d-05,0.3210413406153398d-06,
     6      -.5346480758355691d-07,-.1222134072994607d+00,
     7      0.1469064617112339d+00,-.1168024561823679d+00,
     8      0.7148931337094606d-01,-.3594861914295928d-01/
         data arr1054/
     1      0.1541596019537084d-01,-.5777978762427237d-02,
     2      0.1926172660204585d-02,-.5788512503325817d-03,
     3      0.1580872604465521d-03,-.3976784894517632d-04,
     4      0.8885777641918735d-05,-.1932654363026500d-05,
     5      -.1603292990380878d+00,0.2408023989059198d+00,
     6      -.2392201598950672d+00,0.1829416235668462d+00,
     7      -.1149422313193465d+00,0.6158676214914315d-01,
     8      -.2884172513779561d-01,0.1201108321439963d-01/
         data arr1055/
     1      -.4510310970924316d-02,0.1534311770712041d-02,
     2      -.4826022313613454d-03,0.1318343066932025d-03,
     3      -.3593376812183191d-04,-.1872307153587273d+00,
     4      0.3405404444541704d+00,-.4096845205776017d+00,
     5      0.3794079061489515d+00,-.2886809195302035d+00,
     6      0.1873019597016080d+00,-.1062260673022439d+00,
     7      0.5354262688170733d-01,-.2435251674263332d-01,
     8      0.9973799272310912d-02,-.3804350293948863d-02/
         data arr1056/
     1      0.1224344781643413d-02,-.4057391862416632d-03,
     2      -.1995559878651955d+00,0.4291164833288440d+00,
     3      -.6103462658220232d+00,0.6682583674939268d+00,
     4      -.6011457276639831d+00,0.4610309945177832d+00,
     5      -.3091556262457074d+00,0.1839915443850056d+00,
     6      -.9898025213851727d-01,0.4745426760326982d-01,
     7      -.2145151410142314d-01,0.7894008790234292d-02,
     8      -.3108857803575407d-02,-.1975859136267308d+00/
         data arr1057/
     1      0.4929137632303859d+00,-.8133627231632630d+00,
     2      0.1033067285762206d+01,-.1078175270813925d+01,
     3      0.9586873156696167d+00,-.7460145575540260d+00,
     4      0.5136571199848247d+00,-.3208787615397330d+00,
     5      0.1757145490414748d+00,-.9250946191834128d-01,
     6      0.3797741125587279d-01,-.1746584103961549d-01,
     7      -.1840959752224889d+00,0.5247411755723151d+00,
     8      -.9894160879375758d+00,0.1435558452747693d+01/
         data arr1058/
     1      -.1712161838974126d+01,0.1736798591137806d+01,
     2      -.1545336621073948d+01,0.1209354682703652d+01,
     3      -.8648433921656595d+00,0.5288653618396683d+00,
     4      -.3200448603358666d+00,0.1435585448887079d+00,
     5      -.7606474712647882d-01,-.1629626828381058d+00,
     6      0.5240980313258075d+00,-.1115327048930934d+01,
     7      0.1824879144107887d+01,-.2457157715252417d+01,
     8      0.2802738792482415d+01,-.2818720537262013d+01/
         data arr1059/
     1      0.2466355564557750d+01,-.1997242235085001d+01,
     2      0.1334848882126964d+01,-.9195805782437988d+00,
     3      0.4427762776743339d+00,-.2674948380177598d+00,
     4      -.1380460261974114d+00,0.4955478900342534d+00,
     5      -.1178292334351914d+01,0.2149289201869675d+01,
     6      -.3235663166506418d+01,0.4091966325762575d+01,
     7      -.4611944101830380d+01,0.4439734393880109d+01,
     8      -.4039338428686118d+01,0.2888967484116700d+01/
         data arr1060/
     1      -.2250652895371177d+01,0.1145551675083337d+01,
     2      -.7829486695410837d+00,-.1125248296315895d+00,
     3      0.4463630877293798d+00,-.1176335425956091d+01,
     4      0.2365597922012946d+01,-.3952950442607020d+01,
     5      0.5458849552249881d+01,-.6857329192028589d+01,
     6      0.7143207681521812d+01,-.7265560368992617d+01,
     7      0.5444596910310193d+01,-.4778391910845771d+01,
     8      0.2536554590459319d+01,-.1950539859229506d+01/
         data arr1061/
     1      -.8864295495427504d-01,0.3843571141195442d+00,
     2      -.1115985391446711d+01,0.2444174517094277d+01,
     3      -.4512801031525790d+01,0.6684631630822970d+01,
     4      -.9340582736520911d+01,0.1034511781472064d+02,
     5      -.1174037972084674d+02,0.9021701362340336d+01,
     6      -.8911570375555906d+01,0.4874371454638934d+01,
     7      -.4203173844718187d+01,-.6770681753255874d-01,
     8      0.3163252978464811d+00,-.1008573491103145d+01/
         data arr1062/
     1      0.2370117449833260d+01,-.4830604191601784d+01,
     2      0.7506978656778295d+01,-.1169794050083917d+02,
     3      0.1351551061661247d+02,-.1714144831995424d+02,
     4      0.1320523283104638d+02,-.1471920514533925d+02,
     5      0.8203297895147385d+01,-.7925591019371306d+01,
     6      0.2379547171702867d-07,-.4441030212926049d-09,
     7      0.5560058919516940d-11,-.5419173921257205d-13,
     8      0.4379488720408179d-15,-.3041363816870257d-17/
         data arr1063/
     1      0.1854909365247785d-19,-.3277178111422857d-22,
     2      -.1271715401112233d-21,0.2473160979402015d-22,
     3      0.6762606713467907d-22,0.2071445238559612d-22,
     4      0.1421766799486263d-04,-.1349974121071924d-05,
     5      0.8598620359434966d-07,-.4263734308459530d-08,
     6      0.1753023932413512d-09,-.6193690404198553d-11,
     7      0.1924988626177344d-12,-.5351140605187979d-14,
     8      0.1347335667392978d-15,-.3091550316289376d-17/
         data arr1064/
     1      0.1584670075983179d-18,0.2278717151461081d-19,
     2      0.3498970310526436d-03,-.7760175798779813d-04,
     3      0.1154540359378262d-04,-.1337225674612421d-05,
     4      0.1284211766802435d-06,-.1059821007349960d-07,
     5      0.7693880469191860d-09,-.4995780116905790d-10,
     6      0.2937982183861073d-11,-.1580364781528966d-12,
     7      0.7826750269423008d-14,-.3595749622905479d-15,
     8      0.2574389175489833d-02,-.1001161970859443d-02/
         data arr1065/
     1      0.2611804978333995d-03,-.5304386657984380d-04,
     2      0.8932354558912551d-05,-.1292589649313395d-05,
     3      0.1645403294436742d-06,-.1873393963837644d-07,
     4      0.1931785972320095d-08,-.1822073570912543d-09,
     5      0.1576433083812228d-10,-.1272066199391967d-11,
     6      0.9988185051740556d-02,-.5874485362988959d-02,
     7      0.2317711250661397d-02,-.7118801115345468d-03,
     8      0.1812970472891234d-03,-.3967697517434890d-04/
         data arr1066/
     1      0.7638403906204507d-05,-.1315262820252998d-05,
     2      0.2050813812165265d-06,-.2925441058189838d-07,
     3      0.3803079376674019d-08,-.4640629957877187d-09,
     4      0.2606617941291740d-01,-.2120308463176862d-01,
     5      0.1156982974596363d-01,-.4914880015362027d-02,
     6      0.1731151505712543d-02,-.5239880121426492d-03,
     7      0.1395144345556143d-03,-.3322522511673033d-04,
     8      0.7161358313307800d-05,-.1412914397635632d-05/
         data arr1067/
     1      0.2514063197769462d-06,-.4242185965816535d-07,
     2      0.5193927760140733d-01,-.5506120585457988d-01,
     3      0.3915631001071081d-01,-.2167783279801378d-01,
     4      0.9950963332703341d-02,-.3925362473622547d-02,
     5      0.1362024186950367d-02,-.4227307189186666d-03,
     6      0.1185902697295510d-03,-.3049592053079955d-04,
     7      0.6966556053945324d-05,-.1531752309270797d-05,
     8      0.8513650373548128d-01,-.1127694639797318d+00/
         data arr1068/
     1      0.1002012642984400d+00,-.6931276785474276d-01,
     2      0.3975417117988524d-01,-.1959406086012625d-01,
     3      0.8493448381751385d-02,-.3293793065982182d-02,
     4      0.1151302306758291d-02,-.3700034214037425d-03,
     5      0.1035182993977432d-03,-.2843588287349940d-04,
     6      0.1203992168368490d+00,-.1931271206706177d+00,
     7      0.2078104059332895d+00,-.1740810502262549d+00,
     8      0.1209040602040115d+00,-.7216584725914336d-01/
         data arr1069/
     1      0.3786477046995321d-01,-.1778334781649969d-01,
     2      0.7487976034644927d-02,-.2915530443789642d-02,
     3      0.9631881143439808d-03,-.3204287731003348d-03,
     4      0.1517154775928565d+00,-.2877198316631950d+00,
     5      0.3660213739317614d+00,-.3625034788117877d+00,
     6      0.2976044762810866d+00,-.2100238247557458d+00,
     7      0.1301405741959234d+00,-.7227169162434070d-01,
     8      0.3565811611616169d-01,-.1642783866206773d-01/
         data arr1070/
     1      0.6223803035355439d-02,-.2448897330848854d-02,
     2      0.1742705989278866d+00,-.3834216489711843d+00,
     3      0.5658416089556124d+00,-.6501560862379944d+00,
     4      0.6188943407488749d+00,-.5067700612700373d+00,
     5      0.3634552336083221d+00,-.2342341506280744d+00,
     6      0.1322119273301639d+00,-.7076105027060102d-01,
     7      0.3001438065289659d-01,-.1371451973579846d-01,
     8      0.1855202720199084d+00,-.4664081170499713d+00/
         data arr1071/
     1      0.7863218239393799d+00,-.1032424884871001d+01,
     2      0.1121403953167269d+01,-.1049573936262698d+01,
     3      0.8563084880862716d+00,-.6309934214008971d+00,
     4      0.3986887126294034d+00,-.2443556423875347d+00,
     5      0.1137409749499394d+00,-.5949768609940775d-01,
     6      0.1852812552921881d+00,-.5257373799915648d+00,
     7      0.9996506759868872d+00,-.1481499650274714d+01,
     8      0.1810300605592621d+01,-.1913665024963964d+01/
         data arr1072/
     1      0.1748354158670611d+01,-.1455812240067063d+01,
     2      0.1008852102451644d+01,-.7001925413336921d+00,
     3      0.3516518085006415d+00,-.2082685796084182d+00,
     4      0.1751503111976031d+00,-.5553277601499658d+00,
     5      0.1177569705943480d+01,-.1950325923637452d+01,
     6      0.2644803369935381d+01,-.3128334400086017d+01,
     7      0.3152717345346421d+01,-.2939436561565881d+01,
     8      0.2190482401980970d+01,-.1706984955880541d+01/
         data arr1073/
     1      0.9116464109767857d+00,-.6062507158724637d+00,
     2      0.1576617464446429d+00,-.5541315028629746d+00,
     3      0.1296515260063167d+01,-.2380962151769181d+01,
     4      0.3532271879728859d+01,-.4643049359054870d+01,
     5      0.5084715626900443d+01,-.5272621097527080d+01,
     6      0.4144203973553515d+01,-.3604073284607257d+01,
     7      0.2021250199553137d+01,-.1500520882456513d+01,
     8      0.1355106837782834d+00,-.5249850196181045d+00/
         data arr1074/
     1      0.1340230618776924d+01,-.2713652463796281d+01,
     2      0.4332656922015892d+01,-.6302759238357942d+01,
     3      0.7386161226263689d+01,-.8482610804320453d+01,
     4      0.6896758244250973d+01,-.6669661270803827d+01,
     5      0.3884211006400794d+01,-.3208537775787098d+01,
     6      0.1109978194770661d+00,-.4728117775987686d+00,
     7      0.1300115138872594d+01,-.2894313091797799d+01,
     8      0.4875675161033877d+01,-.7844046319595880d+01/
         data arr1075/
     1      0.9681572314916043d+01,-.1230043080581891d+02,
     2      0.1013948918776280d+02,-.1089790662982600d+02,
     3      0.6523166327164776d+01,-.5994503127030908d+01,
     4      -.1404377063047173d-09,0.2370817089232132d-11,
     5      -.2709586950396644d-13,0.2429301697871021d-15,
     6      -.1817603320531043d-17,0.1176786701040590d-19,
     7      -.6668992227414983d-22,-.3308241788677505d-23,
     8      0.1547353821034636d-23,-.6800998401612261d-23/
         data arr1076/
     1      -.1180110670661667d-23,-.4268993004871382d-06,
     2      0.3666464040604031d-07,-.2131867154169456d-08,
     3      0.9724027184420797d-10,-.3701438020748159d-11,
     4      0.1217470266145694d-12,-.3539490403287537d-14,
     5      0.9241276807006447d-16,-.2189322812084286d-17,
     6      0.2660642957319795d-19,-.5248977974531806d-20,
     7      -.2453983056746131d-04,0.4922976633618973d-05,
     8      -.6686128373048836d-06,0.7123525190245573d-07/
         data arr1077/
     1      -.6333641945300483d-08,0.4866037307799985d-09,
     2      -.3304398158445668d-10,0.2015438633881871d-11,
     3      -.1117481093910828d-12,0.5677054618859134d-14,
     4      -.2673742083720556d-15,-.3165952134659012d-03,
     5      0.1113677384724343d-03,-.2652193328993346d-04,
     6      0.4954778826186765d-05,-.7724700646087531d-06,
     7      0.1040644443024737d-06,-.1239133681794795d-07,
     8      0.1325195130096728d-08,-.1288406911920298d-09/
         data arr1078/
     1      0.1144812986695945d-10,-.9443409697610077d-12,
     2      -.1857675382836454d-02,0.9882753979100066d-03,
     3      -.3559400557825575d-03,0.1005655074898109d-03,
     4      -.2371152800988820d-04,0.4830952270301564d-05,
     5      -.8699649559140317d-06,0.1406851642484422d-06,
     6      -.2068652692553523d-07,0.2765402928607783d-08,
     7      -.3449457733424637d-09,-.6705004085737955d-02,
     8      0.4933391982053850d-02,-.2457440010351029d-02/
         data arr1079/
     1      0.9602700525922034d-03,-.3131427454582850d-03,
     2      0.8823686154739095d-04,-.2197648590070376d-04,
     3      0.4912715253464833d-05,-.9991748794839766d-06,
     4      0.1831954270421065d-06,-.3159841371452301d-07,
     5      -.1741188211959102d-01,0.1669630678942859d-01,
     6      -.1083891656256668d-01,0.5519800031462733d-02,
     7      -.2345853619392602d-02,0.8614285054796911d-03,
     8      -.2796140824703799d-03,0.8135533940993284d-04/
         data arr1080/
     1      -.2156960852108447d-04,0.5092149973932015d-05,
     2      -.1144398691981245d-05,-.3566083561063788d-01,
     3      0.4272596500345654d-01,-.3465638866074129d-01,
     4      0.2205161694534753d-01,-.1170971581320755d-01,
     5      0.5371933171108741d-02,-.2178754980505928d-02,
     6      0.7898608155944299d-03,-.2617982048063010d-03,
     7      0.7598795142385413d-04,-.2133216350785677d-04,
     8      -.6107215694211594d-01,0.8861068685466147d-01/
         data arr1081/
     1      -.8704060318799758d-01,0.6706510406378242d-01,
     2      -.4312775179063031d-01,0.2395059984934010d-01,
     3      -.1176448798260859d-01,0.5137760686936894d-02,
     4      -.2064339882486009d-02,0.7109684943835381d-03,
     5      -.2416505532670723d-03,-.9098498884869044d-01,
     6      0.1560723276845994d+00,-.1812525715340183d+00,
     7      0.1650776551363386d+00,-.1255176136914455d+00,
     8      0.8233382523650401d-01,-.4782359783318463d-01/
         data arr1082/
     1      0.2447124988654865d-01,-.1164561086983551d-01,
     2      0.4626376756718093d-02,-.1858897144927034d-02,
     3      -.1212484880745523d+00,0.2412775528680055d+00,
     4      -.3250842980234021d+00,0.3432775777103684d+00,
     5      -.3028859984823365d+00,0.2300382497727587d+00,
     6      -.1550846259190851d+00,0.9076535799434982d-01,
     7      -.5025718713549748d-01,0.2250435727624642d-01,
     8      -.1049196136829986d-01,-.1474907070861975d+00/
         data arr1083/
     1      0.3352980662895492d+00,-.5162477563099014d+00,
     2      0.6219289685463283d+00,-.6274271642211847d+00,
     3      0.5424266198029258d+00,-.4182299175533793d+00,
     4      0.2738619307003975d+00,-.1740418642290522d+00,
     5      0.8617765990080339d-01,-.4593514845929816d-01,
     6      -.1662504730144841d+00,0.4262892203554334d+00,
     7      -.7409066605376061d+00,0.1003728960440253d+01,
     8      -.1144466630572229d+01,0.1109168206540302d+01/
         data arr1084/
     1      -.9667886277584145d+00,0.6936120793781486d+00,
     2      -.5007203703544942d+00,0.2697863519057325d+00,
     3      -.1624891984946407d+00,-.1756012841380588d+00,
     4      0.5022365169062428d+00,-.9757300110146147d+00,
     5      0.1465645296280047d+01,-.1872564579073318d+01,
     6      0.2005259281239001d+01,-.1958250675829650d+01,
     7      0.1508098280636579d+01,-.1227436995674629d+01,
     8      0.7098739363004289d+00,-.4786303159343119d+00/
         data arr1085/
     1      -.1752032284166716d+00,0.5531606316563511d+00,
     2      -.1192193030833834d+01,0.1955499398344082d+01,
     3      -.2783946653616315d+01,0.3247518006549923d+01,
     4      -.3529938606815168d+01,0.2859146073819040d+01,
     5      -.2610616871135745d+01,0.1601828753476767d+01,
     6      -.1200411610399158d+01,-.1659344798103021d+00,
     7      0.5722318664334778d+00,-.1361221224228675d+01,
     8      0.2394425461340868d+01,-.3790389825498410d+01/
         data arr1086/
     1      0.4747668987513931d+01,-.5720248963916340d+01,
     2      0.4773003519741791d+01,-.4877418176169710d+01,
     3      0.3143269685449757d+01,-.2604512769668521d+01,
     4      -.1493167908522103d+00,0.5558859732638873d+00,
     5      -.1456875762605865d+01,0.2686706981585573d+01,
     6      -.4740734064073239d+01,0.6283090989693276d+01,
     7      -.8380088392525964d+01,0.7049922336142512d+01,
     8      -.8067554503993794d+01,0.5413124002294306d+01/
         data arr1087/
     1      -.4944207795496199d+01,0.6843959423325433d-12,
     2      -.1062787441109395d-13,0.1124548166822641d-15,
     3      -.9386041459969191d-18,0.6569057810885571d-20,
     4      -.3989288823722031d-22,0.2152004031835596d-24,
     5      -.1528381026010778d-26,-.1806667827659450d-26,
     6      0.4840154691596671d-27,0.1058417000408031d-07,
     7      -.8361870938089569d-09,0.4501349908930134d-10,
     8      -.1911414367988277d-11,0.6805862778831561d-13/
         data arr1088/
     1      -.2102771362411609d-14,0.5763661252205620d-16,
     2      -.1423620232864709d-17,0.3201208252797110d-19,
     3      -.6640353925982819d-21,0.1421140942316860d-05,
     4      -.2622515311121104d-06,0.3297551401174003d-07,
     5      -.3270678636249022d-08,0.2720197534321610d-09,
     6      -.1963105036265148d-10,0.1256847149829589d-11,
     7      -.7251193264194157d-13,0.3809099095916648d-14,
     8      -.1843724051414931d-15,0.3214909689307930d-04/
         data arr1089/
     1      -.1040275810643228d-04,0.2293616913486721d-05,
     2      -.3989018260434658d-06,0.5817379359509434d-07,
     3      -.7361551091783242d-08,0.8264038509760040d-09,
     4      -.8360274500260244d-10,0.7679535821420813d-11,
     5      -.6519731066603006d-12,0.2852905335261539d-03,
     6      -.1396111761636606d-03,0.4655278402268636d-04,
     7      -.1224458037849223d-04,0.2700584824685310d-05,
     8      -.5168362551119769d-06,0.8773232275185007d-07/
         data arr1090/
     1      -.1342307556615884d-07,0.1855018787689253d-08,
     2      -.2383009209628646d-09,0.1424147596662739d-02,
     3      -.9638872746358961d-03,0.4445186493250362d-03,
     4      -.1617062124179811d-03,0.4932595598279788d-04,
     5      -.1305598811217463d-04,0.3063577660095174d-05,
     6      -.6483300286081742d-06,0.1228809593663097d-06,
     7      -.2185169809189341d-07,0.4819808714096633d-02,
     8      -.4251372869520913d-02,0.2555170484896185d-02/
         data arr1091/
     1      -.1211393230107982d-02,0.4815555273920091d-03,
     2      -.1661161351248868d-03,0.5073203345792851d-04,
     3      -.1399496595322956d-04,0.3415336866943538d-05,
     4      -.7925985413061469d-06,0.1233392609721619d-01,
     5      -.1359335454902238d-01,0.1020790473994218d-01,
     6      -.6046860445388868d-02,0.3003055275710877d-02,
     7      -.1294391369446951d-02,0.4925160773353310d-03,
     8      -.1698409463065295d-03,0.5095769572458729d-04/
         data arr1092/
     1      -.1480523364011366d-04,0.2557973428468122d-01,
     2      -.3414014237707940d-01,0.3104495948187198d-01,
     3      -.2227089513076585d-01,0.1338949808957176d-01,
     4      -.6989448699178621d-02,0.3203224281737947d-02,
     5      -.1338920862343875d-02,0.4766514775978359d-03,
     6      -.1681738592919611d-03,0.4505448767894616d-01,
     7      -.7109320329097384d-01,0.7641462708894700d-01,
     8      -.6481507000543499d-01,0.4603213342798333d-01/
         data arr1093/
     1      -.2841471674366733d-01,0.1525310952531644d-01,
     2      -.7550234455301994d-02,0.3100317786356458d-02,
     3      -.1298201159465048d-02,0.6965266076952653d-01,
     4      -.1275092710624024d+00,0.1588961299774010d+00,
     5      -.1563947677422983d+00,0.1286330990009786d+00,
     6      -.9215906259842827d-01,0.5654785678711338d-01,
     7      -.3256239254067184d-01,0.1507108600756100d-01,
     8      -.7359182837391155d-02,0.9680106808021229d-01/
         data arr1094/
     1      -.2024930890342058d+00,0.2878396023728086d+00,
     2      -.3239161703503066d+00,0.3034012740088829d+00,
     3      -.2486107785715939d+00,0.1704763189300640d+00,
     4      -.1126551742500947d+00,0.5765596494563544d-01,
     5      -.3239126484873533d-01,0.1230930310517551d+00,
     6      -.2906255566877566d+00,0.4643827766900635d+00,
     7      -.5906093271179258d+00,0.6206820990118693d+00,
     8      -.5750232058936555d+00,0.4311543877798458d+00/
         data arr1095/
     1      -.3236608419680196d+00,0.1802400090957869d+00,
     2      -.1153206674934369d+00,0.1450895105280776d+00,
     3      -.3827782833789839d+00,0.6775363241403289d+00,
     4      -.9655335660704940d+00,0.1122837772191903d+01,
     5      -.1165871547411666d+01,0.9352610872450431d+00,
     6      -.7918873052882909d+00,0.4733074702296706d+00,
     7      -.3423409652253151d+00,0.1599620941929989d+00,
     8      -.4678154084948335d+00,0.9023494131860702d+00/
         data arr1096/
     1      -.1433076681632268d+01,0.1819847700576936d+01,
     2      -.2104986430541585d+01,0.1766483467446119d+01,
     3      -.1679945594506275d+01,0.1065077744669466d+01,
     4      -.8666761397606797d+00,0.1658070279794758d+00,
     5      -.5344300862610984d+00,0.1100708363938180d+01,
     6      -.1945178194851873d+01,0.2662568927976936d+01,
     7      -.3419739215186443d+01,0.2931375591019995d+01,
     8      -.3128133716086678d+01,0.2082194676731954d+01/
         data arr1097/
     1      -.1901841634076863d+01,0.1616419760812465d+00,
     2      -.5725895973533741d+00,0.1225634172837343d+01,
     3      -.2419786495834625d+01,0.3525256540151680d+01,
     4      -.5029158083930548d+01,0.4288714570055383d+01,
     5      -.5151722030827571d+01,0.3567720810818891d+01,
     6      -.3660682856473598d+01,-.2840418913997980d-14,
     7      0.4106269319818866d-16,-.4064275178947676d-18,
     8      0.3186461542794616d-20,-.2102581882631542d-22/
         data arr1098/
     1      0.1207833543631723d-24,-.6243325619318990d-27,
     2      0.1283589293099479d-29,0.4591416987419170d-29,
     3      -.2234804011625191d-09,0.1643660589563604d-10,
     4      -.8276666999268279d-12,0.3301328366700734d-13,
     5      -.1108257820025946d-14,0.3238898077697387d-16,
     6      -.8422194458439737d-18,0.1978428732704130d-19,
     7      -.4242410644567010d-21,-.7008966989845746d-07,
     8      0.1204095524637755d-07,-.1416245393305389d-08/
         data arr1099/
     1      0.1319489622035288d-09,-.1034647201150986d-10,
     2      0.7062874959482659d-12,-.4289864880892310d-13,
     3      0.2352415924387617d-14,-.1179443675836556d-15,
     4      -.2780254050842922d-05,0.8375104812287283d-06,
     5      -.1727295574934217d-06,0.2821843701819816d-07,
     6      -.3879878202465279d-08,0.4644011762545808d-09,
     7      -.4946016914859466d-10,0.4748498979635672d-11,
     8      -.4172015352677117d-12,-.3731265632909876d-04/
         data arr1100/
     1      0.1699867330144244d-04,-.5302058840330301d-05,
     2      0.1309977292688435d-05,-.2723967146549510d-06,
     3      0.4930258275675854d-07,-.7941296894590955d-08,
     4      0.1149683583749584d-08,-.1525825733580385d-09,
     5      -.2576097105628438d-03,0.1623152633765092d-03,
     6      -.7002084517975147d-04,0.2392675965558944d-04,
     7      -.6881125765439879d-05,0.1721743588414774d-05,
     8      -.3835743156748756d-06,0.7644397315076602d-07/
         data arr1101/
     1      -.1400507177563111d-07,-.1136227222400518d-02,
     2      0.9330164558164381d-03,-.5245487296493150d-03,
     3      0.2335961263824243d-03,-.8755185994917624d-04,
     4      0.2851658265405517d-04,-.8280573978517078d-05,
     5      0.2136288458063944d-05,-.5086942415542141d-06,
     6      -.3632977673099089d-02,0.3727402468863744d-02,
     7      -.2618369473634554d-02,0.1456867670308063d-02,
     8      -.6822321642019530d-03,0.2769485843944077d-03/
         data arr1102/
     1      -.1005090891246459d-03,0.3210979324625857d-04,
     2      -.9519590328942293d-05,-.9124350991042949d-02,
     3      0.1133605346425570d-01,-.9643613961136100d-02,
     4      0.6497216860758490d-02,-.3684224049749931d-02,
     5      0.1802513005184233d-02,-.7926021586725592d-03,
     6      0.3032041215302428d-03,-.1083823360830418d-03,
     7      -.1900060912785633d-01,0.2790301757405829d-01,
     8      -.2806609094695922d-01,0.2235027433250939d-01/
         data arr1103/
     1      -.1498077335292957d-01,0.8593942792549712d-02,
     2      -.4471873360983021d-02,0.1995276639816948d-02,
     3      -.8389299700261900d-03,-.3407942953328723d-01,
     4      0.5802292325709532d-01,-.6772335582219277d-01,
     5      0.6253625699390314d-01,-.4860883291046118d-01,
     6      0.3192481222862046d-01,-.1930166584670499d-01,
     7      0.9835495157673787d-02,-.4770458755709053d-02,
     8      -.5412505214707616d-01,0.1051156118716512d+00/
         data arr1104/
     1      -.1402725833315191d+00,0.1478709124330007d+00,
     2      -.1312360905132411d+00,0.9654254965925989d-01,
     3      -.6685377217747540d-01,0.3824444660158890d-01,
     4      -.2106842307590888d-01,-.7770204214739962d-01,
     5      0.1696148638226552d+00,-.2557926237819392d+00,
     6      0.3038641875552574d+00,-.3039781064481610d+00,
     7      0.2452749604191407d+00,-.1923647070496866d+00,
     8      0.1218113079216189d+00,-.7527689690156482d-01/
         data arr1105/
     1      -.1024080833418989d+00,0.2475549112992907d+00,
     2      -.4182493080744139d+00,0.5538185460645263d+00,
     3      -.6177585629787578d+00,0.5354765391071898d+00,
     4      -.4715466122805462d+00,0.3267068689520514d+00,
     5      -.2242724274539137d+00,-.1253540209426633d+00,
     6      0.3299203400095759d+00,-.6209341025576863d+00,
     7      0.9081577929029917d+00,-.1119308011548131d+01,
     8      0.1020429408517221d+01,-.1002590511829283d+01/
         data arr1106/
     1      0.7528027136248867d+00,-.5697249140198269d+00,
     2      -.1436811728343711d+00,0.4029427955513143d+00,
     3      -.8429962166495600d+00,0.1352007217971332d+01,
     4      -.1827592454047637d+01,0.1714126537738107d+01,
     5      -.1871353780638048d+01,0.1511051061703689d+01,
     6      -.1253992967546191d+01,-.1549498840568564d+00,
     7      0.4496254377360204d+00,-.1048500558422822d+01,
     8      0.1835155688321626d+01,-.2706081140085626d+01/
         data arr1107/
     1      0.2550154675224661d+01,-.3088908827701327d+01,
     2      0.2666308147526988d+01,-.2419202217519484d+01,
     3      0.1026567329954835d-16,-.1394034885654642d-18,
     4      0.1300867475690998d-20,-.9647312690746986d-23,
     5      0.6039095228043933d-25,-.3311484963315220d-27,
     6      0.1628369748796542d-29,0.7482027185356744d-30,
     7      0.4109151473909141d-11,-.2838873360135179d-12,
     8      0.1347761661979584d-13,-.5085035631037689d-15/
         data arr1108/
     1      0.1619448993548738d-16,-.4501854185079763d-18,
     2      0.1116117955150913d-19,-.2502343973512016d-21,
     3      0.3010238811566264d-08,-.4857681623318175d-09,
     4      0.5386793844908716d-10,-.4747286950532896d-11,
     5      0.3531435026543750d-12,-.2293029650727653d-13,
     6      0.1327717684734091d-14,-.6960259211725584d-16,
     7      0.2093776201317577d-06,-.5924574943818187d-07,
     8      0.1152012992042264d-07,-.1780210330551191d-08/
         data arr1109/
     1      0.2321990663443515d-09,-.2643761535231216d-10,
     2      0.2683332843777267d-11,-.2465187427794380d-12,
     3      0.4249668228225205d-05,-.1818591173397520d-05,
     4      0.5347966815305742d-06,-.1249842849633834d-06,
     5      0.2465044905424815d-07,-.4244837711265639d-08,
     6      0.6511788108059058d-09,-.9037868799117328d-10,
     7      0.4057880349273618d-04,-.2401695079052717d-04,
     8      0.9768146654180292d-05,-.3157294692555752d-05/
         data arr1110/
     1      0.8607647382735993d-06,-.2050354427970723d-06,
     2      0.4346013549218868d-07,-.8328282312713590d-08,
     3      0.2332535278526592d-03,-.1799186704621824d-03,
     4      0.9536939395339267d-04,-.4017263786643172d-04,
     5      0.1425321486249991d-04,-.4426547382731425d-05,
     6      0.1221189572334678d-05,-.3042400708187944d-06,
     7      0.9318368668090729d-03,-.8980915891549832d-03,
     8      0.5948617524182377d-03,-.3130614226142699d-03/
         data arr1111/
     1      0.1383553119703444d-03,-.5373600617002916d-04,
     2      0.1849247859925404d-04,-.5737905755160439d-05,
     3      0.2833822946596377d-02,-.3307703536739509d-02,
     4      0.2653836412735722d-02,-.1690969784679888d-02,
     5      0.8996110192197797d-03,-.4238605236357110d-03,
     6      0.1763117388037864d-03,-.6598416843705331d-04,
     7      0.6974002019627506d-02,-.9626280331057968d-02,
     8      0.9136981609311040d-02,-.6879410211673734d-02/
         data arr1112/
     1      0.4281854754725176d-02,-.2392481510794599d-02,
     2      0.1174296590217605d-02,-.5171194170582884d-03,
     3      0.1449409001092974d-01,-.2322656600824099d-01,
     4      0.2561362668000451d-01,-.2234741777037389d-01,
     5      0.1586221093865695d-01,-.1033407307730062d-01,
     6      0.5873860538190633d-02,-.2984711821231959d-02,
     7      0.2621965978834812d-01,-.4809961917128690d-01,
     8      0.6079286961142424d-01,-.6047052343505410d-01/
         data arr1113/
     1      0.4776278312043634d-01,-.3583462950015334d-01,
     2      0.2324149999385481d-01,-.1341512523022272d-01,
     3      0.4216238332064487d-01,-.8767521070341056d-01,
     4      0.1257868190265208d+00,-.1406409743012646d+00,
     5      0.1205733555201150d+00,-.1032902812546918d+00,
     6      0.7555759959302007d-01,-.4891486375861560d-01,
     7      0.6107572151404508d-01,-.1432331860115808d+00,
     8      0.2319568518132572d+00,-.2878075989644386d+00/
         data arr1114/
     1      0.2608149940730613d+00,-.2538464667229322d+00,
     2      0.2075469166169339d+00,-.1491532445584333d+00,
     3      0.8015918715189294d-01,-.2122805168742196d+00,
     4      0.3875453085627044d+00,-.5272725886533823d+00,
     5      0.4905583448685703d+00,-.5417164731333467d+00,
     6      0.4916825439939390d+00,-.3890018873026274d+00,
     7      0.9501988738080057d-01,-.2872922951571940d+00,
     8      0.5934813315088346d+00,-.8754330260952726d+00/
         data arr1115/
     1      0.8089838131670788d+00,-.1016448484336456d+01,
     2      0.1019313774497506d+01,-.8820589557811787d+00,
     3      0.1000970512544420d+00,-.3553567826536917d+00,
     4      0.8390760911206264d+00,-.1327999032727942d+01,
     5      0.1172425189749400d+01,-.1690370610954227d+01,
     6      0.1868229932544963d+01,-.1759970382321405d+01,
     7      -.3285771736234669d-19,0.4220571412233722d-21,
     8      -.3736387591836719d-23,0.2635677758049022d-25/
         data arr1116/
     1      -.1573118241664203d-27,0.8214347121650721d-30,
     2      -.3828914239046421d-32,-.6691288679622533d-13,
     3      0.4372716243186133d-14,-.1969425829258416d-15,
     4      0.7067854683088277d-17,-.2146172483009262d-18,
     5      0.5700922553650700d-20,-.1353234581903840d-21,
     6      -.1144966538889186d-09,0.1747706714949521d-10,
     7      -.1838616335598914d-11,0.1541243444554457d-12,
     8      -.1093158137280334d-13,0.6783401765887955d-15/
         data arr1117/
     1      -.3760703396173754d-16,-.1396435705055687d-07,
     2      0.3737624267920946d-08,-.6894725599471911d-09,
     3      0.1013392605631878d-09,-.1260354706896003d-10,
     4      0.1371783359556180d-11,-.1333227447655793d-12,
     5      -.4286460412014018d-06,0.1735112734027300d-06,
     6      -.4840625879130187d-07,0.1075793729366080d-07,
     7      -.2023570229651627d-08,0.3332898046996648d-09,
     8      -.4896726035962947d-10,-.5660847984638336d-05/
         data arr1118/
     1      0.3169245822927748d-05,-.1222824381237053d-05,
     2      0.3756171821589991d-06,-.9773328082590187d-07,
     3      0.2228609247183327d-07,-.4525509014866556d-08,
     4      -.4240713777300831d-04,0.3094385033125527d-04,
     5      -.1555937909477089d-04,0.6218148514308751d-05,
     6      -.2109433746024961d-05,0.6279307847423408d-06,
     7      -.1660300407628100d-06,-.2116792867872566d-03,
     8      0.1930442639316330d-03,-.1212653385462133d-03/
         data arr1119/
     1      0.6032449443828228d-04,-.2559288881611882d-04,
     2      0.9543618548188833d-05,-.3149583602330267d-05,
     3      -.7795837630474765d-03,0.8616550703878512d-03,
     4      -.6551993288939708d-03,0.3917931147722944d-03,
     5      -.2016497810207090d-03,0.9141457523726569d-04,
     6      -.3649332913886116d-04,-.2268394132919541d-02,
     7      0.2970347468512211d-02,-.2667556824815728d-02,
     8      0.1860933889984834d-02,-.1135986542921706d-02/
         data arr1120/
     1      0.6123029203469677d-03,-.2887012400476272d-03,
     2      -.5470338882068849d-02,0.8349961489548698d-02,
     3      -.8679787892715472d-02,0.6869339390894914d-02,
     4      -.4890876125628552d-02,0.3083237895591083d-02,
     5      -.1685455657359979d-02,-.1131239481611981d-01,
     6      0.1992939077724543d-01,-.2356519444838298d-01,
     7      0.2056360759726026d-01,-.1687324276387683d-01,
     8      0.1229369132155864d-01,-.7679037975660677d-02/
         data arr1121/
     1      -.2054966534941315d-01,0.4166291026330772d-01,
     2      -.5514604080935923d-01,0.5142827130321653d-01,
     3      -.4826038628055562d-01,0.4031564806900464d-01,
     4      -.2844914984749526d-01,-.3331808586552133d-01,
     5      0.7818804616917693d-01,-.1140539607637642d+00,
     6      0.1096200059960978d+00,-.1172565786292827d+00,
     7      0.1118268444764128d+00,-.8836876616092804d-01,
     8      -.4860803248258629d-01,0.1343107734751965d+00/
         data arr1122/
     1      -.2125565579561138d+00,0.2014529249988958d+00,
     2      -.2461087758728522d+00,0.2678196550681344d+00,
     3      -.2354596239693350d+00,-.6375569316340449d-01,
     4      0.2142812188307628d+00,-.3622149937445071d+00,
     5      0.3200884959528489d+00,-.4508408300237328d+00,
     6      0.5620319684454804d+00,-.5472944217146464d+00,
     7      -.7415612907005831d-01,0.3206411282844828d+00,
     8      -.5705261216186847d+00,0.4359043238663660d+00/
         data arr1123/
     1      -.7240018966807167d+00,0.1044458793117514d+01,
     2      -.1123983085333525d+01,0.9437484581632423d-22,
     3      -.1153074244328435d-23,0.9732885461265862d-26,
     4      -.6560362670501811d-28,0.3744040547385033d-30,
     5      -.1836002560250667d-32,0.9777690766858167d-15,
     6      -.6077780059303973d-16,0.2609978181356422d-17,
     7      -.8950157775176653d-19,0.2602537014550809d-20,
     8      -.6629915330094198d-22,0.3907991069745733d-11/
         data arr1124/
     1      -.5674093224601742d-12,0.5691410074922173d-13,
     2      -.4558781689316195d-14,0.3099000146011423d-15,
     3      -.1843039986054331d-16,0.8357585068216154d-09,
     4      -.2127758808789249d-09,0.3742147218035081d-10,
     5      -.5256011048606064d-11,0.6278784045861038d-12,
     6      -.6538843579704867d-13,0.3879847397999287d-07,
     7      -.1493852051383692d-07,0.3972337840218718d-08,
     8      -.8438606965099023d-09,0.1530939504316642d-09/
         data arr1125/
     1      -.2405083449708311d-10,0.7086870907738432d-06,
     2      -.3773761636351297d-06,0.1386683939287974d-06,
     3      -.4075291417776581d-07,0.1029552630486788d-07,
     4      -.2227918360474689d-08,0.6920313836342228d-05,
     5      -.4802000261753022d-05,0.2294420715792472d-05,
     6      -.8794020460640124d-06,0.2924769196594968d-06,
     7      -.8201065298572455d-07,0.4319103773596055d-04,
     8      -.3743132247969627d-04,0.2223427540896647d-04/
         data arr1126/
     1      -.1066426712650970d-04,0.4494105971892987d-05,
     2      -.1562700618084407d-05,0.1930220310530048d-03,
     3      -.2023349404124889d-03,0.1440937577840459d-03,
     4      -.8394495948700675d-04,0.4364403257813237d-04,
     5      -.1820891954507887d-04,0.6674525041153413d-03,
     6      -.8247260870332304d-03,0.6817666912684629d-03,
     7      -.4720806138645299d-03,0.2972198795185588d-03,
     8      -.1450370369409562d-03,0.1889115144897968d-02/
         data arr1127/
     1      -.2690397340116131d-02,0.2500272262735543d-02,
     2      -.2026472856388795d-02,0.1525799889073568d-02,
     3      -.8535043084916610d-03,0.4570406691355067d-02,
     4      -.7342159336998572d-02,0.7406279927221725d-02,
     5      -.6957327940933802d-02,0.6218048517134697d-02,
     6      -.3923992477405179d-02,0.9790807432650825d-02,
     7      -.1734728938783333d-01,0.1821775800463712d-01,
     8      -.1974584691363026d-01,0.2088996423185718d-01/
         data arr1128/
     1      -.1468485629027070d-01,0.1912300883400097d-01,
     2      -.3647264247742082d-01,0.3783291057449562d-01,
     3      -.4739712206274199d-01,0.5948635151620221d-01,
     4      -.4612080585768938d-01,0.3485125474497710d-01,
     5      -.6977276801519307d-01,0.6669222986652310d-01,
     6      -.9760584713021726d-01,0.1465364231107078d+00,
     7      -.1243688917209372d+00,0.6018825335070825d-01,
     8      -.1235832827842763d+00,0.9881185404688167d-01/
         data arr1129/
     1      -.1734605805883100d+00,0.3168437685936247d+00,
     2      -.2928267324105756d+00,0.9919277424629321d-01,
     3      -.2053094306464103d+00,0.1180777727777660d+00,
     4      -.2649053035695044d+00,0.6076778768986603d+00,
     5      -.6097833877183318d+00/
        do 1200 i=1,2057
        arr(i)=arr1001(i)
 1200 continue
        return
        end
C
C///////////////////////////////////////////////////////////////////////
      subroutine mptoxf9(mpole,nterms,nlambs,numtets,
     1                      nexptot,mexpup)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 mpole(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
c
      integer *4  nlambs,numtets(nlambs),nexptot
      parameter (nNLAMBS = 26)
      parameter (NMAXNF = 16)
      parameter (nNTERMS = 24)
c
      real *8 lambda(nNLAMBS),weights(nNLAMBS),dtmp(nNLAMBS)
      complex *16 mult(0:nNTERMS,0:nNTERMS),cd(NMAXNF),eye
c
      complex *16 expcoefs(nNLAMBS,NMAXNF)
      save
c
c ... first initializing....
c
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         call  vwts(lambda,weights,NLAMBS)
c
         cd(1) = 0.5d0
         cd(2) = eye
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*eye
         enddo
c
         do i = 1, NLAMBS
            dtmp(i) = 0.5d0*dexp(lambda(i)*1.5d0)/weights(i)
         enddo
c
         do i = 1, nexptot
            mexpup(i) = 0.0d0
         enddo
c
         ifinit = 1
      endif
c
c you don't want to mess the input data:
c
      do i=0,nNTERMS
         do j = 0, i
            mult(i,j)=mpole(i,j)
         enddo
      enddo
c
c generate MEXPUP: using Vladimir's shceme:
c
      call alota9(mult,expcoefs)
c
c the expcoefs needs to be normalized back to Leslie's notation:
c
      ntot = 0
      do i = 1, NLAMBS
         mexpup(ntot+1) = expcoefs(i,1)*(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j 
            mexpup(ncurrent) = expcoefs(i,j)*dtmp(i)/cd(j)
         enddo
         ntot = ntot + numtets(i)
      enddo
c-----------End of MPOLETOEXP-------------------------------------------
      return
      end
c
c
C///////////////////////////////////////////////////////////////////////
      subroutine xftota9(local,nterms,rlams,whts,nlambs,numtets,
     1                      nthmax,nexptot,mexpup,scale)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
c
      complex *16 local(0:nterms,0:nterms)
      complex *16 mexpup(nexptot)
      real *8     rlams(nlambs)
      real *8     whts(nlambs)
C
      integer *4  nlambs,numtets(nlambs),nexptot,nthmax
      parameter (nNLAMBS = 26)
      parameter (NMAXNF = 16)
      parameter (nNTERMS = 24)
C
      real *8 dtmp(nNLAMBS)
      complex *16 expcoefs(nNLAMBS,NMAXNF)
C
      complex *16 taylor(0:nNTERMS,0:nNTERMS),cd(NMAXNF),eye
      save
C
      data eye/(0.0d0, 1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
C
         cd(1) = 0.5d0
         cd(2) = eye
         do i = 3, NMAXNF
            cd(i) = cd(i-1)*eye
         enddo
C
         do i = 1, nlambs
            dtmp(i) = 0.5d0*dexp(-rlams(i)*0.5d0)/whts(i)
         enddo
C
         do i = 1, nlambs
            do j = 1, NMAXNF
              expcoefs(i,j) = 0.0d0
            enddo
         enddo
C
         ifinit = 1
      endif
C
C     initialize LOCAL expansion
C
         do nm = 0,nterms
            do mth = 0,nm
               local(nm,mth) = 0.0d0
            enddo
         enddo
C
      ntot = 0
      do i = 1, nlambs
         expcoefs(i,1) = mexpup(ntot+1)/(dtmp(i)*2.0d0)
         do j = 2, numtets(i)
            ncurrent = ntot + j
            expcoefs(i,j) = mexpup(ncurrent)*cd(j)/dtmp(i)
         enddo
         ntot = ntot + numtets(i)
      enddo
C
      call atalo9(expcoefs,taylor)
C
      do l=0,nNTERMS
         do m=0,l
            local(l,m)=local(l,m)+taylor(l,m)
         enddo
      enddo
C-----------End of EXPTOLOCAL-------------------------------------------
      RETURN
      END
c
c
c
c 
c
        subroutine alota99(mult,expcoefs,expcoefs1)
        implicit real *8 (a-h,o-z)
        complex *16 mult(0:24,0:24),expcoefs(26,16)
        complex *16 expcoefs1(26,16)
        real *8 arr(6000)
c
ccc        dimension ms(26),num1s7(1),num2s7(1),ms7(1)
ccc        data ms/1,3,4,5,7,9,9,11,11,12,13,13,14,15,15,15,
ccc     1      15,15,15,15,15,15,15,15,12,0/
c
        dimension map(16),nsstored(16),num1s(16),num2s(16)
c
c
c       this subroutine transforms a multipole expansion of
c       order 24 into a Bessel expansion of order (26,15)
c       the accuracy of the resulting scheme is about 3 digits.
c
c  ...  one wave number m after another, calculate the coefficients 
c       of the exponential expansion
c
        data ifinit/0/
        data map/1,651,1251,1803,2331,2814,3254,3653,4031,4371,
     1      4691,4961,5213,5421,5589,5721/
        data nsstored/650,600,552,528,483,440,399,378,340,320,
     1      270,252,208,168,132,110/
        data num1s/1,1,2,2,3,4,5,5,6,6,8,8,10,11,13,14/
        data num2s/26,25,25,25,25,25,25,25,25,25,
     1      25,25,25,24,24,24/
        if(ifinit .eq. 0) then
           call lot9get(arr)
c
        do 1400 i=1,16
        do 1200 j=1,26
c
        expcoefs(j,i)=0
        expcoefs1(j,i)=0
 1200 continue
 1400 continue
           ifinit=1
        endif
c
        isgn = -1
        do 2000 m=0,15
c
	mp1=m+1
        isgn = -isgn
        iarr=map(mp1)
        num1=num1s(mp1)
        numexp=num2s(mp1)-num1+1
        nnmult=24-m+1
c
ccc        call matvec34(arr(iarr),numexp,nnmult,mult(m,m),
ccc     1      expcoefs(num1,m+1) )
        call matvec344(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcoefs(num1,mp1), expcoefs1(num1,mp1), isgn )
 2000 continue
        return
        end
c
c
c
c
c 
c
        subroutine alota9(mult,expcoefs)
        implicit real *8 (a-h,o-z)
        complex *16 mult(0:24,0:24),expcoefs(26,16)
        real *8 arr(6000)
c
        dimension ms(26),num1s7(1),num2s7(1),ms7(1)
c
        dimension map(16),nsstored(16),num1s(16),num2s(16)
c
        save
c
c       this subroutine transforms a multipole expansion of
c       order 24 into a Bessel expansion of order (26,15)
c       the accuracy of the resulting scheme is about 3 digits.
c
c  ...  one wave number m after another, calculate the coefficients 
c       of the exponential expansion
c
        data ifinit/0/
        data ms/1,3,4,5,7,9,9,11,11,12,13,13,14,15,15,15,
     1      15,15,15,15,15,15,15,15,12,0/
        data map/1,651,1251,1803,2331,2814,3254,3653,4031,4371,
     1      4691,4961,5213,5421,5589,5721/
        data nsstored/650,600,552,528,483,440,399,378,340,320,
     1      270,252,208,168,132,110/
        data num1s/1,1,2,2,3,4,5,5,6,6,8,8,10,11,13,14/
        data num2s/26,25,25,25,25,25,25,25,25,25,
     1      25,25,25,24,24,24/
        if(ifinit .eq. 0) then
           call lot9get(arr)
c
           ifinit=1
        endif
c
        do 1400 i=1,16
        do 1200 j=1,26
c
        expcoefs(j,i)=0
 1200 continue
 1400 continue
c
        do 2000 m=0,15
c
        mp1=m+1
        iarr=map(mp1)
        numexp=num2s(mp1)-num1s(mp1)+1
cccc        nnmult=15-m+1
        nnmult=24-m+1
        num1=num1s(mp1)
c
        call matvec34(arr(iarr),numexp,nnmult,mult(m,m),
     1      expcoefs(num1,mp1) )
 2000 continue
        return
c
c
c
c
       entry get9dat(num1s7,num2s7,ms7)
c
c       this entry returns to the user three parameters describing
c       the translation operator converting a multipole expansion of 
c       order 24 into a Bessel expansion of order ((26,15)
c
c    Explanation: the subroutiune converts a multipole  expansion 
c       of order 26 into an expansion of the form
c
c    \sum_{m=0}^{15} \sum_{k=m}^24 \alpha_{m,k} * P_k^m (\theta) * 
c         e^{i * m * \phi}/r^{k+1}                                  (1)
c
c        into an expansion of the form 
c
c     \sum_{m=0}^{15} sum_{k=num1s(m+1)}^{num2s(m+1)} 
c        
c        \beta_{m,k} * e^{-rlams_k *z} *
c                                                                   (2)
c        J_m(\rlams(k) * sqrt(x^2+y^2)) * e^{i * m * \phi}.
c
c        The procedure is supposed to lead to 9-digit accuracy under 
c        normal FMM conditions 
c
c                    input parameters: none
c
c                    output parameters:
c
c  num1s - the list of first non-zero 

        do 3200 i=1,16
        num1s7(i)=num1s(i)
        num2s7(i)=num2s(i)
 3200 continue
c
        do 3400 i=1,26
        ms7(i)=ms(i)
 3400 continue
c
        return
        end
c
c
c
c 
c
        subroutine atalo99(expcoefs,expcoefs1,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:24,0:24),expcoefs(26,16)
        complex *16 expcoefs1(26,16)
        real *8 arr(7500)
c
ccc        dimension ms(26),num1s7(1),num2s7(1),ms7(1)
ccc        data ms/1,3,4,5,7,9,9,11,11,12,13,13,14,15,15,15,
ccc     1      15,15,15,15,15,15,15,15,12,0/
c
        dimension map(16),nsstored(16),num1s(16),num2s(16)
c
ccc        data map/1,651,1275,1873,2445,2991,3511,4005,4473,4915,
ccc     1           5331,5721,6085,6423,6735,7021/
ccc        data nsstored/650,624,598,572,546,520,494,468,442,416,
ccc     1           390,364,338,312,286,260/
cccc
ccc        data map/1,651,1251,1803,2331,2814,3254,3653,4031,4371,
ccc     1      4691,4961,5213,5421,5589,5721/
ccc        data nsstored/650,600,552,528,483,440,399,378,340,320,
ccc     1      270,252,208,168,132,110/
ccc        data num1s/1,1,2,2,3,4,5,5,6,6,8,8,10,11,13,14/
        save
c
c
c       this subroutine transforms a Bessel expansion of order (26,16)
c       into a local expansion of order 24; the accuracy of the 
c       resulting scheme is about 9 digits.
c
c   ... one wave number m after another, calculate the coefficients 
c       of the taylor series
c
        data ifinit/0/
        data map/1,651,1275,1895,2466,3011,3530,4023,4558,4995,
     1           5436,5819,6202,6543,6867,7151/
        data nsstored/650,624,598,572,546,520,494,468,442,416,
     1           390,364,338,312,286,260/
        data num1s/1,1,1,2,2,2,2,2,6,6,8,8,10,11,13,14/
        data num2s/26,25,25,25,25,25,25,25,25,25,
     1      25,25,25,24,24,24/
        if(ifinit .eq. 0) then
ccc           do i = 1, 16
ccc              map(i) = map(i) + (num1s(i)-1)*(24-(i-1)+1)
ccc              print *, map(i),','
ccc           enddo
ccc           pause 'check'
           call lot9geta(arr)
        do 1400 i=0,24
        do 1200 j=0,i
c
        taylor(j,i)=0
 1200 continue
 1400 continue
c
           ifinit=1
        endif
c
        ntaylor=24
ccc        numexp=26
***
***	if (2.ne.3) go to 555
***	do i = 3, 16
***           print *, expcoefs(1,i)
***  	enddo
***	pause 'check'
*** 555	continue
***
c
        isgn = -1
        do 2000 m=0,15
c
        mp1 = m+1
        isgn = -isgn
        nntaylor=ntaylor-m+1
        iarr=map(mp1)
        num1=num1s(mp1)
        numexp=num2s(mp1)-num1+1
c
ccc        call matvec34(arr(iarr),nntaylor,numexp,
ccc     1      expcoefs(1,m+1),taylor(m,m) )
        call matvec334(arr(iarr),nntaylor,numexp,
     1      expcoefs(num1,mp1),expcoefs1(num1,mp1),taylor(m,m),isgn )
ccc     1      expcoefs(1,mp1),expcoefs1(1,mp1),taylor(m,m),isgn )
 2000 continue
        return
        end
c
c
c
c 
c
        subroutine atalo9(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:24,0:24),expcoefs(26,16)
        real *8 arr(7500)
c
ccc        dimension ms(26),num1s7(1),num2s7(1),ms7(1)
ccc        data ms/1,3,4,5,7,9,9,11,11,12,13,13,14,15,15,15,
ccc     1      15,15,15,15,15,15,15,15,12,0/
c
        dimension map(16),nsstored(16),num1s(16),num2s(16)
c
ccc        data map/1,651,1275,1873,2445,2991,3511,4005,4473,4915,
ccc     1           5331,5721,6085,6423,6735,7021/
ccc        data nsstored/650,624,598,572,546,520,494,468,442,416,
ccc     1           390,364,338,312,286,260/
cccc
ccc        data map/1,651,1251,1803,2331,2814,3254,3653,4031,4371,
ccc     1      4691,4961,5213,5421,5589,5721/
ccc        data nsstored/650,600,552,528,483,440,399,378,340,320,
ccc     1      270,252,208,168,132,110/
ccc        data num1s/1,1,2,2,3,4,5,5,6,6,8,8,10,11,13,14/
c
c
c       this subroutine transforms a Bessel expansion of order (26,16)
c       into a local expansion of order 24; the accuracy of the 
c       resulting scheme is about 9 digits.
c
c   ... one wave number m after another, calculate the coefficients 
c       of the taylor series
c
        data ifinit/0/
        data map/1,651,1275,1895,2466,3011,3530,4023,4558,4995,
     1           5436,5819,6202,6543,6867,7151/
        data nsstored/650,624,598,572,546,520,494,468,442,416,
     1           390,364,338,312,286,260/
        data num1s/1,1,1,2,2,2,2,2,6,6,8,8,10,11,13,14/
        data num2s/26,25,25,25,25,25,25,25,25,25,
     1      25,25,25,24,24,24/
        if(ifinit .eq. 0) then
           call lot9geta(arr)
           ifinit=1
        endif
c
        do 1400 i=0,24
        do 1200 j=0,i
c
        taylor(j,i)=0
 1200 continue
 1400 continue
c
        ntaylor=24
c
        do 2000 m=0,15
c
        mp1 = m+1
        nntaylor=ntaylor-m+1
        iarr=map(mp1)
        num1=num1s(mp1)
        numexp=num2s(mp1)-num1+1
c
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(num1,mp1),taylor(m,m) )
 2000 continue
        return
        end
c
c
c
c
        subroutine atalo9_old(expcoefs,taylor)
        implicit real *8 (a-h,o-z)
        complex *16 taylor(0:24,0:24),expcoefs(26,16)
        real *8 arr(7500)
c
        dimension map(16),nsstored(16)
c
c
c       this subroutine transforms a Bessel expansion of order (26,16)
c       into a local expansion of order 24; the accuracy of the 
c       resulting scheme is about 9 digits.
c
c   ... one wave number m after another, calculate the coefficients 
c       of the taylor series
c
        data ifinit/0/
        data map/1,651,1275,1873,2445,2991,3511,4005,4473,4915,
     1           5331,5721,6085,6423,6735,7021/
        data nsstored/650,624,598,572,546,520,494,468,442,416,
     1           390,364,338,312,286,260/
        if(ifinit .eq. 0) call lot9geta(arr)
        if(ifinit .eq. 0) ifinit=1
c
        ntaylor=24
        numexp=26

        do 1400 i=0,24
        do 1200 j=0,24
c
        taylor(j,i)=0
 1200 continue
 1400 continue
c
        do 2000 m=0,15
c
        nntaylor=ntaylor-m+1
        iarr=map(m+1)
c
        call matvec34(arr(iarr),nntaylor,numexp,
     1      expcoefs(1,m+1),taylor(m,m) )
 2000 continue
        return
        end
c
c
c
c
c
        subroutine mmatvec34(alota,numexp,nnmult,cw1,cw2)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        do 1200 j=1,nnmult
        cd=cd+alota(i,j)*cw1(j)
 1200 continue
c
        cw2(i)=cd
 1400 continue
        return
        end
c
        subroutine mmatvec334(alota,numexp,nnmult,cw1,cw2,cw3,isgn)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        complex *16 cw3(1), cd1
        dimension alota(numexp,nnmult)
c
        iisgn = -isgn
        do 1400 i=1,numexp
c
        cd=0
        cd1=0
        iisgn = -iisgn
        do 1200 j=1,nnmult
        aij = alota(i,j)
        cd=cd+aij*cw1(j)
        cd1=cd1+aij*cw2(j)
 1200 continue
***        cw3(i)=cd+cd1*iisgn
        if (iisgn .gt. 0) then
           cw3(i)=cd+cd1
        else
           cw3(i)=cd-cd1
        endif
C
 1400 continue
        return
        end
c
c
        subroutine mmatvec344(alota,numexp,nnmult,cw1,cw2,cw3,isgn)
        implicit real *8 (a-h,o-z)
        complex *16 cw1(1),cw2(1),cd
        complex *16 cw3(1), cd1, tmp
        dimension alota(numexp,nnmult)
c
        do 1400 i=1,numexp
c
        cd=0
        cd1=0
ccc        isgnn = -isgn
ccc        do 1200 j=1,nnmult
ccc        isgnn = -isgnn
ccc        tmp=alota(i,j)*cw1(j)
ccc        cd=cd+tmp
ccc        cd1=cd1+isgnn*tmp
ccc 1200 continue
        if (isgn .gt. 0) then
           do j=1,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1+tmp
           enddo
           do j=2,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1-tmp
           enddo
        else
           do j=1,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1-tmp
           enddo
           do j=2,nnmult,2
              tmp=alota(i,j)*cw1(j)
              cd=cd+tmp
              cd1=cd1+tmp
           enddo
        endif
c
        cw2(i)=cd
        cw3(i)=cd1
 1400 continue
        return
        end
c
c
        subroutine lot9get(arr)
        implicit real *8 (a-h,o-z)
c
        real *8 arr(1)
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260(16),
     6  arr1261(16),arr1262(16),arr1263(16),arr1264(16),
     7  arr1265(16),arr1266(16),arr1267(16),arr1268(16),
     8  arr1269(16),arr1270(16),arr1271(16),arr1272(16),
     9  arr1273(16),arr1274(16),arr1275(16),arr1276(16),
     a  arr1277(16),arr1278(16),arr1279(16),arr1280(16)
         real *8
     1  arr1281(16),arr1282(16),arr1283(16),arr1284(16),
     2  arr1285(16),arr1286(16),arr1287(16),arr1288(16),
     3  arr1289(16),arr1290(16),arr1291(16),arr1292(16),
     4  arr1293(16),arr1294(16),arr1295(16),arr1296(16),
     5  arr1297(16),arr1298(16),arr1299(16),arr1300(16),
     6  arr1301(16),arr1302(16),arr1303(16),arr1304(16),
     7  arr1305(16),arr1306(16),arr1307(16),arr1308(16),
     8  arr1309(16),arr1310(16),arr1311(16),arr1312(16),
     9  arr1313(16),arr1314(16),arr1315(16),arr1316(16),
     a  arr1317(16),arr1318(16),arr1319(16),arr1320(16)
         real *8
     1  arr1321(16),arr1322(16),arr1323(16),arr1324(16),
     2  arr1325(16),arr1326(16),arr1327(16),arr1328(16),
     3  arr1329(16),arr1330(16),arr1331(16),arr1332(16),
     4  arr1333(16),arr1334(16),arr1335(16),arr1336(16),
     5  arr1337(16),arr1338(16),arr1339(16),arr1340(16),
     6  arr1341(16),arr1342(16),arr1343(16),arr1344(16),
     7  arr1345(16),arr1346(16),arr1347(16),arr1348(16),
     8  arr1349(16),arr1350(16),arr1351(16),arr1352(16),
     9  arr1353(16),arr1354(16),arr1355(16),arr1356(16),
     a  arr1357(16),arr1358(16),arr1359(16),arr1360(16)
         real *8
     1  arr1361(16),arr1362(16),arr1363(16),arr1364(16)
         real *8
     1  arr1365( 6)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2),
     5  arr2257(2),arr2258(2),arr2259(2),arr2260(2),
     6  arr2261(2),arr2262(2),arr2263(2),arr2264(2),
     7  arr2265(2),arr2266(2),arr2267(2),arr2268(2),
     8  arr2269(2),arr2270(2),arr2271(2),arr2272(2),
     9  arr2273(2),arr2274(2),arr2275(2),arr2276(2),
     a  arr2277(2),arr2278(2),arr2279(2),arr2280(2)
         real *8
     1  arr2281(2),arr2282(2),arr2283(2),arr2284(2),
     2  arr2285(2),arr2286(2),arr2287(2),arr2288(2),
     3  arr2289(2),arr2290(2),arr2291(2),arr2292(2),
     4  arr2293(2),arr2294(2),arr2295(2),arr2296(2),
     5  arr2297(2),arr2298(2),arr2299(2),arr2300(2),
     6  arr2301(2),arr2302(2),arr2303(2),arr2304(2),
     7  arr2305(2),arr2306(2),arr2307(2),arr2308(2),
     8  arr2309(2),arr2310(2),arr2311(2),arr2312(2),
     9  arr2313(2),arr2314(2),arr2315(2),arr2316(2),
     a  arr2317(2),arr2318(2),arr2319(2),arr2320(2)
         real *8
     1  arr2321(2),arr2322(2),arr2323(2),arr2324(2),
     2  arr2325(2),arr2326(2),arr2327(2),arr2328(2),
     3  arr2329(2),arr2330(2),arr2331(2),arr2332(2),
     4  arr2333(2),arr2334(2),arr2335(2),arr2336(2),
     5  arr2337(2),arr2338(2),arr2339(2),arr2340(2),
     6  arr2341(2),arr2342(2),arr2343(2),arr2344(2),
     7  arr2345(2),arr2346(2),arr2347(2),arr2348(2),
     8  arr2349(2),arr2350(2),arr2351(2),arr2352(2),
     9  arr2353(2),arr2354(2),arr2355(2),arr2356(2),
     a  arr2357(2),arr2358(2),arr2359(2),arr2360(2)
         real *8
     1  arr2361(2),arr2362(2),arr2363(2),arr2364(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2)),
     a  (arr1260(16),arr2260(1)),(arr1261(1),arr2260(2))
         equivalence
     1  (arr1261(16),arr2261(1)),(arr1262(1),arr2261(2)),
     2  (arr1262(16),arr2262(1)),(arr1263(1),arr2262(2)),
     3  (arr1263(16),arr2263(1)),(arr1264(1),arr2263(2)),
     4  (arr1264(16),arr2264(1)),(arr1265(1),arr2264(2)),
     5  (arr1265(16),arr2265(1)),(arr1266(1),arr2265(2)),
     6  (arr1266(16),arr2266(1)),(arr1267(1),arr2266(2)),
     7  (arr1267(16),arr2267(1)),(arr1268(1),arr2267(2)),
     8  (arr1268(16),arr2268(1)),(arr1269(1),arr2268(2)),
     9  (arr1269(16),arr2269(1)),(arr1270(1),arr2269(2)),
     a  (arr1270(16),arr2270(1)),(arr1271(1),arr2270(2))
         equivalence
     1  (arr1271(16),arr2271(1)),(arr1272(1),arr2271(2)),
     2  (arr1272(16),arr2272(1)),(arr1273(1),arr2272(2)),
     3  (arr1273(16),arr2273(1)),(arr1274(1),arr2273(2)),
     4  (arr1274(16),arr2274(1)),(arr1275(1),arr2274(2)),
     5  (arr1275(16),arr2275(1)),(arr1276(1),arr2275(2)),
     6  (arr1276(16),arr2276(1)),(arr1277(1),arr2276(2)),
     7  (arr1277(16),arr2277(1)),(arr1278(1),arr2277(2)),
     8  (arr1278(16),arr2278(1)),(arr1279(1),arr2278(2)),
     9  (arr1279(16),arr2279(1)),(arr1280(1),arr2279(2)),
     a  (arr1280(16),arr2280(1)),(arr1281(1),arr2280(2))
         equivalence
     1  (arr1281(16),arr2281(1)),(arr1282(1),arr2281(2)),
     2  (arr1282(16),arr2282(1)),(arr1283(1),arr2282(2)),
     3  (arr1283(16),arr2283(1)),(arr1284(1),arr2283(2)),
     4  (arr1284(16),arr2284(1)),(arr1285(1),arr2284(2)),
     5  (arr1285(16),arr2285(1)),(arr1286(1),arr2285(2)),
     6  (arr1286(16),arr2286(1)),(arr1287(1),arr2286(2)),
     7  (arr1287(16),arr2287(1)),(arr1288(1),arr2287(2)),
     8  (arr1288(16),arr2288(1)),(arr1289(1),arr2288(2)),
     9  (arr1289(16),arr2289(1)),(arr1290(1),arr2289(2)),
     a  (arr1290(16),arr2290(1)),(arr1291(1),arr2290(2))
         equivalence
     1  (arr1291(16),arr2291(1)),(arr1292(1),arr2291(2)),
     2  (arr1292(16),arr2292(1)),(arr1293(1),arr2292(2)),
     3  (arr1293(16),arr2293(1)),(arr1294(1),arr2293(2)),
     4  (arr1294(16),arr2294(1)),(arr1295(1),arr2294(2)),
     5  (arr1295(16),arr2295(1)),(arr1296(1),arr2295(2)),
     6  (arr1296(16),arr2296(1)),(arr1297(1),arr2296(2)),
     7  (arr1297(16),arr2297(1)),(arr1298(1),arr2297(2)),
     8  (arr1298(16),arr2298(1)),(arr1299(1),arr2298(2)),
     9  (arr1299(16),arr2299(1)),(arr1300(1),arr2299(2)),
     a  (arr1300(16),arr2300(1)),(arr1301(1),arr2300(2))
         equivalence
     1  (arr1301(16),arr2301(1)),(arr1302(1),arr2301(2)),
     2  (arr1302(16),arr2302(1)),(arr1303(1),arr2302(2)),
     3  (arr1303(16),arr2303(1)),(arr1304(1),arr2303(2)),
     4  (arr1304(16),arr2304(1)),(arr1305(1),arr2304(2)),
     5  (arr1305(16),arr2305(1)),(arr1306(1),arr2305(2)),
     6  (arr1306(16),arr2306(1)),(arr1307(1),arr2306(2)),
     7  (arr1307(16),arr2307(1)),(arr1308(1),arr2307(2)),
     8  (arr1308(16),arr2308(1)),(arr1309(1),arr2308(2)),
     9  (arr1309(16),arr2309(1)),(arr1310(1),arr2309(2)),
     a  (arr1310(16),arr2310(1)),(arr1311(1),arr2310(2))
         equivalence
     1  (arr1311(16),arr2311(1)),(arr1312(1),arr2311(2)),
     2  (arr1312(16),arr2312(1)),(arr1313(1),arr2312(2)),
     3  (arr1313(16),arr2313(1)),(arr1314(1),arr2313(2)),
     4  (arr1314(16),arr2314(1)),(arr1315(1),arr2314(2)),
     5  (arr1315(16),arr2315(1)),(arr1316(1),arr2315(2)),
     6  (arr1316(16),arr2316(1)),(arr1317(1),arr2316(2)),
     7  (arr1317(16),arr2317(1)),(arr1318(1),arr2317(2)),
     8  (arr1318(16),arr2318(1)),(arr1319(1),arr2318(2)),
     9  (arr1319(16),arr2319(1)),(arr1320(1),arr2319(2)),
     a  (arr1320(16),arr2320(1)),(arr1321(1),arr2320(2))
         equivalence
     1  (arr1321(16),arr2321(1)),(arr1322(1),arr2321(2)),
     2  (arr1322(16),arr2322(1)),(arr1323(1),arr2322(2)),
     3  (arr1323(16),arr2323(1)),(arr1324(1),arr2323(2)),
     4  (arr1324(16),arr2324(1)),(arr1325(1),arr2324(2)),
     5  (arr1325(16),arr2325(1)),(arr1326(1),arr2325(2)),
     6  (arr1326(16),arr2326(1)),(arr1327(1),arr2326(2)),
     7  (arr1327(16),arr2327(1)),(arr1328(1),arr2327(2)),
     8  (arr1328(16),arr2328(1)),(arr1329(1),arr2328(2)),
     9  (arr1329(16),arr2329(1)),(arr1330(1),arr2329(2)),
     a  (arr1330(16),arr2330(1)),(arr1331(1),arr2330(2))
         equivalence
     1  (arr1331(16),arr2331(1)),(arr1332(1),arr2331(2)),
     2  (arr1332(16),arr2332(1)),(arr1333(1),arr2332(2)),
     3  (arr1333(16),arr2333(1)),(arr1334(1),arr2333(2)),
     4  (arr1334(16),arr2334(1)),(arr1335(1),arr2334(2)),
     5  (arr1335(16),arr2335(1)),(arr1336(1),arr2335(2)),
     6  (arr1336(16),arr2336(1)),(arr1337(1),arr2336(2)),
     7  (arr1337(16),arr2337(1)),(arr1338(1),arr2337(2)),
     8  (arr1338(16),arr2338(1)),(arr1339(1),arr2338(2)),
     9  (arr1339(16),arr2339(1)),(arr1340(1),arr2339(2)),
     a  (arr1340(16),arr2340(1)),(arr1341(1),arr2340(2))
         equivalence
     1  (arr1341(16),arr2341(1)),(arr1342(1),arr2341(2)),
     2  (arr1342(16),arr2342(1)),(arr1343(1),arr2342(2)),
     3  (arr1343(16),arr2343(1)),(arr1344(1),arr2343(2)),
     4  (arr1344(16),arr2344(1)),(arr1345(1),arr2344(2)),
     5  (arr1345(16),arr2345(1)),(arr1346(1),arr2345(2)),
     6  (arr1346(16),arr2346(1)),(arr1347(1),arr2346(2)),
     7  (arr1347(16),arr2347(1)),(arr1348(1),arr2347(2)),
     8  (arr1348(16),arr2348(1)),(arr1349(1),arr2348(2)),
     9  (arr1349(16),arr2349(1)),(arr1350(1),arr2349(2)),
     a  (arr1350(16),arr2350(1)),(arr1351(1),arr2350(2))
         equivalence
     1  (arr1351(16),arr2351(1)),(arr1352(1),arr2351(2)),
     2  (arr1352(16),arr2352(1)),(arr1353(1),arr2352(2)),
     3  (arr1353(16),arr2353(1)),(arr1354(1),arr2353(2)),
     4  (arr1354(16),arr2354(1)),(arr1355(1),arr2354(2)),
     5  (arr1355(16),arr2355(1)),(arr1356(1),arr2355(2)),
     6  (arr1356(16),arr2356(1)),(arr1357(1),arr2356(2)),
     7  (arr1357(16),arr2357(1)),(arr1358(1),arr2357(2)),
     8  (arr1358(16),arr2358(1)),(arr1359(1),arr2358(2)),
     9  (arr1359(16),arr2359(1)),(arr1360(1),arr2359(2)),
     a  (arr1360(16),arr2360(1)),(arr1361(1),arr2360(2))
         equivalence
     1  (arr1361(16),arr2361(1)),(arr1362(1),arr2361(2)),
     2  (arr1362(16),arr2362(1)),(arr1363(1),arr2362(2)),
     3  (arr1363(16),arr2363(1)),(arr1364(1),arr2363(2)),
     4  (arr1364(16),arr2364(1)),(arr1365(1),arr2364(2))
c
         data arr1001/
     1      0.8961180435038006d-01,0.1602832301177220d+00,
     2      0.1605517333671379d+00,0.1191375540244585d+00,
     3      0.7196546966842009d-01,0.3718949372966268d-01,
     4      0.1696300526789189d-01,0.6978629416072744d-02,
     5      0.2631361516932021d-02,0.9207229423152100d-03,
     6      0.3019416861284677d-03,0.9355327457998056d-04,
     7      0.2756738151457605d-04,0.7767399649458242d-05,
     8      0.2101920613720808d-05,0.5482383573940307d-06/
         data arr1002/
     1      0.1382214764422087d-06,0.3376576866984212d-07,
     2      0.8009458214797730d-08,0.1845245690611140d-08,
     3      0.4099806599526132d-09,0.8713256658630417d-10,
     4      0.1934653589538669d-10,0.6315339479176633d-11,
     5      0.2790762474740196d-11,-.2924644706776973d-12,
     6      0.3320744367536893d-02,0.3080593434191043d-01,
     7      0.7392760119467086d-01,0.9865200898727704d-01,
     8      0.9220304358980211d-01,0.6723563724636310d-01/
         data arr1003/
     1      0.4067978470094916d-01,0.2124008776245865d-01,
     2      0.9834259474462833d-02,0.4118898050427299d-02,
     3      0.1584395300650292d-02,0.5664303351446221d-03,
     4      0.1899921638344856d-03,0.6024660514431249d-04,
     5      0.1817211790121763d-04,0.5239810335320852d-05,
     6      0.1450128123238157d-05,0.3864141785790667d-06,
     7      0.9938103129270697d-07,0.2472269127688569d-07,
     8      0.5967910059398683d-08,0.1403284872266254d-08/
         data arr1004/
     1      0.3188642487792111d-09,0.6648942770068427d-10,
     2      0.1244393145961508d-10,0.8720488158784232d-11,
     3      0.6153033882471079d-04,0.2960397521381977d-02,
     4      0.1702034472413348d-01,0.4084445973443507d-01,
     5      0.5906583809943875d-01,0.6077833249626035d-01,
     6      0.4877805783131701d-01,0.3232306043963486d-01,
     7      0.1837692396233243d-01,0.9213043361024770d-02,
     8      0.4156942408611719d-02,0.1714763007504741d-02/
         data arr1005/
     1      0.6547049741173274d-03,0.2336465017695370d-03,
     2      0.7855379796741435d-04,0.2503978308863423d-04,
     3      0.7606389513670793d-05,0.2211084278915801d-05,
     4      0.6170750720553323d-06,0.1657521498897146d-06,
     5      0.4292297318296482d-07,0.1072887043792748d-07,
     6      0.2596816257702393d-08,0.6156706660782293d-09,
     7      0.1464874347142752d-09,0.3784957379994304d-10,
     8      0.7589894516660278d-06,0.1896619548046271d-03/
         data arr1006/
     1      0.2612392237410119d-02,0.1127377075306664d-01,
     2      0.2522529196065514d-01,0.3662745857394501d-01,
     3      0.3899232206477902d-01,0.3279271597077901d-01,
     4      0.2289352725127290d-01,0.1373832965744058d-01,
     5      0.7270984448458239d-02,0.3460751492868210d-02,
     6      0.1504057392555522d-02,0.6040804781444474d-03,
     7      0.2263793927130385d-03,0.7977274712126891d-04,
     8      0.2659907285362873d-04,0.8434644983590665d-05/
         data arr1007/
     1      0.2553955791729479d-05,0.7407920368079223d-06,
     2      0.2063488710685263d-06,0.5531065287131291d-07,
     3      0.1429628687363925d-07,0.3578028233606462d-08,
     4      0.8825478041476203d-09,0.2662097543081419d-09,
     5      0.7806542063116019d-08,0.9111341241455472d-05,
     6      0.3007270619160580d-03,0.2333814004064406d-02,
     7      0.8079739177488842d-02,0.1655488020734424d-01,
     8      0.2337733292975691d-01,0.2495189650909996d-01/
         data arr1008/
     1      0.2139015190082880d-01,0.1536476818561810d-01,
     2      0.9538359480830814d-02,0.5238392042601007d-02,
     3      0.2591459441345658d-02,0.1171363195418176d-02,
     4      0.4892918726064933d-03,0.1906073632519250d-03,
     5      0.6976127602391183d-04,0.2413177431866590d-04,
     6      0.7927863900216692d-05,0.2483012698085017d-05,
     7      0.7436292587577692d-06,0.2134473672467375d-06,
     8      0.5882681635289183d-07,0.1559722013493421d-07/
         data arr1009/
     1      0.4011440491140242d-08,0.1185131038447207d-08,
     2      -.4820693583512919d-09,0.3515209427396147d-06,
     3      0.2769325298991436d-04,0.3865043463978378d-03,
     4      0.2070371874088865d-02,0.5985980594661616d-02,
     5      0.1121245740871662d-01,0.1518866919802733d-01,
     6      0.1598840026025829d-01,0.1374700464601119d-01,
     7      0.1001023203388520d-01,0.6343304552283792d-02,
     8      0.3572024429135462d-02,0.1817097935813984d-02/
         data arr1010/
     1      0.8460364328600358d-03,0.3643467307362711d-03,
     2      0.1463702157894012d-03,0.5523348240165271d-04,
     3      0.1968762520525921d-04,0.6658549592164619d-05,
     4      0.2144486371588332d-05,0.6596100558375795d-06,
     5      0.1942580750569851d-06,0.5495069058786409d-07,
     6      0.1510266273132612d-07,0.4851172955119720d-08,
     7      -.1489287129200968d-09,0.1161186475930531d-07,
     8      0.2124936189643523d-05,0.5334108452602435d-04/
         data arr1011/
     1      0.4420975811079134d-03,0.1803695896388936d-02,
     2      0.4481520696717075d-02,0.7704680598085940d-02,
     3      0.9958981140107341d-02,0.1024964682494239d-01,
     4      0.8754540471663434d-02,0.6401059824179804d-02,
     5      0.4103015681258994d-02,0.2349004453583565d-02,
     6      0.1219070721865662d-02,0.5803751585138122d-03,
     7      0.2559230575014131d-03,0.1053496462933123d-03,
     8      0.4074218196468617d-04,0.1487908059929593d-04/
         data arr1012/
     1      0.5152445006034812d-05,0.1697337115133669d-05,
     2      0.5332964111166577d-06,0.1602286561225792d-06,
     3      0.4646656635377710d-07,0.1550799039089152d-07,
     4      0.6565173857210788d-09,-.1319528742940230d-08,
     5      0.1415950239119685d-06,0.6308501225741178d-05,
     6      0.8091813113265184d-04,0.4658478054846787d-03,
     7      0.1535335568306955d-02,0.3349984036456824d-02,
     8      0.5317139243066290d-02,0.6550326126034067d-02/
         data arr1013/
     1      0.6562597726700996d-02,0.5536577972822520d-02,
     2      0.4039662918418186d-02,0.2602810773673665d-02,
     3      0.1505642822094460d-02,0.7924208747917228d-03,
     4      0.3835480959051496d-03,0.1722341252762039d-03,
     5      0.7226942837660419d-04,0.2850020340437388d-04,
     6      0.1061328026987448d-04,0.3746598038691225d-05,
     7      0.1257809647677269d-05,0.4029256017625297d-06,
     8      0.1245286022394366d-06,0.4483876707839802d-07/
         data arr1014/
     1      0.7466136350293897d-09,-.1892770602995544d-08,
     2      0.1041588791364329d-07,0.6508644861868611d-06,
     3      0.1296078393925735d-04,0.1052758792875321d-03,
     4      0.4602458292911442d-03,0.1274496809450414d-02,
     5      0.2483986722745479d-02,0.3662899204000813d-02,
     6      0.4304535430480439d-02,0.4190241085733755d-02,
     7      0.3480127143741907d-02,0.2523535637886014d-02,
     8      0.1627133037949688d-02,0.9466968203761587d-03/
         data arr1015/
     1      0.5029651894406149d-03,0.2463835054556767d-03,
     2      0.1121671250161306d-03,0.4776405355081276d-04,
     3      0.1912511844745538d-04,0.7231567050422928d-05,
     4      0.2591017536844284d-05,0.8824078966707478d-06,
     5      0.2886799171384308d-06,0.1097932028934101d-06,
     6      0.1218518524688978d-08,-.3128886776125384d-08,
     7      0.4392031164176918d-08,0.5622846265457795d-07,
     8      0.1847892969554026d-05,0.2114594232838856d-04/
         data arr1016/
     1      0.1226387582631891d-03,0.4310042627850169d-03,
     2      0.1031497624298513d-02,0.1820683265721045d-02,
     3      0.2509714488837254d-02,0.2818928768807126d-02,
     4      0.2664971258321876d-02,0.2174822604199112d-02,
     5      0.1563045831260771d-02,0.1005341101980209d-02,
     6      0.5862785032341509d-03,0.3132950093356676d-03,
     7      0.1547498711517432d-03,0.7115769592100031d-04,
     8      0.3063854353649815d-04,0.1241243085635716d-04/
         data arr1017/
     1      0.4749826651328023d-05,0.1723049403136909d-05,
     2      0.5995887477423864d-06,0.2444615723770496d-06,
     3      0.2581051853440882d-08,-.6578690793710222d-08,
     4      0.8213264691470023d-08,-.2754222016689313d-08,
     5      0.2424125015885951d-06,0.3819297419334362d-05,
     6      0.2941312068733498d-04,0.1311783802719090d-03,
     7      0.3855059700273066d-03,0.8144902364626266d-03,
     8      0.1316937323566019d-02,0.1706757231117546d-02/
         data arr1018/
     1      0.1836674953668254d-02,0.1686867643639934d-02,
     2      0.1351334639286154d-02,0.9608554549466818d-03,
     3      0.6150528032695796d-03,0.3585395804132084d-03,
     4      0.1921460431101367d-03,0.9540369290916786d-04,
     5      0.4416977722417811d-04,0.1916916334914716d-04,
     6      0.7831136021769349d-05,0.3023009281738726d-05,
     7      0.1116667239598047d-05,0.4859000476379107d-06,
     8      0.5480730713539556d-08,-.1390596594577208d-07/
         data arr1019/
     1      0.1719727042589731d-07,-.1574087795535381d-07,
     2      0.4006465503544482d-07,0.6199454413262158d-06,
     3      0.6417738530528377d-05,0.3629229812894580d-04,
     4      0.1309815365335784d-03,0.3312395461618395d-03,
     5      0.6282237260485228d-03,0.9394353051104136d-03,
     6      0.1150744307278082d-02,0.1189450245714447d-02,
     7      0.1062090336291980d-02,0.8348506048826873d-03,
     8      0.5865800188847067d-03,0.3730140235594588d-03/
         data arr1020/
     1      0.2168831049782520d-03,0.1162723133056981d-03,
     2      0.5787663682709221d-04,0.2690142268873239d-04,
     3      0.1172717364301670d-04,0.4812837116255525d-05,
     4      0.1884179682559826d-05,0.8725254804938362d-06,
     5      0.1040710062397156d-07,-.2643274850607657d-07,
     6      0.3275109986660798d-07,-.3073616274960864d-07,
     7      0.2689641194673216d-07,0.7848406956744577d-07,
     8      0.1292690597387382d-05,0.9198245944238419d-05/
         data arr1021/
     1      0.4079949425865234d-04,0.1234801164422817d-03,
     2      0.2747133549695195d-03,0.4739954778829665d-03,
     3      0.6608986991962708d-03,0.7688212712494013d-03,
     4      0.7651950741469533d-03,0.6649204403152198d-03,
     5      0.5128107382748984d-03,0.3557426108647140d-03,
     6      0.2244149973327773d-03,0.1299116678882088d-03,
     7      0.6953966846739453d-04,0.3463497311110174d-04,
     8      0.1612769592861392d-04,0.7050852480604018d-05/
         data arr1022/
     1      0.2937564746187417d-05,0.1463480124214096d-05,
     2      0.1498200024215982d-07,-.3804892441894344d-07,
     3      0.4713926921329741d-07,-.4426148906809515d-07,
     4      0.3476432399695873d-07,-.1009769855505349d-07,
     5      0.2526550478006354d-06,0.2144337269236700d-05,
     6      0.1173769899134171d-04,0.4248572853704980d-04,
     7      0.1108915160883981d-03,0.2207603505645924d-03,
     8      0.3503684348641186d-03,0.4587184080032348d-03/
         data arr1023/
     1      0.5088842920198420d-03,0.4888311048597855d-03,
     2      0.4138134924221697d-03,0.3131329170788985d-03,
     3      0.2142741602594604d-03,0.1338815095774214d-03,
     4      0.7699645198503141d-04,0.4101874330227819d-04,
     5      0.2033397488404361d-04,0.9414905931354014d-05,
     6      0.4132491399347362d-05,0.2166656978148492d-05,
     7      0.2530272651005713d-07,-.6427526156010634d-07,
     8      0.7966163543495881d-07,-.7485076772053578d-07/
         data arr1024/
     1      0.5834549438852394d-07,-.3773718936661647d-07,
     2      0.6807347939256051d-07,0.4498370073189190d-06,
     3      0.3148366762146887d-05,0.1356464163583688d-04,
     4      0.4157308606623803d-04,0.9547571716979016d-04,
     5      0.1724690063710659d-03,0.2541570983828894d-03,
     6      0.3142592259384888d-03,0.3337047617631167d-03,
     7      0.3101004369146886d-03,0.2559947055559903d-03,
     8      0.1900597740985842d-03,0.1282385616918747d-03/
         data arr1025/
     1      0.7933463347404324d-04,0.4531800887245143d-04,
     2      0.2402203560626233d-04,0.1186861211499528d-04,
     3      0.5561928488637430d-05,0.3163151195571644d-05,
     4      0.3102027255574508d-07,-.7863080062297210d-07,
     5      0.9714318625051812d-07,-.9100195405203793d-07,
     6      0.7072322418689522d-07,-.4744276239258670d-07,
     7      0.3970743451099452d-07,0.7269501525978170d-07,
     8      0.8013086300060421d-06,0.4033037955261679d-05/
         data arr1026/
     1      0.1455440169688310d-04,0.3854029704883086d-04,
     2      0.7923211070940287d-04,0.1314362190023036d-03,
     3      0.1811215446235526d-03,0.2125830265038771d-03,
     4      0.2168116365863320d-03,0.1951701006714027d-03,
     5      0.1570659935463976d-03,0.1142458895335277d-03,
     6      0.7579264695268222d-04,0.4617131380063464d-04,
     7      0.2593889444363907d-04,0.1348855691841261d-04,
     8      0.6605240783524541d-05,0.3904673094332870d-05/
         data arr1027/
     1      0.5027438388223167d-07,-.1276373715618113d-06,
     2      0.1580677582727330d-06,-.1484816742364617d-06,
     3      0.1155905255575459d-06,-.7823974470991050d-07,
     4      0.5555242083527394d-07,-.1920427651187007d-07,
     5      0.2171984753039773d-06,0.1104735584807121d-05,
     6      0.4792491241795757d-05,0.1458967445433421d-04,
     7      0.3410722333750468d-04,0.6374865557565516d-04,
     8      0.9787739641496509d-04,0.1269649245809189d-03/
         data arr1028/
     1      0.1421873028450319d-03,0.1396652959400379d-03,
     2      0.1219489872787984d-03,0.9580848427112983d-04,
     3      0.6842566152630132d-04,0.4475521371399863d-04,
     4      0.2693257427071608d-04,0.1497769141163870d-04,
     5      0.7858021851371041d-05,0.5077729839486993d-05,
     6      0.4812662342075822d-07,-.1219350152281862d-06,
     7      0.1505457520448493d-06,-.1409927388625123d-06,
     8      0.1094902159120517d-06,-.7382138519999395d-07/
         data arr1029/
     1      0.5149917597910630d-07,-.3149791537061023d-07,
     2      0.7284780956014494d-07,0.2722171378505780d-06,
     3      0.1495495353072802d-05,0.5199154787659938d-05,
     4      0.1381151246155290d-04,0.2910229306745486d-04,
     5      0.4975303384372515d-04,0.7128320888361510d-04,
     6      0.8755541372875118d-04,0.9363642794843237d-04,
     7      0.8839101246306139d-04,0.7458383096196836d-04,
     8      0.5682736633540817d-04,0.3936006885403951d-04/
         data arr1030/
     1      0.2487528327812831d-04,0.1439971244898289d-04,
     2      0.7791227165362434d-05,0.5136177766498534d-05,
     3      0.7277887661415251d-07,-.1848978465466473d-06,
     4      0.2292214692342827d-06,-.2156054443217641d-06,
     5      0.1679679807149858d-06,-.1140310638265938d-06,
     6      0.7950613113353278d-07,-.5420091679981868d-07,
     7      0.5927435351173097d-07,0.3365294424639201d-07,
     8      0.4635557936393118d-06,0.1757375204455676d-05/
         data arr1031/
     1      0.5255197140053867d-05,0.1258727069436946d-04,
     2      0.2391184966428488d-04,0.3782079642959984d-04,
     3      0.5107838225958590d-04,0.5965049115488129d-04,
     4      0.6109249560588111d-04,0.5570925699572977d-04,
     5      0.4577366216413349d-04,0.3412620449052022d-04,
     6      0.2316615540589413d-04,0.1438437822079677d-04,
     7      0.8373151445190508d-05,0.6081848527826715d-05,
     8      0.5511284733286619d-07,-.1396594687037729d-06/
         data arr1032/
     1      0.1724819532569292d-06,-.1616434419294781d-06,
     2      0.1255488274046253d-06,-.8482885721902300d-07,
     3      0.5895689751601679d-07,-.4007554038241916d-07,
     4      0.3923370661252379d-07,-.1235201453907974d-07,
     5      0.1451229033605497d-06,0.5629363500971780d-06,
     6      0.1888847886651394d-05,0.5149967547806701d-05,
     7      0.1083717530600912d-04,0.1886979573774731d-04,
     8      0.2786905021259272d-04,0.3525306508325082d-04/
         data arr1033/
     1      0.3876154309522590d-04,0.3764457809005472d-04,
     2      0.3267125369149464d-04,0.2549777472966171d-04,
     3      0.1795013376649756d-04,0.1145210170132992d-04,
     4      0.6785279209217353d-05,0.4952011223855629d-05,
     5      0.7955536451412847d-07,-.2023050311801172d-06,
     6      0.2511634152281810d-06,-.2366490545528285d-06,
     7      0.1845575900232183d-06,-.1257104230387138d-06,
     8      0.8762100519218170d-07,-.6092526873843601d-07/
         data arr1034/
     1      0.5650411722496582d-07,-.4102444123235368d-07,
     2      0.6782936153083015d-07,0.1806438673886166d-06,
     3      0.6125622908812557d-06,0.2048491131191534d-05,
     4      0.4702779022730069d-05,0.8985343574294635d-05,
     5      0.1467430497762963d-04,0.2031154295506977d-04,
     6      0.2421344548115298d-04,0.2543114621856680d-04,
     7      0.2387096506669581d-04,0.2012666281997955d-04,
     8      0.1526761573118535d-04,0.1047624354249181d-04/
         data arr1035/
     1      0.6699953177292897d-05,0.5420441361177465d-05,
     2      0.4230868704580903d-07,-.1072264642034444d-06,
     3      0.1324583245008819d-06,-.1242151951153832d-06,
     4      0.9648392078269780d-07,-.6533688074560743d-07,
     5      0.4533878301925610d-07,-.3113537466834922d-07,
     6      0.2891150445795680d-07,-.2227633780023976d-07,
     7      0.2769235519659059d-07,0.5327680065830965d-07,
     8      0.1898978238741216d-06,0.7525315983494495d-06/
         data arr1036/
     1      0.1874863323549821d-05,0.3898429860298021d-05,
     2      0.6877892424698637d-05,0.1015063317713231d-04,
     3      0.1277169902744888d-04,0.1402899564247010d-04,
     4      0.1363668866237921d-04,0.1178777119287753d-04,
     5      0.9083152375187720d-05,0.6277321962266487d-05,
     6      0.4005305674520218d-05,0.3176570606622981d-05,
     7      0.5800665812272909d-07,-.1476934998641810d-06,
     8      0.1837098337789268d-06,-.1734513243940271d-06/
         data arr1037/
     1      0.1354593142565452d-06,-.9258562345666999d-07,
     2      0.6455739267494402d-07,-.4531911514790699d-07,
     3      0.4145913385648396d-07,-.3318161820412205d-07,
     4      0.2796495113514665d-07,0.2286352125322849d-07,
     5      0.2997650273677406d-07,0.3026289042271422d-06,
     6      0.7514194423535847d-06,0.1670354322439881d-05,
     7      0.3323182034994210d-05,0.5392254507575590d-05,
     8      0.7335477804906660d-05,0.8718705627973241d-05/
         data arr1038/
     1      0.9206470605290468d-05,0.8640055693386730d-05,
     2      0.7199681153968446d-05,0.5365242530602195d-05,
     3      0.3706476500811959d-05,0.3276816886263180d-05,
     4      0.2151243877776902d-07,-.5465365359226947d-07,
     5      0.6776354542720991d-07,-.6379189701494283d-07,
     6      0.4969066991073905d-07,-.3385007593044274d-07,
     7      0.2352774767982979d-07,-.1641056228221733d-07,
     8      0.1502618619606395d-07,-.1209687418400249d-07/
         data arr1039/
     1      0.1017291216119723d-07,0.6268092838025327d-08,
     2      0.4525040340218797d-08,0.9134181909129786d-07,
     3      0.2332308404054026d-06,0.5493396355587656d-06,
     4      0.1155031915326160d-05,0.1952198584822381d-05,
     5      0.2744690170435249d-05,0.3349117249364461d-05,
     6      0.3603208023743499d-05,0.3420637583764999d-05,
     7      0.2866327813426420d-05,0.2136924213532416d-05,
     8      0.1468010801119881d-05,0.1274769533567242d-05/
         data arr1040/
     1      0.2642498757354698d-07,-.6746895583157126d-07,
     2      0.8426631008274453d-07,-.7987563465522188d-07,
     3      0.6257830903075900d-07,-.4299251851805077d-07,
     4      0.3006620635141846d-07,-.2135056685631596d-07,
     5      0.1940621946471148d-07,-.1563249440599743d-07,
     6      0.1167719495786159d-07,0.5881950283174314d-08,
     7      -.1288231815421668d-07,0.4615870398725448d-07,
     8      0.9123044230428660d-07,0.2073480993040880d-06/
         data arr1041/
     1      0.5224001981459975d-06,0.9794726623489901d-06,
     2      0.1474579384100226d-05,0.1942135390418331d-05,
     3      0.2279872024789254d-05,0.2360168760367938d-05,
     4      0.2142583220013437d-05,0.1722527543536191d-05,
     5      0.1281278869101503d-05,0.1241196820747011d-05,
     6      -.4696235871571729d-02,-.4356616929862478d-01,
     7      -.1045494183228609d+00,-.1395150075608279d+00,
     8      -.1303947955399105d+00,-.9508554980590990d-01/
         data arr1042/
     1      -.5752990332668120d-01,-.3003802010467007d-01,
     2      -.1390774314548093d-01,-.5825001477781237d-02,
     3      -.2240673304213381d-02,-.8010534807195550d-03,
     4      -.2686894908670711d-03,-.8520154839371351d-04,
     5      -.2569926667137491d-04,-.7410222729619507d-05,
     6      -.2050776818381669d-05,-.5464586273512895d-06,
     7      -.1405533764571750d-06,-.3497400885582223d-07,
     8      -.8434376513530965d-08,-.1967207607799894d-08/
         data arr1043/
     1      -.4379187879763172d-09,-.9304140880183489d-10,
     2      -.2987367423851437d-10,-.1004983099015653d-03,
     3      -.4834303179765321d-02,-.2779410737534494d-01,
     4      -.6669872380785331d-01,-.9645410936396707d-01,
     5      -.9925060142274113d-01,-.7965423489225928d-01,
     6      -.5278333668711598d-01,-.3000939118297342d-01,
     7      -.1504483679102396d-01,-.6788258550772768d-02,
     8      -.2800196263302853d-02,-.1069128723019085d-02/
         data arr1044/
     1      -.3815431688244103d-03,-.1282778192441344d-03,
     2      -.4088976369518111d-04,-.1242118747090294d-04,
     3      -.3610714220706726d-05,-.1007676181814465d-05,
     4      -.2706434339457152d-06,-.7008046959703769d-07,
     5      -.1753434573581496d-07,-.4258987860008799d-08,
     6      -.1010753015701601d-08,-.2517092185431528d-09,
     7      -.1301746811334027d-05,-.3285080844552445d-03,
     8      -.4524795391239564d-02,-.1952674354772734d-01/
         data arr1045/
     1      -.4369148754046556d-01,-.6344061914614879d-01,
     2      -.6753668292857966d-01,-.5679865016446331d-01,
     3      -.3965275235652893d-01,-.2379548498243168d-01,
     4      -.1259371448564026d-01,-.5994197401807114d-02,
     5      -.2605103842450640d-02,-.1046298076803219d-02,
     6      -.3921005857593958d-03,-.1381704647768754d-03,
     7      -.4607096165399686d-04,-.1460920627411874d-04,
     8      -.4423540620446875d-05,-.1283073477925269d-05/
         data arr1046/
     1      -.3574029746261298d-06,-.9578092219816414d-07,
     2      -.2472738149527609d-07,-.6189119478316080d-08,
     3      -.1761394748750959d-08,-.2503165000973737d-07,
     4      -.1629562573173209d-04,-.5379572959203206d-03,
     5      -.4174853629786139d-02,-.1445347665123526d-01,
     6      -.2961427008791514d-01,-.4181864438247371d-01,
     7      -.4463530948258966d-01,-.3826386690446600d-01,
     8      -.2748533291971245d-01,-.1706273618767153d-01/
         data arr1047/
     1      -.9370720482352208d-02,-.4635743641780683d-02,
     2      -.2095398205893109d-02,-.8752718322608817d-03,
     3      -.3409688372144629d-03,-.1247928398136592d-03,
     4      -.4316820785476065d-04,-.1418171214015486d-04,
     5      -.4441732952585621d-05,-.1330310573739657d-05,
     6      -.3818967131317835d-06,-.1052751931280087d-06,
     7      -.2803355011643956d-07,-.8383838657441667d-08,
     8      0.1630734853434593d-07,-.6471218300460820d-06/
         data arr1048/
     1      -.5056001362002778d-04,-.7056565832721910d-03,
     2      -.3779965054053301d-02,-.1092885515136792d-01,
     3      -.2047105286421622d-01,-.2773058915207463d-01,
     4      -.2919069155630997d-01,-.2509848182741383d-01,
     5      -.1827609969528069d-01,-.1158123650686231d-01,
     6      -.6521594624207553d-02,-.3317551833760209d-02,
     7      -.1544643950876392d-02,-.6652030761999896d-03,
     8      -.2672344092808866d-03,-.1008420010059952d-03/
         data arr1049/
     1      -.3594416812428016d-04,-.1215655135080673d-04,
     2      -.3915305379539026d-05,-.1204382729425418d-05,
     3      -.3547281047225121d-06,-.1007791278689778d-06,
     4      -.3243421782108905d-07,-.1502748519240552d-06,
     5      0.5198021720650359d-07,-.3970745830784401d-05,
     6      -.9875157300008276d-04,-.8186131906228062d-03,
     7      -.3339792527242302d-02,-.8298165325339033d-02,
     8      -.1426629567455302d-01,-.1844045016096772d-01/
         data arr1050/
     1      -.1897865778240823d-01,-.1621025950294910d-01,
     2      -.1185245922380523d-01,-.7597308902532297d-02,
     3      -.4349511603612464d-02,-.2257279734217137d-02,
     4      -.1074645792011367d-02,-.4738782788412880d-03,
     5      -.1950697992490148d-03,-.7543898819418142d-04,
     6      -.2755032887302957d-04,-.9541342816782351d-05,
     7      -.3144178519339744d-05,-.9885527819185681d-06,
     8      -.2988241204052947d-06,-.1025798688510570d-06/
         data arr1051/
     1      -.3037379537006033d-06,0.1484631967235694d-06,
     2      -.3370758034521951d-06,-.1176730196955821d-04,
     3      -.1513997509997065d-03,-.8715147510641537d-03,
     4      -.2872352416838090d-02,-.6267245457107417d-02,
     5      -.9947456833602996d-02,-.1225453769524619d-01,
     6      -.1227749728093400d-01,-.1035798719106227d-01,
     7      -.7557518310281759d-02,-.4869414281917733d-02,
     8      -.2816797614135156d-02,-.1482483594507844d-02/
         data arr1052/
     1      -.7175552075695593d-03,-.3222201595184746d-03,
     2      -.1352004271329591d-03,-.5331739790379075d-04,
     3      -.1985731966592218d-04,-.7011745657523638d-05,
     4      -.2354857940131329d-05,-.7589312982493431d-06,
     5      -.2802923244947974d-06,-.7169459557407260d-06,
     6      0.3515868980326986d-06,-.1936094012595080d-06,
     7      -.1142905911044521d-05,-.2447722701801321d-04,
     8      -.1984939943694337d-03,-.8678541000412443d-03/
         data arr1053/
     1      -.2403212234401279d-02,-.4683850763063309d-02,
     2      -.6906828071901789d-02,-.8116712504139324d-02,
     3      -.7901190382973582d-02,-.6562192930176422d-02,
     4      -.4758427327117011d-02,-.3068146516322045d-02,
     5      -.1785108444102217d-02,-.9484064633603558d-03,
     6      -.4645854391444283d-03,-.2114981845464442d-03,
     7      -.9006310752664672d-04,-.3606957084916814d-04,
     8      -.1364540096510401d-04,-.4893292670585575d-05/
         data arr1054/
     1      -.1679593064165880d-05,-.6644271964024814d-06,
     2      -.1624298864394929d-05,0.7962592718755290d-06,
     3      -.4039118897051208d-06,0.8542737459468017d-07,
     4      -.3593360713427577d-05,-.4008438040628697d-04,
     5      -.2327054319676482d-03,-.8177680491737932d-03,
     6      -.1957130671743558d-02,-.3454501188556067d-02,
     7      -.4761854607433022d-02,-.5348532421074434d-02,
     8      -.5056432094303622d-02,-.4126442589983786d-02/
         data arr1055/
     1      -.2965659745766946d-02,-.1907499432451009d-02,
     2      -.1112398516179951d-02,-.5944349059595912d-03,
     3      -.2936008562108902d-03,-.1350047648693133d-03,
     4      -.5814375875707384d-04,-.2356771204145920d-04,
     5      -.9024970442256168d-05,-.3300362693967328d-05,
     6      -.1401472924733488d-05,-.3404936552675128d-05,
     7      0.1668322856477328d-05,-.8439244217449761d-06,
     8      0.4075007777145118d-06,-.6450053360627874d-06/
         data arr1056/
     1      -.7205097900603470d-05,-.5611951760451705d-04,
     2      -.2501368226875050d-03,-.7351342031687683d-03,
     3      -.1553166904900742d-02,-.2511313827465032d-02,
     4      -.3254639731272087d-02,-.3502411549993878d-02,
     5      -.3216744536655746d-02,-.2576870805790410d-02,
     6      -.1832277769649526d-02,-.1172888704408303d-02,
     7      -.6837096757653923d-03,-.3663791625691791d-03,
     8      -.1819195150550306d-03,-.8426016369775526d-04/
         data arr1057/
     1      -.3659736071603779d-04,-.1496733000086219d-04,
     2      -.5833664663760055d-05,-.2664600153192345d-05,
     3      -.6265701926751678d-05,0.3070153174553831d-05,
     4      -.1553187268222832d-05,0.7668793170191406d-06,
     5      -.4103688789451168d-06,-.1045302072813995d-05,
     6      -.1234471980712157d-04,-.6947585820023255d-04,
     7      -.2508156937202847d-03,-.6342667856616993d-03,
     8      -.1202979966179219d-02,-.1798847567363692d-02/
         data arr1058/
     1      -.2203526103585434d-02,-.2277648806333924d-02,
     2      -.2033705377455052d-02,-.1598614093340022d-02,
     3      -.1123265960784654d-02,-.7142658708815461d-03,
     4      -.4152412470466300d-03,-.2226223478225553d-03,
     5      -.1108731115538492d-03,-.5157923581518324d-04,
     6      -.2250611858539935d-04,-.9330767331821791d-05,
     7      -.4561807410599729d-05,-.1077688011425449d-04,
     8      0.5282038006827140d-05,-.2673403830464930d-05/
         data arr1059/
     1      0.1321969180101252d-05,-.6221691478100486d-06,
     2      0.9082435136201461d-07,-.2578240376188250d-05,
     3      -.1764372921041073d-04,-.7840580531565260d-04,
     4      -.2372574892743790d-03,-.5279112034084032d-03,
     5      -.9107417038132891d-03,-.1269974145482373d-02,
     6      -.1477361223933054d-02,-.1470278220987852d-02,
     7      -.1277666260401344d-02,-.9854743667213543d-03,
     8      -.6835744665181831d-03,-.4311308222283345d-03/
         data arr1060/
     1      -.2496046137556558d-03,-.1337184264685676d-03,
     2      -.6667958735805385d-04,-.3108651780246853d-04,
     3      -.1375088272340791d-04,-.7258407440460642d-05,
     4      -.1619001841593812d-04,0.7934840751495341d-05,
     5      -.4015806416658262d-05,0.1985708913200983d-05,
     6      -.9265342144704881d-06,0.3842431031974748d-06,
     7      -.6297919630887058d-06,-.4085085191053162d-05,
     8      -.2263427781502800d-04,-.8185848175882027d-04/
         data arr1061/
     1      -.2137744894502043d-03,-.4253722452994322d-03,
     2      -.6752945562190108d-03,-.8841277976293445d-03,
     3      -.9806365979623990d-03,-.9420919332582487d-03,
     4      -.7976531232565603d-03,-.6034846798890518d-03,
     5      -.4128182061911049d-03,-.2579777435052103d-03,
     6      -.1485265649040187d-03,-.7923661371548323d-04,
     7      -.3932641976489618d-04,-.1843991229788914d-04,
     8      -.1035390406514673d-04,-.2450617273414785d-04/
         data arr1062/
     1      0.1201131315602067d-04,-.6079472072810463d-05,
     2      0.3006552654530091d-05,-.1402391638400773d-05,
     3      0.6173394239553065d-06,-.3424754196438778d-06,
     4      -.8008065553247699d-06,-.6099352469794878d-05,
     5      -.2617863923006151d-04,-.8041397100845950d-04,
     6      -.1843433596108485d-03,-.3333164323274695d-03,
     7      -.4911704248601173d-03,-.6070402028259813d-03,
     8      -.6447725432114572d-03,-.5993691423228463d-03/
         data arr1063/
     1      -.4946258349510529d-03,-.3670208182719308d-03,
     2      -.2477182951184723d-03,-.1534915769133418d-03,
     3      -.8782755980695921d-04,-.4660487324330758d-04,
     4      -.2334865633558658d-04,-.1421954246867620d-04,
     5      -.3102357468830422d-04,0.1520424507068637d-04,
     6      -.7694318138467669d-05,0.3804340404342763d-05,
     7      -.1773876224495770d-05,0.7842219554720952d-06,
     8      -.3462164847519719d-06,-.5245745636531985d-07/
         data arr1064/
     1      -.1573666723136259d-05,-.7769875213984571d-05,
     2      -.2829505239849462d-04,-.7446529917036590d-04,
     3      -.1535250178562632d-03,-.2546425532020896d-03,
     4      -.3505317140119184d-03,-.4116571007980504d-03,
     5      -.4201067574007135d-03,-.3779507592019939d-03,
     6      -.3039080371543306d-03,-.2211791259005659d-03,
     7      -.1470548631986195d-03,-.8977698908961685d-04,
     8      -.5050264776931858d-04,-.2666834968110956d-04/
         data arr1065/
     1      -.1712947238113186d-04,-.4160174732680454d-04,
     2      0.2039341590773734d-04,-.1032453632463906d-04,
     3      0.5107549011242306d-05,-.2383441289694753d-05,
     4      0.1055676376781901d-05,-.4521538255082450d-06,
     5      0.1439534052520921d-06,-.4405872081588768d-06,
     6      -.2098209288977127d-05,-.9440750850051167d-05,
     7      -.2808164621039124d-04,-.6631055093184323d-04,
     8      -.1238364857840147d-03,-.1896272844731740d-03/
         data arr1066/
     1      -.2463450681510506d-03,-.2762091201411215d-03,
     2      -.2709663923841886d-03,-.2362523787807749d-03,
     3      -.1857799961598633d-03,-.1330727862400184d-03,
     4      -.8722608471925739d-04,-.5250790020039916d-04,
     5      -.2967382966046464d-04,-.2076558480399364d-04,
     6      -.4319062998635118d-04,0.2116997748356567d-04,
     7      -.1071573744832545d-04,0.5299812140987347d-05,
     8      -.2472285855713862d-05,0.1094412286123691d-05/
         data arr1067/
     1      -.4664503441762280d-06,0.1784916437781039d-06,
     2      -.1671782959435861d-06,-.4775150981039857d-06,
     3      -.3056593739300986d-05,-.9872405996113813d-05,
     4      -.2697697942815980d-04,-.5672146900516674d-04,
     5      -.9641439122802742d-04,-.1385476706131369d-03,
     6      -.1705328807905941d-03,-.1820173610301010d-03,
     7      -.1714938550166665d-03,-.1449402528277940d-03,
     8      -.1108977234889146d-03,-.7705393475189939d-04/
         data arr1068/
     1      -.4875894853070837d-04,-.2874808626795730d-04,
     2      -.2090841127115050d-04,-.5228367327705878d-04,
     3      0.2563482010512570d-04,-.1298237671103739d-04,
     4      0.6425254834412193d-05,-.3000408147056229d-05,
     5      0.1330623485248738d-05,-.5689703614407477d-06,
     6      0.2267150822301464d-06,-.1281856118538468d-06,
     7      -.1789295675614010d-07,-.1073434205229011d-05,
     8      -.3135000892936105d-05,-.1040597083204654d-04/
         data arr1069/
     1      -.2467315802551096d-04,-.4619067838612562d-04,
     2      -.7363030322782733d-04,-.9982750595411186d-04,
     3      -.1160616106273732d-03,-.1184531191406621d-03,
     4      -.1082810955122963d-03,-.8943884548398776d-04,
     5      -.6683325025980264d-04,-.4531173216597863d-04,
     6      -.2864857962279318d-04,-.2281016610390531d-04,
     7      -.4418210254733541d-04,0.2165845414013815d-04,
     8      -.1096512176646272d-04,0.5424607627891629d-05/
         data arr1070/
     1      -.2531568541526312d-05,0.1121528122148301d-05,
     2      -.4784951387271274d-06,0.1903666968749490d-06,
     3      -.9594972881471585d-07,0.7120524814107043d-07,
     4      -.4315632592108517d-06,-.8587212383180434d-06,
     5      -.3822510191344127d-05,-.1019161021331046d-04,
     6      -.2083233287742235d-04,-.3679424378745320d-04,
     7      -.5469674828666849d-04,-.6875676781193571d-04,
     8      -.7528972793567333d-04,-.7342115377083206d-04/
         data arr1071/
     1      -.6420297255915331d-04,-.5031497519891664d-04,
     2      -.3544373467495478d-04,-.2309881359850633d-04,
     3      -.1884062585010234d-04,-.4862397305531532d-04,
     4      0.2384618320880536d-04,-.1208137391777971d-04,
     5      0.5982522493292051d-05,-.2795919707647314d-05,
     6      0.1241701143571481d-05,-.5324581145991468d-06,
     7      0.2148348930112087d-06,-.1075715029885482d-06,
     8      0.1122411435174976d-06,-.2827459767073248d-06/
         data arr1072/
     1      -.8400533693194741d-07,-.1371799744536977d-05,
     2      -.4140365790382451d-05,-.8842209484754963d-05,
     3      -.1755595310257784d-04,-.2899279469775897d-04,
     4      -.3955173156812436d-04,-.4678795659601435d-04,
     5      -.4944261844181121d-04,-.4681990629002096d-04,
     6      -.3953288883310483d-04,-.2986052026267410d-04,
     7      -.2089671672626866d-04,-.1872415481990704d-04,
     8      -.3005492637129040d-04,0.1473551631727447d-04/
         data arr1073/
     1      -.7462171640057904d-05,0.3692926747199191d-05,
     2      -.1724313631700516d-05,0.7645981294613800d-06,
     3      -.3268121608648980d-06,0.1308180827819862d-06,
     4      -.6430217280162215d-07,0.7090809790781870d-07,
     5      -.1516944730679074d-06,0.5859885304493594d-07,
     6      -.4711694502468033d-06,-.1568311870447654d-05,
     7      -.3465373088057934d-05,-.7635350553037650d-05,
     8      -.1369890271026371d-04,-.1987489448140546d-04/
         data arr1074/
     1      -.2481336575439153d-04,-.2749938432270866d-04,
     2      -.2705857107973856d-04,-.2350373271070515d-04,
     3      -.1810214683687889d-04,-.1281403834846007d-04,
     4      -.1149244501723882d-04,-.3019934875753273d-04,
     5      0.1481557599033122d-04,-.7510499582686625d-05,
     6      0.3721942964891267d-05,-.1741418676225272d-05,
     7      0.7748965477813208d-06,-.3336032819965057d-06,
     8      0.1360065470488402d-06,-.6885334584526132d-07/
         data arr1075/
     1      0.7612704294291162d-07,-.1421219913372620d-06,
     2      0.1242396114758506d-06,-.1774686211885885d-06,
     3      -.6693638852307886d-06,-.1257213341084495d-05,
     4      -.3287790100264454d-05,-.6708573325405479d-05,
     5      -.1046315755282380d-04,-.1403173389939993d-04,
     6      -.1690519709369265d-04,-.1809501850940559d-04,
     7      -.1697252085391328d-04,-.1402846311047511d-04,
     8      -.1067878108976664d-04,-.1055507775833508d-04/
         data arr1076/
     1      -.1253530422390002d-04,0.6148710339158586d-05,
     2      -.3116123888116384d-05,0.1543674231363490d-05,
     3      -.7218489699970951d-06,0.3209006677536736d-06,
     4      -.1378758854131549d-06,0.5593843527787750d-07,
     5      -.2806669429048599d-07,0.3126995253878223d-07,
     6      -.5807620523924265d-07,0.5652056807531901d-07,
     7      -.5475801139530365d-07,-.2153274811336588d-06,
     8      -.3734201807693635d-06,-.1089660923406314d-05/
         data arr1077/
     1      -.2372480641080569d-05,-.3841741037867848d-05,
     2      -.5327699352941232d-05,-.6614924195320577d-05,
     3      -.7245554565216258d-05,-.6904573214680580d-05,
     4      -.5764723952923776d-05,-.4410414054996008d-05,
     5      -.4350317742139304d-05,-.1124573075583964d-04,
     6      0.5520409011986297d-05,-.2801282780958261d-05,
     7      0.1390057114404028d-05,-.6516600303730976d-06,
     8      0.2909517627633652d-06,-.1261144729621590d-06/
         data arr1078/
     1      0.5229035773609728d-07,-.2719923641980151d-07,
     2      0.2975107429175996d-07,-.5222623047776700d-07,
     3      0.5318484218418609d-07,-.2478073795991032d-07,
     4      -.1132737555679483d-06,-.9637986121100876d-07,
     5      -.4179478097102396d-06,-.1093178793777551d-05,
     6      -.1864785422815322d-05,-.2742687544547895d-05,
     7      -.3712039992310856d-05,-.4441278151430179d-05,
     8      -.4573568313565436d-05,-.4094101055175511d-05/
         data arr1079/
     1      -.3366553808184065d-05,-.3660514222920631d-05,
     2      0.2421753263182013d-02,0.1389614852546330d-01,
     3      0.3334958860619129d-01,0.4822699054232300d-01,
     4      0.4962532116904678d-01,0.3982710993249198d-01,
     5      0.2639167163155475d-01,0.1500469382379061d-01,
     6      0.7522419397371544d-02,0.3394128915028600d-02,
     7      0.1400097879823928d-02,0.5345649359459416d-03,
     8      0.1907712296658774d-03,0.6413873543214304d-04/
         data arr1080/
     1      0.2044523179400208d-04,0.6210618659267976d-05,
     2      0.1805094228596784d-05,0.5038018438460227d-06,
     3      0.1355065940297034d-06,0.3513802108483760d-07,
     4      0.8686640888514918d-08,0.2008281990199267d-08,
     5      0.4690769133663021d-09,0.2124960189154688d-09,
     6      0.2078392640594045d-03,0.2861718315526112d-02,
     7      0.1234980029426020d-01,0.2763292205429104d-01,
     8      0.4012337079505557d-01,0.4271394864556222d-01/
         data arr1081/
     1      0.3592262054590947d-01,0.2507860257462093d-01,
     2      0.1504958612220916d-01,0.7964964386808295d-02,
     3      0.3791063318301722d-02,0.1647612328702090d-02,
     4      0.6617370011499143d-03,0.2479861989731570d-03,
     5      0.8738667026020725d-04,0.2913781842569824d-04,
     6      0.9239675378699478d-05,0.2797700664899088d-05,
     7      0.8114763585566516d-06,0.2260169029552465d-06,
     8      0.6055773345779357d-07,0.1563090555381015d-07/
         data arr1082/
     1      0.3908240908791668d-08,0.1086289789699431d-08,
     2      0.1153246116652603d-04,0.3803894202203699d-03,
     3      0.2952068665001932d-02,0.1022015086739883d-01,
     4      0.2094045138777712d-01,0.2957024696349067d-01,
     5      0.3156193002360757d-01,0.2705663976610776d-01,
     6      0.1943506529170725d-01,0.1206517644526591d-01,
     7      0.6626100028890683d-02,0.3277965741220680d-02,
     8      0.1481670269255498d-02,0.6189106776009011d-03/
         data arr1083/
     1      0.2411013681992695d-03,0.8824183217309951d-04,
     2      0.3052453428400043d-04,0.1002800048695076d-04,
     3      0.3140766080820672d-05,0.9406308941178016d-06,
     4      0.2700023648097071d-06,0.7441492058798928d-07,
     5      0.1979531626184600d-07,0.5833592156278231d-08,
     6      0.4717186649010332d-06,0.3822711269191043d-04,
     7      0.5334238313481882d-03,0.2857385752549279d-02,
     8      0.8261437682053133d-02,0.1547466154110941d-01/
         data arr1084/
     1      0.2096235494831986d-01,0.2206608875820183d-01,
     2      0.1897266889432063d-01,0.1381543273832594d-01,
     3      0.8754591984848117d-02,0.4929862096982397d-02,
     4      0.2507833409474912d-02,0.1167641149742771d-02,
     5      0.5028462600253715d-03,0.2020101097629561d-03,
     6      0.7622933123678642d-04,0.2717125673800947d-04,
     7      0.9189435480930806d-05,0.2959506422322590d-05,
     8      0.9101961567475636d-06,0.2679612886836090d-06/
         data arr1085/
     1      0.7601763730410782d-07,0.2409983167134803d-07,
     2      0.7087278286747747d-08,0.3115660596091615d-05,
     3      0.7808126224748744d-04,0.6471653315380446d-03,
     4      0.2640340219525591d-02,0.6560274584894390d-02,
     5      0.1127849757667119d-01,0.1457845556218425d-01,
     6      0.1500394666409505d-01,0.1281533506019661d-01,
     7      0.9370191973357362d-02,0.6006200096746211d-02,
     8      0.3438590460350216d-02,0.1784536574194359d-02/
         data arr1086/
     1      0.8495822899988581d-03,0.3746332459238928d-03,
     2      0.1542159645760505d-03,0.5964000409578283d-04,
     3      0.2178054980777850d-04,0.7542657163784093d-05,
     4      0.2485034141071542d-05,0.7810452117171392d-06,
     5      0.2359010394838358d-06,0.7994507114666480d-07,
     6      -.1334501095576959d-07,0.2224654085803975d-06,
     7      0.9633859931090644d-05,0.1236052314778021d-03,
     8      0.7115942135104050d-03,0.2345263634248200d-02/
         data arr1087/
     1      0.5117185386000585d-02,0.8122064071083875d-02,
     2      0.1000578858355856d-01,0.1002453370093349d-01,
     3      0.8457262075322899d-02,0.6170687489924004d-02,
     4      0.3975859201132147d-02,0.2299906643455680d-02,
     5      0.1210442951801154d-02,0.5858798980613571d-03,
     6      0.2630910897771429d-03,0.1103912656086781d-03,
     7      0.4353312546744089d-04,0.1621146794629888d-04,
     8      0.5722720737441945d-05,0.1921074833319487d-05/
         data arr1088/
     1      0.6183222445336388d-06,0.2247481111033671d-06,
     2      -.7177623696182557d-07,0.5256603793031059d-07,
     3      0.1011610076116529d-05,0.2045265209199606d-04,
     4      0.1660838575283988d-03,0.7260937814966730d-03,
     5      0.2010673566054508d-02,0.3918789784276220d-02,
     6      0.5778667987205797d-02,0.6790926910713859d-02,
     7      0.6610612352048416d-02,0.5490323681013076d-02,
     8      0.3981183756799021d-02,0.2566997911938420d-02/
         data arr1089/
     1      0.1493529426585338d-02,0.7934905075948052d-03,
     2      0.3886989800476009d-03,0.1769540368000691d-03,
     3      0.7535238706994689d-04,0.3017448826885834d-04,
     4      0.1141209237162487d-04,0.4091015737150575d-05,
     5      0.1402822288617509d-05,0.5466845568534360d-06,
     6      -.1389886957175730d-06,0.7704403963446293d-07,
     7      0.6200281069278624d-07,0.2999996698240908d-05,
     8      0.3421321636801852d-04,0.1984391567037024d-03/
         data arr1090/
     1      0.6974001682370669d-03,0.1669043957106797d-02,
     2      0.2946011318064351d-02,0.4060918470875943d-02,
     3      0.4561248677612196d-02,0.4312138327552421d-02,
     4      0.3519036636414803d-02,0.2529128382701571d-02,
     5      0.1626722467069516d-02,0.9486484341059001d-03,
     6      0.5069317108000808d-03,0.2503863492978067d-03,
     7      0.1151305840229666d-03,0.4957389690367390d-04,
     8      0.2008442271500508d-04,0.7685903305129132d-05/
         data arr1091/
     1      0.2805997604123367d-05,0.1170889694188644d-05,
     2      -.2858303795120641d-06,0.1577296393078843d-06,
     3      -.6469009089507146d-07,0.4212655580903117d-06,
     4      0.6301686415441922d-05,0.4857412846661550d-04,
     5      0.2166357140986875d-03,0.6366394539609408d-03,
     6      0.1345087744026565d-02,0.2174851459006956d-02,
     7      0.2818611362802794d-02,0.3033173874424854d-02,
     8      0.2785771253128024d-02,0.2231647237897589d-02/
         data arr1092/
     1      0.1586802351417288d-02,0.1015735179110048d-02,
     2      0.5921043801591116d-03,0.3173037990111569d-03,
     3      0.1575485574675692d-03,0.7295474109932830d-04,
     4      0.3167261130430639d-04,0.1294801975770848d-04,
     5      0.5041365365514106d-05,0.2264648544727258d-05,
     6      -.5531563389313881d-06,0.3061014521156830d-06,
     7      -.1417476985030754d-06,0.1072830485974170d-06,
     8      0.1030334783381155d-05,0.1077815395872670d-04/
         data arr1093/
     1      0.6095390283440431d-04,0.2199703366643359d-03,
     2      0.5562990477051005d-03,0.1055064608592822d-02,
     3      0.1577713719257975d-02,0.1932613244072705d-02,
     4      0.1997609496428254d-02,0.1783699109819501d-02,
     5      0.1402081807856434d-02,0.9851363994074123d-03,
     6      0.6264371199689156d-03,0.3642004713825351d-03,
     7      0.1952424745781733d-03,0.9719476512504018d-04,
     8      0.4518031258502791d-04,0.1969637961289454d-04/
         data arr1094/
     1      0.8148942985160889d-05,0.3904511438386319d-05,
     2      -.1015517550844381d-05,0.5647078881072389d-06,
     3      -.2654786081266860d-06,0.1210890552291310d-06,
     4      0.1121149664350638d-06,0.2203143588093857d-05,
     5      0.1567166718995921d-04,0.6948404300631584d-04,
     6      0.2103230542747586d-03,0.4679115286103299d-03,
     7      0.8073213067336092d-03,0.1125698538205030d-02,
     8      0.1309506113232040d-02,0.1303300632038207d-02/
         data arr1095/
     1      0.1132538702518986d-02,0.8734775213006638d-03,
     2      0.6059081579965536d-03,0.3821898196182866d-03,
     3      0.2212552015095702d-03,0.1184751800082298d-03,
     4      0.5903765669782534d-04,0.2751259758884461d-04,
     5      0.1215601181746349d-04,0.6296625209480181d-05,
     6      -.1469072632750095d-05,0.8149932354987939d-06,
     7      -.3812868621442389d-06,0.1657339645202626d-06,
     8      -.4624787909795471d-07,0.4356503550653741d-06/
         data arr1096/
     1      0.3704491847742521d-05,0.2022011257714559d-04,
     2      0.7324309314490596d-04,0.1911567407490419d-03,
     3      0.3805176745336415d-03,0.6039828028851581d-03,
     4      0.7907335491306922d-03,0.8771648781069612d-03,
     5      0.8426431968334828d-03,0.7133527062180058d-03,
     6      0.5397276903919005d-03,0.3692540354967359d-03,
     7      0.2307034138844844d-03,0.1327058155937888d-03,
     8      0.7070260553816262d-04,0.3504607029995928d-04/
         data arr1097/
     1      0.1638793087154044d-04,0.8990285788108434d-05,
     2      -.2363147708840404d-05,0.1318047082016982d-05,
     3      -.6237574411681766d-06,0.2758563755457998d-06,
     4      -.1159649157551745d-06,0.1220921225844256d-06,
     5      0.7934802437503906d-06,0.5464931336341353d-05,
     6      0.2363411885252016d-04,0.7241128273033247d-04,
     7      0.1662474977189435d-03,0.3004141295784553d-03,
     8      0.4426562694277212d-03,0.5472692066131227d-03/
         data arr1098/
     1      0.5812078024294237d-03,0.5401426727325305d-03,
     2      0.4458163659517647d-03,0.3309075135929335d-03,
     3      0.2233002242622350d-03,0.1382321438001848d-03,
     4      0.7901458753349879d-04,0.4191663694642181d-04,
     5      0.2097618655911188d-04,0.1250684077553213d-04,
     6      -.2898326203278535d-05,0.1613110241431140d-05,
     7      -.7599222586453301d-06,0.3333694569820524d-06,
     8      -.1415772170026139d-06,0.7159538059885482d-07/
         data arr1099/
     1      0.1418879869713926d-06,0.1383875603253539d-05,
     2      0.7100121789786320d-05,0.2558306166153390d-04,
     3      0.6768164096958419d-04,0.1392808052061893d-03,
     4      0.2309806361181477d-03,0.3182148742907423d-03,
     5      0.3735876116187422d-03,0.3810591543739409d-03,
     6      0.3428895918707638d-03,0.2758114069792935d-03,
     7      0.2006124605057652d-03,0.1331420788868649d-03,
     8      0.8110905105280913d-04,0.4555034122701294d-04/
         data arr1100/
     1      0.2397014726537898d-04,0.1499004472622913d-04,
     2      -.4297951241674151d-05,0.2411997112247456d-05,
     3      -.1156325744064663d-05,0.5226242623528116d-06,
     4      -.2330327139406701d-06,0.1085043145895801d-06,
     5      -.1989862714267498d-07,0.3549841940741188d-06,
     6      0.1971694478030687d-05,0.8496249716400066d-05,
     7      0.2578057299237137d-04,0.6046689693179044d-04,
     8      0.1129180054950404d-03,0.1732654822861418d-03/
         data arr1101/
     1      0.2249033216155428d-03,0.2519355050596250d-03,
     2      0.2473129017564636d-03,0.2158125766772440d-03,
     3      0.1696122923176501d-03,0.1212753470043681d-03,
     4      0.7938596376001548d-04,0.4779992088269388d-04,
     5      0.2699017314812614d-04,0.1844808667856050d-04,
     6      -.4208223022376941d-05,0.2353145218646379d-05,
     7      -.1119612589049336d-05,0.4996253489028299d-06,
     8      -.2185361475785387d-06,0.9730988539357014d-07/
         data arr1102/
     1      -.3882541035524415d-07,0.9754085807124958d-07,
     2      0.5024659311172249d-06,0.2674110635387599d-05,
     3      0.9210994973329458d-05,0.2469196464938110d-04,
     4      0.5190864868375386d-04,0.8863659608563485d-04,
     5      0.1271508382980499d-03,0.1562232636320395d-03,
     6      0.1668800256404661d-03,0.1573655777118895d-03,
     7      0.1328007424756476d-03,0.1012612085493494d-03,
     8      0.7012707331001179d-04,0.4428352968577125d-04/
         data arr1103/
     1      0.2599669580130103d-04,0.1833862081055323d-04,
     2      -.5754519469720111d-05,0.3248823344593597d-05,
     3      -.1576897813403835d-05,0.7273147181812672d-06,
     4      -.3341091087501354d-06,0.1600827353031437d-06,
     5      -.8279774623174118d-07,0.7064079241077071d-07,
     6      0.7834190761412370d-07,0.8391950941437514d-06,
     7      0.3080031530979675d-05,0.9498145740851424d-05,
     8      0.2259274959123874d-04,0.4279530789347336d-04/
         data arr1104/
     1      0.6790107767175167d-04,0.9177415747714300d-04,
     2      0.1069653652284938d-03,0.1094055389728634d-03,
     3      0.9986145254839567d-04,0.8221848030288036d-04,
     4      0.6134723826360704d-04,0.4164809633411503d-04,
     5      0.2632439891399391d-04,0.2042591482880504d-04,
     6      -.4500060572982355d-05,0.2529679703821811d-05,
     7      -.1216976331180800d-05,0.5532215245746436d-06,
     8      -.2488557244126865d-06,0.1155562413455307d-06/
         data arr1105/
     1      -.5736205481195173d-07,0.3948889390427005d-07,
     2      -.5933352718527132d-08,0.2670271996552117d-06,
     3      0.9553108168525599d-06,0.3464697797738309d-05,
     4      0.9293271345076608d-05,0.1945636244502957d-04,
     5      0.3406363717140306d-04,0.5034878581244903d-04,
     6      0.6348663430718052d-04,0.6966234161092210d-04,
     7      0.6770304856675595d-04,0.5884745238599257d-04,
     8      0.4591324510143122d-04,0.3227892326355887d-04/
         data arr1106/
     1      0.2093571049457429d-04,0.1650785520491512d-04,
     2      -.5808840570237365d-05,0.3301824286876024d-05,
     3      -.1624790697040156d-05,0.7658925605118556d-06,
     4      -.3626233856083494d-06,0.1812116985277662d-06,
     5      -.1009551271128993d-06,0.7119742476767975d-07,
     6      -.5871294359012363d-07,0.1275332054720075d-06,
     7      0.2615311365861047d-06,0.1170235459940029d-05,
     8      0.3714189635796377d-05,0.8421239948881815d-05/
         data arr1107/
     1      0.1631846930005867d-04,0.2670377378143230d-04,
     2      0.3675101543133113d-04,0.4369474683706980d-04,
     3      0.4600525943727360d-04,0.4333549359348616d-04,
     4      0.3656269533515123d-04,0.2771628429690570d-04,
     5      0.1941296807583716d-04,0.1692173309424802d-04,
     6      -.3234108017299918d-05,0.1828321921561531d-05,
     7      -.8898116706418473d-06,0.4121780068638531d-06,
     8      -.1905090097227364d-06,0.9207742656294033d-07/
         data arr1108/
     1      -.4887748356073560d-07,0.3296107963876144d-07,
     2      -.3025183160176735d-07,0.5284741172628598d-07,
     3      0.5813266188591362d-07,0.3817681109207201d-06,
     4      0.1368928280961831d-05,0.3349729300510269d-05,
     5      0.7108267946621936d-05,0.1256249319424399d-04,
     6      0.1840110338070424d-04,0.2307420678685803d-04,
     7      0.2539836772820237d-04,0.2475544591460801d-04,
     8      0.2138899116352335d-04,0.1645003990277373d-04/
         data arr1109/
     1      0.1158459832255123d-04,0.1001144535676500d-04,
     2      -.3952933974809374d-05,0.2261655599459145d-05,
     3      -.1127489947600825d-05,0.5421489537269801d-06,
     4      -.2635142859201744d-06,0.1362776354833520d-06,
     5      -.7952342414140738d-07,0.5756602575274377d-07,
     6      -.5150784856239424d-07,0.5270792093907184d-07,
     7      0.2007925579312084d-08,0.9035005319751622d-07,
     8      0.5509398419245408d-06,0.1308189347704137d-05/
         data arr1110/
     1      0.3068500233196342d-05,0.6130074586538467d-05,
     2      0.9805284673433377d-05,0.1327871702494607d-04,
     3      0.1586888111848857d-04,0.1685275554842119d-04,
     4      0.1582129287283543d-04,0.1316177450078356d-04,
     5      0.1003806985325565d-04,0.9633914476872798d-05,
     6      -.1501909353565819d-05,0.8566763164416400d-06,
     7      -.4244812185137299d-06,0.2022285830662617d-06,
     8      -.9711349795889040d-07,0.4944753299840828d-07/
         data arr1111/
     1      -.2827190871828849d-07,0.2015132812049156d-07,
     2      -.1833370448147062d-07,0.1921784496413644d-07,
     3      -.3998957672356387d-08,0.2241565674044114d-07,
     4      0.1662728483530430d-06,0.4016222238024302d-06,
     5      0.1011499791416906d-05,0.2134367824442404d-05,
     6      0.3549283675347782d-05,0.4965472406473565d-05,
     7      0.6090679093333519d-05,0.6586390289095885d-05,
     8      0.6250549835283027d-05,0.5225776214547589d-05/
         data arr1112/
     1      0.3982850071664704d-05,0.3782406226409351d-05,
     2      -.1672899303221584d-05,0.9644957252353226d-06,
     3      -.4880441797632579d-06,0.2399050922023959d-06,
     4      -.1198863433881536d-06,0.6414909482860551d-07,
     5      -.3905034452225367d-07,0.2910014173395389d-07,
     6      -.2547066414840219d-07,0.2158954202851230d-07,
     7      -.4167023515361332d-08,-.1046914776859530d-07,
     8      0.8322840212818977d-07,0.1425999670535364d-06/
         data arr1113/
     1      0.3869179919948379d-06,0.9810035376874325d-06,
     2      0.1781054398779381d-05,0.2663021102035705d-05,
     3      0.3547444753317981d-05,0.4203312092564066d-05,
     4      0.4350979871718071d-05,0.3938814258850865d-05,
     5      0.3251060094127857d-05,0.3429606922604724d-05,
     6      -.8480279234222382d-04,-.1168301826860088d-02,
     7      -.5041782252869108d-02,-.1128109394876854d-01,
     8      -.1638029730076528d-01,-.1743789660269388d-01/
         data arr1114/
     1      -.1466534838487869d-01,-.1023829665099161d-01,
     2      -.6143967793401611d-02,-.3251683099942085d-02,
     3      -.1547695120576481d-02,-.6726349099450386d-03,
     4      -.2701530051257204d-03,-.1012399417031844d-03,
     5      -.3567545418760196d-04,-.1189546637197818d-04,
     6      -.3772083860511576d-05,-.1142153395546232d-05,
     7      -.3312798495705899d-06,-.9227000629422503d-07,
     8      -.2472248309877982d-07,-.6379020998055413d-08/
         data arr1115/
     1      -.1590783706810552d-08,-.4348729411952378d-09,
     2      -.6142550362819955d-05,-.2033328502884712d-03,
     3      -.1577945204093837d-02,-.5462901039540076d-02,
     4      -.1119314186491199d-01,-.1580596193530428d-01,
     5      -.1687056119990055d-01,-.1446238230599816d-01,
     6      -.1038847936249240d-01,-.6449108092567769d-02,
     7      -.3541799435152591d-02,-.1752146392387529d-02,
     8      -.7919860805888786d-03,-.3308216619499797d-03/
         data arr1116/
     1      -.1288741000396186d-03,-.4716725254344747d-04,
     2      -.1631604764938813d-04,-.5360179271355195d-05,
     3      -.1678803575176150d-05,-.5027891586275210d-06,
     4      -.1443192307107882d-06,-.3976297287150949d-07,
     5      -.1055871300012885d-07,-.3072836154205966d-08,
     6      -.1599683807317972d-06,-.2343668746092153d-04,
     7      -.3266471143614962d-03,-.1749786300079194d-02,
     8      -.5059076048257984d-02,-.9476256438029044d-02/
         data arr1117/
     1      -.1283676823547140d-01,-.1351266459102467d-01,
     2      -.1161833941152751d-01,-.8460190228867724d-02,
     3      -.5361070812068491d-02,-.3018911628152200d-02,
     4      -.1535728096784882d-02,-.7150312422645384d-03,
     5      -.3079291430467715d-03,-.1237054378989318d-03,
     6      -.4668075254323624d-04,-.1663886571882653d-04,
     7      -.5627266647702329d-05,-.1812260418579203d-05,
     8      -.5573333233680647d-06,-.1640142935619780d-06/
         data arr1118/
     1      -.4641939911714203d-07,-.1447486602411632d-07,
     2      0.2647464397799506d-06,-.2149726396156089d-05,
     3      -.5203110155460290d-04,-.4314517209106462d-03,
     4      -.1760223625008281d-02,-.4373517779395076d-02,
     5      -.7518997684564567d-02,-.9718970803314780d-02,
     6      -.1000263079307485d-01,-.8543556930227184d-02,
     7      -.6246794581150962d-02,-.4004133237395999d-02,
     8      -.2292393914316179d-02,-.1189690937762321d-02/
         data arr1119/
     1      -.5663879710854752d-03,-.2497556757511084d-03,
     2      -.1028107753449122d-03,-.3975976999899409d-04,
     3      -.1452011181736874d-04,-.5028436961941626d-05,
     4      -.1656766178520504d-05,-.5205751969452065d-06,
     5      -.1568706543807469d-06,-.5235960462056997d-07,
     6      0.1272016302318946d-05,-.4739938203176678d-06,
     7      -.6718509874119326d-05,-.8743333395755582d-04,
     8      -.5031615814606116d-03,-.1658356554209073d-02/
         data arr1120/
     1      -.3618394237891450d-02,-.5743167882115359d-02,
     2      -.7075160025913334d-02,-.7088416440742073d-02,
     3      -.5980187082302639d-02,-.4363334604661132d-02,
     4      -.2811357763104584d-02,-.1626279163915648d-02,
     5      -.8559118446676032d-03,-.4142801552363924d-03,
     6      -.1860336678458484d-03,-.7805751848267737d-04,
     7      -.3078166263994001d-04,-.1146299207195297d-04,
     8      -.4046418584492229d-05,-.1357629795013151d-05/
         data arr1121/
     1      -.4357003947257277d-06,-.1557518580883139d-06,
     2      0.3280718429131386d-05,-.8406929330987586d-06,
     3      -.5118100027900691d-06,-.1518326941543608d-04,
     4      -.1226324393288418d-03,-.5362675533090967d-03,
     5      -.1484975246744993d-02,-.2894221313551741d-02,
     6      -.4267826817370634d-02,-.5015433596647407d-02,
     7      -.4882260135573902d-02,-.4054871785397305d-02,
     8      -.2940300993237766d-02,-.1895852632892864d-02/
         data arr1122/
     1      -.1103043116638854d-02,-.5860329331880073d-03,
     2      -.2870739966342957d-03,-.1306874188775488d-03,
     3      -.5564965083309950d-04,-.2228536674115435d-04,
     4      -.8428791658535340d-05,-.3020229145034586d-05,
     5      -.1032777276699554d-05,-.3959817166198735d-06,
     6      0.7454977795193106d-05,-.1895155495245886d-05,
     7      0.4951700303485326d-06,-.2472374670102616d-05,
     8      -.2606379220695506d-04,-.1515881743392050d-03/
         data arr1123/
     1      -.5326348192603401d-03,-.1274761227736934d-02,
     2      -.2250047630110537d-02,-.3101581799083500d-02,
     3      -.3483709735048387d-02,-.3293447515878789d-02,
     4      -.2687713385519731d-02,-.1931651429533118d-02,
     5      -.1242426026620435d-02,-.7245453217198215d-03,
     6      -.3871772302440971d-03,-.1912309068383795d-03,
     7      -.8792731084460395d-04,-.3786187317769255d-04,
     8      -.1533993952835090d-04,-.5866680894349856d-05/
         data arr1124/
     1      -.2134616992791497d-05,-.8749900881494534d-06,
     2      0.1658964184331101d-04,-.4214785308736770d-05,
     3      0.1259433998606614d-05,-.7337172930364624d-06,
     4      -.4794462483512431d-05,-.3816630375085566d-04,
     5      -.1699135007443014d-03,-.4994383489588259d-03,
     6      -.1055161159830082d-02,-.1706102906297403d-02,
     7      -.2211097194543531d-02,-.2379412027846229d-02,
     8      -.2185349220118450d-02,-.1750642902412107d-02/
         data arr1125/
     1      -.1244782235726431d-02,-.7968156482212774d-03,
     2      -.4644891777328182d-03,-.2489038992595820d-03,
     3      -.1235817583752218d-03,-.5723079223772429d-04,
     4      -.2484851953128365d-04,-.1015122533380046d-04,
     5      -.3937690427043600d-05,-.1736621631855990d-05,
     6      0.3136114677894351d-04,-.7966838693972324d-05,
     7      0.2392111714896666d-05,-.8450471377512350d-06,
     8      -.5461721660494536d-06,-.8757273679050489d-05/
         data arr1126/
     1      -.4881663649108809d-04,-.1764008159157552d-03,
     2      -.4460083190310885d-03,-.8459505110527902d-03,
     3      -.1264978585351162d-02,-.1549528141681308d-02,
     4      -.1601670159474904d-02,-.1430131043488753d-02,
     5      -.1124151792641792d-02,-.7898802624165619d-03,
     6      -.5022749906519852d-03,-.2919921687463969d-03,
     7      -.1565251718069134d-03,-.7793070683702304d-04,
     8      -.3623024871695480d-04,-.1578178283989467d-04/
         data arr1127/
     1      -.6502745282685687d-05,-.3057548435899952d-05,
     2      0.5585570935949481d-04,-.1419295318855718d-04,
     3      0.4264411614104873d-05,-.1445165859101482d-05,
     4      0.4038979074400919d-06,-.2002709272166566d-05,
     5      -.1269884540745588d-04,-.5678976232400695d-04,
     6      -.1716875227970416d-03,-.3820778710344922d-03,
     7      -.6591629809451252d-03,-.9191126334177075d-03,
     8      -.1069241124417782d-02,-.1064122501544721d-02/
         data arr1128/
     1      -.9246888210930200d-03,-.7132161219639985d-03,
     2      -.4947346755353184d-03,-.3120237635095667d-03,
     3      -.1806227864011901d-03,-.9673531072297280d-04,
     4      -.4821020933782082d-04,-.2244122729740036d-04,
     5      -.9866454210006725d-05,-.5006739837834204d-05,
     6      0.8525730639969763d-04,-.2166277459805435d-04,
     7      0.6508234503147076d-05,-.2199461929340601d-05,
     8      0.7983237935775640d-06,-.6745218924241113d-06/
         data arr1129/
     1      -.2922109099155104d-05,-.1685262447624170d-04,
     2      -.6066720313134615d-04,-.1585446961819221d-03,
     3      -.3154902481497100d-03,-.5007702113539053d-03,
     4      -.6556943750094541d-03,-.7272796244001598d-03,
     5      -.6986443067554422d-03,-.5915214014136970d-03,
     6      -.4475441399991908d-03,-.3061273118289190d-03,
     7      -.1912529031852770d-03,-.1100510995058164d-03,
     8      -.5865213540051607d-04,-.2904295932596290d-04/
         data arr1130/
     1      -.1351485255921745d-04,-.7268417833679190d-05,
     2      0.1328494861732309d-03,-.3375859494223583d-04,
     3      0.1014394841002348d-04,-.3428402784566412d-05,
     4      0.1271909682147210d-05,-.5846037988814804d-06,
     5      -.4381475903387201d-06,-.4723401541634750d-05,
     6      -.1976167117567670d-04,-.6090795795045750d-04,
     7      -.1396457965440166d-03,-.2523616328756271d-03,
     8      -.3719852104198054d-03,-.4597536687978391d-03/
         data arr1131/
     1      -.4882541951751543d-03,-.4538699854735363d-03,
     2      -.3745879538266902d-03,-.2779365524608765d-03,
     3      -.1875335883849348d-03,-.1161371337772051d-03,
     4      -.6639416177790149d-04,-.3515519780330076d-04,
     5      -.1747667361715997d-04,-.1018368688340854d-04,
     6      0.1701729740155756d-03,-.4323871303496473d-04,
     7      0.1299032298675723d-04,-.4389234582730306d-05,
     8      0.1630690687063438d-05,-.6816840356461394d-06/
         data arr1132/
     1      0.1743389954514206d-06,-.1346788118314382d-05,
     2      -.5910908566450662d-05,-.2183238318950123d-04,
     3      -.5748006620252421d-04,-.1183175792795884d-03,
     4      -.1963997505161862d-03,-.2703753386170394d-03,
     5      -.3174168077356505d-03,-.3239261574887162d-03,
     6      -.2914598196045542d-03,-.2343282357266924d-03,
     7      -.1704442740302701d-03,-.1132186335055032d-03,
     8      -.6902170614100744d-04,-.3871103840978625d-04/
         data arr1133/
     1      -.2025399075001818d-04,-.1240884135984771d-04,
     2      0.2330430281634902d-03,-.5922887087263386d-04,
     3      0.1780262580692243d-04,-.6019319312291330d-05,
     4      0.2238746840471943d-05,-.9251519759366228d-06,
     5      0.4082410302932461d-06,-.5283252708298823d-06,
     6      -.1532046355729584d-05,-.7413890615448296d-05,
     7      -.2207411733777769d-04,-.5184776771728725d-04,
     8      -.9706260738064838d-04,-.1486485050866155d-03/
         data arr1134/
     1      -.1929612417650254d-03,-.2163641301405436d-03,
     2      -.2123295518537182d-03,-.1851024320050224d-03,
     3      -.1454579277865807d-03,-.1040910217489726d-03,
     4      -.6814001713315002d-04,-.4089958813011714d-04,
     5      -.2289220237838788d-04,-.1525505384073272d-04,
     6      0.2438206977213907d-03,-.6196086648642532d-04,
     7      0.1861996315678988d-04,-.6293800915364268d-05,
     8      0.2339929229327899d-05,-.9650645360249849d-06/
         data arr1135/
     1      0.4497404462849685d-06,-.3238026623058120d-06,
     2      -.2628987067138077d-06,-.2444806291971518d-05,
     3      -.7919539996413494d-05,-.2132007332687225d-04,
     4      -.4510067685161867d-04,-.7668055038308471d-04,
     5      -.1100223059612943d-03,-.1354318331907791d-03,
     6      -.1446237217824073d-03,-.1362190047244742d-03,
     7      -.1149977112581607d-03,-.8785682549034815d-04,
     8      -.6092651863055576d-04,-.3840872551291999d-04/
         data arr1136/
     1      -.2239829182073739d-04,-.1547574230005461d-04,
     2      0.3000321413217692d-03,-.7627060253551226d-04,
     3      0.2293349811737538d-04,-.7758384747364972d-05,
     4      0.2887775738145631d-05,-.1192798573570877d-05,
     5      0.5628611168637217d-06,-.3389893589416552d-06,
     6      0.1299678868498334d-06,-.8845946058047624d-06,
     7      -.2612267376844150d-05,-.8228070835943017d-05,
     8      -.1988660001033039d-04,-.3724410769455102d-04/
         data arr1137/
     1      -.5915628855664891d-04,-.8023984516968476d-04,
     2      -.9339876879506769d-04,-.9528981854806562d-04,
     3      -.8698051174966544d-04,-.7173100054077470d-04,
     4      -.5350530426226040d-04,-.3614060024360993d-04,
     5      -.2258489440267668d-04,-.1704671566806938d-04,
     6      0.2555938164173125d-03,-.6496197897753947d-04,
     7      0.1952674140160084d-04,-.6602740565912490d-05,
     8      0.2456055185784373d-05,-.1013526109877084d-05/
         data arr1138/
     1      0.4781703995989841d-06,-.2786158260773544d-06,
     2      0.1804358406217841d-06,-.3681339738944904d-06,
     3      -.7760194010642551d-06,-.2986186125494734d-05,
     4      -.8319440185548181d-05,-.1701570206871946d-04,
     5      -.2985786830029416d-04,-.4442074974264966d-04,
     6      -.5593502177977273d-04,-.6121169656466975d-04,
     7      -.5957055689125800d-04,-.5198127264607341d-04,
     8      -.4064443912707082d-04,-.2850757468325765d-04/
         data arr1139/
     1      -.1834660070376107d-04,-.1416743994342086d-04,
     2      0.2846473436344052d-03,-.7237849066667341d-04,
     3      0.2177317433331747d-04,-.7370743913221235d-05,
     4      0.2745972730867306d-05,-.1135703083409260d-05,
     5      0.5378951569928471d-06,-.3124733134013243d-06,
     6      0.2294481186476517d-06,-.2524742657768417d-06,
     7      -.1538091507117419d-06,-.9891570661251208d-06,
     8      -.3433875347175081d-05,-.7338144620511913d-05/
         data arr1140/
     1      -.1434100217503719d-04,-.2374640357384248d-04,
     2      -.3251831251393106d-04,-.3843665356505652d-04,
     3      -.4050371917792581d-04,-.3826786383972355d-04,
     4      -.3224627427395442d-04,-.2425139362145489d-04,
     5      -.1674334168522261d-04,-.1416913768384230d-04,
     6      0.1770578475253310d-03,-.4500922096782354d-04,
     7      0.1353343904295256d-04,-.4578237755838084d-05,
     8      0.1704023347652802d-05,-.7038072993055062d-06/
         data arr1141/
     1      0.3326261365353125d-06,-.1924260843302163d-06,
     2      0.1437665445494601d-06,-.1377405030340379d-06,
     3      -.4893104184056016d-08,-.3045294057423669d-06,
     4      -.1318995792216343d-05,-.2918165627934657d-05,
     5      -.6275399887171873d-05,-.1130246976999977d-04,
     6      -.1647735804037027d-04,-.2054757656876469d-04,
     7      -.2269304995405134d-04,-.2226715785539867d-04,
     8      -.1929393873024378d-04,-.1478828248799919d-04/
         data arr1142/
     1      -.1032188033023176d-04,-.8737753372079354d-05,
     2      0.1791985936477652d-03,-.4558178774788940d-04,
     3      0.1372068402381781d-04,-.4648978594530995d-05,
     4      0.1734080639194090d-05,-.7184454864272891d-06,
     5      0.3412357046352162d-06,-.1986819825939390d-06,
     6      0.1500539019622837d-06,-.1315004306614307d-06,
     7      0.5050840137248196d-07,-.6116934376872878d-07,
     8      -.5789430029695686d-06,-.1095274094431521d-05/
         data arr1143/
     1      -.2692840810368793d-05,-.5556793553310491d-05,
     2      -.8755727934380478d-05,-.1172219292135913d-04,
     3      -.1405349682412386d-04,-.1499837448748762d-04,
     4      -.1403922232882164d-04,-.1154828679605173d-04,
     5      -.8657825408319841d-05,-.8057219643320663d-05,
     6      0.7516737298193237d-04,-.1911691143753893d-04,
     7      0.5752824270483469d-05,-.1948435932015026d-05,
     8      0.7263664016742999d-06,-.3006957497293428d-06/
         data arr1144/
     1      0.1426334622833748d-06,-.8289241123539240d-07,
     2      0.6261792172133321d-07,-.5433177232432322d-07,
     3      0.2525282417027273d-07,-.9586875569538273d-08,
     4      -.1896682797835980d-06,-.3332484863275925d-06,
     5      -.8949495472936035d-06,-.1978180734590383d-05,
     6      -.3242215663631096d-05,-.4488135826067500d-05,
     7      -.5543928225871827d-05,-.6055040678136719d-05,
     8      -.5759083948220929d-05,-.4785708094980276d-05/
         data arr1145/
     1      -.3606378786402460d-05,-.3350096051571207d-05,
     2      0.6772255463189315d-04,-.1723660806105292d-04,
     3      0.5193952390622912d-05,-.1762573533982504d-05,
     4      0.6588081540358412d-06,-.2737624887105570d-06,
     5      0.1306420255223806d-06,-.7654952661243056d-07,
     6      0.5807762387126927d-07,-.4935461167665957d-07,
     7      0.2529000078789367d-07,0.1191581281336849d-07,
     8      -.1036705744901235d-06,-.9799268932896113d-07/
         data arr1146/
     1      -.3334618675446017d-06,-.9094229422483227d-06,
     2      -.1588242138063559d-05,-.2329127270091720d-05,
     3      -.3129062050716382d-05,-.3733682009416189d-05,
     4      -.3840885727558718d-05,-.3422745617591300d-05,
     5      -.2769208273304548d-05,-.2830138040826907d-05,
     6      0.7211343458492865d-04,0.5578520414974863d-03,
     7      0.1931434580620445d-02,0.3957371408484702d-02,
     8      0.5588251995768732d-02,0.5964643899377663d-02/
         data arr1147/
     1      0.5113224405890439d-02,0.3672882038801272d-02,
     2      0.2280104065150394d-02,0.1252215199850997d-02,
     3      0.6194772687065975d-03,0.2800093944813037d-03,
     4      0.1169631197553367d-03,0.4556385025495221d-04,
     5      0.1667615094761008d-04,0.5768612331686722d-05,
     6      0.1895102545887531d-05,0.5935297674099501d-06,
     7      0.1777607789660012d-06,0.5103493337134899d-07,
     8      0.1406466375999114d-07,0.3727138994718511d-08/
         data arr1148/
     1      0.1063799387007637d-08,0.1105949347800472d-04,
     2      0.1539805295628392d-03,0.8248577332538552d-03,
     3      0.2384871175505754d-02,0.4467150162352637d-02,
     4      0.6051310571104401d-02,0.6369931174317786d-02,
     5      0.5476937729084198d-02,0.3988171912631651d-02,
     6      0.2527233019793657d-02,0.1423128598646350d-02,
     7      0.7239491509045268d-03,0.3370689626560654d-03,
     8      0.1451592067499981d-03,0.5831528954354246d-04/
         data arr1149/
     1      0.2200549490843986d-04,0.7843638200393172d-05,
     2      0.2652727511414790d-05,0.8542910737026659d-06,
     3      0.2626894488502471d-06,0.7727714504627637d-07,
     4      0.2185046125388856d-07,0.6750315291306102d-08,
     5      0.1145307586803353d-05,0.2850831383730909d-04,
     6      0.2363123716535019d-03,0.9641155969835594d-03,
     7      0.2395473693854447d-02,0.4118324988503987d-02,
     8      0.5323299319677658d-02,0.5478666691475297d-02/
         data arr1150/
     1      0.4679498731032487d-02,0.3421510329200261d-02,
     2      0.2193154201245055d-02,0.1255595694262796d-02,
     3      0.6516206045327626d-03,0.3102236040078664d-03,
     4      0.1367967104659286d-03,0.5631165233032130d-04,
     5      0.2177739833629222d-04,0.7953097128996418d-05,
     6      0.2754118433394350d-05,0.9072587854502681d-06,
     7      0.2849780908165607d-06,0.8583586023820600d-07,
     8      0.2840892965575315d-07,0.1080081271080066d-06/
         data arr1151/
     1      0.4101570736495916d-05,0.5270787833879506d-04,
     2      0.3034239441652449d-03,0.1000024055361375d-02,
     3      0.2181975092191899d-02,0.3463259772807145d-02,
     4      0.4266482593632158d-02,0.4274475525074594d-02,
     5      0.3606188634106777d-02,0.2631190040495422d-02,
     6      0.1695312000052435d-02,0.9806834220621196d-03,
     7      0.5161346405610623d-03,0.2498199253465463d-03,
     8      0.1121821047462686d-03,0.4707063910786911d-04/
         data arr1152/
     1      0.1856221121856558d-04,0.6912018206734421d-05,
     2      0.2439302972892480d-05,0.8180489634238685d-06,
     3      0.2623111778002827d-06,0.9278136227038749d-07,
     4      0.8332713056468146d-07,0.4577259547025466d-06,
     5      0.9759167833413916d-05,0.7917439491699599d-04,
     6      0.3461526359332450d-03,0.9585506710869777d-03,
     7      0.1868209823673660d-02,0.2754871858508381d-02,
     8      0.3237447370314485d-02,0.3151485698440879d-02/
         data arr1153/
     1      0.2617409253557344d-02,0.1897954741083159d-02,
     2      0.1223768069882795d-02,0.7120123601658153d-03,
     3      0.3782816461818296d-03,0.1853044250046694d-03,
     4      0.8435905850226955d-04,0.3592254566929174d-04,
     5      0.1438447118412822d-04,0.5439088944574504d-05,
     6      0.1948188397089902d-05,0.6657856507806504d-06,
     7      0.2527355927371961d-06,0.1833761552949737d-06,
     8      -.2813028801793573d-07,0.1578102889765349d-05/
         data arr1154/
     1      0.1774508743319269d-04,0.1029674556719210d-03,
     2      0.3618623806654071d-03,0.8660245855864282d-03,
     3      0.1528610209941079d-02,0.2107107103605765d-02,
     4      0.2366715492459133d-02,0.2237459084084363d-02,
     5      0.1825938055443288d-02,0.1312299803743141d-02,
     6      0.8440650833587779d-03,0.4922288721200961d-03,
     7      0.2630318827017408d-03,0.1299168048268623d-03,
     8      0.5973600813103572d-04,0.2571901789420968d-04/
         data arr1155/
     1      0.1041559920640711d-04,0.3980659208842983d-05,
     2      0.1446774273213889d-05,0.5860925363420200d-06,
     3      0.4065811460661063d-06,-.1707702763638481d-06,
     4      0.2819652691651356d-06,0.3479093648478189d-05,
     5      0.2694962665169480d-04,0.1201660174474568d-03,
     6      0.3531445343490632d-03,0.7461203811655349d-03,
     7      0.1206390505456032d-02,0.1563483757894763d-02,
     8      0.1682502935647619d-02,0.1545267064440943d-02/
         data arr1156/
     1      0.1237894202823930d-02,0.8802003851287702d-03,
     2      0.5634279462370769d-03,0.3284374711467177d-03,
     3      0.1760059769609589d-03,0.8739074471315889d-04,
     4      0.4046463897261611d-04,0.1756125537820936d-04,
     5      0.7170760702435468d-05,0.2780175588713338d-05,
     6      0.1212867261540880d-05,0.7910415710503428d-06,
     7      -.3415265072771336d-06,0.1552135798580749d-06,
     8      0.5718895211765608d-06,0.6321601594605257d-05/
         data arr1157/
     1      0.3568743799769279d-04,0.1288023733861230d-03,
     2      0.3257353038420105d-03,0.6177824788561674d-03,
     3      0.9238135999946747d-03,0.1131623975901745d-02,
     4      0.1169678701925368d-02,0.1044425301135625d-02,
     5      0.8209761841077618d-03,0.5768344855392052d-03,
     6      0.3667959782239350d-03,0.2132454097642069d-03,
     7      0.1143141091088607d-03,0.5689814974652973d-04,
     8      0.2643291814748079d-04,0.1150382242208281d-04/
         data arr1158/
     1      0.4734181824866183d-05,0.2196444907995305d-05,
     2      0.1425288929437755d-05,-.6183873721465090d-06,
     3      0.2367780386315844d-06,0.1342913758631199d-07,
     4      0.1367696687906734d-05,0.9590733292356471d-05,
     5      0.4255173659550725d-04,0.1287959361892172d-03,
     6      0.2865359459131767d-03,0.4943795838207516d-03,
     7      0.6893494941442303d-03,0.8019026125926259d-03,
     8      0.7981021104903868d-03,0.6935383601926089d-03/
         data arr1159/
     1      0.5348916592553786d-03,0.3710313953611798d-03,
     2      0.2340342323840664d-03,0.1354860924148353d-03,
     3      0.7253992053205899d-04,0.3612745689630650d-04,
     4      0.1680844974655880d-04,0.7387591108388262d-05,
     5      0.3704084185431267d-05,0.2210007755651907d-05,
     6      -.9566906504974718d-06,0.3602045088141779d-06,
     7      -.1158498137968510d-06,0.3059981725090516d-06,
     8      0.2346262383066252d-05,0.1286109983982795d-04/
         data arr1160/
     1      0.4657768125349604d-04,0.1215626940392668d-03,
     2      0.2419813337047570d-03,0.3840974269423699d-03,
     3      0.5028495014821045d-03,0.5578133360765041d-03,
     4      0.5358687725102058d-03,0.4536391607088022d-03,
     5      0.3432096035226464d-03,0.2347989897925526d-03,
     6      0.1466918307202753d-03,0.8435802806366013d-04,
     7      0.4490367838609565d-04,0.2220767431099196d-04,
     8      0.1031860686825321d-04,0.5465474850462713d-05/
         data arr1161/
     1      0.3407315784090261d-05,-.1481923221987801d-05,
     2      0.5628632828667261d-06,-.2053962890005374d-06,
     3      0.1233903246385394d-06,0.5069512021930269d-06,
     4      0.3592880605770652d-05,0.1552260573948140d-04,
     5      0.4755840551423922d-04,0.1091854882745658d-03,
     6      0.1973155405944544d-03,0.2907250532597662d-03,
     7      0.3594328637767039d-03,0.3817383380464776d-03,
     8      0.3547556528623859d-03,0.2927836430368926d-03/
         data arr1162/
     1      0.2173174727996526d-03,0.1466516614090020d-03,
     2      0.9076421337060607d-04,0.5183540800786737d-04,
     3      0.2743581044985156d-04,0.1364079364421619d-04,
     4      0.7845547422363196d-05,0.4414431268505730d-05,
     5      -.1916582096032261d-05,0.7252797594690862d-06,
     6      -.2651851080442045d-06,0.1051643567329771d-06,
     7      0.7706289982793889d-07,0.9394750226948770d-06,
     8      0.4795131783827105d-05,0.1727764188370926d-04/
         data arr1163/
     1      0.4570564970824431d-04,0.9407625229834132d-04,
     2      0.1559910044927611d-03,0.2149061535630478d-03,
     3      0.2523223641662114d-03,0.2573519029229037d-03,
     4      0.2315452349241862d-03,0.1862444791059942d-03,
     5      0.1354644636546878d-03,0.8987225637151307d-04,
     6      0.5468284967094312d-04,0.3062427604703958d-04,
     7      0.1599894754178748d-04,0.9637034775180326d-05,
     8      0.5903961854237210d-05,-.2583761124342381d-05/
         data arr1164/
     1      0.9936161519814049d-06,-.3741334846297929d-06,
     2      0.1457407171262104d-06,-.3664776874311636d-07,
     3      0.2510241855257864d-06,0.1364988578030323d-05,
     4      0.5878490315925557d-05,0.1783478577924154d-04,
     5      0.4185832802951847d-04,0.7813364041736045d-04,
     6      0.1198967989343696d-03,0.1556595536084189d-03,
     7      0.1743477731507555d-03,0.1711161912134472d-03,
     8      0.1493265595619594d-03,0.1173720360260345d-03/
         data arr1165/
     1      0.8389444425703390d-04,0.5484346430599456d-04,
     2      0.3292373877064958d-04,0.1844723058477373d-04,
     3      0.1212410517128919d-04,0.6248563944675446d-05,
     4      -.2724814561723720d-05,0.1040346958268135d-05,
     5      -.3868401235388959d-06,0.1463796375236432d-06,
     6      -.5291110539290331d-07,0.7532788213125738d-07,
     7      0.3553422242189769d-06,0.1889679260684837d-05,
     8      0.6505847822598137d-05,0.1747191462883887d-04/
         data arr1166/
     1      0.3669216206741166d-04,0.6266153567486989d-04,
     2      0.8992234707876022d-04,0.1104584586778509d-03,
     3      0.1179586287862458d-03,0.1112394603740394d-03,
     4      0.9388581244546365d-04,0.7155380844826928d-04,
     5      0.4947263344721639d-04,0.3113544559125940d-04,
     6      0.1812874700589307d-04,0.1228901495582071d-04,
     7      0.7401598064427874d-05,-.3262396263919871d-05,
     8      0.1272437868635243d-05,-.4908188202739102d-06/
         data arr1167/
     1      0.1973334562740948d-06,-.8548365708053301d-07,
     2      0.5610924677939319d-07,0.5803320933310311d-07,
     3      0.6023039267167696d-06,0.2211469858909050d-05,
     4      0.6860664851923317d-05,0.1626736905440570d-04,
     5      0.3082812065231786d-04,0.4895699266485668d-04,
     6      0.6613884788926242d-04,0.7704847508231370d-04,
     7      0.7882372335747150d-04,0.7197195251117647d-04,
     8      0.5922535113799111d-04,0.4410504734365387d-04/
         data arr1168/
     1      0.2982841547505962d-04,0.1868455307976433d-04,
     2      0.1389875808420475d-04,0.6369871144029246d-05,
     3      -.2794457487915829d-05,0.1079812819571221d-05,
     4      -.4099906681279119d-06,0.1606203245438987d-06,
     5      -.6694675340396899d-07,0.3511492590725694d-07,
     6      -.4244705291783487d-08,0.1945001489123739d-06,
     7      0.6931207873688028d-06,0.2552256239336751d-05,
     8      0.6801364010646688d-05,0.1425230779330361d-04/
         data arr1169/
     1      0.2499268307627346d-04,0.3691929985249708d-04,
     2      0.4652812983036698d-04,0.5108010364358921d-04,
     3      0.4967747183575758d-04,0.4316855151895581d-04,
     4      0.3362389181276012d-04,0.2355780887848721d-04,
     5      0.1515111644361970d-04,0.1146769733212227d-04,
     6      0.6733014366652708d-05,-.2999082788134636d-05,
     7      0.1193634590221536d-05,-.4758135499352027d-06,
     8      0.2011851673262129d-06,-.9518276058467920d-07/
         data arr1170/
     1      0.5600940083561386d-07,-.4122090162474782d-07,
     2      0.9180780377260686d-07,0.1873169900630471d-06,
     3      0.8850308620409934d-06,0.2749868288688037d-05,
     4      0.6255284559231484d-05,0.1216746314457629d-04,
     5      0.1987938873817413d-04,0.2732859937050923d-04,
     6      0.3252124356881897d-04,0.3427550389446276d-04,
     7      0.3226752438718302d-04,0.2715713787589551d-04,
     8      0.2049595871277450d-04,0.1421449175367103d-04/
         data arr1171/
     1      0.1185224063648597d-04,0.4250322776395587d-05,
     2      -.1878846560137197d-05,0.7368662071329016d-06,
     3      -.2868253434355002d-06,0.1169692141197496d-06,
     4      -.5231839246733608d-07,0.2851688120632800d-07,
     5      -.2252900369391318d-07,0.3883513178934729d-07,
     6      0.3921941098216530d-07,0.2961242715125572d-06,
     7      0.1025565367468123d-05,0.2521446918638132d-05,
     8      0.5381044110161967d-05,0.9493954801017835d-05/
         data arr1172/
     1      0.1389252906897496d-04,0.1744453724778881d-04,
     2      0.1923032466481151d-04,0.1874090951259896d-04,
     3      0.1616045924794131d-04,0.1238191754138191d-04,
     4      0.8641570807056922d-05,0.7157384947983204d-05,
     5      0.4038144171360195d-05,-.1822635272876236d-05,
     6      0.7434620034046116d-06,-.3077562965210859d-06,
     7      0.1372163077787778d-06,-.6990161746760655d-07,
     8      0.4428368380310321d-07,-.3689775879622213d-07/
         data arr1173/
     1      0.3766598875558340d-07,-.2719752372855924d-08,
     2      0.7766075955279887d-07,0.4112048449074143d-06,
     3      0.9915741248460780d-06,0.2358117269975991d-05,
     4      0.4687402429849472d-05,0.7480808812694733d-05,
     5      0.1015496401731966d-04,0.1216123580174923d-04,
     6      0.1290491586495996d-04,0.1207592309597595d-04,
     7      0.9994712029419816d-05,0.7540245409720289d-05,
     8      0.6907201060944989d-05,0.1709523319068315d-05/
         data arr1174/
     1      -.7677528960367934d-06,0.3102831070946847d-06,
     2      -.1266566691845547d-06,0.5539794079402088d-07,
     3      -.2750347336086368d-07,0.1695367147159624d-07,
     4      -.1414540776808723d-07,0.1453047359167447d-07,
     5      -.4951742126673353d-08,0.2027136140287919d-07,
     6      0.1263316982569990d-06,0.3091318644771257d-06,
     7      0.7929197042663073d-06,0.1668308207447543d-05,
     8      0.2771814468748837d-05,0.3892907991940168d-05/
         data arr1175/
     1      0.4794265088020356d-05,0.5192092759936394d-05,
     2      0.4923386167658002d-05,0.4105509113913776d-05,
     3      0.3104157926336990d-05,0.2826677017904947d-05,
     4      0.1431099664340646d-05,-.6599690554549076d-06,
     5      0.2796890689477713d-06,-.1222427632348254d-06,
     6      0.5838141886923284d-07,-.3232386920729953d-07,
     7      0.2214167709487071d-07,-.1863489972117760d-07,
     8      0.1566882538395369d-07,-.4747355930619085d-08/
         data arr1176/
     1      -.5063134337456715d-08,0.6141097017732438d-07,
     2      0.1085937277030356d-06,0.3081427868615355d-06,
     3      0.7710110267041706d-06,0.1394751079335493d-05,
     4      0.2097389374351457d-05,0.2806650058795208d-05,
     5      0.3324343964033306d-05,0.3429454189863779d-05,
     6      0.3088734617515378d-05,0.2521213712598860d-05,
     7      0.2535372288319219d-05,-.4951713169522713d-04,
     8      -.2606433455281544d-03,-.7542150580052803d-03/
         data arr1177/
     1      -.1412621190110949d-02,-.1913598169324841d-02,
     2      -.2014346378542617d-02,-.1731961294132330d-02,
     3      -.1261170093872230d-02,-.7991809419909958d-03,
     4      -.4500336272327004d-03,-.2289322860501104d-03,
     5      -.1065902457418674d-03,-.4590394664102238d-04,
     6      -.1844103727892867d-04,-.6958270758696589d-05,
     7      -.2480205365806169d-05,-.8391999080690285d-06,
     8      -.2704410292624395d-06,-.8297972550961482d-07/
         data arr1178/
     1      -.2414388780810952d-07,-.6729810650863968d-08,
     2      -.2263309256555783d-08,-.1226901305507564d-04,
     3      -.1007372185486718d-03,-.4111070584253165d-03,
     4      -.1021431495752065d-02,-.1756060322909485d-02,
     5      -.2269862179432197d-02,-.2336111458633970d-02,
     6      -.1995344932287686d-02,-.1458936856712505d-02,
     7      -.9351641607417599d-03,-.5353877994752860d-03,
     8      -.2778518997864212d-03,-.1322798071086920d-03/
         data arr1179/
     1      -.5833036981185258d-04,-.2401135031747999d-04,
     2      -.9285848124372948d-05,-.3391198811456653d-05,
     3      -.1174403794267735d-05,-.3868805642296386d-06,
     4      -.1214733113325253d-06,-.3650859333853401d-07,
     5      -.1194666564197029d-07,-.2059283651003763d-05,
     6      -.2635396295967049d-04,-.1517110128969271d-03,
     7      -.5000127398215470d-03,-.1090987090111131d-02,
     8      -.1731630205445900d-02,-.2133241041007502d-02/
         data arr1180/
     1      -.2137237955185926d-02,-.1803094257932996d-02,
     2      -.1315594879765348d-02,-.8476562482646520d-03,
     3      -.4903416178109045d-03,-.2580671237308712d-03,
     4      -.1249101260883681d-03,-.5609118488856297d-04,
     5      -.2353512832070763d-04,-.9280890404316670d-05,
     6      -.3456025491503673d-05,-.1219753164202601d-05,
     7      -.4089614408932148d-06,-.1308504428326815d-06,
     8      -.4563255380462515d-07,-.2542797462835235d-06/
         data arr1181/
     1      -.5419042147197338d-05,-.4391387585895791d-04,
     2      -.1920134037159155d-03,-.5317067733472872d-03,
     3      -.1036297358927010d-02,-.1528127169670947d-02,
     4      -.1795813269512560d-02,-.1748129585069604d-02,
     5      -.1451876966803254d-02,-.1052796623667909d-02,
     6      -.6788241439423841d-03,-.3949527745087188d-03,
     7      -.2098333801263033d-03,-.1027888533729611d-03,
     8      -.4679345704862069d-04,-.1992559516533930d-04/
         data arr1182/
     1      -.7979122245867298d-05,-.3017413385184240d-05,
     2      -.1080523315001463d-05,-.3684003786188912d-06,
     3      -.1377788052137139d-06,0.2085052037945605d-07,
     4      -.9596787484588264d-06,-.1059304187969429d-04,
     5      -.6154165364229746d-04,-.2162500538458903d-03,
     6      -.5175514791502238d-03,-.9135171194573037d-03,
     7      -.1259238938272203d-02,-.1414382667288252d-02,
     8      -.1337136214463981d-02,-.1091208819734171d-02/
         data arr1183/
     1      -.7842485138166236d-03,-.5044235988975325d-03,
     2      -.2941643323044335d-03,-.1571929803390658d-03,
     3      -.7763878846954739d-04,-.3569737528955310d-04,
     4      -.1537031982550648d-04,-.6225683553241048d-05,
     5      -.2378761825649183d-05,-.8623211525758686d-06,
     6      -.3439170656528605d-06,0.1233125915691717d-06,
     7      -.2210085349495030d-06,-.2171043439603904d-05,
     8      -.1706140203290412d-04,-.7598961741331204d-04/
         data arr1184/
     1      -.2233550479801336d-03,-.4718825850265094d-03,
     2      -.7629922626350269d-03,-.9888329557092650d-03,
     3      -.1064105149971499d-02,-.9773178398836779d-03,
     4      -.7829113827211093d-03,-.5566833849940128d-03,
     5      -.3563463580671665d-03,-.2077251407568546d-03,
     6      -.1113123189344001d-03,-.5526632484426787d-04,
     7      -.2559239731843658d-04,-.1110901765876336d-04,
     8      -.4534221057053045d-05,-.1752268939238468d-05/
         data arr1185/
     1      -.7514697369007425d-06,0.2559676675891174d-06,
     2      -.1887009246970481d-06,-.3191186654451983d-06,
     3      -.4215509648006237d-05,-.2358483484951807d-04,
     4      -.8520846130205675d-04,-.2154428784613457d-03,
     5      -.4086325685452031d-03,-.6110431958366453d-03,
     6      -.7484926930418904d-03,-.7736800408759583d-03,
     7      -.6908190632477815d-03,-.5430164789239527d-03,
     8      -.3815471244183676d-03,-.2426196375092300d-03/
         data arr1186/
     1      -.1410426755409670d-03,-.7560490238433338d-04,
     2      -.3763789512865773d-04,-.1749122573723470d-04,
     3      -.7609841262424676d-05,-.3121581874999814d-05,
     4      -.1424170786785744d-05,0.4888815389058945d-06,
     5      -.3283995340293577d-06,0.1036690897240577d-06,
     6      -.1002992685135848d-05,-.6541162557336093d-05,
     7      -.2921591406556281d-04,-.8833312211988361d-04,
     8      -.1965768849486163d-03,-.3391374307019461d-03/
         data arr1187/
     1      -.4728785275345098d-03,-.5501199168673756d-03,
     2      -.5474867968273143d-03,-.4757478698171362d-03,
     3      -.3669451534112861d-03,-.2545363397452490d-03,
     4      -.1605318280062199d-03,-.9292587687205935d-04,
     5      -.4976303921973516d-04,-.2479118236810236d-04,
     6      -.1152563571545918d-04,-.5043764635138600d-05,
     7      -.2480925474729446d-05,0.7834951083126691d-06,
     8      -.5229953737708731d-06,0.2643608867177220d-06/
         data arr1188/
     1      -.3211983227375781d-06,-.1597354813230726d-05,
     2      -.9135927157552125d-05,-.3290255848978319d-04,
     3      -.8598190851744769d-04,-.1711000825567166d-03,
     4      -.2715791917393802d-03,-.3555998315034931d-03,
     5      -.3944232011882877d-03,-.3788918563145308d-03,
     6      -.3207939745010487d-03,-.2427087750698848d-03,
     7      -.1660128253187165d-03,-.1037107031287162d-03,
     8      -.5966619661057666d-04,-.3178078608204331d-04/
         data arr1189/
     1      -.1571105309398151d-04,-.7271010304706935d-05,
     2      -.3782465821139003d-05,0.1284691059236382d-05,
     3      -.8576870419005739d-06,0.4493014164867416d-06,
     4      -.2602621345820976d-06,-.2682568607644031d-06,
     5      -.2673300373424265d-05,-.1120890041647934d-04,
     6      -.3454145138675924d-04,-.7919972978429514d-04,
     7      -.1431192516899995d-03,-.2109642475281676d-03,
     8      -.2607412713800827d-03,-.2769023090439402d-03/
         data arr1190/
     1      -.2574000139264065d-03,-.2124343408776673d-03,
     2      -.1576189282090026d-03,-.1063468686514092d-03,
     3      -.6584814523712445d-04,-.3762246592995076d-04,
     4      -.1988649518334931d-04,-.9828862052760150d-05,
     5      -.5532319600474907d-05,0.1707573150567344d-05,
     6      -.1139568646117470d-05,0.5984514414483302d-06,
     7      -.3065987067097926d-06,0.7628132025945800d-07,
     8      -.7863677662835567d-06,-.3485776440678375d-05/
         data arr1191/
     1      -.1286571532258544d-04,-.3388068249765780d-04,
     2      -.6973024906584710d-04,-.1157538751641125d-03,
     3      -.1593549008437421d-03,-.1870768946587172d-03,
     4      -.1909106481372936d-03,-.1717725637582534d-03,
     5      -.1380984380784789d-03,-.1004435378332649d-03,
     6      -.6670470112114681d-04,-.4063513223945725d-04,
     7      -.2274441169384651d-04,-.1182439074956681d-04,
     8      -.6988408714818409d-05,0.2432802216281147d-05/
         data arr1192/
     1      -.1625503888864286d-05,0.8548742399564746d-06,
     2      -.4312556708161298d-06,0.2125790207931394d-06,
     3      -.3123652362689308d-06,-.9358471192921614d-06,
     4      -.4516337250350449d-05,-.1345725890718605d-04,
     5      -.3159288570186070d-04,-.5915540674214037d-04,
     6      -.9059518248980709d-04,-.1175967278348140d-03,
     7      -.1318579056552714d-03,-.1293962281577759d-03,
     8      -.1128010695292931d-03,-.8863872672440999d-04/
         data arr1193/
     1      -.6341690145360305d-04,-.4148129202243738d-04,
     2      -.2484392145139603d-04,-.1380993089580982d-04,
     3      -.8862587422061505d-05,0.2613467462305016d-05,
     4      -.1745358648985908d-05,0.9174924320669422d-06,
     5      -.4617204044489667d-06,0.2426051776045133d-06,
     6      -.1924422102531921d-06,-.1676605650487660d-06,
     7      -.1531972951725334d-05,-.4975333318593101d-05,
     8      -.1337549406165021d-04,-.2830762117494911d-04/
         data arr1194/
     1      -.4813022735850835d-04,-.6905223907141042d-04,
     2      -.8499829292803674d-04,-.9076496420236366d-04,
     3      -.8548847941422158d-04,-.7216649309144281d-04,
     4      -.5511676089406901d-04,-.3818346156360916d-04,
     5      -.2400973062041986d-04,-.1389629845979954d-04,
     6      -.9234804038716373d-05,0.3324007282500598d-05,
     7      -.2223137141650689d-05,0.1170333129914423d-05,
     8      -.5899103855950232d-06,0.3144396063646791d-06/
         data arr1195/
     1      -.2060817446416036d-06,0.8145994523866705d-07,
     2      -.5675851606347595d-06,-.1688483085574161d-05,
     3      -.5292478357824038d-05,-.1281309234251631d-04,
     4      -.2399536024546055d-04,-.3810488563586370d-04,
     5      -.5168720662525356d-04,-.6016246292680904d-04,
     6      -.6137957272928465d-04,-.5602744178459950d-04,
     7      -.4619232792081859d-04,-.3441936010932694d-04,
     8      -.2318476010893175d-04,-.1437105129182357d-04/
         data arr1196/
     1      -.1041458010751889d-04,0.2904339774038484d-05,
     2      -.1941092763154008d-05,0.1021157639558805d-05,
     3      -.5142546628832539d-06,0.2741365117100598d-06,
     4      -.1735058930217941d-06,0.1173956126988412d-06,
     5      -.2410785822540362d-06,-.5164343785927931d-06,
     6      -.1961791946274070d-05,-.5487966076503457d-05,
     7      -.1122257354856171d-04,-.1968689181032321d-04,
     8      -.2929473998274759d-04,-.3689260718530697d-04/
         data arr1197/
     1      -.4037924288414708d-04,-.3930584900138265d-04,
     2      -.3429673260988190d-04,-.2679312558488304d-04,
     3      -.1874277774785390d-04,-.1196495487270740d-04,
     4      -.8871128883199137d-05,0.3328272611090684d-05,
     5      -.2228705854610867d-05,0.1174652446747384d-05,
     6      -.5929739999034848d-06,0.3173979081976522d-06,
     7      -.2001907358359535d-06,0.1538507226923945d-06,
     8      -.1690275330206069d-06,-.1086495801345579d-06/
         data arr1198/
     1      -.6569619775518787d-06,-.2315802119562544d-05,
     2      -.4942504862764748d-05,-.9651292656145350d-05,
     3      -.1599015671464692d-04,-.2190008980356405d-04,
     4      -.2588936495714569d-04,-.2729224977095423d-04,
     5      -.2578900207340169d-04,-.2171234277042872d-04,
     6      -.1628300161631082d-04,-.1114428264424666d-04,
     7      -.9040503290870722d-05,0.2102186422555068d-05,
     8      -.1406144169696394d-05,0.7403187583042529d-06/
         data arr1199/
     1      -.3731985303922389d-06,0.1993295309237263d-06,
     2      -.1252059439716734d-06,0.9793398128784556d-07,
     3      -.9365474021976391d-07,-.6689508719116234d-08,
     4      -.2034650857088316d-06,-.9072782483417054d-06,
     5      -.2004451213531024d-05,-.4305788450258988d-05,
     6      -.7761255831412523d-05,-.1131850610697351d-04,
     7      -.1411879839685419d-04,-.1560007375631408d-04,
     8      -.1530726263626021d-04,-.1324816625044588d-04/
         data arr1200/
     1      -.1012156988949293d-04,-.6999372963218800d-05,
     2      -.5674648227759631d-05,0.2186801231695328d-05,
     3      -.1466513737435390d-05,0.7740336032522938d-06,
     4      -.3914450271672554d-06,0.2101308559819759d-06,
     5      -.1328177522257087d-06,0.1049662898367312d-06,
     6      -.9168899794309507d-07,0.3212564695656632d-07,
     7      -.3643276223151806d-07,-.4074013830119357d-06,
     8      -.7655228583209470d-06,-.1876757898954689d-05/
         data arr1201/
     1      -.3882483257783746d-05,-.6120214855011165d-05,
     2      -.8196063154834966d-05,-.9834865012560286d-05,
     3      -.1050119400191734d-04,-.9820694249911475d-05,
     4      -.8051928841441905d-05,-.5978091570340802d-05,
     5      -.5321955790927482d-05,0.9474218603004016d-06,
     6      -.6349899802799512d-06,0.3349575782103719d-06,
     7      -.1692676342289978d-06,0.9075619952705575d-07,
     8      -.5727174108161506d-07,0.4527935157949636d-07/
         data arr1202/
     1      -.3914995238651281d-07,0.1690242457725938d-07,
     2      -.3904294697851898d-08,-.1371772815018502d-06,
     3      -.2377175910199933d-06,-.6372207206678942d-06,
     4      -.1415726414631602d-05,-.2323446904357719d-05,
     5      -.3219982667152831d-05,-.3985640900203233d-05,
     6      -.4360213857759171d-05,-.4147419604994475d-05,
     7      -.3438180231863279d-05,-.2568000340597408d-05,
     8      -.2284556266188735d-05,0.8806315492784938d-06/
         data arr1203/
     1      -.5920446682732300d-06,0.3132407054504074d-06,
     2      -.1589017291416239d-06,0.8571113719911493d-07,
     3      -.5451360713878760d-07,0.4325733494077418d-07,
     4      -.3661954883077412d-07,0.1749771732233957d-07,
     5      0.1166114867231241d-07,-.7760376442825690d-07,
     6      -.7058736335800167d-07,-.2393803682691783d-06,
     7      -.6623243131586865d-06,-.1158198288876778d-05,
     8      -.1699728904933155d-05,-.2291144752355585d-05/
         data arr1204/
     1      -.2742417627665562d-05,-.2824046702497550d-05,
     2      -.2511920808008938d-05,-.2014687210739757d-05,
     3      -.1971969786200605d-05,0.3032447330939914d-04,
     4      0.1182719666134985d-03,0.2950063821201462d-03,
     5      0.5068697482905911d-03,0.6552850998734955d-03,
     6      0.6743573282972508d-03,0.5760169737794984d-03,
     7      0.4211591658154757d-03,0.2699488001185046d-03,
     8      0.1545636969052906d-03,0.8020838897387037d-04/
         data arr1205/
     1      0.3817738323141155d-04,0.1684216234494254d-04,
     2      0.6937919875217832d-05,0.2677771125008396d-05,
     3      0.9731081043623169d-06,0.3390803219983680d-06,
     4      0.1163266557588574d-06,0.3816654764595678d-07,
     5      0.9527081870139848d-08,-.6501816261874261d-09,
     6      0.1062058497312066d-04,0.5941386407423603d-04,
     7      0.1961539482650229d-03,0.4279064955196612d-03,
     8      0.6792085310889255d-03,0.8367215009746487d-03/
         data arr1206/
     1      0.8382960346409415d-03,0.7072318487068345d-03,
     2      0.5160165798473528d-03,0.3324804557905969d-03,
     3      0.1923276986984626d-03,0.1012203896328878d-03,
     4      0.4899455722800802d-04,0.2200216441270449d-04,
     5      0.9230624031119774d-05,0.3638985343306879d-05,
     6      0.1355539425450948d-05,0.4793752004518052d-06,
     7      0.1610196133815545d-06,0.5103748285933452d-07,
     8      0.1681724620735875d-07,0.2549545157324093d-05/
         data arr1207/
     1      0.2031541813916608d-04,0.8888912700073061d-04,
     2      0.2461308344099686d-03,0.4797131727708241d-03,
     3      0.7073850702652805d-03,0.8313001374174160d-03,
     4      0.8092267916795046d-03,0.6720883515149693d-03,
     5      0.4873501522929775d-03,0.3142345545210881d-03,
     6      0.1828276412749078d-03,0.9713391510885181d-04,
     7      0.4758192034600180d-04,0.2166122603681554d-04,
     8      0.9223858011525308d-05,0.3693572015025063d-05/
         data arr1208/
     1      0.1396612103256713d-05,0.4999984691856769d-06,
     2      0.1703595505826278d-06,0.6315579720790545d-07,
     3      0.4910409819743680d-06,0.5473376816465336d-05,
     4      0.3177773659520347d-04,0.1116726236073309d-03,
     5      0.2672612167447228d-03,0.4717392284907744d-03,
     6      0.6502674839813704d-03,0.7303841205395005d-03,
     7      0.6904949717666370d-03,0.5634967333652492d-03,
     8      0.4049843304934805d-03,0.2604842363968989d-03/
         data arr1209/
     1      0.1519051996293628d-03,0.8117310422432441d-04,
     2      0.4009286317639971d-04,0.1843481282461283d-04,
     3      0.7936848696817498d-05,0.3213635113771829d-05,
     4      0.1227238967694339d-05,0.4446720405872226d-06,
     5      0.1759930281747587d-06,0.9665351010064628d-07,
     6      0.1226997702788622d-05,0.9529902048493684d-05,
     7      0.4248438532216690d-04,0.1248556934053253d-03,
     8      0.2637932795353571d-03,0.4265236363235454d-03/
         data arr1210/
     1      0.5527746329890479d-03,0.5948549891854646d-03,
     2      0.5463343466548631d-03,0.4376612474793149d-03,
     3      0.3111981891469222d-03,0.1992020807584745d-03,
     4      0.1161195107375468d-03,0.6222693952016112d-04,
     5      0.3089741385113372d-04,0.1430633896437720d-04,
     6      0.6207565191836483d-05,0.2532615143759449d-05,
     7      0.9787643835167591d-06,0.4168197329077136d-06,
     8      0.5234481576457406d-07,0.2190095080925202d-06/
         data arr1211/
     1      0.2487574866109041d-05,0.1402206019106450d-04,
     2      0.5061369825628651d-04,0.1279983388500098d-03,
     3      0.2427596137306724d-03,0.3630142403535768d-03,
     4      0.4446754077655056d-03,0.4596281722514096d-03,
     5      0.4104087436463506d-03,0.3226055749110049d-03,
     6      0.2266692328482024d-03,0.1441323012978239d-03,
     7      0.8379460259543510d-04,0.4492093695272046d-04,
     8      0.2235891197861614d-04,0.1038500238388449d-04/
         data arr1212/
     1      0.4515635826289885d-05,0.1852087515439679d-05,
     2      0.8383105381427948d-06,0.8143675521195623d-07,
     3      -.3860573535819116d-08,0.5912002510365736d-06,
     4      0.4100411401472415d-05,0.1820405546332202d-04,
     5      0.5509767268976972d-04,0.1225786090721036d-03,
     6      0.2114905207070012d-03,0.2949002386442536d-03,
     7      0.3430476702127184d-03,0.3414203913598791d-03,
     8      0.2966922046353168d-03,0.2288237043490438d-03/
         data arr1213/
     1      0.1587219124668043d-03,0.1001162379773143d-03,
     2      0.5796121579922886d-04,0.3103269303269385d-04,
     3      0.1545076882378511d-04,0.7180547299749797d-05,
     4      0.3143745756966187d-05,0.1534942560405111d-05,
     5      0.1352905630604101d-06,-.7085786478358636d-07,
     6      0.1513502216475302d-06,0.1072126056984696d-05,
     7      0.5902498705248568d-05,0.2137070501724477d-04,
     8      0.5577795870253712d-04,0.1110262364205680d-03/
         data arr1214/
     1      0.1762386215444856d-03,0.2307227185599963d-03,
     2      0.2559393810722679d-03,0.2458764550619928d-03,
     3      0.2081466158985936d-03,0.1574729720528372d-03,
     4      0.1077329250192470d-03,0.6731293405370626d-04,
     5      0.3871209711495160d-04,0.2060122800530753d-04,
     6      0.1017764456529954d-04,0.4710743335198076d-05,
     7      0.2429435319752758d-05,0.2154615703981398d-06,
     8      -.1235916515549486d-06,0.7554747219835573d-07/
         data arr1215/
     1      0.2406062775691750d-06,0.1750261377717640d-05,
     2      0.7553707156920721d-05,0.2314661364559543d-04,
     3      0.5313284540421844d-04,0.9603083420566604d-04,
     4      0.1414844419493240d-03,0.1749182595954075d-03,
     5      0.1857829365667746d-03,0.1726498788069003d-03,
     6      0.1424809124745279d-03,0.1057566799020444d-03,
     7      0.7137532723277750d-04,0.4417573617738750d-04,
     8      0.2521725211292338d-04,0.1332718777678982d-04/
         data arr1216/
     1      0.6595105195865724d-05,0.3683981955385658d-05,
     2      0.2967200428899528d-06,-.1710459197219405d-06,
     3      0.7650493591187419d-07,0.3027957387314612d-07,
     4      0.4836881973770287d-06,0.2452768313440126d-05,
     5      0.8844645779329170d-05,0.2338532266904049d-04,
     6      0.4815084063633959d-04,0.7983018606550279d-04,
     7      0.1099757982307291d-03,0.1291383161728087d-03,
     8      0.1317144441707251d-03,0.1185004877028364d-03/
         data arr1217/
     1      0.9532716973913086d-04,0.6935979106430056d-04,
     2      0.4603227916892306d-04,0.2800823442063094d-04,
     3      0.1567232668620921d-04,0.8157371039377879d-05,
     4      0.4780865496044704d-05,0.3961938279564289d-06,
     5      -.2318282284263043d-06,0.1015979502905172d-06,
     6      -.2865475962838989d-07,0.1361997395637234d-06,
     7      0.7292863482667363d-06,0.3144748253540867d-05,
     8      0.9526095905551357d-05,0.2238270128753460d-04/
         data arr1218/
     1      0.4176188560949577d-04,0.6407866460603619d-04,
     2      0.8321283692116951d-04,0.9319986018083487d-04,
     3      0.9145659701519685d-04,0.7981702148366882d-04,
     4      0.6275722954103617d-04,0.4486352682867939d-04,
     5      0.2931185857447053d-04,0.1756538931474075d-04,
     6      0.9790184247125780d-05,0.6236199079559345d-05,
     7      0.4459331402557303d-06,-.2595274668046211d-06,
     8      0.1119766369310888d-06,-.4166345535740155d-07/
         data arr1219/
     1      0.4542032639542077d-07,0.1959222116717505d-06,
     2      0.1052804465094651d-05,0.3604407593810347d-05,
     3      0.9710154051634530d-05,0.2037220117363937d-04,
     4      0.3478438946837069d-04,0.4994398493249515d-04,
     5      0.6135329277818668d-04,0.6551244566600247d-04,
     6      0.6180393338742497d-04,0.5220673636790765d-04,
     7      0.3982098134375677d-04,0.2753957766137194d-04,
     8      0.1731962393817659d-04,0.1004608158459507d-04/
         data arr1220/
     1      0.6617379115861254d-05,0.5133896743490354d-06,
     2      -.3048847748655435d-06,0.1363525756946341d-06,
     3      -.5728209448363707d-07,0.3285669900700198d-07,
     4      0.3420648251471909d-07,0.3484022947672140d-06,
     5      0.1260769118443367d-05,0.3951177449131332d-05,
     6      0.9337065312930336d-05,0.1769015293651226d-04,
     7      0.2812498617649237d-04,0.3798844790922652d-04,
     8      0.4423369897327989d-04,0.4526698047172648d-04/
         data arr1221/
     1      0.4136469618283263d-04,0.3405020192601059d-04,
     2      0.2533843844874846d-04,0.1709964244641495d-04,
     3      0.1064740234767478d-04,0.7658987557500864d-05,
     4      0.4722974022970661d-06,-.2786418101629602d-06,
     5      0.1231557259112768d-06,-.5085949687470011d-07,
     6      0.2380727424950307d-07,-.3628133874888297d-08,
     7      0.1187790985449825d-06,0.4015302416979944d-06,
     8      0.1519498738677815d-05,0.4023628560666656d-05/
         data arr1222/
     1      0.8424857685974332d-05,0.1480836312898777d-04,
     2      0.2188298561729892d-04,0.2757895862166351d-04,
     3      0.3031761466852486d-04,0.2955428105109387d-04,
     4      0.2574049759436426d-04,0.2008063417141407d-04,
     5      0.1407760030448321d-04,0.9031505980554801d-05,
     6      0.6648618326044283d-05,0.4658270156630339d-06,
     7      -.2834486781633857d-06,0.1321214820379920d-06,
     8      -.6027309242681796d-07,0.3190864034273797d-07/
         data arr1223/
     1      -.2250913576393647d-07,0.5714283900123658d-07,
     2      0.1055888584385101d-06,0.5493863689025219d-06,
     3      0.1666867905120697d-05,0.3790784706073591d-05,
     4      0.7408907950565570d-05,0.1209580978549981d-04,
     5      0.1661031122559189d-04,0.1978845829093861d-04,
     6      0.2089701583220017d-04,0.1969277647456703d-04,
     7      0.1656570170925102d-04,0.1247780822849766d-04,
     8      0.8602357340399282d-05,0.6929070174400542d-05/
         data arr1224/
     1      0.3187571409187071d-06,-.1912791918700202d-06,
     2      0.8709477808385654d-07,-.3811941789089551d-07,
     3      0.1875869950473875d-07,-.1416595506068845d-07,
     4      0.2637201937003924d-07,0.1863482359146415d-07,
     5      0.1910913566170181d-06,0.6385164066976592d-06,
     6      0.1565830775856928d-05,0.3368615235672020d-05,
     7      0.5947116905482694d-05,0.8701326282126128d-05,
     8      0.1095498393056046d-04,0.1212504279004370d-04/
         data arr1225/
     1      0.1185630103007170d-04,0.1024493622633230d-04,
     2      0.7856005600144169d-05,0.5468503112412531d-05,
     3      0.4399340060610751d-05,0.2699644118019766d-06,
     4      -.1698638290159463d-06,0.8347746512325642d-07,
     5      -.4145043986820273d-07,0.2446302197936834d-07,
     6      -.2035540349379877d-07,0.2381533790870598d-07,
     7      -.6528280913527522d-08,0.5712891838650444d-07,
     8      0.2583582021355284d-06,0.6249627397795528d-06/
         data arr1226/
     1      0.1511487787038618d-05,0.2994944950053080d-05,
     2      0.4767761264366774d-05,0.6488759385166199d-05,
     3      0.7798069298050017d-05,0.8286422657466434d-05,
     4      0.7747865755663414d-05,0.6397328057189987d-05,
     5      0.4794339031275255d-05,0.4233850355534426d-05,
     6      0.1260646044450113d-06,-.7886439651844819d-07,
     7      0.3841576042136866d-07,-.1882033326927612d-07,
     8      0.1091347719344603d-07,-.9077885740051475d-08/
         data arr1227/
     1      0.1038829662050114d-07,-.5664792902398991d-08,
     2      0.1591774566393817d-07,0.8323812584050984d-07,
     3      0.2011076079413132d-06,0.5293620840044531d-06,
     4      0.1117392249165861d-05,0.1858119078587588d-05,
     5      0.2626142947055549d-05,0.3262055418539931d-05,
     6      0.3558454060697098d-05,0.3392011136476887d-05,
     7      0.2839025816520876d-05,0.2146609120630770d-05,
     8      0.1902762684920402d-05,0.8745085377502933d-07/
         data arr1228/
     1      -.5887335956831282d-07,0.3179615636046927d-07,
     2      -.1791407549260362d-07,0.1213831303896518d-07,
     3      -.1051127046858726d-07,0.9939241189516470d-08,
     4      -.4767759931132287d-08,-.4098763163285456d-09,
     5      0.3947425209185605d-07,0.7007021668301087d-07,
     6      0.2095757395531640d-06,0.5196534260841685d-06,
     7      0.9360882498742823d-06,0.1416080357663877d-05,
     8      0.1908150560798071d-05,0.2267258665512341d-05/
         data arr1229/
     1      0.2339482833040240d-05,0.2104220522421967d-05,
     2      0.1707627637703948d-05,0.1655303003084338d-05,
     3      -.2818323707333543d-05,-.1588969260500464d-04,
     4      -.5241943348091775d-04,-.1143652717225949d-03,
     5      -.1815246772752899d-03,-.2236241606375471d-03,
     6      -.2240435573022075d-03,-.1890155976546837d-03,
     7      -.1379117619920099d-03,-.8885860829412736d-04,
     8      -.5140173301651229d-04,-.2705274111656529d-04/
         data arr1230/
     1      -.1309418066151020d-04,-.5879974640829020d-05,
     2      -.2467116013983833d-05,-.9728736857991247d-06,
     3      -.3622969603523053d-06,-.1278743138006128d-06,
     4      -.4285237326823859d-07,-.1366708509837761d-07,
     5      -.4659961071427809d-08,-.9271048591615546d-06,
     6      -.7419954693823128d-05,-.3245701651738218d-04,
     7      -.8987455202627277d-04,-.1751663643951306d-03,
     8      -.2583005559023916d-03,-.3035478815618446d-03/
         data arr1231/
     1      -.2954878413738909d-03,-.2454119572759027d-03,
     2      -.1779551428576017d-03,-.1147422285129280d-03,
     3      -.6675917563470535d-04,-.3546831632584531d-04,
     4      -.1737449848538347d-04,-.7909526341216397d-05,
     5      -.3368018369708813d-05,-.1348696723698077d-05,
     6      -.5099975746161923d-06,-.1825583421453305d-06,
     7      -.6210354316229315d-07,-.2274057763331133d-07,
     8      -.2137184212043589d-06,-.2368648523828316d-05/
         data arr1232/
     1      -.1376128769320606d-04,-.4835483205745330d-04,
     2      -.1157281589553078d-03,-.2042685436453413d-03,
     3      -.2815744118790592d-03,-.3162656435745367d-03,
     4      -.2989926367343358d-03,-.2440017635004741d-03,
     5      -.1753633447337018d-03,-.1127924741063614d-03,
     6      -.6577710500176111d-04,-.3514941636898677d-04,
     7      -.1736050273546784d-04,-.7982052326529043d-05,
     8      -.3436738039353576d-05,-.1391856616155685d-05/
         data arr1233/
     1      -.5315168920427767d-06,-.1921593648351293d-06,
     2      -.7490253789033980d-07,-.5256924996431635d-07,
     3      -.5897265100315257d-06,-.4626616804994696d-05,
     4      -.2060520011820202d-04,-.6056601165967576d-04,
     5      -.1279568525852474d-03,-.2068954012515261d-03,
     6      -.2681351782680953d-03,-.2885456807839982d-03,
     7      -.2650126806249810d-03,-.2122968002363371d-03,
     8      -.1509517645083985d-03,-.9662790406940782d-04/
         data arr1234/
     1      -.5632748485600280d-04,-.3018376497875496d-04,
     2      -.1498602939489802d-04,-.6939506468145787d-05,
     3      -.3011984519601555d-05,-.1228736034159280d-05,
     4      -.4735517095579858d-06,-.1983490750480904d-06,
     5      -.4123469182456690d-07,-.1024781544482360d-06,
     6      -.1320336333464987d-05,-.7383826288439737d-05,
     7      -.2668066794130070d-04,-.6745712968819679d-04,
     8      -.1279479946189728d-03,-.1913255055266531d-03/
         data arr1235/
     1      -.2343613526067908d-03,-.2422490238367087d-03,
     2      -.2163041850806547d-03,-.1700245755390946d-03,
     3      -.1194669227889651d-03,-.7596747141856777d-04,
     4      -.4416224541492346d-04,-.2367260773986413d-04,
     5      -.1178457450448220d-04,-.5476013838607801d-05,
     6      -.2381052941581592d-05,-.9737758959281279d-06,
     7      -.4334213421058483d-06,-.7545659065798685d-07,
     8      0.3034960805338105d-07,-.3522435403935167d-06/
         data arr1236/
     1      -.2290420502741259d-05,-.1024023952313070d-04,
     2      -.3095389053306100d-04,-.6888847204128434d-04,
     3      -.1188477243559382d-03,-.1657130206191560d-03,
     4      -.1927840170585627d-03,-.1918610715145050d-03,
     5      -.1667192135671221d-03,-.1285914524270613d-03,
     6      -.8920006875470835d-04,-.5625677571062185d-04,
     7      -.3256462606544883d-04,-.1743879066318227d-04,
     8      -.8687115715949164d-05,-.4036378595291548d-05/
         data arr1237/
     1      -.1760727534234279d-05,-.8440094359400895d-06,
     2      -.1315402340997712d-06,0.9099914332697333d-07,
     3      -.1245656153043606d-06,-.6100106751774153d-06,
     4      -.3510373538839584d-05,-.1262838144803736d-04,
     5      -.3300790677800516d-04,-.6568463677855933d-04,
     6      -.1042524139223578d-03,-.1365113325532752d-03,
     7      -.1514148265842823d-03,-.1454494609003160d-03,
     8      -.1231479569375733d-03,-.9317384093409274d-04/
         data arr1238/
     1      -.6373043487205887d-04,-.3981251558417258d-04,
     2      -.2290412167876845d-04,-.1219785399693470d-04,
     3      -.6025206300930651d-05,-.2777871081442980d-05,
     4      -.1405758968214673d-05,-.2297316889528373d-06,
     5      0.1668118661990230d-06,-.1100766829673996d-06,
     6      -.1052106006562039d-06,-.1112761246677448d-05,
     7      -.4636393035946356d-05,-.1430284610664062d-04,
     8      -.3279481667108592d-04,-.5925148667379985d-04/
         data arr1239/
     1      -.8735051034206662d-04,-.1079593721420619d-03,
     2      -.1146450250467293d-03,-.1065734336694475d-03,
     3      -.8795921256085526d-04,-.6526198430772068d-04,
     4      -.4403229427882753d-04,-.2726508621407934d-04,
     5      -.1557728808308526d-04,-.8227931638714299d-05,
     6      -.4050833264105815d-05,-.2215981130052860d-05,
     7      -.3281822302245115d-06,0.2384012708459085d-06,
     8      -.1392799107736800d-06,0.4230244038605651d-07/
         data arr1240/
     1      -.3556505979112315d-06,-.1531939288255813d-05,
     2      -.5680485699643407d-05,-.1495807007401230d-04,
     3      -.3076878601432805d-04,-.5109446639303448d-04,
     4      -.7033746642552815d-04,-.8256554850593339d-04,
     5      -.8426339638894978d-04,-.7582293479673044d-04,
     6      -.6096008888988906d-04,-.4434085589039237d-04,
     7      -.2945203958475131d-04,-.1794389810313674d-04,
     8      -.1003773278977657d-04,-.5198015964543804d-05/
         data arr1241/
     1      -.2984310443890138d-05,-.4825934173144309d-06,
     2      0.3559190011477071d-06,-.2063489056135343d-06,
     3      0.1122506570283229d-06,-.1588685031517496d-06,
     4      -.4260902360769679d-06,-.2109041057013877d-05,
     5      -.6280801966811183d-05,-.1471804386239678d-04,
     6      -.2758858436795147d-04,-.4224492513806140d-04,
     7      -.5482233209549737d-04,-.6148059953314585d-04,
     8      -.6034195978272189d-04,-.5260286407787299d-04/
         data arr1242/
     1      -.4133817038652824d-04,-.2958484922199021d-04,
     2      -.1935799025065293d-04,-.1158866124478705d-04,
     3      -.6415706359010261d-05,-.3995641974422583d-05,
     4      -.5478365688812443d-06,0.4017681186282137d-06,
     5      -.2317362877237100d-06,0.1332134676417013d-06,
     6      -.1087603297051451d-06,-.7067472974942436d-07,
     7      -.7526425295094086d-06,-.2440155957233517d-05,
     8      -.6527186026429257d-05,-.1385062402188330d-04/
         data arr1243/
     1      -.2354201214134964d-04,-.3376035603239522d-04,
     2      -.4156896005256072d-04,-.4440094087599843d-04,
     3      -.4182103297906871d-04,-.3530805884260532d-04,
     4      -.2697583978535142d-04,-.1869280515657354d-04,
     5      -.1174495874315474d-04,-.6765199019463534d-05,
     6      -.4355168818910803d-05,-.7071648760526727d-06,
     7      0.5285268887041941d-06,-.3081711938917839d-06,
     8      0.1803695285619033d-06,-.1254185820568708d-06/
         data arr1244/
     1      0.5745670002607425d-07,-.2948014843318897d-06,
     2      -.8702939815452171d-06,-.2679855702241978d-05,
     3      -.6545124514256968d-05,-.1224225571232484d-04,
     4      -.1941846785439197d-04,-.2636002928529752d-04,
     5      -.3069737157246829d-04,-.3131721765000974d-04,
     6      -.2859306080934897d-04,-.2359251585548646d-04,
     7      -.1759398787597873d-04,-.1184793443958661d-04,
     8      -.7310484580526739d-05,-.5130443475303635d-05/
         data arr1245/
     1      -.6548572197447584d-06,0.4862080206902475d-06,
     2      -.2823946508461346d-06,0.1650436059791920d-06,
     3      -.1113513219930444d-06,0.7737678918759782d-07,
     4      -.1330227576826189d-06,-.2815229249379199d-06,
     5      -.1020726954017822d-05,-.2915750241569188d-05,
     6      -.5946029775292548d-05,-.1041130171487677d-04,
     7      -.1551721347037109d-04,-.1956158653088388d-04,
     8      -.2141683795674845d-04,-.2086457637888942d-04/
         data arr1246/
     1      -.1823461957324906d-04,-.1426819560814618d-04,
     2      -.9985089452724401d-05,-.6348724154653492d-05,
     3      -.4560827715895609d-05,-.7483420162126481d-06,
     4      0.5694445194286805d-06,-.3354201969537209d-06,
     5      0.1980156615903694d-06,-.1337298718543058d-06,
     6      0.1033554092984935d-06,-.9987228411106162d-07,
     7      -.6898758267095740d-07,-.3376927371271129d-06,
     8      -.1281916974056267d-05,-.2710509251215651d-05/
         data arr1247/
     1      -.5266665279044128d-05,-.8759119898649120d-05,
     2      -.1201605677844610d-04,-.1420451505433723d-04,
     3      -.1499099255018017d-04,-.1420219101551183d-04,
     4      -.1198958463542285d-04,-.9002484857408461d-05,
     5      -.6139593610367371d-05,-.4826283334551922d-05,
     6      -.4955890072740027d-06,0.3720285858613710d-06,
     7      -.2174438447880259d-06,0.1276776619503386d-06,
     8      -.8574781349017196d-07,0.6714494029838097d-07/
         data arr1248/
     1      -.5712532425957604d-07,-.1007956047022294d-07,
     2      -.1010300421619844d-06,-.5206488573780447d-06,
     3      -.1135353829722371d-05,-.2421630756027794d-05,
     4      -.4386828355519587d-05,-.6410997199468641d-05,
     5      -.7997830770783492d-05,-.8846024230115823d-05,
     6      -.8698591287871795d-05,-.7542436946065018d-05,
     7      -.5762460556227163d-05,-.3964042487722060d-05,
     8      -.3104840345288249d-05,-.5074686471347196d-06/
         data arr1249/
     1      0.3935542035034218d-06,-.2342560256692638d-06,
     2      0.1392895044892194d-06,-.9448107032197872d-07,
     3      0.7485868307922644d-07,-.5883287824154417d-07,
     4      0.1214168263368659d-07,-.5473541238733526d-08,
     5      -.2475138616380309d-06,-.4479913993180706d-06,
     6      -.1077893397068828d-05,-.2259841393122774d-05,
     7      -.3575077570571486d-05,-.4783982336580753d-05,
     8      -.5751320832462436d-05,-.6167282572733618d-05/
         data arr1250/
     1      -.5790073991238493d-05,-.4754482013128698d-05,
     2      -.3515374177953818d-05,-.3027083144155742d-05,
     3      -.2365470410135339d-06,0.1823731343247006d-06,
     4      -.1082023160164519d-06,0.6419458437566876d-07,
     5      -.4345777246450333d-07,0.3443790444674514d-07,
     6      -.2676043701593865d-07,0.7515570124488117d-08,
     7      0.5219976611009624d-08,-.8843038431092401d-07,
     8      -.1444357845623455d-06,-.3788544393614906d-06/
         data arr1251/
     1      -.8599209730961559d-06,-.1419262212684250d-05,
     2      -.1968032632284467d-05,-.2446325183967318d-05,
     3      -.2694660912808630d-05,-.2578882037784928d-05,
     4      -.2145232532162594d-05,-.1598666591157699d-05,
     5      -.1379047298917747d-05,-.2144725950750210d-06,
     6      0.1722539973703752d-06,-.1044578069021631d-06,
     7      0.6289042803273048d-07,-.4308631990967496d-07,
     8      0.3435697230071589d-07,-.2634227749418169d-07/
         data arr1252/
     1      0.8394845662522950d-08,0.1497554112952570d-07,
     2      -.5473182106899401d-07,-.4459787694196659d-07,
     3      -.1421015212298718d-06,-.4161582812054649d-06,
     4      -.7333691038430857d-06,-.1073510876913735d-05,
     5      -.1455801856992544d-05,-.1761615404663448d-05,
     6      -.1830875617881973d-05,-.1637350796996259d-05,
     7      -.1312110191944600d-05,-.1247317655379779d-05,
     8      0.1927112004434454d-05,0.8094088261752710d-05/
         data arr1253/
     1      0.2247512222532940d-04,0.4378887834777655d-04,
     2      0.6457662553107670d-04,0.7588614995458503d-04,
     3      0.7387208955343386d-04,0.6135352700377911d-04,
     4      0.4448807376765165d-04,0.2868569789738138d-04,
     5      0.1669031623535205d-04,0.8866771051203372d-05,
     6      0.4343229882838209d-05,0.1977624814130881d-05,
     7      0.8423921325700864d-06,0.3371301427368902d-06,
     8      0.1271615959493460d-06,0.4543458146359126d-07/
         data arr1254/
     1      0.1560758920936009d-07,0.5931504611793526d-08,
     2      0.8346275435773832d-06,0.4714011976388098d-05,
     3      0.1658753302133917d-04,0.3969356849571633d-04,
     4      0.7006403751990477d-04,0.9657894758196330d-04,
     5      0.1084782253877864d-03,0.1025538990082010d-03,
     6      0.8369160386231225d-04,0.6014914322395479d-04,
     7      0.3868778816789285d-04,0.2256125062325420d-04,
     8      0.1205591370990082d-04,0.5954713084131579d-05/
         data arr1255/
     1      0.2738090265523481d-05,0.1178840753074621d-05,
     2      0.4772294384893481d-06,0.1821535798689815d-06,
     3      0.6589294262088972d-07,0.2564446855323158d-07,
     4      0.2453589313203651d-06,0.1887923847072983d-05,
     5      0.8412392968669359d-05,0.2472565678041008d-04,
     6      0.5223846344611654d-04,0.8446452033718927d-04,
     7      0.1094656215911585d-03,0.1177987003705040d-03,
     8      0.1081905701493616d-03,0.8666972030409661d-04/
         data arr1256/
     1      0.6162630127990402d-04,0.3944806222792318d-04,
     2      0.2299512977607244d-04,0.1232259874401939d-04,
     3      0.6118540991075349d-05,0.2833181534351786d-05,
     4      0.1229279092447019d-05,0.5012249245063854d-06,
     5      0.1931433214288436d-06,0.8050261708471574d-07,
     6      0.4764016342266995d-07,0.6066347209498689d-06,
     7      0.3387869630808337d-05,0.1224152028657739d-04,
     8      0.3095200503925414d-04,0.5870623301258224d-04/
         data arr1257/
     1      0.8778587068531260d-04,0.1075333659160482d-03,
     2      0.1111505361925161d-03,0.9924694386870538d-04,
     3      0.7801389055408185d-04,0.5481504646328241d-04,
     4      0.3485534271848944d-04,0.2026370621131188d-04,
     5      0.1086356945234332d-04,0.5408185127880513d-05,
     6      0.2512439233179100d-05,0.1092201640912444d-05,
     7      0.4469248550701727d-06,0.1982125438542608d-06,
     8      -.1438937127919066d-07,0.1777364231921627d-06/
         data arr1258/
     1      0.1145325821345976d-05,0.5119003860309566d-05,
     2      0.1547834009735877d-04,0.3444336181544074d-04,
     3      0.5942325412988717d-04,0.8285882284571062d-04,
     4      0.9638973516489802d-04,0.9593008344354553d-04,
     5      0.8336246029232156d-04,0.6429507958549701d-04,
     6      0.4459747671291374d-04,0.2812936804325643d-04,
     7      0.1628559015638759d-04,0.8720544766999002d-05,
     8      0.4341931682537376d-05,0.2016349895315544d-05/
         data arr1259/
     1      0.8797478038085065d-06,0.4195756855314373d-06,
     2      -.4832402435341923d-07,0.7030021736241833d-07,
     3      0.3259444481031586d-06,0.1874452195428127d-05,
     4      0.6752664136993888d-05,0.1764191369677665d-04,
     5      0.3510870806227293d-04,0.5572962172310951d-04,
     6      0.7296418723736898d-04,0.8093376565137924d-04,
     7      0.7775158514282418d-04,0.6582474766638274d-04,
     8      0.4979970984363556d-04,0.3406878931654937d-04/
         data arr1260/
     1      0.2128922786277412d-04,0.1224794524406358d-04,
     2      0.6520178598694967d-05,0.3220113075899388d-05,
     3      0.1486187219147025d-05,0.7494690802291155d-06,
     4      -.8724507805244055d-07,0.6479338427754226d-07,
     5      0.6130866562264296d-07,0.6229305555348660d-06,
     6      0.2620712282739757d-05,0.8064386716747034d-05,
     7      0.1849695819373323d-04,0.3343038769894728d-04,
     8      0.4926403582829600d-04,0.6089615663483797d-04/
         data arr1261/
     1      0.6467855147452344d-04,0.6011293491160359d-04,
     2      0.4960713522087285d-04,0.3681708688825712d-04,
     3      0.2484973900690204d-04,0.1538418749779505d-04,
     4      0.8782088801491659d-05,0.4636227295458973d-05,
     5      0.2284391531578133d-05,0.1243275682158953d-05,
     6      -.1315223826916501d-06,0.8704173939710396d-07,
     7      -.2255244296676329d-07,0.2030184701851408d-06,
     8      0.9113192280268746d-06,0.3345159396305819d-05/
         data arr1262/
     1      0.8819011090469685d-05,0.1815832707263909d-04,
     2      0.3012193097263135d-04,0.4148136068914371d-04,
     3      0.4871056053854742d-04,0.4969550455537798d-04,
     4      0.4471179125220223d-04,0.3596915291036438d-04,
     5      0.2618390940283110d-04,0.1739586260238761d-04,
     6      0.1059672828040437d-04,0.5932370974487759d-05,
     7      0.3081585750898443d-05,0.1767245748838833d-05,
     8      -.1845177895730018d-06,0.1208085221519014d-06/
         data arr1263/
     1      -.5817303208626633d-07,0.8313919625147496d-07,
     2      0.2754854904557425d-06,0.1281823141526443d-05,
     3      0.3843216541208403d-05,0.9031183039152798d-05,
     4      0.1687429814476004d-04,0.2586863798173922d-04,
     5      0.3359493073737265d-04,0.3764226811022746d-04,
     6      0.3693425841452271d-04,0.3222695586786094d-04,
     7      0.2534655985805389d-04,0.1813217333180303d-04,
     8      0.1185021271142691d-04,0.7093509354476074d-05/
         data arr1264/
     1      0.3935540551886246d-05,0.2439768377809621d-05,
     2      -.2229278035154835d-06,0.1454985243510800d-06,
     3      -.7483115796775023d-07,0.5393331097056698d-07,
     4      0.6056084220208821d-07,0.4656219942562062d-06,
     5      0.1539298622123253d-05,0.4149426266143635d-05,
     6      0.8737514966253320d-05,0.1488827705505519d-04,
     7      0.2138153150403700d-04,0.2629049081741437d-04,
     8      0.2807477351660622d-04,0.2648786750746457d-04/
         data arr1265/
     1      0.2239940823390504d-04,0.1711843339723009d-04,
     2      0.1186031009067469d-04,0.7464209548322892d-05,
     3      0.4319881097842113d-05,0.2780228196599930d-05,
     4      -.2634479708803741d-06,0.1730787626988117d-06,
     5      -.9104098300225622d-07,0.5413408514656447d-07,
     6      -.1111312038056260d-07,0.1738497768081630d-06,
     7      0.5632810533287628d-06,0.1771547117901870d-05,
     8      0.4223569509242129d-05,0.7963925420272514d-05/
         data arr1266/
     1      0.1266754075241721d-04,0.1713355753810762d-04,
     2      0.1994229776830804d-04,0.2039905110418065d-04,
     3      0.1865447075827177d-04,0.1537518425777186d-04,
     4      0.1144578276860291d-04,0.7712338085938800d-05,
     5      0.4776162453483726d-05,0.3336272015627717d-05,
     6      -.2591841271010123d-06,0.1701425144649409d-06,
     7      -.8953313709412976d-07,0.5092307947201086d-07,
     8      -.2866988453971762d-07,0.7330307625220560d-07/
         data arr1267/
     1      0.1842826789929775d-06,0.7069916279162574d-06,
     2      0.1914494385323742d-05,0.3966134598449673d-05,
     3      0.6981937562300984d-05,0.1035295423690804d-04,
     4      0.1305364820596121d-04,0.1436147561901032d-04,
     5      0.1404481882819350d-04,0.1228923443328312d-04,
     6      0.9628322506424469d-05,0.6769825560084291d-05,
     7      0.4343368515272971d-05,0.3131741295100719d-05,
     8      -.2549676485446767d-06,0.1692273745527298d-06/
         data arr1268/
     1      -.9069139504632928d-07,0.5246551711307445d-07,
     2      -.3593642008261914d-07,0.4396366581890292d-07,
     3      0.4671358714638208d-07,0.2614114103825453d-06,
     4      0.8329720977180021d-06,0.1852044222960816d-05,
     5      0.3630728488619169d-05,0.5953570479772336d-05,
     6      0.8166900831540821d-05,0.9724801411990740d-05,
     7      0.1029257059832338d-04,0.9727753003270023d-05,
     8      0.8194883079005838d-05,0.6167785413131177d-05/
         data arr1269/
     1      0.4232391738083033d-05,0.3312320875290292d-05,
     2      -.1863785347679688d-06,0.1231830149066019d-06,
     3      -.6556804338484731d-07,0.3748160801667183d-07,
     4      -.2620725135455170d-07,0.2569200378369599d-07,
     5      0.5684490778138257d-08,0.9083221748308564d-07,
     6      0.3374780258166883d-06,0.7927561745092180d-06,
     7      0.1716258478084227d-05,0.3056419363031487d-05,
     8      0.4472501854176388d-05,0.5637052241007381d-05/
         data arr1270/
     1      0.6270713571005297d-05,0.6170294681368954d-05,
     2      0.5357651698559914d-05,0.4119325363890517d-05,
     3      0.2865106700303034d-05,0.2252386387356032d-05,
     4      -.1535631285984278d-06,0.1033673630654806d-06,
     5      -.5663954059948408d-07,0.3373636302983119d-07,
     6      -.2482304149375660d-07,0.2161758220673742d-07,
     7      -.6841011973192458d-08,0.2577237420674992d-07,
     8      0.1441710510323486d-06,0.3231459697976583d-06/
         data arr1271/
     1      0.7925675097803228d-06,0.1586247918182106d-05,
     2      0.2517149776920661d-05,0.3423465135348633d-05,
     3      0.4130162511884045d-05,0.4405581107738441d-05,
     4      0.4124052789975141d-05,0.3399919764892053d-05,
     5      0.2533610037118629d-05,0.2168804781673857d-05,
     6      -.7885150230456656d-07,0.5314799902922964d-07,
     7      -.2918121506310819d-07,0.1742654905977428d-07,
     8      -.1288344545296211d-07,0.1093620456158008d-07/
         data arr1272/
     1      -.5110853302829312d-08,0.6105752806119692d-08,
     2      0.5126785119620517d-07,0.1084484810748883d-06,
     3      0.2934694206459779d-06,0.6338575955433361d-06,
     4      0.1055003772093756d-05,0.1497024162314847d-05,
     5      0.1880173237381744d-05,0.2075630399462635d-05,
     6      0.1996682488306469d-05,0.1681592453067452d-05,
     7      0.1274744868931990d-05,0.1107681080897411d-05,
     8      -.5031060856160648d-07,0.3507781888839893d-07/
         data arr1273/
     1      -.2025005948426240d-07,0.1291073171919797d-07,
     2      -.1010945117704513d-07,0.8375145518236082d-08,
     3      -.4122853504538020d-08,-.1375157355671766d-08,
     4      0.2477577882648581d-07,0.3714614566163271d-07,
     5      0.1178294149394944d-06,0.2985107675849580d-06,
     6      0.5346229655954744d-06,0.8099782122051116d-06,
     7      0.1101196204917527d-05,0.1318613913222482d-05,
     8      0.1365931309264926d-05,0.1229903802661703d-05/
         data arr1274/
     1      0.9953537289725515d-06,0.9381052514026310d-06,
     2      -.7494980974880295d-07,-.1170344854486784d-05,
     3      -.3885374812815787d-05,-.9366931353333577d-05,
     4      -.1650815663007545d-04,-.2276750812815026d-04,
     5      -.2556714500777021d-04,-.2417125193356438d-04,
     6      -.1972864974084475d-04,-.1417579646102633d-04,
     7      -.9117956183421625d-05,-.5319332001947479d-05,
     8      -.2841880297279860d-05,-.1402243019636436d-05/
         data arr1275/
     1      -.6449631088953906d-06,-.2787408127589845d-06,
     2      -.1132274074025216d-06,-.4272569264374943d-07,
     3      -.1480874472797937d-07,-.5551795018987897d-08,
     4      -.3166341605552469d-07,-.6358764175940640d-06,
     5      -.2719675021726207d-05,-.8026526473651513d-05,
     6      -.1694589135174985d-04,-.2740540054098901d-04,
     7      -.3551482041354652d-04,-.3821843849775542d-04,
     8      -.3510272244718724d-04,-.2811880855205300d-04/
         data arr1276/
     1      -.1999372595829610d-04,-.1279931610285061d-04,
     2      -.7460857278902440d-05,-.3997428502391090d-05,
     3      -.1984820344843229d-05,-.9195467177568993d-06,
     4      -.3992386351363903d-06,-.1626092531636926d-06,
     5      -.6229948609093554d-07,-.2555414456005934d-07,
     6      -.1149083226493812d-07,-.2384349569606085d-06,
     7      -.1310440805075123d-05,-.4742126508105427d-05,
     8      -.1198694537025671d-04,-.2273724732432278d-04/
         data arr1277/
     1      -.3399937931201039d-04,-.4164695262592089d-04,
     2      -.4304903958539571d-04,-.3843817753598519d-04,
     3      -.3021407074964636d-04,-.2123004771471778d-04,
     4      -.1349996270248163d-04,-.7847937528806551d-05,
     5      -.4207025507583979d-05,-.2094695978204025d-05,
     6      -.9735987901500182d-06,-.4233334161912111d-06,
     7      -.1728490892906316d-06,-.7554177603092194d-07,
     8      -.9493033781435672d-08,-.7024831911894649d-07/
         data arr1278/
     1      -.5021888671697313d-06,-.2233722232691173d-05,
     2      -.6755080990700092d-05,-.1503243882265219d-04,
     3      -.2593495505031179d-04,-.3616137283841015d-04,
     4      -.4206893375341686d-04,-.4186769741922977d-04,
     5      -.3638104138044492d-04,-.2806096263209218d-04,
     6      -.1946527590303929d-04,-.1227652899641247d-04,
     7      -.7106596573681729d-05,-.3806046741184091d-05,
     8      -.1896244584006799d-05,-.8809928209656638d-06/
         data arr1279/
     1      -.3835890241233452d-06,-.1801810965333632d-06,
     2      -.1550279804119310d-07,-.1539218393079630d-07,
     3      -.1614778826704447d-06,-.8921847836312630d-06,
     4      -.3219104312145547d-05,-.8410481951361399d-05,
     5      -.1673858359656008d-04,-.2656567096245419d-04,
     6      -.3478620776208568d-04,-.3858452783893080d-04,
     7      -.3706390092536830d-04,-.3138102561341127d-04,
     8      -.2374348585166226d-04,-.1624090095361773d-04/
         data arr1280/
     1      -.1014625230354255d-04,-.5837804693696754d-05,
     2      -.3109404498551686d-05,-.1535619664662136d-05,
     3      -.7063954950900884d-06,-.3497570163314601d-06,
     4      -.3230745306865770d-07,0.2400393707714210d-08,
     5      -.4289246037203251d-07,-.3157264510376327d-06,
     6      -.1338016413969574d-05,-.4119240276531308d-05,
     7      -.9449526558963452d-05,-.1706989367584616d-04,
     8      -.2516584032003188d-04,-.3110442162115520d-04/
         data arr1281/
     1      -.3302941094370651d-04,-.3070413964735032d-04,
     2      -.2534246067028712d-04,-.1880373777887739d-04,
     3      -.1268778244579440d-04,-.7857804800164560d-05,
     4      -.4490540919226924d-05,-.2371766928845436d-05,
     5      -.1165044017183453d-05,-.6230448229903066d-06,
     6      -.5160964061957593d-07,0.9526033309192578d-08,
     7      -.6206496742597014d-08,-.1058189743813446d-06,
     8      -.4912823363600660d-06,-.1807156449315248d-05/
         data arr1282/
     1      -.4766191618634696d-05,-.9798949158209681d-05,
     2      -.1627422269077438d-04,-.2240485396142283d-04,
     3      -.2629819199532381d-04,-.2684094034841845d-04,
     4      -.2415631532612623d-04,-.1942514959044966d-04,
     5      -.1413505720980963d-04,-.9396421028623188d-05,
     6      -.5731976036931608d-05,-.3210626201196124d-05,
     7      -.1661925549924537d-05,-.9356550407398167d-06,
     8      -.9037910394074650d-07,0.1929848093697573d-07/
         data arr1283/
     1      0.5653642407203422d-08,-.4241263248520042d-07,
     2      -.1532660132912488d-06,-.7269373627061027d-06,
     3      -.2178911022936345d-05,-.5096286636465005d-05,
     4      -.9556916515919581d-05,-.1463641094847661d-04,
     5      -.1899013626203173d-04,-.2129859272299574d-04,
     6      -.2090858648208199d-04,-.1822995798610400d-04,
     7      -.1433099595025461d-04,-.1026450307725729d-04,
     8      -.6724184451966158d-05,-.4029531727467199d-05/
         data arr1284/
     1      -.2228108064835355d-05,-.1357376716072550d-05,
     2      -.1066980232575021d-06,0.2239353910463151d-07,
     3      0.9844138614833888d-08,-.2540170285442869d-07,
     4      -.3307029922336963d-07,-.2757470164316733d-06,
     5      -.9118628862530971d-06,-.2426323148161078d-05,
     6      -.5154083755662117d-05,-.8763382965202592d-05,
     7      -.1256254099964340d-04,-.1547183772150118d-04,
     8      -.1653288845079931d-04,-.1557795351036801d-04/
         data arr1285/
     1      -.1316027010276612d-04,-.1006641498722825d-04,
     2      -.6986130044392743d-05,-.4394762762604326d-05,
     3      -.2528018565043449d-05,-.1590591168678415d-05,
     4      -.1654071024043693d-06,0.3760979653839146d-07,
     5      0.1312144909258069d-07,-.2768751439592157d-07,
     6      0.1301965105772679d-07,-.1104726104034223d-06,
     7      -.3501387219047088d-06,-.1056756594101131d-05,
     8      -.2591253095004633d-05,-.4850288870663519d-05/
         data arr1286/
     1      -.7685108598972063d-05,-.1043738401338004d-04,
     2      -.1216304399022540d-04,-.1241294020806310d-04,
     3      -.1134147692309412d-04,-.9372727582193060d-05,
     4      -.7003978862953804d-05,-.4724063721418076d-05,
     5      -.2911066209078370d-05,-.1994810132211718d-05,
     6      -.1646106354737698d-06,0.3711563087859404d-07,
     7      0.1346631858972330d-07,-.2651030316305705d-07,
     8      0.2414109633398533d-07,-.5059729487341996d-07/
         data arr1287/
     1      -.1229988774534189d-06,-.4218311807935141d-06,
     2      -.1221084233060632d-05,-.2489977156495267d-05,
     3      -.4352750853707749d-05,-.6500696436170719d-05,
     4      -.8210863468982421d-05,-.9003515005827425d-05,
     5      -.8795765773592613d-05,-.7722016902008002d-05,
     6      -.6075660022281397d-05,-.4274594201828971d-05,
     7      -.2726100093061106d-05,-.1925004770359436d-05,
     8      -.2232397945014742d-06,0.5411482784147979d-07/
         data arr1288/
     1      0.1444063621076042d-07,-.3230719773280396d-07,
     2      0.3442833706025687d-07,-.3696842926451530d-07,
     3      -.3713681626982453d-07,-.1416124434897856d-06,
     4      -.5643133494727643d-06,-.1193267346871807d-05,
     5      -.2306256973830426d-05,-.3848963628667718d-05,
     6      -.5293380607818491d-05,-.6263753766497586d-05,
     7      -.6627463294143578d-05,-.6308834313232321d-05,
     8      -.5355819922959441d-05,-.4040980637783142d-05/
         data arr1289/
     1      -.2760490687511109d-05,-.2125801919959186d-05,
     2      -.1445875900943378d-06,0.3379737981583042d-07,
     3      0.1062183531517065d-07,-.2194591724388042d-07,
     4      0.2359403859186153d-07,-.2182114982655048d-07,
     5      -.9327852542255216d-08,-.4230003664860260d-07,
     6      -.2405388268506796d-06,-.5240777473889657d-06,
     7      -.1109483100726220d-05,-.2020176551971414d-05,
     8      -.2962776784752295d-05,-.3702622873175958d-05/
         data arr1290/
     1      -.4109044220634404d-05,-.4062111493454542d-05,
     2      -.3542351989882102d-05,-.2718844559512138d-05,
     3      -.1872368773161164d-05,-.1435129078141755d-05,
     4      -.1818849104289626d-06,0.4603273797124954d-07,
     5      0.9789379713173903d-08,-.2461012003352210d-07,
     6      0.2737922703479796d-07,-.2286746494076983d-07,
     7      0.4044459960646433d-09,0.2728842476967859d-08,
     8      -.1200115026082689d-06,-.2169882181309454d-06/
         data arr1291/
     1      -.5104541594002704d-06,-.1082945586905981d-05,
     2      -.1722548655415797d-05,-.2306897766684357d-05,
     3      -.2783664700971677d-05,-.3005640694879881d-05,
     4      -.2841772044470645d-05,-.2345619438554137d-05,
     5      -.1735811468637387d-05,-.1460394038934525d-05,
     6      -.9805591096052616d-07,0.2482977265914588d-07,
     7      0.5263353875505075d-08,-.1325536918975355d-07,
     8      0.1475948401003852d-07,-.1215911241509558d-07/
         data arr1292/
     1      0.1310840421382056d-08,0.6499729680508312d-08,
     2      -.4792035886895185d-07,-.7455500605920825d-07,
     3      -.1904385175664808d-06,-.4466167326971016d-06,
     4      -.7451717049585496d-06,-.1037903280961756d-05,
     5      -.1304853301796986d-05,-.1460924205029521d-05,
     6      -.1420543265791810d-05,-.1197533821121029d-05,
     7      -.9009546612629266d-06,-.7689057014199784d-06,
     8      -.1061252349015633d-06,0.2863080181854180d-07/
         data arr1293/
     1      0.3913940350280371d-08,-.1285782341013019d-07,
     2      0.1473302753225045d-07,-.1182666045036284d-07,
     3      0.1866330198591405d-08,0.1189734381804329d-07,
     4      -.3091348670800646d-07,-.2436548666593697d-07,
     5      -.7114237250204661d-07,-.2230373067018539d-06,
     6      -.3983427907129591d-06,-.5828774539876686d-06,
     7      -.7982631506092810d-06,-.9819449761327474d-06,
     8      -.1035790806957909d-05,-.9363797255240013d-06/
         data arr1294/
     1      -.7545397193890544d-06,-.7044997574856399d-06,
     2      0.6926260100933863d-06,0.1723470226464918d-05,
     3      0.3842971813748800d-05,0.6102848727515624d-05,
     4      0.7927070249108001d-05,0.8592512217544360d-05,
     5      0.7807843665215971d-05,0.6282827382927791d-05,
     6      0.4509839387813226d-05,0.2850331932371595d-05,
     7      0.1637122422277996d-05,0.9034225367423888d-06,
     8      0.4718381293477813d-06,0.2081305385374513d-06/
         data arr1295/
     1      0.6786954271139664d-07,0.1971358677034818d-07,
     2      0.1699876665382337d-07,0.2587462365141894d-07,
     3      0.4480112252708212d-06,0.1426469111636947d-05,
     4      0.3727177453289277d-05,0.7003817700417835d-05,
     5      0.1048491146630019d-04,0.1287692077353703d-04,
     6      0.1326366667949558d-04,0.1185973615638693d-04,
     7      0.9344773257502023d-05,0.6545727424228569d-05,
     8      0.4149854725272912d-05,0.2426948661382736d-05/
         data arr1296/
     1      0.1313149202548818d-05,0.6479740698014071d-06,
     2      0.2893946359555040d-06,0.1219827176221234d-06,
     3      0.5497670439530146d-07,0.3382416657166897d-07,
     4      0.2009654550095458d-06,0.8112188665358015d-06,
     5      0.2504922049211332d-05,0.5546292994836662d-05,
     6      0.9574017784641512d-05,0.1336307736783741d-04,
     7      0.1552669521609554d-04,0.1545947673513181d-04,
     8      0.1344277606513440d-04,0.1036002911417348d-04/
         data arr1297/
     1      0.7181430614470999d-05,0.4535248880567091d-05,
     2      0.2630329862584507d-05,0.1406312099421028d-05,
     3      0.6958198885964688d-06,0.3216597471311891d-06,
     4      0.1420488905408393d-06,0.7021922924775009d-07,
     5      0.7161555682086909d-07,0.3672521668219234d-06,
     6      0.1346461285750763d-05,0.3505743038709425d-05,
     7      0.6978619477679715d-05,0.1108339097597910d-04,
     8      0.1450314735734307d-04,0.1608982569121066d-04/
         data arr1298/
     1      0.1546102059428388d-04,0.1308624486286181d-04,
     2      0.9898291085695038d-05,0.6773867147063188d-05,
     3      0.4235179189833933d-05,0.2436027627074817d-05,
     4      0.1295020813133851d-05,0.6385871625467194d-06,
     5      0.2947118094433505d-06,0.1471488472112563d-06,
     6      0.2028427441901181d-07,0.1409202975007378d-06,
     7      0.6139449883254002d-06,0.1879009215652262d-05,
     8      0.4310672690964261d-05,0.7796685449323025d-05/
         data arr1299/
     1      0.1148266623552161d-04,0.1419550177059079d-04,
     2      0.1508095136640654d-04,0.1401403099166498d-04,
     3      0.1156252338378378d-04,0.8583085716089317d-05,
     4      0.5795493368982161d-05,0.3587856532471216d-05,
     5      0.2046401621864809d-05,0.1078797311984049d-05,
     6      0.5304501645390113d-06,0.2837853498464791d-06,
     7      0.2607933015215226d-08,0.4776901786213055d-07,
     8      0.2451462291524907d-06,0.8838397829212899d-06/
         data arr1300/
     1      0.2331022521548552d-05,0.4808757123044064d-05,
     2      0.7966828410129328d-05,0.1097338363610753d-04,
     3      0.1289186002002592d-04,0.1314997047140017d-04,
     4      0.1182900922735711d-04,0.9520560302004929d-05,
     5      0.6937116667260046d-05,0.4612525852380374d-05,
     6      0.2810838513616799d-05,0.1574332067748309d-05,
     7      0.8183659101665683d-06,0.4634535878255462d-06,
     8      -.3928874669020146d-08,0.1532035190103283d-07/
         data arr1301/
     1      0.8701457278024871d-07,0.3744205819367763d-06,
     2      0.1124556777668047d-05,0.2657749598389166d-05,
     3      0.4948778562380313d-05,0.7590317956282348d-05,
     4      0.9866745758863893d-05,0.1105016630734637d-04,
     5      0.1083738765404093d-04,0.9461341403948248d-05,
     6      0.7448934676487570d-05,0.5331310389586860d-05,
     7      0.3483014817186491d-05,0.2083772360437184d-05,
     8      0.1155289203110900d-05,0.7049187843963148d-06/
         data arr1302/
     1      -.6731193534190792d-08,0.5368625430744272d-08,
     2      0.2746320559652629d-07,0.1467498786985844d-06,
     3      0.4883720251208545d-06,0.1338011942549144d-05,
     4      0.2792852971953963d-05,0.4764791468145739d-05,
     5      0.6855958366385035d-05,0.8422730867862113d-05,
     6      0.8988591723993657d-05,0.8488905038313733d-05,
     7      0.7189729832508634d-05,0.5498478674471485d-05,
     8      0.3808048027854404d-05,0.2395003654374299d-05/
         data arr1303/
     1      0.1384785236369016d-05,0.8760779983671730d-06,
     2      -.9251532727662540d-08,0.3307897828614081d-08,
     3      0.6618160447841158d-08,0.5697307281995387d-07,
     4      0.1884421704167487d-06,0.6232754540941981d-06,
     5      0.1450441254341614d-05,0.2743494915352938d-05,
     6      0.4381167037952741d-05,0.5914161340634687d-05,
     7      0.6874363548690789d-05,0.7041284075297386d-05,
     8      0.6451317243229432d-05,0.5319367088407751d-05/
         data arr1304/
     1      0.3955489076583447d-05,0.2661652331319164d-05,
     2      0.1645623775309118d-05,0.1127757810332211d-05,
     3      -.9980037627284676d-08,0.2783921454493363d-08,
     4      0.2515244663517151d-09,0.2411211008626148d-07,
     5      0.6141819238999694d-07,0.2730792582517320d-06,
     6      0.6982820048776097d-06,0.1456084458859355d-05,
     7      0.2583945577776338d-05,0.3821677522734197d-05,
     8      0.4813520805606524d-05,0.5314078503216563d-05/
         data arr1305/
     1      0.5221355665007758d-05,0.4584275160092441d-05,
     2      0.3600127953089397d-05,0.2538781745061876d-05,
     3      0.1635023318875038d-05,0.1165776801089108d-05,
     4      -.1096845273100318d-07,0.3438204075642442d-08,
     5      -.2448396166688041d-08,0.1410438907778379d-07,
     6      0.1143971506431053d-07,0.1157331746082154d-06,
     7      0.3177253654082635d-06,0.7169212457387178d-06,
     8      0.1427496196401485d-05,0.2326207352013709d-05/
         data arr1306/
     1      0.3181431088112760d-05,0.3803689073330121d-05,
     2      0.4046482224391782d-05,0.3834911740440156d-05,
     3      0.3234379783661497d-05,0.2438773556349928d-05,
     4      0.1677905896776002d-05,0.1295156204498877d-05,
     5      -.8260684442978368d-08,0.2365177456794191d-08,
     6      -.1880218728230486d-08,0.8237666618796929d-08,
     7      -.2749523253618222d-08,0.4808281763515303d-07,
     8      0.1333587385716430d-06,0.3220457056443466d-06/
         data arr1307/
     1      0.7147836941958495d-06,0.1260434573369961d-05,
     2      0.1837460570841733d-05,0.2328894721010623d-05,
     3      0.2606451301972245d-05,0.2571085091426918d-05,
     4      0.2233065789197554d-05,0.1717961679379771d-05,
     5      0.1195901163768024d-05,0.9240693790580383d-06,
     6      -.7841861648805859d-08,0.2858604969830957d-08,
     7      -.2676927938279917d-08,0.7352122118156627d-08,
     8      -.7466072289144879d-08,0.2124959958944328d-07/
         data arr1308/
     1      0.5778427559562396d-07,0.1359285994239412d-06,
     2      0.3496281063771945d-06,0.6853050614916294d-06,
     3      0.1078749219968683d-05,0.1477622688696232d-05,
     4      0.1795801368717919d-05,0.1919825501699584d-05,
     5      0.1796433857780698d-05,0.1481362014926329d-05,
     6      0.1104546343347186d-05,0.9281178571946322d-06,
     7      -.4568768727367657d-08,0.1744709001332953d-08,
     8      -.1659823165444559d-08,0.4249964483551742d-08/
         data arr1309/
     1      -.5010456948545408d-08,0.8644626698825234d-08,
     2      0.2183694856200445d-07,0.4818833783223665d-07,
     3      0.1407001620692488d-06,0.2970429586048751d-06,
     4      0.4911350069719455d-06,0.7061717188251296d-06,
     5      0.9000608465950402d-06,0.1002940437690783d-05,
     6      0.9709742693438814d-06,0.8234347934036543d-06,
     7      0.6289272870060667d-06,0.5411483769138946d-06,
     8      -.3570705050411371d-08,0.1801045366908628d-08/
         data arr1310/
     1      -.1881131537647666d-08,0.3547116703761807d-08,
     2      -.3960977571270242d-08,0.3462930701907663d-08,
     3      0.1081336678993028d-07,0.1635031850120755d-07,
     4      0.6007241060841968d-07,0.1462015414217707d-06,
     5      0.2582102798346608d-06,0.3969086572108370d-06,
     6      0.5491638791862974d-06,0.6649400166671381d-06,
     7      0.6941472160846779d-06,0.6302499693235126d-06,
     8      0.5146611317103920d-06,0.4810113604828058d-06/
         data arr1311/
     1      -.9370057084608166d-07,-.3066928643822850d-06,
     2      -.7920971156230610d-06,-.1493711202722171d-05,
     3      -.2238150547114052d-05,-.2740595156221316d-05,
     4      -.2830860775098595d-05,-.2530372529180263d-05,
     5      -.1988416370707514d-05,-.1395555109458206d-05,
     6      -.8882489634877878d-06,-.5175182242680494d-06,
     7      -.2770488001758523d-06,-.1370453554506823d-06,
     8      -.6357253308612767d-07,-.2823562286742014d-07/
         data arr1312/
     1      -.1210469143554840d-07,-.5277513538577396d-08,
     2      -.5811464678046333d-07,-.2406203625840636d-06,
     3      -.7372748611151526d-06,-.1635794087498369d-05,
     4      -.2824780949020616d-05,-.3937945512583186d-05,
     5      -.4580344294790892d-05,-.4559868633304797d-05,
     6      -.3961938364067524d-05,-.3055078151418315d-05,
     7      -.2119710326558867d-05,-.1337443130280274d-05,
     8      -.7740163843722125d-06,-.4141288902787939d-06/
         data arr1313/
     1      -.2063175943955672d-06,-.9616376539288293d-07,
     2      -.4210313758570805d-07,-.1946689187487756d-07,
     3      -.2485652264261328d-07,-.1306799174106611d-06,
     4      -.4751849556051040d-06,-.1239688043422012d-05,
     5      -.2468274046856056d-05,-.3916967926159062d-05,
     6      -.5128882399694331d-05,-.5689383672487441d-05,
     7      -.5464964682227005d-05,-.4626823511648873d-05,
     8      -.3500922663480343d-05,-.2394842348555190d-05/
         data arr1314/
     1      -.1496089467840665d-05,-.8607132253990277d-06,
     2      -.4584374209114281d-06,-.2264029843275135d-06,
     3      -.1039840444024913d-06,-.5047156910661713d-07,
     4      -.7984596709034072d-08,-.5753048948127854d-07,
     5      -.2443139028029754d-06,-.7520335330143554d-06,
     6      -.1725456077612658d-05,-.3116427976731898d-05,
     7      -.4594942011018818d-05,-.5679167041497071d-05,
     8      -.6030447053937467d-05,-.5606062152864868d-05/
         data arr1315/
     1      -.4627168143464681d-05,-.3433216267302360d-05,
     2      -.2316636632206724d-05,-.1434949013736672d-05,
     3      -.8201189963600751d-06,-.4329753716289827d-06,
     4      -.2121279867273251d-06,-.1110832041904558d-06,
     5      -.1089919834465464d-08,-.2310970852266933d-07,
     6      -.1051232847984458d-06,-.3884777366205319d-06,
     7      -.1024175616219125d-05,-.2104641518093489d-05,
     8      -.3497082297675384d-05,-.4813632971604774d-05/
         data arr1316/
     1      -.5649955814651675d-05,-.5768114668907823d-05,
     2      -.5192444017718842d-05,-.4176835878629800d-05,
     3      -.3042221443161704d-05,-.2026398445300903d-05,
     4      -.1239959673489653d-05,-.6972495237287279d-06,
     5      -.3623140087813228d-06,-.2022480674182580d-06,
     6      0.2043837388717320d-08,-.1112887219415889d-07,
     7      -.3672962665264522d-07,-.1781967081061182d-06,
     8      -.5333352880328531d-06,-.1245607045853749d-05/
         data arr1317/
     1      -.2338764244896613d-05,-.3580230995697084d-05,
     2      -.4644622299077814d-05,-.5210956309259035d-05,
     3      -.5116078318430840d-05,-.4460683146255933d-05,
     4      -.3508342916154419d-05,-.2515795859984263d-05,
     5      -.1650569417902058d-05,-.9902942690139929d-06,
     6      -.5472447524574900d-06,-.3275331533959441d-06,
     7      0.3495166178888029d-08,-.7922889608839592d-08,
     8      -.7950324467651748d-08,-.7554160031335991d-07/
         data arr1318/
     1      -.2485431753692776d-06,-.6588086476439900d-06,
     2      -.1403920456313672d-05,-.2384806969602753d-05,
     3      -.3418289507640707d-05,-.4213063425343270d-05,
     4      -.4503582298511008d-05,-.4244652246523807d-05,
     5      -.3589668603789956d-05,-.2751241930950982d-05,
     6      -.1913877039370994d-05,-.1206312563282038d-05,
     7      -.6939516433546300d-06,-.4291790552004854d-06,
     8      0.5720546678361322d-08,-.1005002749233320d-07/
         data arr1319/
     1      0.5599987724279897d-08,-.3376001300581770d-07,
     2      -.1050081084102071d-06,-.3125298391235157d-06,
     3      -.7738108384539898d-06,-.1444242720967575d-05,
     4      -.2287060317235900d-05,-.3109980150732297d-05,
     5      -.3624710082412101d-05,-.3698345979612643d-05,
     6      -.3381556873734505d-05,-.2799106833392449d-05,
     7      -.2094821178399499d-05,-.1413366390462890d-05,
     8      -.8686649437412915d-06,-.5819192445349122d-06/
         data arr1320/
     1      0.6988468489688747d-08,-.1176383282534862d-07,
     2      0.1100352938494136d-07,-.1823126394838526d-07,
     3      -.4037015975052807d-07,-.1320947337420547d-06,
     4      -.3974311351696194d-06,-.8014468766994744d-06,
     5      -.1400315643983757d-05,-.2103058216160483d-05,
     6      -.2662635913172358d-05,-.2925653535153201d-05,
     7      -.2874388366678544d-05,-.2546957087409077d-05,
     8      -.2025375835291547d-05,-.1440073450387799d-05/
         data arr1321/
     1      -.9273699362093078d-06,-.6528722265048429d-06,
     2      0.8942184364612725d-08,-.1503311627642123d-07,
     3      0.1547892114162433d-07,-.1489127512669207d-07,
     4      -.1418946004642151d-07,-.4521319175152911d-07,
     5      -.1997888685155051d-06,-.4115622710026362d-06,
     6      -.7921424269307856d-06,-.1330986837574742d-05,
     7      -.1831357796136853d-05,-.2165597418610778d-05,
     8      -.2298697020374983d-05,-.2201610257640027d-05/
         data arr1322/
     1      -.1880279681068969d-05,-.1424775695794741d-05,
     2      -.9747416100898540d-06,-.7381439892569829d-06,
     3      0.6555534242597004d-08,-.1095391904741591d-07,
     4      0.1147564364055534d-07,-.9632674972323834d-08,
     5      -.4175859930346872d-08,-.1221856890185044d-07,
     6      -.9164293061667207d-07,-.1914098789569915d-06,
     7      -.4042554634454687d-06,-.7457855004551954d-06,
     8      -.1096624190752117d-05,-.1371952782828145d-05/
         data arr1323/
     1      -.1531709833341384d-05,-.1528130643914358d-05,
     2      -.1344245175456649d-05,-.1038738321451325d-05,
     3      -.7182637100206483d-06,-.5434046295250977d-06,
     4      0.7736951838820595d-08,-.1306629215054114d-07,
     5      0.1373289765991309d-07,-.1078386592588278d-07,
     6      -.1289293076707280d-08,0.3600472562994170d-08,
     7      -.5174385321522981d-07,-.8534342797653569d-07,
     8      -.1962088282415210d-06,-.4228409894776343d-06/
         data arr1324/
     1      -.6709881314749189d-06,-.8950449827463815d-06,
     2      -.1083900246367845d-05,-.1178598040642891d-05,
     3      -.1120203361420400d-05,-.9264456328648739d-06,
     4      -.6841299218912143d-06,-.5623609168731524d-06,
     5      0.5552613457277968d-08,-.9415219455411508d-08,
     6      0.9890762484694465d-08,-.7686890245527627d-08,
     7      -.4559195167515580d-09,0.5625735327936526d-08,
     8      -.2669667184396718d-07,-.3302359190268296d-07/
         data arr1325/
     1      -.8060002536898348d-07,-.2002571213715662d-06,
     2      -.3348824695603399d-06,-.4660108113773174d-06,
     3      -.5967596358819676d-06,-.6861435063820888d-06,
     4      -.6828545045389953d-06,-.5861718051716566d-06,
     5      -.4475525382464425d-06,-.3822355795724407d-06,
     6      0.5178186297754226d-08,-.8864552322411391d-08,
     7      0.9294672707577477d-08,-.7209402532108034d-08,
     8      -.5225095263205346d-09,0.6673128939348247d-08/
         data arr1326/
     1      -.1960939176563384d-07,-.1350259467233933d-07,
     2      -.3207970046324838d-07,-.1040819128219318d-06,
     3      -.1821261672859936d-06,-.2616847863307421d-06,
     4      -.3616634846505950d-06,-.4532268107763915d-06,
     5      -.4846679994886080d-06,-.4415168768854860d-06,
     6      -.3568843904513912d-06,-.3279395254199657d-06,
     7      0.1400472787892620d-06,0.3377392593994090d-06,
     8      0.5725417090178841d-06,0.8088095162108331d-06/
         data arr1327/
     1      0.9328672447487832d-06,0.9287532484708377d-06,
     2      0.8124946207501075d-06,0.6240163372505707d-06,
     3      0.4296432114062367d-06,0.2729648193342655d-06,
     4      0.1606776637902436d-06,0.8556300356086585d-07,
     5      0.4049927379599616d-07,0.1776528686436044d-07,
     6      0.8391597636576758d-08,0.5693508095810204d-08,
     7      0.1251013459592072d-06,0.3535219571168168d-06,
     8      0.6950996120139510d-06,0.1112039729453374d-05/
         data arr1328/
     1      0.1449085409286439d-05,0.1607874434797840d-05,
     2      0.1549110189175136d-05,0.1309149524997758d-05,
     3      0.9877796940477342d-06,0.6773307662052096d-06,
     4      0.4252483314975219d-06,0.2440235331706945d-06,
     5      0.1279553272552960d-06,0.6210823875603381d-07,
     6      0.2890595896158597d-07,0.1530760122657913d-07,
     7      0.7717453241940038d-07,0.2571242162687446d-06,
     8      0.5843487833722114d-06,0.1061348627145125d-05/
         data arr1329/
     1      0.1560124746421591d-05,0.1928594559332777d-05,
     2      0.2051115447667942d-05,0.1905110507593095d-05,
     3      0.1570462174738261d-05,0.1166356512253496d-05,
     4      0.7885233394621348d-06,0.4879766924398094d-06,
     5      0.2774187382329849d-06,0.1456179095169331d-06,
     6      0.7152597664178113d-07,0.3810922412922159d-07,
     7      0.3747040701616614d-07,0.1506346814113885d-06,
     8      0.3928262937671760d-06,0.8122928837289130d-06/
         data arr1330/
     1      0.1345793349468996d-05,0.1852476265833098d-05,
     2      0.2177421139426412d-05,0.2221765972671313d-05,
     3      0.1998326752744478d-05,0.1608908509103736d-05,
     4      0.1174145787282168d-05,0.7827489358646975d-06,
     5      0.4785442730661208d-06,0.2691030449077832d-06,
     6      0.1406937718033736d-06,0.7971392767333032d-07,
     7      0.1423150708268709d-07,0.7633899674559181d-07,
     8      0.2235206917286138d-06,0.5290484619278627d-06/
         data arr1331/
     1      0.9877330188364599d-06,0.1512079826205704d-05,
     2      0.1966046388235026d-05,0.2203822958385395d-05,
     3      0.2161001642495687d-05,0.1886086785540312d-05,
     4      0.1486427878244450d-05,0.1066364851588713d-05,
     5      0.6985175674787547d-06,0.4187724305214392d-06,
     6      0.2324661826097847d-06,0.1404755570518673d-06,
     7      0.3049296560502334d-08,0.3556385128685541d-07,
     8      0.1103292319671993d-06,0.3027588109974776d-06/
         data arr1332/
     1      0.6368514721691476d-06,0.1082094765162529d-05,
     2      0.1557436481575310d-05,0.1916321085442060d-05,
     3      0.2044170148595704d-05,0.1928597544435157d-05,
     4      0.1633552863211744d-05,0.1250060563566667d-05,
     5      0.8651442687315801d-06,0.5421437473709992d-06,
     6      0.3109389353736191d-06,0.1913239705420637d-06,
     7      -.2546071361654691d-08,0.1769672989797322d-07,
     8      0.4660951556336258d-07,0.1557459775336186d-06/
         data arr1333/
     1      0.3703553103510617d-06,0.6932728168511163d-06,
     2      0.1108428188976457d-05,0.1501616577691417d-05,
     3      0.1744554095010829d-05,0.1785046911764063d-05,
     4      0.1637686830097385d-05,0.1354044099331004d-05,
     5      0.1008494816877738d-05,0.6779490762692283d-06,
     6      0.4173999249077692d-06,0.2801980774698363d-06,
     7      -.5142165280502366d-08,0.1093234263015149d-07,
     8      0.1535108365722174d-07,0.7308485255625093d-07/
         data arr1334/
     1      0.1975289105369049d-06,0.4016594607261818d-06,
     2      0.7162868448760700d-06,0.1069020932836535d-05,
     3      0.1348183133185897d-05,0.1490786996232656d-05,
     4      0.1475369717967021d-05,0.1309638535988025d-05,
     5      0.1040067112649378d-05,0.7409315098426252d-06,
     6      0.4819233141144025d-06,0.3441070236894689d-06,
     7      -.6665637408977421d-08,0.9233824073163267d-08,
     8      0.1603126298140288d-08,0.3210845276500660d-07/
         data arr1335/
     1      0.1002515009372437d-06,0.2127870379650203d-06,
     2      0.4273292459701657d-06,0.7061062792085955d-06,
     3      0.9647519458182695d-06,0.1153038239988099d-05,
     4      0.1235763098368336d-05,0.1184349985627407d-05,
     5      0.1009094828733736d-05,0.7671031182567735d-06,
     6      0.5317513180146578d-06,0.4094951966981295d-06,
     7      -.5225448360684530d-08,0.6227387460462287d-08,
     8      -.2718825817497661d-08,0.1200241090280833d-07/
         data arr1336/
     1      0.4392843977879810d-07,0.9786127123843066d-07,
     2      0.2236000419088591d-06,0.4044716746844287d-06,
     3      0.5907284500623630d-06,0.7490461991058027d-06,
     4      0.8435362408527848d-06,0.8379397510279091d-06,
     5      0.7301469043407689d-06,0.5610897747973738d-06,
     6      0.3886991401449650d-06,0.2937790710992780d-06,
     7      -.5575723636785721d-08,0.6408951014646025d-08,
     8      -.4330390438234751d-08,0.4740218474461308d-08/
         data arr1337/
     1      0.2226962231053693d-07,0.4229689219026735d-07,
     2      0.1154321874904859d-06,0.2359279485681088d-06,
     3      0.3707670127163505d-06,0.5077765678705303d-06,
     4      0.6239124646686770d-06,0.6751927482255296d-06,
     5      0.6364296580117787d-06,0.5263226938064387d-06,
     6      0.3926485967436207d-06,0.3253522721585992d-06,
     7      -.4109735996963688d-08,0.4721227685247567d-08,
     8      -.3343671439523845d-08,0.1849870156180634d-08/
         data arr1338/
     1      0.1098145219768517d-07,0.1568924661302949d-07,
     2      0.5170747752904078d-07,0.1176098047476545d-06,
     3      0.1946260960042747d-06,0.2819381471141525d-06,
     4      0.3693962991907630d-06,0.4243740455157157d-06,
     5      0.4209692521816608d-06,0.3639780267642348d-06,
     6      0.2831387765578922d-06,0.2460512556214784d-06,
     7      -.3447742276499555d-08,0.4191554376142558d-08,
     8      -.2168244809706844d-08,0.1927857174883934d-08/
         data arr1339/
     1      0.9467895458367835d-08,0.8717149368575239d-08,
     2      0.2790317930059264d-07,0.6733537620042385d-07,
     3      0.1127836010244923d-06,0.1699060023468570d-06,
     4      0.2397431253375247d-06,0.2983948886544325d-06,
     5      0.3182737150130926d-06,0.2939359655743409d-06,
     6      0.2440763760061772d-06,0.2297874744200473d-06,
     7      -.6846766601563343d-07,-.1396900914045201d-06,
     8      -.2163536235782725d-06,-.2856457281677884d-06/
         data arr1340/
     1      -.3173527732896460d-06,-.3036611609613604d-06,
     2      -.2573590826424962d-06,-.1952898509078078d-06,
     3      -.1334144451554233d-06,-.8293720688450160d-07,
     4      -.4756790007593164d-07,-.2537846503869702d-07,
     5      -.1258197370380219d-07,-.6366973162322716d-08,
     6      -.6920692800141073d-07,-.1621004353502531d-06,
     7      -.2879503873451190d-06,-.4265422810269537d-06,
     8      -.5277739717905418d-06,-.5596500736418913d-06/
         data arr1341/
     1      -.5203880555524847d-06,-.4297829425855403d-06,
     2      -.3187908649603702d-06,-.2149429934676105d-06,
     3      -.1329871412457279d-06,-.7577563024483805d-07,
     4      -.3987089891949315d-07,-.2195071555344077d-07,
     5      -.4874179463744273d-07,-.1306213202324551d-06,
     6      -.2660069892712644d-06,-.4425444380956045d-06,
     7      -.6097003821285676d-06,-.7159646645347680d-06,
     8      -.7308640380867580d-06,-.6577057108898157d-06/
         data arr1342/
     1      -.5296213054327744d-06,-.3869617016555749d-06,
     2      -.2586709337727912d-06,-.1585502932961077d-06,
     3      -.8961937910098745d-07,-.5408532215546899d-07,
     4      -.2777910304340030d-07,-.8426192957301097d-07,
     5      -.1971874266159922d-06,-.3685222939086301d-06,
     6      -.5649550938129101d-06,-.7345866537880975d-06,
     7      -.8232247374745392d-06,-.8068960331077616d-06,
     8      -.7044410854222624d-06,-.5560811505326150d-06/
         data arr1343/
     1      -.3995870972944312d-06,-.2614816156972238d-06,
     2      -.1568423408453354d-06,-.1008022674800727d-06,
     3      -.1374130956564594d-07,-.4581506778418680d-07,
     4      -.1244793510720874d-06,-.2607567521637508d-06,
     5      -.4445660648817236d-06,-.6402858475855088d-06,
     6      -.7868145444319340d-06,-.8384590837511687d-06,
     7      -.7913892222868413d-06,-.6711453382266668d-06,
     8      -.5133071651162041d-06,-.3534531400150868d-06/
         data arr1344/
     1      -.2204303068592335d-06,-.1453229612057497d-06,
     2      -.6495911672601033d-08,-.2116457531321022d-07,
     3      -.6865666342347039d-07,-.1620604128910142d-06,
     4      -.3056185194549276d-06,-.4892754156527909d-06,
     5      -.6619509072449133d-06,-.7682839439268176d-06,
     6      -.7869471694276938d-06,-.7238155348481140d-06,
     7      -.5987494427869472d-06,-.4437134944505311d-06,
     8      -.2969127005849711d-06,-.2125826846965615d-06/
         data arr1345/
     1      -.3451592154163088d-08,-.7944624913333692d-08,
     2      -.3333503098995024d-07,-.9062029151609639d-07,
     3      -.1864922225009877d-06,-.3339153552193862d-06,
     4      -.4998073087537549d-06,-.6312036985139947d-06,
     5      -.7010894101210919d-06,-.7003302137152886d-06,
     6      -.6274964018286550d-06,-.5004866832271980d-06,
     7      -.3589417670867447d-06,-.2787654850347823d-06,
     8      -.2391882307142661d-08,-.1885418597439248d-08/
         data arr1346/
     1      -.1389947817020399d-07,-.4669544360233756d-07,
     2      -.1015288342626409d-06,-.2056499309789711d-06,
     3      -.3431309022060544d-06,-.4702228025871567d-06,
     4      -.5647587036040002d-06,-.6118547091462392d-06,
     5      -.5919965187720189d-06,-.5051853193395853d-06,
     6      -.3850781310784966d-06,-.3202859537604699d-06,
     7      -.1381874062267471d-08,0.6337369478996887d-09,
     8      -.4660795003731760d-08,-.1956979034634271d-07/
         data arr1347/
     1      -.4690605147159910d-07,-.1099828269734814d-06,
     2      -.2022807237190527d-06,-.2980908271670083d-06,
     3      -.3816252902299120d-06,-.4349712890888677d-06,
     4      -.4355146832499457d-06,-.3791762427969543d-06,
     5      -.2913659256889822d-06,-.2401400662848033d-06,
     6      -.1303391096939426d-08,0.1587883143362703d-08,
     7      0.7150798218153754d-09,-.7002269336412792d-08,
     8      -.1512419614076629d-07,-.4990762819594725d-07/
         data arr1348/
     1      -.1124721221947657d-06,-.1833478075572758d-06,
     2      -.2575915615072373d-06,-.3250094337522039d-06,
     3      -.3575863038647827d-06,-.3373334762985187d-06,
     4      -.2785806853042524d-06,-.2497937895565445d-06,
     5      -.1121469946261341d-08,0.1380936914453938d-08,
     6      0.2455412003183498d-08,-.2202217500775670d-08,
     7      -.1150790772824204d-08,-.1721520397928789d-07,
     8      -.5443489601154163d-07,-.9810346172245946d-07/
         data arr1349/
     1      -.1501393030713691d-06,-.2087980535563472d-06,
     2      -.2502589030044525d-06,-.2526562854468945d-06,
     3      -.2211326429396360d-06,-.2119743970637970d-06,
     4      -.1114234347932952d-08,0.5853823302060463d-09,
     5      0.2163027876388124d-08,-.2836465070755096d-08,
     6      0.9745588827270995d-09,-.6124715001551125d-08,
     7      -.2908235935201800d-07,-.5419856373114748d-07,
     8      -.8699517379752134d-07,-.1332125505742800d-06/
         data arr1350/
     1      -.1749239378489700d-06,-.1896756560896639d-06,
     2      -.1765712213683232d-06,-.1824069695592496d-06,
     3      0.4968407016227166d-07,0.8762113851617272d-07,
     4      0.1058927364635521d-06,0.1096659128318477d-06,
     5      0.1038824191892119d-06,0.8713763962886071d-07,
     6      0.6352268839594764d-07,0.4173208009518410d-07,
     7      0.2611390545754179d-07,0.1570186148421520d-07,
     8      0.8533930239921649d-08,0.4035207929723759d-08/
         data arr1351/
     1      0.6394284378079868d-07,0.1262560826072262d-06,
     2      0.1702355646965845d-06,0.1967668202361419d-06,
     3      0.2036000945977236d-06,0.1846602967578737d-06,
     4      0.1471726147523648d-06,0.1065728978559729d-06,
     5      0.7217521423991920d-07,0.4560581756472155d-07,
     6      0.2629876286971972d-07,0.1534138922459997d-07,
     7      0.5739077553398176d-07,0.1270468370269853d-06,
     8      0.1904987957397471d-06,0.2455476613835520d-06/
         data arr1352/
     1      0.2781649483705163d-06,0.2733194024530294d-06,
     2      0.2368521747692076d-06,0.1863634815029846d-06,
     3      0.1348443770053133d-06,0.8900902439662702d-07,
     4      0.5321310220902920d-07,0.3314406503638519d-07,
     5      0.4165107127840222d-07,0.1034089040613176d-06,
     6      0.1719388477689033d-06,0.2469766680790120d-06,
     7      0.3063527630546037d-06,0.3261301577213064d-06,
     8      0.3057730942767641d-06,0.2584431207762034d-06/
         data arr1353/
     1      0.1972987394941923d-06,0.1345596532249868d-06,
     2      0.8169473297769564d-07,0.5059599107625323d-07,
     3      0.2550549448548426d-07,0.7177998673035166d-07,
     4      0.1288065108076816d-06,0.2083083804350442d-06,
     5      0.2849785885378183d-06,0.3282071661979290d-06,
     6      0.3340616623956726d-06,0.3083459617975161d-06,
     7      0.2559327025333230d-06,0.1881819535321745d-06,
     8      0.1232165872409088d-06,0.8505768922831305d-07/
         data arr1354/
     1      0.1308126046018035d-07,0.4357266849746133d-07,
     2      0.7903391716460015d-07,0.1492642826698528d-06,
     3      0.2290728389990275d-06,0.2847316474514772d-06,
     4      0.3159983982039637d-06,0.3230325780323225d-06,
     5      0.2960277646476483d-06,0.2379125257939310d-06,
     6      0.1703312213900884d-06,0.1331782012338422d-06,
     7      0.5712215782538951d-08,0.2414697623567362d-07,
     8      0.4055271296419597d-07,0.9454305686801478d-07/
         data arr1355/
     1      0.1644072760877538d-06,0.2193188066041282d-06,
     2      0.2637196090229626d-06,0.2943495496980335d-06,
     3      0.2907313750629951d-06,0.2478185554733600d-06,
     4      0.1866880793173942d-06,0.1546505080485144d-06,
     5      0.2830928146714483d-08,0.1337351505884335d-07,
     6      0.2217174197223864d-07,0.5915572095434784d-07,
     7      0.1105255863368226d-06,0.1557905193112555d-06,
     8      0.1967523836407121d-06,0.2266071399922008d-06/
         data arr1356/
     1      0.2268656945542276d-06,0.1934659306699310d-06,
     2      0.1437528787781922d-06,0.1138701370330950d-06,
     3      -.1525181191133453d-09,0.4854525689541858d-08,
     4      0.5379935079372235d-09,0.2249024590009917d-07,
     5      0.5791826125598221d-07,0.8941785021822112d-07,
     6      0.1279048074066297d-06,0.1702210821615819d-06,
     7      0.1915966534934043d-06,0.1789255562947673d-06,
     8      0.1445365213871089d-06,0.1274855272798372d-06/
         data arr1357/
     1      -.2252001421488514d-08,-.8317491421565046d-09,
     2      -.1477669404405493d-07,-.4907016947160750d-08,
     3      0.1609718603640290d-07,0.3246701792330608d-07,
     4      0.6310288850316871d-07,0.1105401923723307d-06,
     5      0.1475371056408095d-06,0.1540609735132865d-06,
     6      0.1368202881958403d-06,0.1355456834072947d-06,
     7      -.2545404139311751d-08,-.2662207784316968d-08,
     8      -.1737768200590962d-07,-.1484313536324995d-07/
         data arr1358/
     1      -.5104253987769336d-08,-.1808383996657742d-09,
     2      0.1822198361924582d-07,0.5553194585984268d-07,
     3      0.9045993422514320d-07,0.1046289467262375d-06,
     4      0.1003500458891461d-06,0.1084168940368079d-06,
     5      -.3153747491071670d-07,-.6033196194818891d-07,
     6      -.7020253127420414d-07,-.6855304705968286d-07,
     7      -.6228161769785728d-07,-.5227702627950031d-07,
     8      -.3869128816986109d-07,-.2542880359052859d-07/
         data arr1359/
     1      -.1585908071314874d-07,-.1012778870370332d-07,
     2      -.7678406002429467d-08,-.4394122115176686d-07,
     3      -.9282737792733348d-07,-.1198372730871648d-06,
     4      -.1298941716989001d-06,-.1279051353518657d-06,
     5      -.1143638604756525d-06,-.9071580664999608d-07,
     6      -.6428666520472408d-07,-.4208820299376223d-07,
     7      -.2647764248932064d-07,-.1867661688885419d-07,
     8      -.4249134701599658d-07,-.9939695003239463d-07/
         data arr1360/
     1      -.1422630939332900d-06,-.1695703014513401d-06,
     2      -.1801687993837242d-06,-.1711649543826692d-06,
     3      -.1427914090160491d-06,-.1044324331415983d-06,
     4      -.6778976437213657d-07,-.3961756929945296d-07,
     5      -.2296736864449274d-07,-.3325762297417315d-07,
     6      -.8547449019858356d-07,-.1366783832161683d-06,
     7      -.1805545494426694d-06,-.2089925269860321d-06,
     8      -.2155904729194398d-06,-.1974176363101574d-06/
         data arr1361/
     1      -.1603629447464947d-06,-.1162091335347102d-06,
     2      -.7617518972082443d-07,-.5221379649435531d-07,
     3      -.2273417064781932d-07,-.6240008389960418d-07,
     4      -.1129415948920794d-06,-.1674175609120761d-06,
     5      -.2120940727511701d-06,-.2401681701527952d-06,
     6      -.2465126873279224d-06,-.2278528537440237d-06,
     7      -.1886158333515998d-06,-.1419886632099055d-06,
     8      -.1173882404980492d-06,-.1368980393427838d-07/
         data arr1362/
     1      -.3962480624623787d-07,-.8113789406199538d-07,
     2      -.1325696898985810d-06,-.1805904730123015d-06,
     3      -.2191955030686541d-06,-.2409967281509471d-06,
     4      -.2365239584938637d-06,-.2052554753713711d-06,
     5      -.1602456260466032d-06,-.1369165267708219d-06,
     6      -.6751360151258509d-08,-.2211941256671305d-07,
     7      -.5028150625546015d-07,-.8606901301512488d-07,
     8      -.1231695642798185d-06,-.1555091837743175d-06/
         data arr1363/
     1      -.1721654355105414d-06,-.1648293137573644d-06,
     2      -.1363289108458652d-06,-.9892083774719376d-07,
     3      -.7357584895162938d-07,-.3687873498998400d-08,
     4      -.1102480693887254d-07,-.3034313885250177d-07,
     5      -.5862691676784728d-07,-.9044906292958289d-07,
     6      -.1245536227996051d-06,-.1532201462924214d-06,
     7      -.1634236922502369d-06,-.1498815246542408d-06,
     8      -.1208250426510921d-06,-.1036560165656871d-06/
         data arr1364/
     1      -.2770960901181187d-08,-.4646135802722126d-08,
     2      -.1771882363730368d-07,-.4203479625007376d-07,
     3      -.6936102318136098d-07,-.1039565253835964d-06,
     4      -.1454150735973481d-06,-.1767387787237240d-06,
     5      -.1818962299877306d-06,-.1634742164767786d-06,
     6      -.1609599969471421d-06,-.1861673239032677d-08,
     7      -.1354330284613654d-08,-.8086345806830435d-08,
     8      -.2363719943900815d-07,-.4040189296348131d-07/
         data arr1365/
     1      -.6347057803985425d-07,-.9647968907402622d-07,
     2      -.1267082574341193d-06,-.1385501327683601d-06,
     3      -.1311188932833206d-06,-.1370587799547012d-06/
        do 1200 i=1,5830
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c
c
c
c
        subroutine lot9geta(arr)
        implicit real *8 (a-h,o-z)
        dimension arr(1)
c
         real *8
     1  arr1001(16),arr1002(16),arr1003(16),arr1004(16),
     2  arr1005(16),arr1006(16),arr1007(16),arr1008(16),
     3  arr1009(16),arr1010(16),arr1011(16),arr1012(16),
     4  arr1013(16),arr1014(16),arr1015(16),arr1016(16),
     5  arr1017(16),arr1018(16),arr1019(16),arr1020(16),
     6  arr1021(16),arr1022(16),arr1023(16),arr1024(16),
     7  arr1025(16),arr1026(16),arr1027(16),arr1028(16),
     8  arr1029(16),arr1030(16),arr1031(16),arr1032(16),
     9  arr1033(16),arr1034(16),arr1035(16),arr1036(16),
     a  arr1037(16),arr1038(16),arr1039(16),arr1040(16)
         real *8
     1  arr1041(16),arr1042(16),arr1043(16),arr1044(16),
     2  arr1045(16),arr1046(16),arr1047(16),arr1048(16),
     3  arr1049(16),arr1050(16),arr1051(16),arr1052(16),
     4  arr1053(16),arr1054(16),arr1055(16),arr1056(16),
     5  arr1057(16),arr1058(16),arr1059(16),arr1060(16),
     6  arr1061(16),arr1062(16),arr1063(16),arr1064(16),
     7  arr1065(16),arr1066(16),arr1067(16),arr1068(16),
     8  arr1069(16),arr1070(16),arr1071(16),arr1072(16),
     9  arr1073(16),arr1074(16),arr1075(16),arr1076(16),
     a  arr1077(16),arr1078(16),arr1079(16),arr1080(16)
         real *8
     1  arr1081(16),arr1082(16),arr1083(16),arr1084(16),
     2  arr1085(16),arr1086(16),arr1087(16),arr1088(16),
     3  arr1089(16),arr1090(16),arr1091(16),arr1092(16),
     4  arr1093(16),arr1094(16),arr1095(16),arr1096(16),
     5  arr1097(16),arr1098(16),arr1099(16),arr1100(16),
     6  arr1101(16),arr1102(16),arr1103(16),arr1104(16),
     7  arr1105(16),arr1106(16),arr1107(16),arr1108(16),
     8  arr1109(16),arr1110(16),arr1111(16),arr1112(16),
     9  arr1113(16),arr1114(16),arr1115(16),arr1116(16),
     a  arr1117(16),arr1118(16),arr1119(16),arr1120(16)
         real *8
     1  arr1121(16),arr1122(16),arr1123(16),arr1124(16),
     2  arr1125(16),arr1126(16),arr1127(16),arr1128(16),
     3  arr1129(16),arr1130(16),arr1131(16),arr1132(16),
     4  arr1133(16),arr1134(16),arr1135(16),arr1136(16),
     5  arr1137(16),arr1138(16),arr1139(16),arr1140(16),
     6  arr1141(16),arr1142(16),arr1143(16),arr1144(16),
     7  arr1145(16),arr1146(16),arr1147(16),arr1148(16),
     8  arr1149(16),arr1150(16),arr1151(16),arr1152(16),
     9  arr1153(16),arr1154(16),arr1155(16),arr1156(16),
     a  arr1157(16),arr1158(16),arr1159(16),arr1160(16)
         real *8
     1  arr1161(16),arr1162(16),arr1163(16),arr1164(16),
     2  arr1165(16),arr1166(16),arr1167(16),arr1168(16),
     3  arr1169(16),arr1170(16),arr1171(16),arr1172(16),
     4  arr1173(16),arr1174(16),arr1175(16),arr1176(16),
     5  arr1177(16),arr1178(16),arr1179(16),arr1180(16),
     6  arr1181(16),arr1182(16),arr1183(16),arr1184(16),
     7  arr1185(16),arr1186(16),arr1187(16),arr1188(16),
     8  arr1189(16),arr1190(16),arr1191(16),arr1192(16),
     9  arr1193(16),arr1194(16),arr1195(16),arr1196(16),
     a  arr1197(16),arr1198(16),arr1199(16),arr1200(16)
         real *8
     1  arr1201(16),arr1202(16),arr1203(16),arr1204(16),
     2  arr1205(16),arr1206(16),arr1207(16),arr1208(16),
     3  arr1209(16),arr1210(16),arr1211(16),arr1212(16),
     4  arr1213(16),arr1214(16),arr1215(16),arr1216(16),
     5  arr1217(16),arr1218(16),arr1219(16),arr1220(16),
     6  arr1221(16),arr1222(16),arr1223(16),arr1224(16),
     7  arr1225(16),arr1226(16),arr1227(16),arr1228(16),
     8  arr1229(16),arr1230(16),arr1231(16),arr1232(16),
     9  arr1233(16),arr1234(16),arr1235(16),arr1236(16),
     a  arr1237(16),arr1238(16),arr1239(16),arr1240(16)
         real *8
     1  arr1241(16),arr1242(16),arr1243(16),arr1244(16),
     2  arr1245(16),arr1246(16),arr1247(16),arr1248(16),
     3  arr1249(16),arr1250(16),arr1251(16),arr1252(16),
     4  arr1253(16),arr1254(16),arr1255(16),arr1256(16),
     5  arr1257(16),arr1258(16),arr1259(16),arr1260(16),
     6  arr1261(16),arr1262(16),arr1263(16),arr1264(16),
     7  arr1265(16),arr1266(16),arr1267(16),arr1268(16),
     8  arr1269(16),arr1270(16),arr1271(16),arr1272(16),
     9  arr1273(16),arr1274(16),arr1275(16),arr1276(16),
     a  arr1277(16),arr1278(16),arr1279(16),arr1280(16)
         real *8
     1  arr1281(16),arr1282(16),arr1283(16),arr1284(16),
     2  arr1285(16),arr1286(16),arr1287(16),arr1288(16),
     3  arr1289(16),arr1290(16),arr1291(16),arr1292(16),
     4  arr1293(16),arr1294(16),arr1295(16),arr1296(16),
     5  arr1297(16),arr1298(16),arr1299(16),arr1300(16),
     6  arr1301(16),arr1302(16),arr1303(16),arr1304(16),
     7  arr1305(16),arr1306(16),arr1307(16),arr1308(16),
     8  arr1309(16),arr1310(16),arr1311(16),arr1312(16),
     9  arr1313(16),arr1314(16),arr1315(16),arr1316(16),
     a  arr1317(16),arr1318(16),arr1319(16),arr1320(16)
         real *8
     1  arr1321(16),arr1322(16),arr1323(16),arr1324(16),
     2  arr1325(16),arr1326(16),arr1327(16),arr1328(16),
     3  arr1329(16),arr1330(16),arr1331(16),arr1332(16),
     4  arr1333(16),arr1334(16),arr1335(16),arr1336(16),
     5  arr1337(16),arr1338(16),arr1339(16),arr1340(16),
     6  arr1341(16),arr1342(16),arr1343(16),arr1344(16),
     7  arr1345(16),arr1346(16),arr1347(16),arr1348(16),
     8  arr1349(16),arr1350(16),arr1351(16),arr1352(16),
     9  arr1353(16),arr1354(16),arr1355(16),arr1356(16),
     a  arr1357(16),arr1358(16),arr1359(16),arr1360(16)
         real *8
     1  arr1361(16),arr1362(16),arr1363(16),arr1364(16),
     2  arr1365(16),arr1366(16),arr1367(16),arr1368(16),
     3  arr1369(16),arr1370(16),arr1371(16),arr1372(16),
     4  arr1373(16),arr1374(16),arr1375(16),arr1376(16),
     5  arr1377(16),arr1378(16),arr1379(16),arr1380(16),
     6  arr1381(16),arr1382(16),arr1383(16),arr1384(16),
     7  arr1385(16),arr1386(16),arr1387(16),arr1388(16),
     8  arr1389(16),arr1390(16),arr1391(16),arr1392(16),
     9  arr1393(16),arr1394(16),arr1395(16),arr1396(16),
     a  arr1397(16),arr1398(16),arr1399(16),arr1400(16)
         real *8
     1  arr1401(16),arr1402(16),arr1403(16),arr1404(16),
     2  arr1405(16),arr1406(16),arr1407(16),arr1408(16),
     3  arr1409(16),arr1410(16),arr1411(16),arr1412(16),
     4  arr1413(16),arr1414(16),arr1415(16),arr1416(16),
     5  arr1417(16),arr1418(16),arr1419(16),arr1420(16),
     6  arr1421(16),arr1422(16),arr1423(16),arr1424(16),
     7  arr1425(16),arr1426(16),arr1427(16),arr1428(16),
     8  arr1429(16),arr1430(16),arr1431(16),arr1432(16),
     9  arr1433(16),arr1434(16),arr1435(16),arr1436(16),
     a  arr1437(16),arr1438(16),arr1439(16),arr1440(16)
         real *8
     1  arr1441(16),arr1442(16),arr1443(16),arr1444(16),
     2  arr1445(16),arr1446(16),arr1447(16),arr1448(16),
     3  arr1449(16),arr1450(16),arr1451(16),arr1452(16)
         real *8
     1  arr1453(16),arr1454(16),arr1455(16)
         real *8
     1  arr2001(2),arr2002(2),arr2003(2),arr2004(2),
     2  arr2005(2),arr2006(2),arr2007(2),arr2008(2),
     3  arr2009(2),arr2010(2),arr2011(2),arr2012(2),
     4  arr2013(2),arr2014(2),arr2015(2),arr2016(2),
     5  arr2017(2),arr2018(2),arr2019(2),arr2020(2),
     6  arr2021(2),arr2022(2),arr2023(2),arr2024(2),
     7  arr2025(2),arr2026(2),arr2027(2),arr2028(2),
     8  arr2029(2),arr2030(2),arr2031(2),arr2032(2),
     9  arr2033(2),arr2034(2),arr2035(2),arr2036(2),
     a  arr2037(2),arr2038(2),arr2039(2),arr2040(2)
         real *8
     1  arr2041(2),arr2042(2),arr2043(2),arr2044(2),
     2  arr2045(2),arr2046(2),arr2047(2),arr2048(2),
     3  arr2049(2),arr2050(2),arr2051(2),arr2052(2),
     4  arr2053(2),arr2054(2),arr2055(2),arr2056(2),
     5  arr2057(2),arr2058(2),arr2059(2),arr2060(2),
     6  arr2061(2),arr2062(2),arr2063(2),arr2064(2),
     7  arr2065(2),arr2066(2),arr2067(2),arr2068(2),
     8  arr2069(2),arr2070(2),arr2071(2),arr2072(2),
     9  arr2073(2),arr2074(2),arr2075(2),arr2076(2),
     a  arr2077(2),arr2078(2),arr2079(2),arr2080(2)
         real *8
     1  arr2081(2),arr2082(2),arr2083(2),arr2084(2),
     2  arr2085(2),arr2086(2),arr2087(2),arr2088(2),
     3  arr2089(2),arr2090(2),arr2091(2),arr2092(2),
     4  arr2093(2),arr2094(2),arr2095(2),arr2096(2),
     5  arr2097(2),arr2098(2),arr2099(2),arr2100(2),
     6  arr2101(2),arr2102(2),arr2103(2),arr2104(2),
     7  arr2105(2),arr2106(2),arr2107(2),arr2108(2),
     8  arr2109(2),arr2110(2),arr2111(2),arr2112(2),
     9  arr2113(2),arr2114(2),arr2115(2),arr2116(2),
     a  arr2117(2),arr2118(2),arr2119(2),arr2120(2)
         real *8
     1  arr2121(2),arr2122(2),arr2123(2),arr2124(2),
     2  arr2125(2),arr2126(2),arr2127(2),arr2128(2),
     3  arr2129(2),arr2130(2),arr2131(2),arr2132(2),
     4  arr2133(2),arr2134(2),arr2135(2),arr2136(2),
     5  arr2137(2),arr2138(2),arr2139(2),arr2140(2),
     6  arr2141(2),arr2142(2),arr2143(2),arr2144(2),
     7  arr2145(2),arr2146(2),arr2147(2),arr2148(2),
     8  arr2149(2),arr2150(2),arr2151(2),arr2152(2),
     9  arr2153(2),arr2154(2),arr2155(2),arr2156(2),
     a  arr2157(2),arr2158(2),arr2159(2),arr2160(2)
         real *8
     1  arr2161(2),arr2162(2),arr2163(2),arr2164(2),
     2  arr2165(2),arr2166(2),arr2167(2),arr2168(2),
     3  arr2169(2),arr2170(2),arr2171(2),arr2172(2),
     4  arr2173(2),arr2174(2),arr2175(2),arr2176(2),
     5  arr2177(2),arr2178(2),arr2179(2),arr2180(2),
     6  arr2181(2),arr2182(2),arr2183(2),arr2184(2),
     7  arr2185(2),arr2186(2),arr2187(2),arr2188(2),
     8  arr2189(2),arr2190(2),arr2191(2),arr2192(2),
     9  arr2193(2),arr2194(2),arr2195(2),arr2196(2),
     a  arr2197(2),arr2198(2),arr2199(2),arr2200(2)
         real *8
     1  arr2201(2),arr2202(2),arr2203(2),arr2204(2),
     2  arr2205(2),arr2206(2),arr2207(2),arr2208(2),
     3  arr2209(2),arr2210(2),arr2211(2),arr2212(2),
     4  arr2213(2),arr2214(2),arr2215(2),arr2216(2),
     5  arr2217(2),arr2218(2),arr2219(2),arr2220(2),
     6  arr2221(2),arr2222(2),arr2223(2),arr2224(2),
     7  arr2225(2),arr2226(2),arr2227(2),arr2228(2),
     8  arr2229(2),arr2230(2),arr2231(2),arr2232(2),
     9  arr2233(2),arr2234(2),arr2235(2),arr2236(2),
     a  arr2237(2),arr2238(2),arr2239(2),arr2240(2)
         real *8
     1  arr2241(2),arr2242(2),arr2243(2),arr2244(2),
     2  arr2245(2),arr2246(2),arr2247(2),arr2248(2),
     3  arr2249(2),arr2250(2),arr2251(2),arr2252(2),
     4  arr2253(2),arr2254(2),arr2255(2),arr2256(2),
     5  arr2257(2),arr2258(2),arr2259(2),arr2260(2),
     6  arr2261(2),arr2262(2),arr2263(2),arr2264(2),
     7  arr2265(2),arr2266(2),arr2267(2),arr2268(2),
     8  arr2269(2),arr2270(2),arr2271(2),arr2272(2),
     9  arr2273(2),arr2274(2),arr2275(2),arr2276(2),
     a  arr2277(2),arr2278(2),arr2279(2),arr2280(2)
         real *8
     1  arr2281(2),arr2282(2),arr2283(2),arr2284(2),
     2  arr2285(2),arr2286(2),arr2287(2),arr2288(2),
     3  arr2289(2),arr2290(2),arr2291(2),arr2292(2),
     4  arr2293(2),arr2294(2),arr2295(2),arr2296(2),
     5  arr2297(2),arr2298(2),arr2299(2),arr2300(2),
     6  arr2301(2),arr2302(2),arr2303(2),arr2304(2),
     7  arr2305(2),arr2306(2),arr2307(2),arr2308(2),
     8  arr2309(2),arr2310(2),arr2311(2),arr2312(2),
     9  arr2313(2),arr2314(2),arr2315(2),arr2316(2),
     a  arr2317(2),arr2318(2),arr2319(2),arr2320(2)
         real *8
     1  arr2321(2),arr2322(2),arr2323(2),arr2324(2),
     2  arr2325(2),arr2326(2),arr2327(2),arr2328(2),
     3  arr2329(2),arr2330(2),arr2331(2),arr2332(2),
     4  arr2333(2),arr2334(2),arr2335(2),arr2336(2),
     5  arr2337(2),arr2338(2),arr2339(2),arr2340(2),
     6  arr2341(2),arr2342(2),arr2343(2),arr2344(2),
     7  arr2345(2),arr2346(2),arr2347(2),arr2348(2),
     8  arr2349(2),arr2350(2),arr2351(2),arr2352(2),
     9  arr2353(2),arr2354(2),arr2355(2),arr2356(2),
     a  arr2357(2),arr2358(2),arr2359(2),arr2360(2)
         real *8
     1  arr2361(2),arr2362(2),arr2363(2),arr2364(2),
     2  arr2365(2),arr2366(2),arr2367(2),arr2368(2),
     3  arr2369(2),arr2370(2),arr2371(2),arr2372(2),
     4  arr2373(2),arr2374(2),arr2375(2),arr2376(2),
     5  arr2377(2),arr2378(2),arr2379(2),arr2380(2),
     6  arr2381(2),arr2382(2),arr2383(2),arr2384(2),
     7  arr2385(2),arr2386(2),arr2387(2),arr2388(2),
     8  arr2389(2),arr2390(2),arr2391(2),arr2392(2),
     9  arr2393(2),arr2394(2),arr2395(2),arr2396(2),
     a  arr2397(2),arr2398(2),arr2399(2),arr2400(2)
         real *8
     1  arr2401(2),arr2402(2),arr2403(2),arr2404(2),
     2  arr2405(2),arr2406(2),arr2407(2),arr2408(2),
     3  arr2409(2),arr2410(2),arr2411(2),arr2412(2),
     4  arr2413(2),arr2414(2),arr2415(2),arr2416(2),
     5  arr2417(2),arr2418(2),arr2419(2),arr2420(2),
     6  arr2421(2),arr2422(2),arr2423(2),arr2424(2),
     7  arr2425(2),arr2426(2),arr2427(2),arr2428(2),
     8  arr2429(2),arr2430(2),arr2431(2),arr2432(2),
     9  arr2433(2),arr2434(2),arr2435(2),arr2436(2),
     a  arr2437(2),arr2438(2),arr2439(2),arr2440(2)
         real *8
     1  arr2441(2),arr2442(2),arr2443(2),arr2444(2),
     2  arr2445(2),arr2446(2),arr2447(2),arr2448(2),
     3  arr2449(2),arr2450(2),arr2451(2),arr2452(2)
         real *8
     1  arr2453(2),arr2454(2)
         equivalence
     1  (arr1001(16),arr2001(1)),(arr1002(1),arr2001(2)),
     2  (arr1002(16),arr2002(1)),(arr1003(1),arr2002(2)),
     3  (arr1003(16),arr2003(1)),(arr1004(1),arr2003(2)),
     4  (arr1004(16),arr2004(1)),(arr1005(1),arr2004(2)),
     5  (arr1005(16),arr2005(1)),(arr1006(1),arr2005(2)),
     6  (arr1006(16),arr2006(1)),(arr1007(1),arr2006(2)),
     7  (arr1007(16),arr2007(1)),(arr1008(1),arr2007(2)),
     8  (arr1008(16),arr2008(1)),(arr1009(1),arr2008(2)),
     9  (arr1009(16),arr2009(1)),(arr1010(1),arr2009(2)),
     a  (arr1010(16),arr2010(1)),(arr1011(1),arr2010(2))
         equivalence
     1  (arr1011(16),arr2011(1)),(arr1012(1),arr2011(2)),
     2  (arr1012(16),arr2012(1)),(arr1013(1),arr2012(2)),
     3  (arr1013(16),arr2013(1)),(arr1014(1),arr2013(2)),
     4  (arr1014(16),arr2014(1)),(arr1015(1),arr2014(2)),
     5  (arr1015(16),arr2015(1)),(arr1016(1),arr2015(2)),
     6  (arr1016(16),arr2016(1)),(arr1017(1),arr2016(2)),
     7  (arr1017(16),arr2017(1)),(arr1018(1),arr2017(2)),
     8  (arr1018(16),arr2018(1)),(arr1019(1),arr2018(2)),
     9  (arr1019(16),arr2019(1)),(arr1020(1),arr2019(2)),
     a  (arr1020(16),arr2020(1)),(arr1021(1),arr2020(2))
         equivalence
     1  (arr1021(16),arr2021(1)),(arr1022(1),arr2021(2)),
     2  (arr1022(16),arr2022(1)),(arr1023(1),arr2022(2)),
     3  (arr1023(16),arr2023(1)),(arr1024(1),arr2023(2)),
     4  (arr1024(16),arr2024(1)),(arr1025(1),arr2024(2)),
     5  (arr1025(16),arr2025(1)),(arr1026(1),arr2025(2)),
     6  (arr1026(16),arr2026(1)),(arr1027(1),arr2026(2)),
     7  (arr1027(16),arr2027(1)),(arr1028(1),arr2027(2)),
     8  (arr1028(16),arr2028(1)),(arr1029(1),arr2028(2)),
     9  (arr1029(16),arr2029(1)),(arr1030(1),arr2029(2)),
     a  (arr1030(16),arr2030(1)),(arr1031(1),arr2030(2))
         equivalence
     1  (arr1031(16),arr2031(1)),(arr1032(1),arr2031(2)),
     2  (arr1032(16),arr2032(1)),(arr1033(1),arr2032(2)),
     3  (arr1033(16),arr2033(1)),(arr1034(1),arr2033(2)),
     4  (arr1034(16),arr2034(1)),(arr1035(1),arr2034(2)),
     5  (arr1035(16),arr2035(1)),(arr1036(1),arr2035(2)),
     6  (arr1036(16),arr2036(1)),(arr1037(1),arr2036(2)),
     7  (arr1037(16),arr2037(1)),(arr1038(1),arr2037(2)),
     8  (arr1038(16),arr2038(1)),(arr1039(1),arr2038(2)),
     9  (arr1039(16),arr2039(1)),(arr1040(1),arr2039(2)),
     a  (arr1040(16),arr2040(1)),(arr1041(1),arr2040(2))
         equivalence
     1  (arr1041(16),arr2041(1)),(arr1042(1),arr2041(2)),
     2  (arr1042(16),arr2042(1)),(arr1043(1),arr2042(2)),
     3  (arr1043(16),arr2043(1)),(arr1044(1),arr2043(2)),
     4  (arr1044(16),arr2044(1)),(arr1045(1),arr2044(2)),
     5  (arr1045(16),arr2045(1)),(arr1046(1),arr2045(2)),
     6  (arr1046(16),arr2046(1)),(arr1047(1),arr2046(2)),
     7  (arr1047(16),arr2047(1)),(arr1048(1),arr2047(2)),
     8  (arr1048(16),arr2048(1)),(arr1049(1),arr2048(2)),
     9  (arr1049(16),arr2049(1)),(arr1050(1),arr2049(2)),
     a  (arr1050(16),arr2050(1)),(arr1051(1),arr2050(2))
         equivalence
     1  (arr1051(16),arr2051(1)),(arr1052(1),arr2051(2)),
     2  (arr1052(16),arr2052(1)),(arr1053(1),arr2052(2)),
     3  (arr1053(16),arr2053(1)),(arr1054(1),arr2053(2)),
     4  (arr1054(16),arr2054(1)),(arr1055(1),arr2054(2)),
     5  (arr1055(16),arr2055(1)),(arr1056(1),arr2055(2)),
     6  (arr1056(16),arr2056(1)),(arr1057(1),arr2056(2)),
     7  (arr1057(16),arr2057(1)),(arr1058(1),arr2057(2)),
     8  (arr1058(16),arr2058(1)),(arr1059(1),arr2058(2)),
     9  (arr1059(16),arr2059(1)),(arr1060(1),arr2059(2)),
     a  (arr1060(16),arr2060(1)),(arr1061(1),arr2060(2))
         equivalence
     1  (arr1061(16),arr2061(1)),(arr1062(1),arr2061(2)),
     2  (arr1062(16),arr2062(1)),(arr1063(1),arr2062(2)),
     3  (arr1063(16),arr2063(1)),(arr1064(1),arr2063(2)),
     4  (arr1064(16),arr2064(1)),(arr1065(1),arr2064(2)),
     5  (arr1065(16),arr2065(1)),(arr1066(1),arr2065(2)),
     6  (arr1066(16),arr2066(1)),(arr1067(1),arr2066(2)),
     7  (arr1067(16),arr2067(1)),(arr1068(1),arr2067(2)),
     8  (arr1068(16),arr2068(1)),(arr1069(1),arr2068(2)),
     9  (arr1069(16),arr2069(1)),(arr1070(1),arr2069(2)),
     a  (arr1070(16),arr2070(1)),(arr1071(1),arr2070(2))
         equivalence
     1  (arr1071(16),arr2071(1)),(arr1072(1),arr2071(2)),
     2  (arr1072(16),arr2072(1)),(arr1073(1),arr2072(2)),
     3  (arr1073(16),arr2073(1)),(arr1074(1),arr2073(2)),
     4  (arr1074(16),arr2074(1)),(arr1075(1),arr2074(2)),
     5  (arr1075(16),arr2075(1)),(arr1076(1),arr2075(2)),
     6  (arr1076(16),arr2076(1)),(arr1077(1),arr2076(2)),
     7  (arr1077(16),arr2077(1)),(arr1078(1),arr2077(2)),
     8  (arr1078(16),arr2078(1)),(arr1079(1),arr2078(2)),
     9  (arr1079(16),arr2079(1)),(arr1080(1),arr2079(2)),
     a  (arr1080(16),arr2080(1)),(arr1081(1),arr2080(2))
         equivalence
     1  (arr1081(16),arr2081(1)),(arr1082(1),arr2081(2)),
     2  (arr1082(16),arr2082(1)),(arr1083(1),arr2082(2)),
     3  (arr1083(16),arr2083(1)),(arr1084(1),arr2083(2)),
     4  (arr1084(16),arr2084(1)),(arr1085(1),arr2084(2)),
     5  (arr1085(16),arr2085(1)),(arr1086(1),arr2085(2)),
     6  (arr1086(16),arr2086(1)),(arr1087(1),arr2086(2)),
     7  (arr1087(16),arr2087(1)),(arr1088(1),arr2087(2)),
     8  (arr1088(16),arr2088(1)),(arr1089(1),arr2088(2)),
     9  (arr1089(16),arr2089(1)),(arr1090(1),arr2089(2)),
     a  (arr1090(16),arr2090(1)),(arr1091(1),arr2090(2))
         equivalence
     1  (arr1091(16),arr2091(1)),(arr1092(1),arr2091(2)),
     2  (arr1092(16),arr2092(1)),(arr1093(1),arr2092(2)),
     3  (arr1093(16),arr2093(1)),(arr1094(1),arr2093(2)),
     4  (arr1094(16),arr2094(1)),(arr1095(1),arr2094(2)),
     5  (arr1095(16),arr2095(1)),(arr1096(1),arr2095(2)),
     6  (arr1096(16),arr2096(1)),(arr1097(1),arr2096(2)),
     7  (arr1097(16),arr2097(1)),(arr1098(1),arr2097(2)),
     8  (arr1098(16),arr2098(1)),(arr1099(1),arr2098(2)),
     9  (arr1099(16),arr2099(1)),(arr1100(1),arr2099(2)),
     a  (arr1100(16),arr2100(1)),(arr1101(1),arr2100(2))
         equivalence
     1  (arr1101(16),arr2101(1)),(arr1102(1),arr2101(2)),
     2  (arr1102(16),arr2102(1)),(arr1103(1),arr2102(2)),
     3  (arr1103(16),arr2103(1)),(arr1104(1),arr2103(2)),
     4  (arr1104(16),arr2104(1)),(arr1105(1),arr2104(2)),
     5  (arr1105(16),arr2105(1)),(arr1106(1),arr2105(2)),
     6  (arr1106(16),arr2106(1)),(arr1107(1),arr2106(2)),
     7  (arr1107(16),arr2107(1)),(arr1108(1),arr2107(2)),
     8  (arr1108(16),arr2108(1)),(arr1109(1),arr2108(2)),
     9  (arr1109(16),arr2109(1)),(arr1110(1),arr2109(2)),
     a  (arr1110(16),arr2110(1)),(arr1111(1),arr2110(2))
         equivalence
     1  (arr1111(16),arr2111(1)),(arr1112(1),arr2111(2)),
     2  (arr1112(16),arr2112(1)),(arr1113(1),arr2112(2)),
     3  (arr1113(16),arr2113(1)),(arr1114(1),arr2113(2)),
     4  (arr1114(16),arr2114(1)),(arr1115(1),arr2114(2)),
     5  (arr1115(16),arr2115(1)),(arr1116(1),arr2115(2)),
     6  (arr1116(16),arr2116(1)),(arr1117(1),arr2116(2)),
     7  (arr1117(16),arr2117(1)),(arr1118(1),arr2117(2)),
     8  (arr1118(16),arr2118(1)),(arr1119(1),arr2118(2)),
     9  (arr1119(16),arr2119(1)),(arr1120(1),arr2119(2)),
     a  (arr1120(16),arr2120(1)),(arr1121(1),arr2120(2))
         equivalence
     1  (arr1121(16),arr2121(1)),(arr1122(1),arr2121(2)),
     2  (arr1122(16),arr2122(1)),(arr1123(1),arr2122(2)),
     3  (arr1123(16),arr2123(1)),(arr1124(1),arr2123(2)),
     4  (arr1124(16),arr2124(1)),(arr1125(1),arr2124(2)),
     5  (arr1125(16),arr2125(1)),(arr1126(1),arr2125(2)),
     6  (arr1126(16),arr2126(1)),(arr1127(1),arr2126(2)),
     7  (arr1127(16),arr2127(1)),(arr1128(1),arr2127(2)),
     8  (arr1128(16),arr2128(1)),(arr1129(1),arr2128(2)),
     9  (arr1129(16),arr2129(1)),(arr1130(1),arr2129(2)),
     a  (arr1130(16),arr2130(1)),(arr1131(1),arr2130(2))
         equivalence
     1  (arr1131(16),arr2131(1)),(arr1132(1),arr2131(2)),
     2  (arr1132(16),arr2132(1)),(arr1133(1),arr2132(2)),
     3  (arr1133(16),arr2133(1)),(arr1134(1),arr2133(2)),
     4  (arr1134(16),arr2134(1)),(arr1135(1),arr2134(2)),
     5  (arr1135(16),arr2135(1)),(arr1136(1),arr2135(2)),
     6  (arr1136(16),arr2136(1)),(arr1137(1),arr2136(2)),
     7  (arr1137(16),arr2137(1)),(arr1138(1),arr2137(2)),
     8  (arr1138(16),arr2138(1)),(arr1139(1),arr2138(2)),
     9  (arr1139(16),arr2139(1)),(arr1140(1),arr2139(2)),
     a  (arr1140(16),arr2140(1)),(arr1141(1),arr2140(2))
         equivalence
     1  (arr1141(16),arr2141(1)),(arr1142(1),arr2141(2)),
     2  (arr1142(16),arr2142(1)),(arr1143(1),arr2142(2)),
     3  (arr1143(16),arr2143(1)),(arr1144(1),arr2143(2)),
     4  (arr1144(16),arr2144(1)),(arr1145(1),arr2144(2)),
     5  (arr1145(16),arr2145(1)),(arr1146(1),arr2145(2)),
     6  (arr1146(16),arr2146(1)),(arr1147(1),arr2146(2)),
     7  (arr1147(16),arr2147(1)),(arr1148(1),arr2147(2)),
     8  (arr1148(16),arr2148(1)),(arr1149(1),arr2148(2)),
     9  (arr1149(16),arr2149(1)),(arr1150(1),arr2149(2)),
     a  (arr1150(16),arr2150(1)),(arr1151(1),arr2150(2))
         equivalence
     1  (arr1151(16),arr2151(1)),(arr1152(1),arr2151(2)),
     2  (arr1152(16),arr2152(1)),(arr1153(1),arr2152(2)),
     3  (arr1153(16),arr2153(1)),(arr1154(1),arr2153(2)),
     4  (arr1154(16),arr2154(1)),(arr1155(1),arr2154(2)),
     5  (arr1155(16),arr2155(1)),(arr1156(1),arr2155(2)),
     6  (arr1156(16),arr2156(1)),(arr1157(1),arr2156(2)),
     7  (arr1157(16),arr2157(1)),(arr1158(1),arr2157(2)),
     8  (arr1158(16),arr2158(1)),(arr1159(1),arr2158(2)),
     9  (arr1159(16),arr2159(1)),(arr1160(1),arr2159(2)),
     a  (arr1160(16),arr2160(1)),(arr1161(1),arr2160(2))
         equivalence
     1  (arr1161(16),arr2161(1)),(arr1162(1),arr2161(2)),
     2  (arr1162(16),arr2162(1)),(arr1163(1),arr2162(2)),
     3  (arr1163(16),arr2163(1)),(arr1164(1),arr2163(2)),
     4  (arr1164(16),arr2164(1)),(arr1165(1),arr2164(2)),
     5  (arr1165(16),arr2165(1)),(arr1166(1),arr2165(2)),
     6  (arr1166(16),arr2166(1)),(arr1167(1),arr2166(2)),
     7  (arr1167(16),arr2167(1)),(arr1168(1),arr2167(2)),
     8  (arr1168(16),arr2168(1)),(arr1169(1),arr2168(2)),
     9  (arr1169(16),arr2169(1)),(arr1170(1),arr2169(2)),
     a  (arr1170(16),arr2170(1)),(arr1171(1),arr2170(2))
         equivalence
     1  (arr1171(16),arr2171(1)),(arr1172(1),arr2171(2)),
     2  (arr1172(16),arr2172(1)),(arr1173(1),arr2172(2)),
     3  (arr1173(16),arr2173(1)),(arr1174(1),arr2173(2)),
     4  (arr1174(16),arr2174(1)),(arr1175(1),arr2174(2)),
     5  (arr1175(16),arr2175(1)),(arr1176(1),arr2175(2)),
     6  (arr1176(16),arr2176(1)),(arr1177(1),arr2176(2)),
     7  (arr1177(16),arr2177(1)),(arr1178(1),arr2177(2)),
     8  (arr1178(16),arr2178(1)),(arr1179(1),arr2178(2)),
     9  (arr1179(16),arr2179(1)),(arr1180(1),arr2179(2)),
     a  (arr1180(16),arr2180(1)),(arr1181(1),arr2180(2))
         equivalence
     1  (arr1181(16),arr2181(1)),(arr1182(1),arr2181(2)),
     2  (arr1182(16),arr2182(1)),(arr1183(1),arr2182(2)),
     3  (arr1183(16),arr2183(1)),(arr1184(1),arr2183(2)),
     4  (arr1184(16),arr2184(1)),(arr1185(1),arr2184(2)),
     5  (arr1185(16),arr2185(1)),(arr1186(1),arr2185(2)),
     6  (arr1186(16),arr2186(1)),(arr1187(1),arr2186(2)),
     7  (arr1187(16),arr2187(1)),(arr1188(1),arr2187(2)),
     8  (arr1188(16),arr2188(1)),(arr1189(1),arr2188(2)),
     9  (arr1189(16),arr2189(1)),(arr1190(1),arr2189(2)),
     a  (arr1190(16),arr2190(1)),(arr1191(1),arr2190(2))
         equivalence
     1  (arr1191(16),arr2191(1)),(arr1192(1),arr2191(2)),
     2  (arr1192(16),arr2192(1)),(arr1193(1),arr2192(2)),
     3  (arr1193(16),arr2193(1)),(arr1194(1),arr2193(2)),
     4  (arr1194(16),arr2194(1)),(arr1195(1),arr2194(2)),
     5  (arr1195(16),arr2195(1)),(arr1196(1),arr2195(2)),
     6  (arr1196(16),arr2196(1)),(arr1197(1),arr2196(2)),
     7  (arr1197(16),arr2197(1)),(arr1198(1),arr2197(2)),
     8  (arr1198(16),arr2198(1)),(arr1199(1),arr2198(2)),
     9  (arr1199(16),arr2199(1)),(arr1200(1),arr2199(2)),
     a  (arr1200(16),arr2200(1)),(arr1201(1),arr2200(2))
         equivalence
     1  (arr1201(16),arr2201(1)),(arr1202(1),arr2201(2)),
     2  (arr1202(16),arr2202(1)),(arr1203(1),arr2202(2)),
     3  (arr1203(16),arr2203(1)),(arr1204(1),arr2203(2)),
     4  (arr1204(16),arr2204(1)),(arr1205(1),arr2204(2)),
     5  (arr1205(16),arr2205(1)),(arr1206(1),arr2205(2)),
     6  (arr1206(16),arr2206(1)),(arr1207(1),arr2206(2)),
     7  (arr1207(16),arr2207(1)),(arr1208(1),arr2207(2)),
     8  (arr1208(16),arr2208(1)),(arr1209(1),arr2208(2)),
     9  (arr1209(16),arr2209(1)),(arr1210(1),arr2209(2)),
     a  (arr1210(16),arr2210(1)),(arr1211(1),arr2210(2))
         equivalence
     1  (arr1211(16),arr2211(1)),(arr1212(1),arr2211(2)),
     2  (arr1212(16),arr2212(1)),(arr1213(1),arr2212(2)),
     3  (arr1213(16),arr2213(1)),(arr1214(1),arr2213(2)),
     4  (arr1214(16),arr2214(1)),(arr1215(1),arr2214(2)),
     5  (arr1215(16),arr2215(1)),(arr1216(1),arr2215(2)),
     6  (arr1216(16),arr2216(1)),(arr1217(1),arr2216(2)),
     7  (arr1217(16),arr2217(1)),(arr1218(1),arr2217(2)),
     8  (arr1218(16),arr2218(1)),(arr1219(1),arr2218(2)),
     9  (arr1219(16),arr2219(1)),(arr1220(1),arr2219(2)),
     a  (arr1220(16),arr2220(1)),(arr1221(1),arr2220(2))
         equivalence
     1  (arr1221(16),arr2221(1)),(arr1222(1),arr2221(2)),
     2  (arr1222(16),arr2222(1)),(arr1223(1),arr2222(2)),
     3  (arr1223(16),arr2223(1)),(arr1224(1),arr2223(2)),
     4  (arr1224(16),arr2224(1)),(arr1225(1),arr2224(2)),
     5  (arr1225(16),arr2225(1)),(arr1226(1),arr2225(2)),
     6  (arr1226(16),arr2226(1)),(arr1227(1),arr2226(2)),
     7  (arr1227(16),arr2227(1)),(arr1228(1),arr2227(2)),
     8  (arr1228(16),arr2228(1)),(arr1229(1),arr2228(2)),
     9  (arr1229(16),arr2229(1)),(arr1230(1),arr2229(2)),
     a  (arr1230(16),arr2230(1)),(arr1231(1),arr2230(2))
         equivalence
     1  (arr1231(16),arr2231(1)),(arr1232(1),arr2231(2)),
     2  (arr1232(16),arr2232(1)),(arr1233(1),arr2232(2)),
     3  (arr1233(16),arr2233(1)),(arr1234(1),arr2233(2)),
     4  (arr1234(16),arr2234(1)),(arr1235(1),arr2234(2)),
     5  (arr1235(16),arr2235(1)),(arr1236(1),arr2235(2)),
     6  (arr1236(16),arr2236(1)),(arr1237(1),arr2236(2)),
     7  (arr1237(16),arr2237(1)),(arr1238(1),arr2237(2)),
     8  (arr1238(16),arr2238(1)),(arr1239(1),arr2238(2)),
     9  (arr1239(16),arr2239(1)),(arr1240(1),arr2239(2)),
     a  (arr1240(16),arr2240(1)),(arr1241(1),arr2240(2))
         equivalence
     1  (arr1241(16),arr2241(1)),(arr1242(1),arr2241(2)),
     2  (arr1242(16),arr2242(1)),(arr1243(1),arr2242(2)),
     3  (arr1243(16),arr2243(1)),(arr1244(1),arr2243(2)),
     4  (arr1244(16),arr2244(1)),(arr1245(1),arr2244(2)),
     5  (arr1245(16),arr2245(1)),(arr1246(1),arr2245(2)),
     6  (arr1246(16),arr2246(1)),(arr1247(1),arr2246(2)),
     7  (arr1247(16),arr2247(1)),(arr1248(1),arr2247(2)),
     8  (arr1248(16),arr2248(1)),(arr1249(1),arr2248(2)),
     9  (arr1249(16),arr2249(1)),(arr1250(1),arr2249(2)),
     a  (arr1250(16),arr2250(1)),(arr1251(1),arr2250(2))
         equivalence
     1  (arr1251(16),arr2251(1)),(arr1252(1),arr2251(2)),
     2  (arr1252(16),arr2252(1)),(arr1253(1),arr2252(2)),
     3  (arr1253(16),arr2253(1)),(arr1254(1),arr2253(2)),
     4  (arr1254(16),arr2254(1)),(arr1255(1),arr2254(2)),
     5  (arr1255(16),arr2255(1)),(arr1256(1),arr2255(2)),
     6  (arr1256(16),arr2256(1)),(arr1257(1),arr2256(2)),
     7  (arr1257(16),arr2257(1)),(arr1258(1),arr2257(2)),
     8  (arr1258(16),arr2258(1)),(arr1259(1),arr2258(2)),
     9  (arr1259(16),arr2259(1)),(arr1260(1),arr2259(2)),
     a  (arr1260(16),arr2260(1)),(arr1261(1),arr2260(2))
         equivalence
     1  (arr1261(16),arr2261(1)),(arr1262(1),arr2261(2)),
     2  (arr1262(16),arr2262(1)),(arr1263(1),arr2262(2)),
     3  (arr1263(16),arr2263(1)),(arr1264(1),arr2263(2)),
     4  (arr1264(16),arr2264(1)),(arr1265(1),arr2264(2)),
     5  (arr1265(16),arr2265(1)),(arr1266(1),arr2265(2)),
     6  (arr1266(16),arr2266(1)),(arr1267(1),arr2266(2)),
     7  (arr1267(16),arr2267(1)),(arr1268(1),arr2267(2)),
     8  (arr1268(16),arr2268(1)),(arr1269(1),arr2268(2)),
     9  (arr1269(16),arr2269(1)),(arr1270(1),arr2269(2)),
     a  (arr1270(16),arr2270(1)),(arr1271(1),arr2270(2))
         equivalence
     1  (arr1271(16),arr2271(1)),(arr1272(1),arr2271(2)),
     2  (arr1272(16),arr2272(1)),(arr1273(1),arr2272(2)),
     3  (arr1273(16),arr2273(1)),(arr1274(1),arr2273(2)),
     4  (arr1274(16),arr2274(1)),(arr1275(1),arr2274(2)),
     5  (arr1275(16),arr2275(1)),(arr1276(1),arr2275(2)),
     6  (arr1276(16),arr2276(1)),(arr1277(1),arr2276(2)),
     7  (arr1277(16),arr2277(1)),(arr1278(1),arr2277(2)),
     8  (arr1278(16),arr2278(1)),(arr1279(1),arr2278(2)),
     9  (arr1279(16),arr2279(1)),(arr1280(1),arr2279(2)),
     a  (arr1280(16),arr2280(1)),(arr1281(1),arr2280(2))
         equivalence
     1  (arr1281(16),arr2281(1)),(arr1282(1),arr2281(2)),
     2  (arr1282(16),arr2282(1)),(arr1283(1),arr2282(2)),
     3  (arr1283(16),arr2283(1)),(arr1284(1),arr2283(2)),
     4  (arr1284(16),arr2284(1)),(arr1285(1),arr2284(2)),
     5  (arr1285(16),arr2285(1)),(arr1286(1),arr2285(2)),
     6  (arr1286(16),arr2286(1)),(arr1287(1),arr2286(2)),
     7  (arr1287(16),arr2287(1)),(arr1288(1),arr2287(2)),
     8  (arr1288(16),arr2288(1)),(arr1289(1),arr2288(2)),
     9  (arr1289(16),arr2289(1)),(arr1290(1),arr2289(2)),
     a  (arr1290(16),arr2290(1)),(arr1291(1),arr2290(2))
         equivalence
     1  (arr1291(16),arr2291(1)),(arr1292(1),arr2291(2)),
     2  (arr1292(16),arr2292(1)),(arr1293(1),arr2292(2)),
     3  (arr1293(16),arr2293(1)),(arr1294(1),arr2293(2)),
     4  (arr1294(16),arr2294(1)),(arr1295(1),arr2294(2)),
     5  (arr1295(16),arr2295(1)),(arr1296(1),arr2295(2)),
     6  (arr1296(16),arr2296(1)),(arr1297(1),arr2296(2)),
     7  (arr1297(16),arr2297(1)),(arr1298(1),arr2297(2)),
     8  (arr1298(16),arr2298(1)),(arr1299(1),arr2298(2)),
     9  (arr1299(16),arr2299(1)),(arr1300(1),arr2299(2)),
     a  (arr1300(16),arr2300(1)),(arr1301(1),arr2300(2))
         equivalence
     1  (arr1301(16),arr2301(1)),(arr1302(1),arr2301(2)),
     2  (arr1302(16),arr2302(1)),(arr1303(1),arr2302(2)),
     3  (arr1303(16),arr2303(1)),(arr1304(1),arr2303(2)),
     4  (arr1304(16),arr2304(1)),(arr1305(1),arr2304(2)),
     5  (arr1305(16),arr2305(1)),(arr1306(1),arr2305(2)),
     6  (arr1306(16),arr2306(1)),(arr1307(1),arr2306(2)),
     7  (arr1307(16),arr2307(1)),(arr1308(1),arr2307(2)),
     8  (arr1308(16),arr2308(1)),(arr1309(1),arr2308(2)),
     9  (arr1309(16),arr2309(1)),(arr1310(1),arr2309(2)),
     a  (arr1310(16),arr2310(1)),(arr1311(1),arr2310(2))
         equivalence
     1  (arr1311(16),arr2311(1)),(arr1312(1),arr2311(2)),
     2  (arr1312(16),arr2312(1)),(arr1313(1),arr2312(2)),
     3  (arr1313(16),arr2313(1)),(arr1314(1),arr2313(2)),
     4  (arr1314(16),arr2314(1)),(arr1315(1),arr2314(2)),
     5  (arr1315(16),arr2315(1)),(arr1316(1),arr2315(2)),
     6  (arr1316(16),arr2316(1)),(arr1317(1),arr2316(2)),
     7  (arr1317(16),arr2317(1)),(arr1318(1),arr2317(2)),
     8  (arr1318(16),arr2318(1)),(arr1319(1),arr2318(2)),
     9  (arr1319(16),arr2319(1)),(arr1320(1),arr2319(2)),
     a  (arr1320(16),arr2320(1)),(arr1321(1),arr2320(2))
         equivalence
     1  (arr1321(16),arr2321(1)),(arr1322(1),arr2321(2)),
     2  (arr1322(16),arr2322(1)),(arr1323(1),arr2322(2)),
     3  (arr1323(16),arr2323(1)),(arr1324(1),arr2323(2)),
     4  (arr1324(16),arr2324(1)),(arr1325(1),arr2324(2)),
     5  (arr1325(16),arr2325(1)),(arr1326(1),arr2325(2)),
     6  (arr1326(16),arr2326(1)),(arr1327(1),arr2326(2)),
     7  (arr1327(16),arr2327(1)),(arr1328(1),arr2327(2)),
     8  (arr1328(16),arr2328(1)),(arr1329(1),arr2328(2)),
     9  (arr1329(16),arr2329(1)),(arr1330(1),arr2329(2)),
     a  (arr1330(16),arr2330(1)),(arr1331(1),arr2330(2))
         equivalence
     1  (arr1331(16),arr2331(1)),(arr1332(1),arr2331(2)),
     2  (arr1332(16),arr2332(1)),(arr1333(1),arr2332(2)),
     3  (arr1333(16),arr2333(1)),(arr1334(1),arr2333(2)),
     4  (arr1334(16),arr2334(1)),(arr1335(1),arr2334(2)),
     5  (arr1335(16),arr2335(1)),(arr1336(1),arr2335(2)),
     6  (arr1336(16),arr2336(1)),(arr1337(1),arr2336(2)),
     7  (arr1337(16),arr2337(1)),(arr1338(1),arr2337(2)),
     8  (arr1338(16),arr2338(1)),(arr1339(1),arr2338(2)),
     9  (arr1339(16),arr2339(1)),(arr1340(1),arr2339(2)),
     a  (arr1340(16),arr2340(1)),(arr1341(1),arr2340(2))
         equivalence
     1  (arr1341(16),arr2341(1)),(arr1342(1),arr2341(2)),
     2  (arr1342(16),arr2342(1)),(arr1343(1),arr2342(2)),
     3  (arr1343(16),arr2343(1)),(arr1344(1),arr2343(2)),
     4  (arr1344(16),arr2344(1)),(arr1345(1),arr2344(2)),
     5  (arr1345(16),arr2345(1)),(arr1346(1),arr2345(2)),
     6  (arr1346(16),arr2346(1)),(arr1347(1),arr2346(2)),
     7  (arr1347(16),arr2347(1)),(arr1348(1),arr2347(2)),
     8  (arr1348(16),arr2348(1)),(arr1349(1),arr2348(2)),
     9  (arr1349(16),arr2349(1)),(arr1350(1),arr2349(2)),
     a  (arr1350(16),arr2350(1)),(arr1351(1),arr2350(2))
         equivalence
     1  (arr1351(16),arr2351(1)),(arr1352(1),arr2351(2)),
     2  (arr1352(16),arr2352(1)),(arr1353(1),arr2352(2)),
     3  (arr1353(16),arr2353(1)),(arr1354(1),arr2353(2)),
     4  (arr1354(16),arr2354(1)),(arr1355(1),arr2354(2)),
     5  (arr1355(16),arr2355(1)),(arr1356(1),arr2355(2)),
     6  (arr1356(16),arr2356(1)),(arr1357(1),arr2356(2)),
     7  (arr1357(16),arr2357(1)),(arr1358(1),arr2357(2)),
     8  (arr1358(16),arr2358(1)),(arr1359(1),arr2358(2)),
     9  (arr1359(16),arr2359(1)),(arr1360(1),arr2359(2)),
     a  (arr1360(16),arr2360(1)),(arr1361(1),arr2360(2))
         equivalence
     1  (arr1361(16),arr2361(1)),(arr1362(1),arr2361(2)),
     2  (arr1362(16),arr2362(1)),(arr1363(1),arr2362(2)),
     3  (arr1363(16),arr2363(1)),(arr1364(1),arr2363(2)),
     4  (arr1364(16),arr2364(1)),(arr1365(1),arr2364(2)),
     5  (arr1365(16),arr2365(1)),(arr1366(1),arr2365(2)),
     6  (arr1366(16),arr2366(1)),(arr1367(1),arr2366(2)),
     7  (arr1367(16),arr2367(1)),(arr1368(1),arr2367(2)),
     8  (arr1368(16),arr2368(1)),(arr1369(1),arr2368(2)),
     9  (arr1369(16),arr2369(1)),(arr1370(1),arr2369(2)),
     a  (arr1370(16),arr2370(1)),(arr1371(1),arr2370(2))
         equivalence
     1  (arr1371(16),arr2371(1)),(arr1372(1),arr2371(2)),
     2  (arr1372(16),arr2372(1)),(arr1373(1),arr2372(2)),
     3  (arr1373(16),arr2373(1)),(arr1374(1),arr2373(2)),
     4  (arr1374(16),arr2374(1)),(arr1375(1),arr2374(2)),
     5  (arr1375(16),arr2375(1)),(arr1376(1),arr2375(2)),
     6  (arr1376(16),arr2376(1)),(arr1377(1),arr2376(2)),
     7  (arr1377(16),arr2377(1)),(arr1378(1),arr2377(2)),
     8  (arr1378(16),arr2378(1)),(arr1379(1),arr2378(2)),
     9  (arr1379(16),arr2379(1)),(arr1380(1),arr2379(2)),
     a  (arr1380(16),arr2380(1)),(arr1381(1),arr2380(2))
         equivalence
     1  (arr1381(16),arr2381(1)),(arr1382(1),arr2381(2)),
     2  (arr1382(16),arr2382(1)),(arr1383(1),arr2382(2)),
     3  (arr1383(16),arr2383(1)),(arr1384(1),arr2383(2)),
     4  (arr1384(16),arr2384(1)),(arr1385(1),arr2384(2)),
     5  (arr1385(16),arr2385(1)),(arr1386(1),arr2385(2)),
     6  (arr1386(16),arr2386(1)),(arr1387(1),arr2386(2)),
     7  (arr1387(16),arr2387(1)),(arr1388(1),arr2387(2)),
     8  (arr1388(16),arr2388(1)),(arr1389(1),arr2388(2)),
     9  (arr1389(16),arr2389(1)),(arr1390(1),arr2389(2)),
     a  (arr1390(16),arr2390(1)),(arr1391(1),arr2390(2))
         equivalence
     1  (arr1391(16),arr2391(1)),(arr1392(1),arr2391(2)),
     2  (arr1392(16),arr2392(1)),(arr1393(1),arr2392(2)),
     3  (arr1393(16),arr2393(1)),(arr1394(1),arr2393(2)),
     4  (arr1394(16),arr2394(1)),(arr1395(1),arr2394(2)),
     5  (arr1395(16),arr2395(1)),(arr1396(1),arr2395(2)),
     6  (arr1396(16),arr2396(1)),(arr1397(1),arr2396(2)),
     7  (arr1397(16),arr2397(1)),(arr1398(1),arr2397(2)),
     8  (arr1398(16),arr2398(1)),(arr1399(1),arr2398(2)),
     9  (arr1399(16),arr2399(1)),(arr1400(1),arr2399(2)),
     a  (arr1400(16),arr2400(1)),(arr1401(1),arr2400(2))
         equivalence
     1  (arr1401(16),arr2401(1)),(arr1402(1),arr2401(2)),
     2  (arr1402(16),arr2402(1)),(arr1403(1),arr2402(2)),
     3  (arr1403(16),arr2403(1)),(arr1404(1),arr2403(2)),
     4  (arr1404(16),arr2404(1)),(arr1405(1),arr2404(2)),
     5  (arr1405(16),arr2405(1)),(arr1406(1),arr2405(2)),
     6  (arr1406(16),arr2406(1)),(arr1407(1),arr2406(2)),
     7  (arr1407(16),arr2407(1)),(arr1408(1),arr2407(2)),
     8  (arr1408(16),arr2408(1)),(arr1409(1),arr2408(2)),
     9  (arr1409(16),arr2409(1)),(arr1410(1),arr2409(2)),
     a  (arr1410(16),arr2410(1)),(arr1411(1),arr2410(2))
         equivalence
     1  (arr1411(16),arr2411(1)),(arr1412(1),arr2411(2)),
     2  (arr1412(16),arr2412(1)),(arr1413(1),arr2412(2)),
     3  (arr1413(16),arr2413(1)),(arr1414(1),arr2413(2)),
     4  (arr1414(16),arr2414(1)),(arr1415(1),arr2414(2)),
     5  (arr1415(16),arr2415(1)),(arr1416(1),arr2415(2)),
     6  (arr1416(16),arr2416(1)),(arr1417(1),arr2416(2)),
     7  (arr1417(16),arr2417(1)),(arr1418(1),arr2417(2)),
     8  (arr1418(16),arr2418(1)),(arr1419(1),arr2418(2)),
     9  (arr1419(16),arr2419(1)),(arr1420(1),arr2419(2)),
     a  (arr1420(16),arr2420(1)),(arr1421(1),arr2420(2))
         equivalence
     1  (arr1421(16),arr2421(1)),(arr1422(1),arr2421(2)),
     2  (arr1422(16),arr2422(1)),(arr1423(1),arr2422(2)),
     3  (arr1423(16),arr2423(1)),(arr1424(1),arr2423(2)),
     4  (arr1424(16),arr2424(1)),(arr1425(1),arr2424(2)),
     5  (arr1425(16),arr2425(1)),(arr1426(1),arr2425(2)),
     6  (arr1426(16),arr2426(1)),(arr1427(1),arr2426(2)),
     7  (arr1427(16),arr2427(1)),(arr1428(1),arr2427(2)),
     8  (arr1428(16),arr2428(1)),(arr1429(1),arr2428(2)),
     9  (arr1429(16),arr2429(1)),(arr1430(1),arr2429(2)),
     a  (arr1430(16),arr2430(1)),(arr1431(1),arr2430(2))
         equivalence
     1  (arr1431(16),arr2431(1)),(arr1432(1),arr2431(2)),
     2  (arr1432(16),arr2432(1)),(arr1433(1),arr2432(2)),
     3  (arr1433(16),arr2433(1)),(arr1434(1),arr2433(2)),
     4  (arr1434(16),arr2434(1)),(arr1435(1),arr2434(2)),
     5  (arr1435(16),arr2435(1)),(arr1436(1),arr2435(2)),
     6  (arr1436(16),arr2436(1)),(arr1437(1),arr2436(2)),
     7  (arr1437(16),arr2437(1)),(arr1438(1),arr2437(2)),
     8  (arr1438(16),arr2438(1)),(arr1439(1),arr2438(2)),
     9  (arr1439(16),arr2439(1)),(arr1440(1),arr2439(2)),
     a  (arr1440(16),arr2440(1)),(arr1441(1),arr2440(2))
         equivalence
     1  (arr1441(16),arr2441(1)),(arr1442(1),arr2441(2)),
     2  (arr1442(16),arr2442(1)),(arr1443(1),arr2442(2)),
     3  (arr1443(16),arr2443(1)),(arr1444(1),arr2443(2)),
     4  (arr1444(16),arr2444(1)),(arr1445(1),arr2444(2)),
     5  (arr1445(16),arr2445(1)),(arr1446(1),arr2445(2)),
     6  (arr1446(16),arr2446(1)),(arr1447(1),arr2446(2)),
     7  (arr1447(16),arr2447(1)),(arr1448(1),arr2447(2)),
     8  (arr1448(16),arr2448(1)),(arr1449(1),arr2448(2)),
     9  (arr1449(16),arr2449(1)),(arr1450(1),arr2449(2)),
     a  (arr1450(16),arr2450(1)),(arr1451(1),arr2450(2))
         equivalence
     1  (arr1451(16),arr2451(1)),(arr1452(1),arr2451(2)),
     2  (arr1452(16),arr2452(1)),(arr1453(1),arr2452(2)),
     3  (arr1453(16),arr2453(1)),(arr1454(1),arr2453(2)),
     4  (arr1454(16),arr2454(1)),(arr1455(1),arr2454(2))
c
         data arr1001/
     1      0.9816420878036026d+00,-.3637673002721756d-01,
     2      0.6740065976760899d-03,-.8325558556319216d-05,
     3      0.7713009630972221d-07,-.5716326142483016d-09,
     4      0.3530520871019650d-11,-.2446186882775863d-13,
     5      0.1759641994584386d-13,-.1671553576964007d-13,
     6      0.2195173026679963d-13,-.4899346242539366d-13,
     7      0.1746658947918832d-13,-.8032058412703090d-13,
     8      -.3451719271022098d-13,-.4497708856730276d-13/
         data arr1002/
     1      0.6846049435389069d-13,0.6335179116739778d-13,
     2      0.3829249369854373d-12,0.3537547113122420d-12,
     3      0.7673380952420304d-12,0.3558682136977873d-12,
     4      0.8375173496904506d-12,0.4202218025008851d-12,
     5      0.4188109160125288d-12,0.9083746100760842d+00,
     6      -.1745867283207215d+00,0.1677750862234001d-01,
     7      -.1074861372267003d-02,0.5164623941957497d-04,
     8      -.1985248780366863d-05,0.6359308769032336d-07/
         data arr1003/
     1      -.1746065455874668d-08,0.4197124462612747d-10,
     2      -.9170631308686040d-12,0.1069573489847940d-12,
     3      -.1091056045922408d-13,0.2275600948862975d-12,
     4      0.7132750213777709d-13,0.4065174344383347d-12,
     5      0.3398130184780027d-12,0.5742359230190764d-12,
     6      0.5685110557336641d-12,0.7039541752125729d-12,
     7      0.8049287973492188d-12,0.7671486573556984d-12,
     8      0.4736207676883017d-12,0.6329296899324333d-12/
         data arr1004/
     1      0.3392708048888509d-12,0.4036802340077132d-12,
     2      0.7943509951159291d+00,-.3657666305563284d+00,
     3      0.8421039870983241d-01,-.1292516531662742d-01,
     4      0.1487879475292068d-02,-.1370217109735880d-03,
     5      0.1051549626409330d-04,-.6917089156747122d-06,
     6      0.3981303637158717d-07,-.2036943830280661d-08,
     7      0.9388220386921214d-10,-.3918930392996983d-11,
     8      0.2720563181857118d-12,0.9791360207274513d-13/
         data arr1005/
     1      0.4537184835500079d-13,0.4609630479275626d-12,
     2      -.4534671489163438d-12,0.5879814823319330d-12,
     3      -.1003132847362445d-11,0.6232008771818677d-12,
     4      -.1508969418690646d-11,0.7809954621178859d-13,
     5      -.1178297673091374d-11,-.9444900170258528d-13,
     6      -.5736569240659205d-12,0.6609839964737625d+00,
     7      -.5473286582296786d+00,0.2266081037647264d+00,
     8      -.6254771171424961d-01,0.1294817851511225d-01/
         data arr1006/
     1      -.2144351213037857d-02,0.2959388019648455d-03,
     2      -.3500750143091936d-04,0.3623500924527253d-05,
     3      -.3333827725034086d-06,0.2760592313885775d-07,
     4      -.2078039028432281d-08,0.1435200846723221d-09,
     5      -.8879299909465399d-11,0.5388761932139618d-12,
     6      0.9579506099365464d-12,-.7211857134244382d-12,
     7      0.1103482715347403d-11,-.1237791798498446d-11,
     8      0.9967271022691556d-12,-.1468649504683401d-11/
         data arr1007/
     1      -.1794928707680639d-12,-.8305044589882712d-12,
     2      -.5464130624105482d-12,0.6460250779067315d-13,
     3      0.5269729027344416d+00,-.6751641644591124d+00,
     4      0.4325143158257296d+00,-.1847142203744004d+00,
     5      0.5916453275665302d-01,-.1516046541178452d-01,
     6      0.3237295791826052d-02,-.5925233122048511d-03,
     7      0.9489351948027656d-04,-.1350874943604087d-04,
     8      0.1730757873752967d-05,-.2015879413045213d-06/
         data arr1008/
     1      0.2152356828844044d-07,-.2120959322969690d-08,
     2      0.1949142570585003d-09,-.1520835720074017d-10,
     3      0.1473428137193576d-11,0.1109976342411732d-11,
     4      -.1455231724375615d-12,0.8625495562127698d-12,
     5      -.6000121062773125d-12,-.1169094339395393d-11,
     6      -.8769174173630756d-13,-.1487447493674787d-11,
     7      0.7593116224687935d-12,0.4049627884847229d+00,
     8      -.7321404026191306d+00,0.6618257089163682d+00/
         data arr1009/
     1      -.3988426877465221d+00,0.1802689372282004d+00,
     2      -.6518237034856621d-01,0.1964075392755598d-01,
     3      -.5072702232384747d-02,0.1146380099831993d-02,
     4      -.2302848591317067d-03,0.4163366513188506d-04,
     5      -.6842758349225382d-05,0.1030930788178396d-05,
     6      -.1433718000295199d-06,0.1851563411293160d-07,
     7      -.2229024586420549d-08,0.2516240116895647d-09,
     8      -.2454478304426592d-10,0.1282841618916179d-11/
         data arr1010/
     1      0.1517342957694393d-11,-.2150720446801959d-11,
     2      -.1799489214255671d-11,-.1022560752435633d-11,
     3      -.2465639475476104d-11,0.9542738921993984d-12,
     4      0.3014733553440475d+00,-.7229775073348932d+00,
     5      0.8669032716268812d+00,-.6929872411731663d+00,
     6      0.4154713670023139d+00,-.1992723058006821d+00,
     7      0.7964738971387793d-01,-.2728659586580250d-01,
     8      0.8179659459691109d-02,-.2179558676973649d-02/
         data arr1011/
     1      0.5226902720631991d-03,-.1139534774855930d-03,
     2      0.2277310287466834d-04,-.4201019092585093d-05,
     3      0.7196202873152888d-06,-.1150468540255169d-06,
     4      0.1724372564921065d-07,-.2429864613126064d-08,
     5      0.3224854888811131d-09,-.3854558834794269d-10,
     6      0.2174844167062394d-11,-.3327623315274573d-11,
     7      -.1306572248126452d-11,-.3528132668522098d-11,
     8      0.1298114027836923d-11,0.2183196378181522d+00/
         data arr1012/
     1      -.6644754933346300d+00,0.1011195524266278d+01,
     2      -.1025888236715068d+01,0.7805958261588427d+00,
     3      -.4751627493207329d+00,0.2410334417801722d+00,
     4      -.1048010003901103d+00,0.3987141120952854d-01,
     5      -.1348358148379970d-01,0.4103849543481153d-02,
     6      -.1135494176105464d-02,0.2879982394490777d-03,
     7      -.6742681536253343d-04,0.1465854379269251d-04,
     8      -.2974302942091494d-05,0.5657852028047254d-06/
         data arr1013/
     1      -.1012928072943041d-06,0.1712624644467783d-07,
     2      -.2740375867233315d-08,0.4146814891931071d-09,
     3      -.6363402582089824d-10,0.6756610204596177d-11,
     4      -.4645066404850172d-11,0.1373533319688151d-11,
     5      0.1543297526784940d+00,-.5767808178332980d+00,
     6      0.1077809385574197d+01,-.1342708860066592d+01,
     7      0.1254535663052925d+01,-.9377221088978340d+00,
     8      0.5840957597647769d+00,-.3118510148960810d+00/
         data arr1014/
     1      0.1456861689761150d+00,-.6049743504265004d-01,
     2      0.2260987233881894d-01,-.7681863279376381d-02,
     3      0.2392469862372438d-02,-.6878033286971233d-03,
     4      0.1836104464455510d-03,-.4574748873834060d-04,
     5      0.1068583354395629d-04,-.2349201959821959d-05,
     6      0.4877614878864026d-06,-.9593619180399864d-07,
     7      0.1792600563899961d-07,-.3188127907882021d-08,
     8      0.5395668282423592d-09,-.8548243733429033d-10/
         data arr1015/
     1      0.1357493153666565d-10,0.1068025106577496d+00,
     2      -.4777861247752997d+00,0.1068699507258440d+01,
     3      -.1593626070453698d+01,0.1782290556312272d+01,
     4      -.1594632360007023d+01,0.1188943984925558d+01,
     5      -.7598282309419883d+00,0.4248909783590123d+00,
     6      -.2111966727227254d+00,0.9447983872618200d-01,
     7      -.3842364220457515d-01,0.1432416631522757d-01,
     8      -.4929218545129606d-02,0.1575078156047727d-02/
         data arr1016/
     1      -.4697457799465540d-03,0.1313393839060594d-03,
     2      -.3456183487510904d-04,0.8589670316019842d-05,
     3      -.2022236009679707d-05,0.4523377210764615d-06,
     4      -.9609788188572945d-07,0.1954583879559097d-07,
     5      -.3591400073109889d-08,0.6709985427667342d-09,
     6      0.7253561540000264d-01,-.3806201373265861d+00,
     7      0.9986245249289313d+00,-.1746712525151081d+01,
     8      0.2291405254945535d+01,-.2404763447581516d+01/
         data arr1017/
     1      0.2103107989568343d+01,-.1576536372394156d+01,
     2      0.1034080787848905d+01,-.6029099089453207d+00,
     3      0.3163682434735547d+00,-.1509178673887441d+00,
     4      0.6599330445070610d-01,-.2663771560612544d-01,
     5      0.9984111101772952d-02,-.3492676927356226d-02,
     6      0.1145457399224588d-02,-.3535619153266564d-03,
     7      0.1030705396961671d-03,-.2845863587012125d-04,
     8      0.7466970649423928d-05,-.1856507698157934d-05/
         data arr1018/
     1      0.4430907484577213d-06,-.9376496233052756d-07,
     2      0.2061213911976490d-07,0.4844555237502123d-01,
     3      -.2933198698856531d+00,0.8879715665496862d+00,
     4      -.1792112943251385d+01,0.2712644967203934d+01,
     5      -.3284812040832897d+01,0.3314719973163942d+01,
     6      -.2867057326972216d+01,0.2169871228759853d+01,
     7      -.1459751813827729d+01,0.8838256373525039d+00,
     8      -.4864760683862198d+00,0.2454526957403092d+00/
         data arr1019/
     1      -.1143173078484131d+00,0.4943921137578636d-01,
     2      -.1995570387895358d-01,0.7551528247457091d-02,
     3      -.2689416772090401d-02,0.9046419311361659d-03,
     4      -.2881139300764529d-03,0.8723023645922784d-04,
     5      -.2493383963711426d-04,0.6869741827915561d-05,
     6      -.1638445283287666d-05,0.4164335025095417d-06,
     7      0.3187420413990096d-01,-.2196743530554856d+00,
     8      0.7569886478904018d+00,-.1739034181237795d+01/
         data arr1020/
     1      0.2996319586643685d+01,-.4130076872833366d+01,
     2      0.4744024149111449d+01,-.4670774037817450d+01,
     3      0.4023823074303424d+01,-.3081316957072286d+01,
     4      0.2123617912317631d+01,-.1330527009020071d+01,
     5      0.7641567542649802d+00,-.4051155737895106d+00,
     6      0.1994302153783966d+00,-.9162983099914289d-01,
     7      0.3946914033241555d-01,-.1599951148637406d-01,
     8      0.6126098539177297d-02,-.2219480117290976d-02/
         data arr1021/
     1      0.7649927052205477d-03,-.2475523286794170d-03,
     2      0.7769390821430258d-04,-.2052064456299618d-04,
     3      0.5950821425824288d-05,0.2068866520216922d-01,
     4      -.1604682926724095d+00,0.6223232066708012d+00,
     5      -.1608983171800254d+01,0.3119954572634136d+01,
     6      -.4839884825019239d+01,0.6256630916399722d+01,
     7      -.6932649724485106d+01,0.6721497324272637d+01,
     8      -.5792689940347462d+01,0.4493006438019982d+01/
         data arr1022/
     1      -.3168116074388006d+01,0.2047748441029032d+01,
     2      -.1221769644461383d+01,0.6768902367910710d+00,
     3      -.3500055272970958d+00,0.1696735236677326d+00,
     4      -.7739587322747717d-01,0.3335235031357327d-01,
     5      -.1358357022785865d-01,0.5270243791671847d-02,
     6      -.1904506908390333d-02,0.6734111716786839d-03,
     7      -.1940042587489238d-03,0.6349465637044138d-04,
     8      0.1326323211587029d-01,-.1146675275786037d+00/
         data arr1023/
     1      0.4956801511935296d+00,-.1428470751042324d+01,
     2      0.3087467801086866d+01,-.5338552439315216d+01,
     3      0.7692426185093617d+01,-.9500717031756910d+01,
     4      0.1026732873442744d+02,-.9862932179782346d+01,
     5      0.8527016651197572d+01,-.6701860239284657d+01,
     6      0.4828421986103475d+01,-.3211075700013523d+01,
     7      0.1982961467378181d+01,-.1142849517223737d+01,
     8      0.6175427035688160d+00,-.3138860011176141d+00/
         data arr1024/
     1      0.1507810091783766d+00,-.6831562464422294d-01,
     2      0.2955524382644237d-01,-.1177879689286587d-01,
     3      0.4649227126614919d-02,-.1441627809304993d-02,
     4      0.5276789555865857d-03,0.8406419571504207d-02,
     5      -.8034451927960012d-01,0.3839471326311655d+00,
     6      -.1223194073292349d+01,0.2922675173927025d+01,
     7      -.5586705151485313d+01,0.8899173374108882d+01,
     8      -.1215057582559411d+02,0.1451616914426991d+02/
         data arr1025/
     1      -.1541539819230243d+02,0.1473329445324399d+02,
     2      -.1280123394073673d+02,0.1019567189312741d+02,
     3      -.7495663451913469d+01,0.5117165004599719d+01,
     4      -.3260007097314594d+01,0.1947429086617683d+01,
     5      -.1093592663917510d+01,0.5808292958032144d+00,
     6      -.2900047920966140d+00,0.1387852362325078d+00,
     7      -.6029247223038582d-01,0.2636206155016141d-01,
     8      -.8694966989520700d-02,0.3532313418063371d-02/
         data arr1026/
     1      0.5271746263704391d-02,-.5530478095575111d-01,
     2      0.2900952605269804d+00,-.1014442764940311d+01,
     3      0.2660575453163926d+01,-.5582308043613716d+01,
     4      0.9760465708791367d+01,-.1462786133776562d+02,
     5      0.1918221505961635d+02,-.2235962690482359d+02,
     6      0.2345699529300624d+02,-.2237102679483068d+02,
     7      0.1955748632820371d+02,-.1578177431172069d+02,
     8      0.1182611914223859d+02,-.8268070654361511d+01/
         data arr1027/
     1      0.5421701140848032d+01,-.3338086567891411d+01,
     2      0.1946592420924805d+01,-.1061663438375681d+01,
     3      0.5582288009907534d+00,-.2614500995800965d+00,
     4      0.1258169540861371d+00,-.4367946661192909d-01,
     5      0.1956826167623937d-01,0.3272963050400073d-02,
     6      -.3745623494785161d-01,0.2143263376020633d+00,
     7      -.8175931570157933d+00,0.2339156582756624d+01,
     8      -.5353927132589636d+01,0.1021182012653382d+02/
         data arr1028/
     1      -.1669508625828750d+02,0.2388253015507659d+02,
     2      -.3036834149854917d+02,0.3475382037352174d+02,
     3      -.3615649943231134d+02,0.3448168320731082d+02,
     4      -.3035073944338334d+02,0.2481079762482077d+02,
     5      -.1891415368802306d+02,0.1353153395956993d+02,
     6      -.9070107337133283d+01,0.5772743236942075d+01,
     7      -.3410112514438164d+01,0.1958891020341800d+01,
     8      -.9786917668808144d+00,0.5155750946382200d+00/
         data arr1029/
     1      -.1866343216657664d+00,0.9170729870818484d-01,
     2      0.2012633663556610d-02,-.2499031319542409d-01,
     3      0.1551453999845125d+00,-.6421322344519780d+00,
     4      0.1993270660018407d+01,-.4949983299245317d+01,
     5      0.1024363875092734d+02,-.1817040993725393d+02,
     6      0.2820172627435469d+02,-.3890809433050786d+02,
     7      0.4831041752572328d+02,-.5452992233828511d+02,
     8      0.5642354347767593d+02,-.5387378707378726d+02/
         data arr1030/
     1      0.4778548168430299d+02,-.3949007264940479d+02,
     2      0.3066049018850573d+02,-.2222350052935563d+02,
     3      0.1535945058778331d+02,-.9745507135207690d+01,
     4      0.6087018757073885d+01,-.3211159167225526d+01,
     5      0.1843616185145667d+01,-.6900089727789275d+00,
     6      0.3702067618938845d+00,0.1226227647271212d-02,
     7      -.1644137835418314d-01,0.1102106679886591d+00,
     8      -.4925738940606367d+00,0.1651034177458073d+01/
         data arr1031/
     1      -.4427478485061132d+01,0.9893538912183230d+01,
     2      -.1895073080359470d+02,0.3176003765582209d+02,
     3      -.4731546366480057d+02,0.6343799699971272d+02,
     4      -.7731548647917752d+02,0.8638713401365092d+02,
     5      -.8902903876247919d+02,0.8528231809812688d+02,
     6      -.7598068051926033d+02,0.6373159722143948d+02,
     7      -.4961691982306149d+02,0.3708099859372580d+02,
     8      -.2505911277889203d+02,0.1695293092838703d+02/
         data arr1032/
     1      -.9350281095226572d+01,0.5829439757250995d+01,
     2      -.2238574001057557d+01,0.1306537064192490d+01,
     3      0.7405461283808688d-03,-.1067710208869183d-01,
     4      0.7692824062627303d-01,-.3697398938622484d+00,
     5      0.1332485222628483d+01,-.3842598736919622d+01,
     6      0.9232410992748852d+01,-.1901734192450037d+02,
     7      0.3426907125230882d+02,-.5489886132396232d+02,
     8      0.7914351705887745d+02,-.1037017705857624d+03/
         data arr1033/
     1      0.1245963505507500d+03,-.1379522005607054d+03,
     2      0.1421343627931675d+03,-.1357794155872157d+03,
     3      0.1225706354938969d+03,-.1017827599627305d+03,
     4      0.8197281846834009d+02,-.5849800295123414d+02,
     5      0.4273408726934464d+02,-.2440645772381733d+02,
     6      0.1647659878934435d+02,-.6446837644565394d+01,
     7      0.4080907890584420d+01,0.4440262760099201d-03,
     8      -.6856532354659250d-02,0.5282126209602982d-01/
         data arr1034/
     1      -.2720527960231381d+00,0.1049891174566509d+01,
     2      -.3244375154812245d+01,0.8348694697388050d+01,
     3      -.1842715136831042d+02,0.3556570112904810d+02,
     4      -.6104210863105601d+02,0.9426177123701950d+02,
     5      -.1322666051047115d+03,0.1702555150393855d+03,
     6      -.2015975925760067d+03,0.2226357348394185d+03,
     7      -.2267609921224395d+03,0.2196212577692766d+03,
     8      -.1930835902311079d+03,0.1671402768430655d+03/
         data arr1035/
     1      -.1248484836417119d+03,0.9826308879971573d+02,
     2      -.5757250522604262d+02,0.4199798750518733d+02,
     3      -.1663651108164823d+02,0.1139546124199474d+02,
     4      0.2663030204190519d-03,-.4378994212061165d-02,
     5      0.3572812494626268d-01,-.1966533273488776d+00,
     6      0.8090513465199275d+00,-.2671592638586797d+01,
     7      0.7334408668958429d+01,-.1729513856426597d+02,
     8      0.3562196836946839d+02,-.6528954623602125d+02/
         data arr1036/
     1      0.1076180446080598d+03,-.1611081962105907d+03,
     2      0.2214566043953275d+03,-.2791081384877657d+03,
     3      0.3294463031046939d+03,-.3555695053003737d+03,
     4      0.3686092105675586d+03,-.3403372068226838d+03,
     5      0.3160920768929402d+03,-.2449139312361179d+03,
     6      0.2073762337001387d+03,-.1235156917452786d+03,
     7      0.9722975653015374d+02,-.3876147062305993d+02,
     8      0.2868325804749561d+02,0.1647288261921590d-03/
         data arr1037/
     1      -.2836703271149011d-02,0.2388658780857784d-01,
     2      -.1402750485748629d+00,0.6110510422378737d+00,
     3      -.2152494191323587d+01,0.6275086329674600d+01,
     4      -.1577419199017669d+02,0.3453503657195787d+02,
     5      -.6740069688199202d+02,0.1181877594135808d+03,
     6      -.1880506330514989d+03,0.2752502701463894d+03,
     7      -.3672921300799842d+03,0.4623593203394045d+03,
     8      -.5251244599111116d+03,0.5818124868284384d+03/
         data arr1038/
     1      -.5591707150534503d+03,0.5567133742275628d+03,
     2      -.4432863637801029d+03,0.4035464616236766d+03,
     3      -.2421642121881559d+03,0.2055912869843993d+03,
     4      -.8202015266752962d+02,0.6551179006371876d+02,
     5      0.1159822369494212d-03,-.1976386681632263d-02,
     6      0.1595087381789100d-01,-.9987294753229814d-01,
     7      0.4540745342490536d+00,-.1706439112341388d+01,
     8      0.5244318084191908d+01,-.1403698486007514d+02/
         data arr1039/
     1      0.3250458491981070d+02,-.6737157427026634d+02,
     2      0.1252262214153937d+03,-.2108826309004359d+03,
     3      0.3278621308340690d+03,-.4603078070437387d+03,
     4      0.6170966285054625d+03,-.7316080700823404d+03,
     5      0.8658269717273818d+03,-.8577603763880912d+03,
     6      0.9155442037255789d+03,-.7420224048004882d+03,
     7      0.7264635494589519d+03,-.4353290760261758d+03,
     8      0.3987194901166127d+03,-.1583118305379537d+03/
         data arr1040/
     1      0.1364724641672659d+03,0.1112755698391468d-03,
     2      -.1669670629907379d-02,0.1096961298452587d-01,
     3      -.7299257891537210d-01,0.3348688263248503d+00,
     4      -.1345986346044978d+01,0.4300943980264800d+01,
     5      -.1225891681169378d+02,0.2979980580643138d+02,
     6      -.6542030889268874d+02,0.1283526729359984d+03,
     7      -.2276140040646258d+03,0.3750846433428437d+03,
     8      -.5498179539191982d+03,0.7846395412846811d+03/
         data arr1041/
     1      -.9619799351969604d+03,0.1216842456769594d+04,
     2      -.1229331215770671d+04,0.1408669450763930d+04,
     3      -.1150548394514293d+04,0.1213239134816267d+04,
     4      -.7194327334986431d+03,0.7119692497230947d+03,
     5      -.2797839140895500d+03,0.2605766669426576d+03,
     6      -.1286111623981901d-01,0.2751620412627996d-03,
     7      -.3605072603770491d-05,0.3449362772598886d-07,
     8      -.2609178217577566d-09,0.1634343861182355d-11/
         data arr1042/
     1      -.8692766442168942d-14,-.1056546457276844d-16,
     2      -.1431619140975765d-15,0.5146677399801946d-16,
     3      -.1044457604500159d-15,-.1205407081316643d-16,
     4      0.3392867059676295d-15,-.2168881501910162d-15,
     5      0.1733926547061828d-14,-.9886167594890016d-15,
     6      0.4272065417109875d-14,-.1229361558893051d-14,
     7      0.6028892771389870d-14,-.2203390114880351d-14,
     8      0.5600636496319448d-14,-.1314880294676986d-14/
         data arr1043/
     1      0.2498483772957234d-14,-.1695935041348165d-14,
     2      -.6172572975037783d-01,0.6849389213313291d-02,
     3      -.4654286269632963d-03,0.2309690042510208d-04,
     4      -.9061379530695980d-06,0.2943788060382716d-07,
     5      -.8166425118806311d-09,0.1977444555559488d-10,
     6      -.4248257117335066d-12,0.7936309182605842d-14,
     7      0.5092933416955249d-15,-.1128279773038354d-14,
     8      0.2008084362366300d-14,-.3817689723072691d-14/
         data arr1044/
     1      0.4741548224419661d-14,-.6255744926029276d-14,
     2      0.9502261647325388d-14,-.8189627496876561d-14,
     3      0.1497400763172083d-13,-.4592690150144935d-14,
     4      0.1410957576543844d-13,-.2309408614409426d-14,
     5      0.1068204511881827d-13,0.1662289586668434d-14,
     6      -.1293180323990672d+00,0.3437875131256952d-01,
     7      -.5596760756155905d-02,0.6653999298161112d-03,
     8      -.6254156831037718d-04,0.4867728901173479d-05/
         data arr1045/
     1      -.3235172196403831d-06,0.1876803317482894d-07,
     2      -.9661966226800609d-09,0.4471373895096733d-10,
     3      -.1883122533907919d-11,0.7128030291260497d-13,
     4      -.1728023896320358d-13,-.4965291850506989d-14,
     5      -.4517646847638176d-13,-.1791534243093927d-13,
     6      -.8471171648627842d-13,-.3270871757260093d-13,
     7      -.1137019738805712d-12,-.5870705409420736d-13,
     8      -.9101506490944351d-13,-.5000253868617805d-13/
         data arr1046/
     1      -.4256995582457827d-13,-.4664951768999140d-13,
     2      -.1935099028859703d+00,0.9251237096720738d-01,
     3      -.2708395364656266d-01,0.5790601468918401d-02,
     4      -.9787579421637004d-03,0.1369930455807775d-03,
     5      -.1637325953820362d-04,0.1708134699936248d-05,
     6      -.1581373156259104d-06,0.1316054748504896d-07,
     7      -.9948135573904924d-09,0.6887816129197045d-10,
     8      -.4410130952722733d-11,0.2375558258715552d-12/
         data arr1047/
     1      -.4461773972308602d-13,-.5166856135797609d-13,
     2      -.6069543632817956d-13,-.9163412651680574d-13,
     3      -.7866938309253491d-13,-.1209223205296417d-12,
     4      -.6296217206600118d-13,-.1002431152034049d-12,
     5      -.2635070245947054d-13,-.5991976031010019d-13,
     6      -.2387065795515948d+00,0.1765732300370015d+00,
     7      -.7998360364223529d-01,0.2645918342017741d-01,
     8      -.6919774073593286d-02,0.1498576756488320d-02/
         data arr1048/
     1      -.2771274034952063d-03,0.4473323404811809d-04,
     2      -.6407762443501965d-05,0.8251063002807062d-06,
     3      -.9650291106160195d-07,0.1033934839379566d-07,
     4      -.1022037551390019d-08,0.9375111102804384d-10,
     5      -.8070548882610854d-11,0.6309145011421264d-12,
     6      -.1202483167580498d-12,-.3271956582795888d-13,
     7      -.9234540155875217d-13,-.5262937234997746d-13,
     8      -.6421555082066775d-13,-.6643225830481564d-13/
         data arr1049/
     1      -.3072912234445948d-13,-.4956777165624767d-13,
     2      -.2588507217363193d+00,0.2701892142501410d+00,
     3      -.1727039498510789d+00,0.8061871957477902d-01,
     4      -.2975154549297169d-01,0.9091902380405548d-02,
     5      -.2372539222344703d-02,0.5404087615637100d-03,
     6      -.1092336997495358d-03,0.1984807084922493d-04,
     7      -.3275721234947946d-05,0.4952427922542846d-06,
     8      -.6907851031019828d-07,0.8943413237650200d-08/
         data arr1050/
     1      -.1080390980201659d-08,0.1223117317699173d-09,
     2      -.1308970574254501d-10,0.1259664070880245d-11,
     3      -.1610596037604861d-12,-.6783074908776453d-13,
     4      -.2193725774180976d-14,-.1220006803982526d-12,
     5      0.1806931842455776d-13,-.7301594491888528d-13,
     6      -.2556111490409275d+00,0.3539117786392026d+00,
     7      -.3000722776772322d+00,0.1858044438643877d+00,
     8      -.9095494747758538d-01,0.3686957714576473d-01/
         data arr1051/
     1      -.1276213662266496d-01,0.3855928447776801d-02,
     2      -.1033855456841924d-02,0.2491828097438156d-03,
     3      -.5455107425022077d-04,0.1093984425206252d-04,
     4      -.2024101876815544d-05,0.3476088356985670d-06,
     5      -.5569851168057596d-07,0.8364662692828191d-08,
     6      -.1182135126253726d-08,0.1576302426684295d-09,
     7      -.1990917217262534d-10,0.2263311532209821d-11,
     8      -.2131729180563010d-12,-.1853592920361582d-12/
         data arr1052/
     1      0.9980935926407987d-13,-.1335345222120083d-12,
     2      -.2349275636345999d+00,0.4128188441064150d+00,
     3      -.4442226372194431d+00,0.3490930660487609d+00,
     4      -.2168811302409475d+00,0.1115768025587396d+00,
     5      -.4901617965639301d-01,0.1879556349443809d-01,
     6      -.6395824275517762d-02,0.1956433505338476d-02,
     7      -.5435764524226454d-03,0.1383498785004493d-03,
     8      -.3248705250046273d-04,0.7080748329631611d-05/
         data arr1053/
     1      -.1439930131051893d-05,0.2744463473059516d-06,
     2      -.4922096612043769d-07,0.8335343276642206d-08,
     3      -.1337041223568802d-08,0.2035318490181931d-09,
     4      -.2939081478271576d-10,0.3656451467423443d-11,
     5      -.2893258898816907d-12,-.1577458095855630d-12,
     6      -.2039228137741281d+00,0.4400138391065694d+00,
     7      -.5814099913520702d+00,0.5610454045568393d+00,
     8      -.4280096264288689d+00,0.2703837972911335d+00/
         data arr1054/
     1      -.1458549566823915d+00,0.6867711867205835d-01,
     2      -.2869645309940701d-01,0.1077883371082775d-01,
     3      -.3677412070490795d-02,0.1149305345716077d-02,
     4      -.3313919348327646d-03,0.8869227098211703d-04,
     5      -.2214740885012705d-04,0.5183391227747162d-05,
     6      -.1141507664016006d-05,0.2373769314255128d-06,
     7      -.4675547561483393d-07,0.8748247396060552d-08,
     8      -.1556276070412275d-08,0.2643057629550039d-09/
         data arr1055/
     1      -.4088918285011516d-10,0.6321284692385873d-11,
     2      -.1689229043927329d+00,0.4362947468578279d+00,
     3      -.6900603305730639d+00,0.7970645679140748d+00,
     4      -.7278467620862334d+00,0.5503741193739980d+00,
     5      -.3553771141229408d+00,0.2002955280418846d+00,
     6      -.1001793780068265d+00,0.4504149583123630d-01,
     7      -.1839391831103875d-01,0.6881106920333110d-02,
     8      -.2374956916968705d-02,0.7608350318981079d-03/
         data arr1056/
     1      -.2274146956291580d-03,0.6370895957777810d-04,
     2      -.1679403210660833d-04,0.4180285194431606d-05,
     3      -.9855210336102664d-06,0.2207170177657394d-06,
     4      -.4694888187629138d-07,0.9557052651218770d-08,
     5      -.1762628005827983d-08,0.3287370881966453d-09,
     6      -.1345695400798940d+00,0.4076867551175187d+00,
     7      -.7563487099446834d+00,0.1024747582811782d+01,
     8      -.1097619321419915d+01,0.9735498243674604d+00/
         data arr1057/
     1      -.7373573704096203d+00,0.4874703582552668d+00,
     2      -.2859852804161483d+00,0.1508226422873536d+00,
     3      -.7224642862538520d-01,0.3170215801225128d-01,
     4      -.1283437249113577d-01,0.4822783839119367d-02,
     5      -.1690884931219748d-02,0.5556284294067965d-03,
     6      -.1718002499863499d-03,0.5016070716379198d-04,
     7      -.1386914410857886d-04,0.3643449045946483d-05,
     8      -.9070618271299437d-06,0.2166262807693636d-06/
         data arr1058/
     1      -.4599274582046478d-07,0.1006574047441970d-07,
     2      -.1037042345263857d+00,0.3625128740243957d+00,
     3      -.7760076676528092d+00,0.1213131709098128d+01,
     4      -.1499304709935510d+01,0.1534417188135214d+01,
     5      -.1340943278192756d+01,0.1022887106764964d+01,
     6      -.6924210824234235d+00,0.4213473402827474d+00,
     7      -.2328826872706323d+00,0.1179116609325452d+00,
     8      -.5507945664035541d-01,0.2388140763053674d-01/
         data arr1059/
     1      -.9661013417435974d-02,0.3663028560750542d-02,
     2      -.1306822734694995d-02,0.4402557571501018d-03,
     3      -.1404120925673098d-03,0.4256241016595448d-04,
     4      -.1218362619470814d-04,0.3358019511221812d-05,
     5      -.8040072947796347d-06,0.2030599270362587d-06,
     6      -.7766661234802506d-01,0.3090393214013492d+00,
     7      -.7530238894910197d+00,0.1339994855606386d+01,
     8      -.1885113556153751d+01,0.2196056455500250d+01/
         data arr1060/
     1      -.2184554522102213d+01,0.1896848387945381d+01,
     2      -.1461596964749879d+01,0.1012395115994279d+01,
     3      -.6369413081469602d+00,0.3670890286577531d+00,
     4      -.1951895599208764d+00,0.9633394036270240d-01,
     5      -.4436009825601619d-01,0.1914533231470942d-01,
     6      -.7774382474645586d-02,0.2981331809301021d-02,
     7      -.1081684373061291d-02,0.3732485897736532d-03,
     8      -.1209837160785868d-03,0.3796778578305654d-04/
         data arr1061/
     1      -.1007645899409482d-04,0.2897467136766738d-05,
     2      -.5673410894343008d-01,0.2540623852333811d+00,
     3      -.6967101504011405d+00,0.1395286102172401d+01,
     4      -.2209095077687235d+01,0.2896257329262844d+01,
     5      -.3242450000796309d+01,0.3168544223151335d+01,
     6      -.2747714076406368d+01,0.2141956767330170d+01,
     7      -.1516620045999665d+01,0.9837065020981777d+00,
     8      -.5886632519663628d+00,0.3269689679456848d+00/
         data arr1062/
     1      -.1694456577437686d+00,0.8230357098661312d-01,
     2      -.3760783444361711d-01,0.1623110325301249d-01,
     3      -.6620324092024418d-02,0.2571210217129430d-02,
     4      -.9309893789822569d-03,0.3289586332774555d-03,
     5      -.9533763682050709d-04,0.3086281222551210d-04,
     6      -.4054109303943729d-01,0.2023605742799706d+00,
     7      -.6185459783665360d+00,0.1380757575768254d+01,
     8      -.2436704653798044d+01,0.3560901385250928d+01/
         data arr1063/
     1      -.4443553454945744d+01,0.4840065160997763d+01,
     2      -.4678399306797364d+01,0.4065095597268371d+01,
     3      -.3208270777781834d+01,0.2319498582389569d+01,
     4      -.1547134108127511d+01,0.9578605506881688d+00,
     5      -.5532792238327729d+00,0.2995503507025112d+00,
     6      -.1525229409997348d+00,0.7337664471518948d-01,
     7      -.3329751509458155d-01,0.1441723384076793d-01,
     8      -.5759708463111416d-02,0.2269894348717161d-02/
         data arr1064/
     1      -.7090516880621507d-03,0.2559740726158638d-03,
     2      -.2840607626036436d-01,0.1567457600156743d+00,
     3      -.5296585622678417d+00,0.1307060068484331d+01,
     4      -.2549970293594629d+01,0.4119516758814833d+01,
     5      -.5682911079719010d+01,0.6842987586349000d+01,
     6      -.7312163844418841d+01,0.7023821790429614d+01,
     7      -.6128120017374878d+01,0.4897839748239847d+01,
     8      -.3611494333043724d+01,0.2471818537557994d+01/
         data arr1065/
     1      -.1578240574630511d+01,0.9446263513315427d+00,
     2      -.5314027328576245d+00,0.2826431450541110d+00,
     3      -.1413637188192329d+00,0.6768491151723599d-01,
     4      -.2949442476111976d-01,0.1286118485166970d-01,
     5      -.4280482966813427d-02,0.1709501861924256d-02,
     6      -.1955318701514001d-01,0.1184308907352612d+00,
     7      -.4392665512107467d+00,0.1189845483886039d+01,
     8      -.2547962948850877d+01,0.4518217453580883d+01/
         data arr1066/
     1      -.6841553253682982d+01,0.9042581727402183d+01,
     2      -.1060609271375696d+02,0.1118267865318659d+02,
     3      -.1070928784667658d+02,0.9395094826824895d+01,
     4      -.7603807050018046d+01,0.5712510581606633d+01,
     5      -.4002737403547997d+01,0.2629805582917796d+01,
     6      -.1622087036794472d+01,0.9471615664963248d+00,
     7      -.5175824013590417d+00,0.2721472436591055d+00,
     8      -.1279635050405411d+00,0.6132097477782805d-01/
         data arr1067/
     1      -.2152396974261588d-01,0.9444671326437670d-02,
     2      -.1324274885922669d-01,0.8749834139603355d-01,
     3      -.3540279559040745d+00,0.1046102452346661d+01,
     4      -.2443720061265029d+01,0.4727152949351570d+01,
     5      -.7808399041361725d+01,0.1125832604386020d+02,
     6      -.1440491940124230d+02,0.1656820488084919d+02,
     7      -.1730847097220267d+02,0.1656436386141216d+02,
     8      -.1462312850083590d+02,0.1198448145886733d+02/
         data arr1068/
     1      -.9156626990787990d+01,0.6563153752314781d+01,
     2      -.4407595971844939d+01,0.2808385473598489d+01,
     3      -.1662814405558069d+01,0.9544701727571705d+00,
     4      -.4793007189502573d+00,0.2509556571458207d+00,
     5      -.9205891004490638d-01,0.4412493147054986d-01,
     6      -.8835276931395136d-02,0.6333774974797379d-01,
     7      -.2780502304253384d+00,0.8914168992838404d+00,
     8      -.2259338339702404d+01,0.4741877450153779d+01/
         data arr1069/
     1      -.8498375209044287d+01,0.1329438908522365d+02,
     2      -.1845550754975008d+02,0.2303094742195054d+02,
     3      -.2610360472909553d+02,0.2710450167686376d+02,
     4      -.2595601661829176d+02,0.2308125047756186d+02,
     5      -.1911729743980349d+02,0.1486957097195403d+02,
     6      -.1079988943815419d+02,0.7470000303671266d+01,
     7      -.4753204624734928d+01,0.2963486618692794d+01,
     8      -.1573733677878197d+01,0.8958779931009957d+00/
         data arr1070/
     1      -.3406847718030029d+00,0.1774879436137082d+00,
     2      -.5812390890061804d-02,0.4499291905123885d-01,
     3      -.2132861625616450d+00,0.7383614031020799d+00,
     4      -.2020821039407394d+01,0.4579793916044247d+01,
     5      -.8863176093544087d+01,0.1497168988808168d+02,
     6      -.2244283076010667d+02,0.3024228522232065d+02,
     7      -.3700958528674796d+02,0.4149695454488618d+02,
     8      -.4289116803105391d+02,0.4118962950215293d+02/
         data arr1071/
     1      -.3678066878105474d+02,0.3090184276609087d+02,
     2      -.2411332166641151d+02,0.1802522615224946d+02,
     3      -.1222581808689340d+02,0.8243959635634589d+01,
     4      -.4586038091663823d+01,0.2826717677965748d+01,
     5      -.1106287779926620d+01,0.6238241067361150d+00,
     6      -.3773170253554073d-02,0.3140434930989295d-01,
     7      -.1600863373363751d+00,0.5958924511163368d+00,
     8      -.1753771083107465d+01,0.4273684569785243d+01/
         data arr1072/
     1      -.8893804806288225d+01,0.1615409292270997d+02,
     2      -.2603784259274158d+02,0.3772798440983036d+02,
     3      -.4963516011172290d+02,0.5984638454730121d+02,
     4      -.6645250381093066d+02,0.6863632203056645d+02,
     5      -.6572098757253092d+02,0.5940868648280303d+02,
     6      -.4946736053950338d+02,0.3981562354803908d+02,
     7      -.2854957193691618d+02,0.2074702395183260d+02,
     8      -.1198079992117030d+02,0.7968251451446339d+01/
         data arr1073/
     1      -.3188535948084716d+01,0.1939326263420334d+01,
     2      -.2418798249171182d-02,0.2155932608369683d-01,
     3      -.1177541364065301d+00,0.4694825530560109d+00,
     4      -.1480458579269263d+01,0.3864393945229697d+01,
     5      -.8616237733199318d+01,0.1676417305100247d+02,
     6      -.2894566774621500d+02,0.4493021858904972d+02,
     7      -.6329208721543258d+02,0.8176228813640633d+02,
     8      -.9708596028365744d+02,0.1074729855654603d+03/
         data arr1074/
     1      -.1097351952866547d+03,0.1063760774043207d+03,
     2      -.9384049788355266d+02,0.8108279439757420d+02,
     3      -.6095207988115781d+02,0.4759910303111815d+02,
     4      -.2828582824630372d+02,0.2024300450337496d+02,
     5      -.8233213510768177d+01,0.5386103899684016d+01,
     6      -.1533500838440815d-02,0.1457149570540591d-01,
     7      -.8502034294311739d-01,0.3616910107788978d+00,
     8      -.1218335891193238d+01,0.3394279803912141d+01/
         data arr1075/
     1      -.8082784423425991d+01,0.1678742316921485d+02,
     2      -.3094416656695665d+02,0.5128305078349891d+02,
     3      -.7705248685155908d+02,0.1063070745146543d+03,
     4      -.1343448177514442d+03,0.1589269198835048d+03,
     5      -.1719984009401241d+03,0.1783346291941548d+03,
     6      -.1653907041055846d+03,0.1530568626465883d+03,
     7      -.1196015293194670d+03,0.1001507180211258d+03,
     8      -.6073258535469046d+02,0.4667046581679691d+02/
         data arr1076/
     1      -.1918832620443415d+02,0.1347286171447609d+02,
     2      -.9662167090786122d-03,0.9712695254568870d-02,
     3      -.6040699867215447d-01,0.2729263731313757d+00,
     4      -.9797839684362426d+00,0.2902401585495350d+01,
     5      -.7361956326770925d+01,0.1626665831269757d+02,
     6      -.3190689107216090d+02,0.5628464788553327d+02,
     7      -.8983797452306368d+02,0.1320162364337572d+03,
     8      -.1766173424209315d+03,0.2227673266944029d+03/
         data arr1077/
     1      -.2538239547970398d+03,0.2809508351623288d+03,
     2      -.2716505287019223d+03,0.2688308808498162d+03,
     3      -.2164947455056260d+03,0.1941044144806516d+03,
     4      -.1191460115292822d+03,0.9817537250881074d+02,
     5      -.4059641647642493d+02,0.3054961668658483d+02,
     6      -.6149955232732274d-03,0.6415872437844371d-02,
     7      -.4247982205196719d-01,0.2022219038116492d+00,
     8      -.7727130510843196d+00,0.2421748959273499d+01/
         data arr1078/
     1      -.6529059144558903d+01,0.1528996557086781d+02,
     2      -.3180911273721906d+02,0.5955277939718946d+02,
     3      -.1005205491443987d+03,0.1569794175918850d+03,
     4      -.2209427894825631d+03,0.2966602640207624d+03,
     5      -.3531460972965323d+03,0.4168353168267436d+03,
     6      -.4164085301652768d+03,0.4403510897294331d+03,
     7      -.3622926152491010d+03,0.3475587874184847d+03,
     8      -.2142416960192738d+03,0.1891729763879907d+03/
         data arr1079/
     1      -.7829149648013744d+02,0.6310320942059981d+02,
     2      -.4143993406295551d-03,0.4260191641020324d-02,
     3      -.2998619004921091d-01,0.1478394635105218d+00,
     4      -.6013441094420088d+00,0.1977591051891031d+01,
     5      -.5657185807917315d+01,0.1397312707407238d+02,
     6      -.3071621905439016d+02,0.6085559204002065d+02,
     7      -.1080282630911576d+03,0.1789952203352876d+03,
     8      -.2630400969049488d+03,0.3757531420420894d+03/
         data arr1080/
     1      -.4632203719991587d+03,0.5830521928190531d+03,
     2      -.5959152050632025d+03,0.6736615048816668d+03,
     3      -.5612142611730023d+03,0.5763179890686208d+03,
     4      -.3539278192198623d+03,0.3350467380386318d+03,
     5      -.1381061642559628d+03,0.1192813356116073d+03,
     6      0.1375810206313941d-03,-.2280048111649662d-05,
     7      0.2439067810652207d-07,-.1972353322001546d-09,
     8      0.1292051744031053d-11,-.7138580520996590d-14/
         data arr1081/
     1      0.3676808071000672d-16,0.4706982764601664d-17,
     2      -.1552263756235139d-17,0.1900989778050669d-16,
     3      0.8118302737668538d-18,0.4729728166146749d-16,
     4      0.6746632608168387d-17,0.7324241271913528d-16,
     5      0.1179110649044533d-16,0.6178008431355458d-16,
     6      0.2118953118855616d-16,-.2382345351590210d-16,
     7      0.2403524652872207d-16,-.7725918100353027d-16,
     8      0.1653709766089942d-16,-.1079238159684878d-15/
         data arr1082/
     1      0.1002340331375252d-16,0.3424694606656618d-02,
     2      -.2943629098898525d-03,0.1633197491511232d-04,
     3      -.6849759078381357d-06,0.2327268797451815d-07,
     4      -.6667861118649489d-09,0.1654470091167042d-10,
     5      -.3622343049888482d-12,0.7062463795557478d-14,
     6      0.4022256192589526d-15,-.6020650760033964d-16,
     7      0.1329254136458022d-14,-.8287867641410705d-16,
     8      0.2018933790957463d-14,-.2573067290010883d-15/
         data arr1083/
     1      0.1674925952439566d-14,-.2672951398316629d-15,
     2      -.7625423257471948d-15,-.2349933870140681d-15,
     3      -.2241577843248057d-14,-.1276642939921641d-15,
     4      -.3074613484850528d-14,-.9324328314530766d-18,
     5      0.1718937565628470d-01,-.3539702301699914d-02,
     6      0.4705088025742186d-03,-.4727698181528095d-04,
     7      0.3848277589819783d-05,-.2641507040700486d-06,
     8      0.1570246355127618d-07,-.8239741549794618d-09/
         data arr1084/
     1      0.3872296805321514d-10,-.1645059587318079d-11,
     2      0.6423479799892041d-13,0.6266174317216106d-14,
     3      0.6486680818430843d-15,0.1335250782151991d-13,
     4      0.1810349229448715d-14,0.1142435916200524d-13,
     5      0.4580992117254457d-14,-.3659441294374354d-14,
     6      0.8171295622711556d-14,-.1339841590146618d-13,
     7      0.7482416539737322d-14,-.1923070790253879d-13,
     8      0.5475113049624458d-14,0.4625618548360372d-01/
         data arr1085/
     1      -.1712939631311233d-01,0.4094573565821022d-02,
     2      -.7398714596272165d-03,0.1083025119095328d-03,
     3      -.1336871043159500d-04,0.1429128023541749d-05,
     4      -.1348599537379065d-06,0.1139736908929798d-07,
     5      -.8724959691158128d-09,0.6105892418440639d-10,
     6      -.3907615803379653d-11,0.2332474108162292d-12,
     7      0.3008479510121146d-13,-.1621874130064509d-14,
     8      0.3568723559042470d-13,0.3658591493570643d-14/
         data arr1086/
     1      -.1643130667075285d-13,0.7572389593695813d-14,
     2      -.4754440847133428d-13,0.9523058759444735d-14,
     3      -.6659664964155155d-13,0.5161462063891626d-14,
     4      0.8828661501850107d-01,-.5058607259552035d-01,
     5      0.1870946802106611d-01,-.5230857522137543d-02,
     6      0.1184728949773294d-02,-.2262735774328693d-03,
     7      0.3742650878294580d-04,-.5464558167331207d-05,
     8      0.7145630172735072d-06,-.8463861814530780d-07/
         data arr1087/
     1      0.9164855015618617d-08,-.9140498832458495d-09,
     2      0.8451677575437201d-10,-.7165589551946046d-11,
     3      0.5782151746968456d-12,0.6749520311540243d-13,
     4      -.4819358489553346d-14,-.1218134464522591d-14,
     5      -.1428768714155353d-13,-.8282403347533485d-13,
     6      -.1103759326792571d-13,-.1390681966409173d-12,
     7      -.1307050827406184d-13,0.1350946071250715d+00,
     8      -.1092275684873802d+00,0.5700604330190279d-01/
         data arr1088/
     1      -.2249005442692298d-01,0.7187779946500918d-02,
     2      -.1937170163153915d-02,0.4521384087778289d-03,
     3      -.9315481213808968d-04,0.1718893357095150d-04,
     4      -.2872997513328197d-05,0.4389858091870197d-06,
     5      -.6178553109955837d-07,0.8061483688831929d-08,
     6      -.9801642843853864d-09,0.1116206160676751d-09,
     7      -.1174767512816597d-10,0.1187085632295841d-11,
     8      -.1308203177777191d-12,-.2893500223789637d-13/
         data arr1089/
     1      -.1731285998628941d-12,-.2317852646486807d-13,
     2      -.2791947743082991d-12,-.4879178118869438d-13,
     3      0.1769558893196043d+00,-.1897823720269080d+00,
     4      0.1313835822311029d+00,-.6875547758189748d-01,
     5      0.2914796003698740d-01,-.1042024091772007d-01,
     6      0.3226101197400471d-02,-.8816748960089896d-03,
     7      0.2157986434219206d-03,-.4784445700887279d-04,
     8      0.9697135476285627d-05,-.1810411432640244d-05/
         data arr1090/
     1      0.3133303782621680d-06,-.5054507327888684d-07,
     2      0.7635813964951778d-08,-.1084322448975845d-08,
     3      0.1454486056143326d-09,-.1848232021887239d-10,
     4      0.2223429363559168d-11,-.5546697300510556d-12,
     5      0.7077159231761078d-13,-.5129372189131489d-12,
     6      -.1065752586813565d-12,0.2064094220532135d+00,
     7      -.2809510643640200d+00,0.2468460742682801d+00,
     8      -.1639467241943388d+00,0.8820920753115145d-01/
         data arr1091/
     1      -.4002154309955037d-01,0.1572549665191516d-01,
     2      -.5454377268872615d-02,0.1694321116429509d-02,
     3      -.4767480864851343d-03,0.1226340600298934d-03,
     4      -.2905730251920130d-04,0.6382500260444105d-05,
     5      -.1306714369552054d-05,0.2505339100467960d-06,
     6      -.4516731224438291d-07,0.7685018686777296d-08,
     7      -.1237931314306632d-08,0.1892923914149073d-09,
     8      -.2798121227721787d-10,0.3933637988365497d-11/
         data arr1092/
     1      -.1330283576109114d-11,-.2545491181932865d-12,
     2      0.2200069195532957d+00,-.3677159654102603d+00,
     3      0.3967190101156857d+00,-.3235448657921506d+00,
     4      0.2137571604613427d+00,-.1190900734424835d+00,
     5      0.5745939993032551d-01,-.2447241743059781d-01,
     6      0.9334743816718939d-02,-.3225303746339782d-02,
     7      0.1018750304140249d-02,-.2964059563058172d-03,
     8      0.7994613251413829d-04,-.2009844431754128d-04/
         data arr1093/
     1      0.4731766520257565d-05,-.1047517377249545d-05,
     2      0.2188508426061452d-06,-.4328732636013952d-07,
     3      0.8129706985607484d-08,-.1452155997180960d-08,
     4      0.2480371723577500d-09,-.4037361476926987d-10,
     5      0.5387426853101836d-11,0.2181473734289304d+00,
     6      -.4364324735079108d+00,0.5636097610155559d+00,
     7      -.5502004357268445d+00,0.4351089456078439d+00,
     8      -.2901641986212654d+00,0.1675792618059634d+00/
         data arr1094/
     1      -.8543326062032026d-01,0.3900707961421691d-01,
     2      -.1613253356007632d-01,0.6099449371399951d-02,
     3      -.2124226040524691d-02,0.6858074294166454d-03,
     4      -.2063754667327636d-03,0.5815805567557454d-04,
     5      -.1541125045755074d-04,0.3854032938208768d-05,
     6      -.9124072318962108d-06,0.2051168100722237d-06,
     7      -.4377429940563671d-07,0.8942220849591283d-08,
     8      -.1654010847201456d-08,0.3085725041641636d-09/
         data arr1095/
     1      0.2038433775587822d+00,-.4783569257510331d+00,
     2      0.7246059648107093d+00,-.8297222167704950d+00,
     3      0.7696587151645061d+00,-.6020497718606771d+00,
     4      0.4078469628718691d+00,-.2438890666037837d+00,
     5      0.1306162396856018d+00,-.6336430957428286d-01,
     6      0.2810095962544039d-01,-.1147941167556770d-01,
     7      0.4347198598580811d-02,-.1534452929241148d-02,
     8      0.5072170308359914d-03,-.1576544645409926d-03/
         data arr1096/
     1      0.4624588507996211d-04,-.1284001628427898d-04,
     2      0.3385944213318490d-05,-.8455664552644232d-06,
     3      0.2026591335128891d-06,-.4302376823760704d-07,
     4      0.9489033587204744d-08,0.1812564370122199d+00,
     5      -.4907903423074012d+00,0.8578136579755918d+00,
     6      -.1133367829140655d+01,0.1213063298853720d+01,
     7      -.1094875601848717d+01,0.8558087538811546d+00,
     8      -.5904986830820887d+00,0.3648975004762642d+00/
         data arr1097/
     1      -.2042516280336420d+00,0.1045175164401819d+00,
     2      -.4926456236033237d-01,0.2152640977554736d-01,
     3      -.8767223606765009d-02,0.3343872103872039d-02,
     4      -.1199216934415306d-02,0.4058956963901624d-03,
     5      -.1299889322996596d-03,0.3955449195979302d-04,
     6      -.1135485900696650d-04,0.3141684576239354d-05,
     7      -.7512313239904593d-06,0.1916267251341093d-06,
     8      0.1545196607005651d+00,-.4762541246593774d+00/
         data arr1098/
     1      0.9475194491526217d+00,-.1425011903602174d+01,
     2      0.1736135067408188d+01,-.1783681297922392d+01,
     3      0.1587017222483745d+01,-.1246454078196981d+01,
     4      0.8767598886507256d+00,-.5586344757076960d+00,
     5      0.3253896446591208d+00,-.1745828282492916d+00,
     6      0.8683423745991979d-01,-.4025608094721804d-01,
     7      0.1747721403703005d-01,-.7134167434805311d-02,
     8      0.2748651088095506d-02,-.1001324533662136d-02/
         data arr1099/
     1      0.3468745721808761d-03,-.1127132278218273d-03,
     2      0.3552561104844254d-04,-.9403774315693112d-05,
     3      0.2737116077504431d-05,0.1270311926147346d+00,
     4      -.4406381888118818d+00,0.9866162645180511d+00,
     5      -.1669918913408401d+01,0.2289692462388481d+01,
     6      -.2647449336759828d+01,0.2650994292385108d+01,
     7      -.2343258420355816d+01,0.1854988967963842d+01,
     8      -.1330163695894367d+01,0.8719625993283111d+00/
         data arr1100/
     1      -.5265161589703946d+00,0.2947258051564980d+00,
     2      -.1537687989641568d+00,0.7513249317827875d-01,
     3      -.3451016977458492d-01,0.1496432401195509d-01,
     4      -.6127779489741540d-02,0.2389573819441229d-02,
     5      -.8668953761965036d-03,0.3078482218781542d-03,
     6      -.8885083152082399d-04,0.2918926098216881d-04,
     7      0.1011802871192043d+00,-.3912028255228325d+00,
     8      0.9763430447563000d+00,-.1841975577680237d+01/
         data arr1101/
     1      0.2815139722883146d+01,-.3628146177666011d+01,
     2      0.4049489031109040d+01,-.3989752172081027d+01,
     3      0.3520475989875714d+01,-.2813838888628908d+01,
     4      0.2056015548761938d+01,-.1383796392081136d+01,
     5      0.8634034198582881d+00,-.5020868539527883d+00,
     6      0.2734503483854683d+00,-.1399540023856177d+00,
     7      0.6764978190828555d-01,-.3081406534722766d-01,
     8      0.1339922269051652d-01,-.5359317423911653d-02/
         data arr1102/
     1      0.2124699117979023d-02,-.6597657080227228d-03,
     2      0.2424250291100799d-03,0.7837287983594614d-01,
     3      -.3349854854584111d+00,0.9242310358209689d+00,
     4      -.1927596333747726d+01,0.3256763935398094d+01,
     5      -.4640077275480021d+01,0.5725254052047284d+01,
     6      -.6235833064741889d+01,0.6082807554912312d+01,
     7      -.5374711390991872d+01,0.4341469295835243d+01,
     8      -.3230200679392091d+01,0.2228063714421756d+01/
         data arr1103/
     1      -.1432186391362567d+01,0.8623181511392041d+00,
     2      -.4875695221911065d+00,0.2605829420561110d+00,
     3      -.1307777565777078d+00,0.6290913255699748d-01,
     4      -.2741758824630007d-01,0.1204211717992243d-01,
     5      -.3975814554257270d-02,0.1621554245729767d-02,
     6      0.5921544420855854d-01,-.2778165459615661d+00,
     7      0.8413477965259150d+00,-.1926078806538550d+01,
     8      0.3571964401408640d+01,-.5586103662709255d+01/
         data arr1104/
     1      0.7565565831838373d+01,-.9044898783151666d+01,
     2      0.9684480096268526d+01,-.9392633533594259d+01,
     3      0.8327850520121425d+01,-.6800941118146892d+01,
     4      0.5149164479210543d+01,-.3632158341237138d+01,
     5      0.2400647529976008d+01,-.1488046396696892d+01,
     6      0.8732320022725992d+00,-.4785815041968515d+00,
     7      0.2529667086967153d+00,-.1188031346349694d+00,
     8      0.5743828575076404d-01,-.1995167892238555d-01/
         data arr1105/
     1      0.8974723662032003d-02,0.4374916415956818d-01,
     2      -.2239068645848834d+00,0.7397060602300184d+00,
     3      -.1847278002958721d+01,0.3737141816102059d+01,
     4      -.6375525001662673d+01,0.9419386626628448d+01,
     5      -.1228451779229085d+02,0.1434846537773369d+02,
     6      -.1518036127691177d+02,0.1468267727563383d+02,
     7      -.1307875272616809d+02,0.1080253582405621d+02,
     8      -.8308130906651385d+01,0.5991167839592171d+01/
         data arr1106/
     1      -.4042207859045527d+01,0.2589159166355424d+01,
     2      -.1536359602215489d+01,0.8873148886717188d+00,
     3      -.4442747270197061d+00,0.2351839369060755d+00,
     4      -.8514203392240562d-01,0.4201341798735658d-01,
     5      0.3166884339238887d-01,-.1758540741974900d+00,
     6      0.6303265583563469d+00,-.1707896001862564d+01,
     7      0.3748779762687585d+01,-.6938866995003989d+01,
     8      0.1112286097221580d+02,-.1573873726767620d+02/
         data arr1107/
     1      0.1994528426806289d+02,-.2289361249336597d+02,
     2      0.2402527329740163d+02,-.2321323938469883d+02,
     3      0.2080453172335907d+02,-.1734260502319600d+02,
     4      0.1357330051606110d+02,-.9899739412408818d+01,
     5      0.6886783384940014d+01,-.4386972273495916d+01,
     6      0.2755487513967670d+01,-.1455797751440929d+01,
     7      0.8401038149473266d+00,-.3142996059271387d+00,
     8      0.1693735672005268d+00,0.2249632800167191d-01/
         data arr1108/
     1      -.1348927234698721d+00,0.5220987739554018d+00,
     2      -.1527584462319429d+01,0.3620630178826781d+01,
     3      -.7236646648949302d+01,0.1252611793908297d+02,
     4      -.1913864107174304d+02,0.2619016203371539d+02,
     5      -.3245660001784002d+02,0.3678186140351318d+02,
     6      -.3835327704367386d+02,0.3712520474951265d+02,
     7      -.3335461066125999d+02,0.2820645488510344d+02,
     8      -.2208603272678595d+02,0.1661750638434936d+02/
         data arr1109/
     1      -.1126678933893461d+02,0.7667286738415566d+01,
     2      -.4231854546049327d+01,0.2652789217670085d+01,
     3      -.1017787466896430d+01,0.5967887572708266d+00,
     4      0.1570169130000349d-01,-.1012430635644509d+00,
     5      0.4213537390976934d+00,-.1325682722267929d+01,
     6      0.3378589370272662d+01,-.7261395219744039d+01,
     7      0.1351512644236189d+02,-.2220285153924839d+02,
     8      0.3267182081869102d+02,-.4352282221476409d+02/
         data arr1110/
     1      0.5304350224677047d+02,-.5940372433239150d+02,
     2      0.6185824865299135d+02,-.5956174551346870d+02,
     3      0.5422155099801435d+02,-.4525273481301171d+02,
     4      0.3670461371853749d+02,-.2625616255360902d+02,
     5      0.1930227917758449d+02,-.1102218072130514d+02,
     6      0.7484968008348698d+01,-.2924517566930300d+01,
     7      0.1860398022719554d+01,0.1077808246307732d-01,
     8      -.7446068617889255d-01,0.3319549937159922d+00/
         data arr1111/
     1      -.1118987183834067d+01,0.3054890216415060d+01,
     2      -.7034002613933820d+01,0.1402473486247472d+02,
     3      -.2467791703660629d+02,0.3890553346754962d+02,
     4      -.5548003585327643d+02,0.7245921439230058d+02,
     5      -.8673541432067361d+02,0.9684292190237248d+02,
     6      -.9934366287498125d+02,0.9707143683909796d+02,
     7      -.8568674676971834d+02,0.7474217770542779d+02,
     8      -.5590330575713354d+02,0.4430376944861680d+02/
         data arr1112/
     1      -.2592786225299796d+02,0.1903645941153961d+02,
     2      -.7526104954966529d+01,0.5182590044763430d+01,
     3      0.7281104561596239d-02,-.5373407705478378d-01,
     4      0.2556969210217974d+00,-.9206020470784756d+00,
     5      0.2682874792165840d+01,-.6596440522128622d+01,
     6      0.1404186962294096d+02,-.2636985372781554d+02,
     7      0.4439708800436572d+02,-.6749482496135383d+02,
     8      0.9418577948049591d+02,-.1198854588617119d+03/
         data arr1113/
     1      0.1431601793371860d+03,-.1554335940104147d+03,
     2      0.1626881218998062d+03,-.1506135778716575d+03,
     3      0.1410716043957974d+03,-.1093053703862101d+03,
     4      0.9326768794595597d+02,-.5542624142888980d+02,
     5      0.4394624878933062d+02,-.1747523726827414d+02,
     6      0.1300693946003044d+02,0.4843994200112070d-02,
     7      -.3811051892143976d-01,0.1928341515457679d+00,
     8      -.7397033433920023d+00,0.2293097773638523d+01/
         data arr1114/
     1      -.6003125809568429d+01,0.1360025654348646d+02,
     2      -.2716155747880353d+02,0.4870272514200683d+02,
     3      -.7858172161800911d+02,0.1168978507512730d+03,
     4      -.1572853751199432d+03,0.2005450459613702d+03,
     5      -.2287291280606220d+03,0.2561761359915397d+03,
     6      -.2464320486768139d+03,0.2477318296622323d+03,
     7      -.1969514684939890d+03,0.1808815946910264d+03,
     8      -.1081646892318525d+03,0.9258479800676869d+02/
         data arr1115/
     1      -.3681978121467852d+02,0.2960018035910031d+02,
     2      0.3177969646713889d-02,-.2665013507576323d-01,
     3      0.1426144984445984d+00,-.5819320967307617d+00,
     4      0.1910987669061667d+01,-.5312743281019373d+01,
     5      0.1276939059531620d+02,-.2701509287648230d+02,
     6      0.5147306582419647d+02,-.8768012909151244d+02,
     7      0.1388473222732517d+03,-.1960616493030640d+03,
     8      0.2667784426184618d+03,-.3168389362275275d+03/
         data arr1116/
     1      0.3797756071360756d+03,-.3757273046299038d+03,
     2      0.4056577023681985d+03,-.3276523769654945d+03,
     3      0.3241228788430876d+03,-.1932635716332578d+03,
     4      0.1787080122034201d+03,-.7068063215851002d+02,
     5      0.6138259720259633d+02,0.2063341507122993d-02,
     6      -.1850702015440555d-01,0.1036844873110666d+00,
     7      -.4499134300392545d+00,0.1555333728057630d+01,
     8      -.4580322364475324d+01,0.1163849687559458d+02/
         data arr1117/
     1      -.2595871579835794d+02,0.5247392889853541d+02,
     2      -.9373523831313547d+02,0.1579825649746768d+03,
     3      -.2320285041875690d+03,0.3372730066314905d+03,
     4      -.4128368869158450d+03,0.5305292525494965d+03,
     5      -.5336902932367060d+03,0.6202391189683805d+03,
     6      -.5037151252159198d+03,0.5378848059668837d+03,
     7      -.3168024722387975d+03,0.3171206759742768d+03,
     8      -.1240255922288479d+03,0.1165208375136265d+03/
         data arr1118/
     1      -.9308257437561141d-06,0.1303736584340763d-07,
     2      -.1207814802019680d-09,0.8613683865794231d-12,
     3      -.5046943834243494d-14,0.2524112648172682d-16,
     4      -.1120593482923621d-18,0.1086066413042662d-19,
     5      -.5939031717041557d-20,0.2443433589442814d-19,
     6      -.3834465363465468d-19,0.5970518081036961d-19,
     7      -.4859238402896744d-19,0.1336625632090532d-18,
     8      -.5591252867822381d-19,0.1931307481571987d-18/
         data arr1119/
     1      -.6378583794993211d-19,0.3026731228139056d-18,
     2      -.4136023997539289d-19,0.2562641257153296d-18,
     3      -.1607588805318810d-19,0.1919660758541728d-18,
     4      -.1201731547384949d-03,0.8729807797386599d-05,
     5      -.4194603650604667d-06,0.1551512532598170d-07,
     6      -.4714889629888747d-09,0.1221902458500245d-10,
     7      -.2767684380884798d-12,0.5577968055312907d-14,
     8      -.1020235358609834d-15,0.5295283163540064d-17/
         data arr1120/
     1      -.4378881921347346d-17,0.7736769618929886d-17,
     2      -.2746712773049036d-17,0.1554547840064136d-16,
     3      0.1022215533762235d-17,0.2094770883004127d-16,
     4      0.1983831522609767d-17,0.3043560276291724d-16,
     5      0.4081884855694566d-17,0.2555257510715977d-16,
     6      -.7803972979031419d-18,0.1620280971571034d-16,
     7      -.1445077413419960d-02,0.2514975338134278d-03,
     8      -.2895112050648343d-04,0.2565518393219420d-05/
         data arr1121/
     1      -.1867827540342121d-06,0.1159703770047870d-07,
     2      -.6293213304747535d-09,0.3037691737848551d-10,
     3      -.1321679448098419d-11,0.5241904432501245d-13,
     4      -.1933748034180908d-14,0.1299535063595385d-15,
     5      0.6045772308493071d-16,0.1352144496567272d-15,
     6      0.1995852416802001d-15,0.1802009578693126d-15,
     7      0.3284524564659539d-15,0.3385252241989982d-15,
     8      0.3253938650287278d-15,0.3144505351008055d-15/
         data arr1122/
     1      0.1908411984196721d-15,0.2358514094951998d-15,
     2      -.6993046761506014d-02,0.2188641632606289d-02,
     3      -.4530768878334041d-03,0.7220167460611704d-04,
     4      -.9453105801861429d-05,0.1055480995139875d-05,
     5      -.1030009933422301d-06,0.8940832632692572d-08,
     6      -.6995619745970613d-09,0.4985606435101699d-10,
     7      -.3263834684606945d-11,0.1977596270689386d-12,
     8      -.1070980482104221d-13,0.8770936651332390d-15/
         data arr1123/
     1      0.1263170661430974d-14,0.2403958185727570d-15,
     2      0.1999460085218750d-14,0.8110005776140475d-15,
     3      0.2007822642982030d-14,0.8964021223779034d-15,
     4      0.1161778601491559d-14,0.6166828019172025d-15,
     5      -.2065167765840190d-01,0.1000063131766217d-01,
     6      -.3203232961608101d-02,0.7898192998475861d-03,
     7      -.1599995810065876d-03,0.2764130861024810d-04,
     8      -.4173625245567818d-05,0.5605493507942420d-06/
         data arr1124/
     1      -.6786188874906143d-07,0.7483076539981602d-08,
     2      -.7579528026024767d-09,0.7101391004902471d-10,
     3      -.6192945927972713d-11,0.5059601351024021d-12,
     4      -.4109183805470946d-13,0.4872560908557436d-14,
     5      -.2645467460887476d-14,0.4751956549187828d-14,
     6      -.1017237605255664d-15,0.5087156809141889d-14,
     7      0.3787875109493274d-15,0.2689519884715890d-14,
     8      -.4459196810649733d-01,0.3047101185876091d-01/
         data arr1125/
     1      -.1377228940834329d-01,0.4791853297663031d-02,
     2      -.1369786158681002d-02,0.3339263451977649d-03,
     3      -.7114816300504757d-04,0.1348410888120532d-04,
     4      -.2303522692150958d-05,0.3584304247219833d-06,
     5      -.5122997736474365d-07,0.6773020270042313d-08,
     6      -.8331772224359224d-09,0.9583920196187855d-10,
     7      -.1035630291447899d-10,0.1048004598452426d-11,
     8      -.9724603505001824d-13,0.9197063624254696d-14/
         data arr1126/
     1      0.1073691348224172d-13,0.5671812368260735d-14,
     2      0.1059805527615759d-13,0.2926533865516911d-14,
     3      -.7747832894016224d-01,0.7022747870797744d-01,
     4      -.4210395927424800d-01,0.1943197335798018d-01,
     5      -.7368223014525283d-02,0.2382633638644187d-02,
     6      -.6733903248988017d-03,0.1692863836763795d-03,
     7      -.3836090706961712d-04,0.7917677993402400d-05,
     8      -.1501114081892015d-05,0.2632502194160839d-06/
         data arr1127/
     1      -.4295541899299429d-07,0.6554588995871336d-08,
     2      -.9394016353111465d-09,0.1269463839601684d-09,
     3      -.1622802913598757d-10,0.2007684194014239d-11,
     4      -.2011098074282315d-12,0.7538546834333587d-13,
     5      0.3125355968444576d-13,0.2351760232986255d-13,
     6      -.1146977917306150d+00,0.1319447767402981d+00,
     7      -.1003964548192202d+00,0.5880613835407500d-01,
     8      -.2829950451926168d-01,0.1161404897568447d-01/
         data arr1128/
     1      -.4165849450595658d-02,0.1329134836184567d-02,
     2      -.3822488571374548d-03,0.1001302908103678d-03,
     3      -.2409304284326555d-04,0.5362372937675588d-05,
     4      -.1110494307017762d-05,0.2150572088453038d-06,
     5      -.3911667613418394d-07,0.6708018020031001d-08,
     6      -.1088207069600360d-08,0.1675703272565861d-09,
     7      -.2444552529210463d-10,0.3535563989064692d-11,
     8      -.3348765575766909d-12,0.7866988751246713d-13/
         data arr1129/
     1      -.1501194142550106d+00,0.2120552306675791d+00,
     2      -.1981299575219801d+00,0.1425047736408431d+00,
     3      -.8420939850322492d-01,0.4243657924928553d-01,
     4      -.1869111755239746d-01,0.7322775519454118d-02,
     5      -.2585996054560927d-02,0.8318061403814946d-03,
     6      -.2457668363107632d-03,0.6716818663844918d-04,
     7      -.1708039440498118d-04,0.4061725409193327d-05,
     8      -.9071778814281256d-06,0.1910285747115789d-06/
         data arr1130/
     1      -.3805172803657240d-07,0.7192055491805319d-08,
     2      -.1291351542789628d-08,0.2216746649251738d-09,
     3      -.3462791995658841d-10,0.5443647404590815d-11,
     4      -.1781728112125246d+00,0.3012620893659779d+00,
     5      -.3369275809468814d+00,0.2900726304051321d+00,
     6      -.2051770725027235d+00,0.1237654871576168d+00,
     7      -.6525073060989844d-01,0.3059967078808244d-01,
     8      -.1293480286367251d-01,0.4980179557780314d-02/
         data arr1131/
     1      -.1761315187965207d-02,0.5761934915980886d-03,
     2      -.1753854253757927d-03,0.4992258906474119d-04,
     3      -.1334654019530180d-04,0.3364074982106736d-05,
     4      -.8020563489627283d-06,0.1814562907780331d-06,
     5      -.3895266209185455d-07,0.7996900561776758d-08,
     6      -.1486369149295265d-08,0.2791961888461494d-09,
     7      -.1952883971694140d+00,0.3873181801049431d+00,
     8      -.5080990148345266d+00,0.5131058101094904d+00/
         data arr1132/
     1      -.4257134762942898d+00,0.3012149445079043d+00,
     2      -.1862733514794224d+00,0.1024638084536544d+00,
     3      -.5080447220844532d-01,0.2294433745410666d-01,
     4      -.9518225345106161d-02,0.3652377367280911d-02,
     5      -.1304034286993561d-02,0.4353925898217088d-03,
     6      -.1365328941821146d-03,0.4036669403760279d-04,
     7      -.1128720170002166d-04,0.2995348303223930d-05,
     8      -.7525414792134378d-06,0.1812322735334458d-06/
         data arr1133/
     1      -.3877755408582397d-07,0.8546521541581524d-08,
     2      -.2003643182231507d+00,0.4585206871199968d+00,
     3      -.6940432180689478d+00,0.8087088659018057d+00,
     4      -.7741939626152484d+00,0.6320566530479050d+00,
     5      -.4510008188034098d+00,0.2862491500460649d+00,
     6      -.1637656312790636d+00,0.8533819476696770d-01,
     7      -.4084801737295775d-01,0.1808580157731790d-01,
     8      -.7450708407126939d-02,0.2870362985039075d-02/
         data arr1134/
     1      -.1038555050045947d-02,0.3542941691083738d-03,
     2      -.1142711968169451d-03,0.3499104953512237d-04,
     3      -.1010757146202917d-04,0.2809190961271420d-05,
     4      -.6778653731614866d-06,0.1724153574221739d-06,
     5      -.1944299322181018d+00,0.5064704494328739d+00,
     6      -.8726380102874819d+00,0.1157423378264168d+01,
     7      -.1261253141107898d+01,0.1172089896698439d+01,
     8      -.9519950267913982d+00,0.6877870429471056d+00/
         data arr1135/
     1      -.4479040306642369d+00,0.2656795312866983d+00,
     2      -.1447564366424950d+00,0.7295534899091159d-01,
     3      -.3421110676720378d-01,0.1500234758826609d-01,
     4      -.6178413787023300d-02,0.2399207304768836d-02,
     5      -.8802865264931383d-03,0.3068462811344104d-03,
     6      -.1003600332212330d-03,0.3175980381198672d-04,
     7      -.8495265580191933d-05,0.2460198361446328d-05,
     8      -.1798897872899749d+00,0.5273685762842600d+00/
         data arr1136/
     1      -.1022612312217043d+01,0.1526461641488986d+01,
     2      -.1872029377311272d+01,0.1957889039418239d+01,
     3      -.1789693174851752d+01,0.1455173064647001d+01,
     4      -.1066503596368496d+01,0.7119544666175232d+00,
     5      -.4365641661345000d+00,0.2476191636796105d+00,
     6      -.1306785437720420d+00,0.6449326742829795d-01,
     7      -.2988719903801936d-01,0.1306176679331483d-01,
     8      -.5387485528193973d-02,0.2113708313202733d-02/
         data arr1137/
     1      -.7721885659925260d-03,0.2751384476989069d-03,
     2      -.8037203765416594d-04,0.2620468915974158d-04,
     3      -.1597078846919371d+00,0.5218773092652292d+00,
     4      -.1127975069121053d+01,0.1876759814184688d+01,
     5      -.2565486750785697d+01,0.2990745847457216d+01,
     6      -.3047223500495337d+01,0.2761688539665266d+01,
     7      -.2256090153153383d+01,0.1678729514087194d+01,
     8      -.1147383615022237d+01,0.7254035309972749d+00/
         data arr1138/
     1      -.4266935199629138d+00,0.2347274332334517d+00,
     2      -.1212084139778086d+00,0.5904781920384683d-01,
     3      -.2709498017676325d-01,0.1185120149416116d-01,
     4      -.4776367728522225d-02,0.1898189457484156d-02,
     5      -.5976810035648393d-03,0.2173298279548180d-03,
     6      -.1367572513738558d+00,0.4940222682085053d+00,
     7      -.1180406847947936d+01,0.2171175948089741d+01,
     8      -.3281029997708539d+01,0.4228380280275679d+01/
         data arr1139/
     1      -.4762695758939183d+01,0.4771746498657508d+01,
     2      -.4309355532990188d+01,0.3544793568269136d+01,
     3      -.2678342704639340d+01,0.1871944287542147d+01,
     4      -.1217136920528681d+01,0.7402012804622228d+00,
     5      -.4222816224811397d+00,0.2274407624318070d+00,
     6      -.1150175021565397d+00,0.5563224983055481d-01,
     7      -.2445233293831452d-01,0.1075245224212362d-01,
     8      -.3607500955908444d-02,0.1451293225394362d-02/
         data arr1140/
     1      -.1134181275008003d+00,0.4497193093222848d+00,
     2      -.1179477484240882d+01,0.2381309541230026d+01,
     3      -.3949971109399827d+01,0.5587540231131991d+01,
     4      -.6908152979035546d+01,0.7597128947219679d+01,
     5      -.7530856841782589d+01,0.6799652812673566d+01,
     6      -.5639052422854467d+01,0.4326138405566924d+01,
     7      -.3086814645251761d+01,0.2060646594395780d+01,
     8      -.1288888019085112d+01,0.7621187561613449d+00/
         data arr1141/
     1      -.4210384620392109d+00,0.2236478466134076d+00,
     2      -.1060479107069130d+00,0.5124922353053152d-01,
     3      -.1813505484193192d-01,0.8016965454753500d-02,
     4      -.9140958186418534d-01,0.3953894943924753d+00,
     5      -.1131221686309370d+01,0.2491427539829832d+01,
     6      -.4508173484522358d+01,0.6956675571483162d+01,
     7      -.9382441947220990d+01,0.1125584928400964d+02,
     8      -.1217134522398039d+02,0.1198830619137317d+02/
         data arr1142/
     1      -.1084437409711241d+02,0.9075801452963526d+01,
     2      -.7060914691226689d+01,0.5142458949868002d+01,
     3      -.3501658793624705d+01,0.2259425269619757d+01,
     4      -.1352239563751838d+01,0.7841653573345635d+00,
     5      -.3970057140479056d+00,0.2096398820101806d+00,
     6      -.7753405167847159d-01,0.3744648899746883d-01,
     7      -.7179206748713436d-01,0.3369235909787360d+00,
     8      -.1045866466476714d+01,0.2499184878656929d+01/
         data arr1143/
     1      -.4906504430443118d+01,0.8214765155295085d+01,
     2      -.1202059836069099d+02,0.1564630481411315d+02,
     3      -.1835562394326766d+02,0.1961631075263784d+02,
     4      -.1924757086195450d+02,0.1747859588024951d+02,
     5      -.1473988512247726d+02,0.1164963306923892d+02,
     6      -.8577678720787672d+01,0.6008438399805425d+01,
     7      -.3863609574965441d+01,0.2433736302402979d+01,
     8      -.1302595866564457d+01,0.7479216894808181d+00/
         data arr1144/
     1      -.2867739515230963d+00,0.1505755751104250d+00,
     2      -.5506949738100915d-01,0.2790730027306870d+00,
     3      -.9354430096913658d+00,0.2413746621293441d+01,
     4      -.5117021865298157d+01,0.9251100259173965d+01,
     5      -.1461713951380178d+02,0.2054498476167119d+02,
     6      -.2602274864059549d+02,0.3003123184837990d+02,
     7      -.3180137807686329d+02,0.3118839504850637d+02,
     8      -.2835136728101493d+02,0.2420536190501600d+02/
         data arr1145/
     1      -.1914263867175810d+02,0.1449283771464742d+02,
     2      -.9930724419541205d+01,0.6766263231179067d+01,
     3      -.3792249152796034d+01,0.2357936220185838d+01,
     4      -.9305149509635372d+00,0.5289883087017930d+00,
     5      -.4133152188906410d-01,0.2252210892851898d+00,
     6      -.8117855833971944d+00,0.2252367711007739d+01,
     7      -.5134375889695604d+01,0.9981393405087347d+01,
     8      -.1695687611794603d+02,0.2562888287963207d+02/
         data arr1146/
     1      -.3489432110506417d+02,0.4330597190427445d+02,
     2      -.4925622735997143d+02,0.5195999168054448d+02,
     3      -.5063458217545431d+02,0.4651749731411171d+02,
     4      -.3923987469648866d+02,0.3199291634303719d+02,
     5      -.2316636640325875d+02,0.1701364775639883d+02,
     6      -.9894231481288841d+01,0.6639591734534381d+01,
     7      -.2679128073404043d+01,0.1643436136684457d+01,
     8      -.3039600945235886d-01,0.1774309771198775d+00/
         data arr1147/
     1      -.6851577381411941d+00,0.2036510686379761d+01,
     2      -.4973160223764194d+01,0.1035732863078509d+02,
     3      -.1884548079920417d+02,0.3051668173118637d+02,
     4      -.4447780085695931d+02,0.5914979738679082d+02,
     5      -.7191928464407928d+02,0.8132638794228789d+02,
     6      -.8447173312014486d+02,0.8323852102611039d+02,
     7      -.7434760580332679d+02,0.6508809479499556d+02,
     8      -.4938627091875590d+02,0.3898644808327030d+02/
         data arr1148/
     1      -.2331908886611901d+02,0.1684357308446008d+02,
     2      -.6908087334046455d+01,0.4560242242006375d+01,
     3      -.2193001727860737d-01,0.1366567659301594d+00,
     4      -.5635339112252838d+00,0.1788338654905977d+01,
     5      -.4662646015460038d+01,0.1036875165688007d+02,
     6      -.2013302862022680d+02,0.3481798736569203d+02,
     7      -.5410075150647806d+02,0.7686362553194417d+02,
     8      -.9940403940297932d+02,0.1201643444882778d+03/
         data arr1149/
     1      -.1322023531101331d+03,0.1393882870051791d+03,
     2      -.1307870962247981d+03,0.1226794456150376d+03,
     3      -.9670340484590854d+02,0.8188998310419504d+02,
     4      -.4995226612694265d+02,0.3876035733049978d+02,
     5      -.1606930720336214d+02,0.1139307796081456d+02,
     6      -.1554117109972141d-01,0.1030233779320748d+00,
     7      -.4524319739289746d+00,0.1528077060046669d+01,
     8      -.4240480875448195d+01,0.1003945105304798d+02/
         data arr1150/
     1      -.2072635878020276d+02,0.3817857276325572d+02,
     2      -.6296339205674492d+02,0.9534120451849911d+02,
     3      -.1303995789880356d+03,0.1681795003886198d+03,
     4      -.1946079604077228d+03,0.2191839267891759d+03,
     5      -.2141976903321204d+03,0.2149895727739983d+03,
     6      -.1745257082842641d+03,0.1583377168224586d+03,
     7      -.9769110676164317d+02,0.8133441023001279d+02,
     8      -.3391002745710430d+02,0.2579054912158125d+02/
         data arr1151/
     1      -.1083937662047881d-01,0.7610656420563680d-01,
     2      -.3551250272576449d+00,0.1272391249271006d+01,
     3      -.3746651680155544d+01,0.9418501464338204d+01,
     4      -.2058947585215281d+02,0.4031196974893289d+02,
     5      -.7019547105528457d+02,0.1131060709574044d+03,
     6      -.1624934658092987d+03,0.2233608021235852d+03,
     7      -.2696558369830724d+03,0.3242125109477785d+03,
     8      -.3269237444689434d+03,0.3509819327718302d+03/
         data arr1152/
     1      -.2908294285063606d+03,0.2825837150512270d+03,
     2      -.1749181555512980d+03,0.1562070991614919d+03,
     3      -.6516755766406074d+02,0.5315092551965644d+02,
     4      -.7468557961253538d-02,0.5514308543453747d-01,
     5      -.2729306687645880d+00,0.1033291122948296d+01,
     6      -.3217607847502595d+01,0.8567700436113308d+01,
     7      -.1973195957635821d+02,0.4101170785348008d+02,
     8      -.7491393644171711d+02,0.1283923506500931d+03/
         data arr1153/
     1      -.1921435997222480d+03,0.2815827186810400d+03,
     2      -.3513879213901502d+03,0.4513159221916524d+03,
     3      -.4648240865710031d+03,0.5342941070068371d+03,
     4      -.4477957358588871d+03,0.4664155511267961d+03,
     5      -.2872719615808040d+03,0.2754290526218259d+03,
     6      -.1143993221824853d+03,0.1001499327024532d+03,
     7      0.4609404898337403d-08,-.5693693579230734d-10,
     8      0.4717909212283044d-12,-.3043428530665637d-14/
         data arr1154/
     1      0.1627837132076065d-16,-.7490310141137607d-19,
     2      0.3137906331362489d-21,-.4013582571662617d-22,
     3      0.1439932003831874d-23,-.9525857522268616d-22,
     4      0.1661075270498644d-21,0.8477851585692760d-24,
     5      0.2959209276061260d-21,0.2093134583627316d-21,
     6      0.2504576722647102d-21,0.4660768998755351d-21,
     7      0.5463655437051648d-21,0.2733162524631618d-21,
     8      0.2952501770756983d-21,0.4156038679429319d-21/
         data arr1155/
     1      0.2459319513546328d-21,0.3086453145993060d-05,
     2      -.1977355123818225d-06,0.8497984126828942d-08,
     3      -.2843185433705500d-09,0.7887344368300025d-11,
     4      -.1880271255789279d-12,0.3943005746385732d-14,
     5      -.7398468250223114d-16,0.1291709251949389d-17,
     6      -.7345879404507175d-19,0.1397531919663859d-18,
     7      0.1721517320996883d-19,0.1837603390193327d-18,
     8      0.1436614649177665d-18,0.4492664767227375d-19/
         data arr1156/
     1      0.2679926306505653d-18,0.1155765672130964d-18,
     2      0.8635331408132271d-19,-.8875289231570906d-19,
     3      0.2024172375616279d-18,0.3382462319528759d-19,
     4      0.8891780580557656d-04,-.1364768908871774d-04,
     5      0.1405192295699822d-05,-.1126342386380214d-06,
     6      0.7485855619232916d-08,-.4275396606594621d-09,
     7      0.2147970907758597d-10,-.9652192544056817d-12,
     8      0.3928556429217766d-13,-.1464046944606353d-14/
         data arr1157/
     1      0.5425794686047460d-16,-.6222213074454306d-18,
     2      0.3488682862615124d-17,0.6344640860517310d-17,
     3      -.3515870279559348d-17,0.1162576487417621d-16,
     4      -.5226415686283885d-17,0.4700036670429182d-17,
     5      -.1080229819831947d-16,0.7880267747574906d-17,
     6      -.4639357017093797d-17,0.7738016700015128d-03,
     7      -.2135824931905776d-03,0.3954648587160624d-04,
     8      -.5700437281564185d-05,0.6813100525832793d-06/
         data arr1158/
     1      -.6997539563504415d-07,0.6322123319804361d-08,
     2      -.5108878503868829d-09,0.3739195640587555d-10,
     3      -.2503186946779672d-11,0.1545408086286101d-12,
     4      -.8851943463281166d-14,0.5045394050268814d-15,
     5      0.1604063864186647d-16,-.6631832466408662d-16,
     6      0.7097052754605752d-16,-.1062428015979863d-15,
     7      -.1194096979507092d-16,-.1764789433631336d-15,
     8      0.2989079823399835d-16,-.6035874560381256d-16/
         data arr1159/
     1      0.3535757110432603d-02,-.1510018499248858d-02,
     2      0.4326018468800036d-03,-.9648337760245723d-04,
     3      0.1784238798524812d-04,-.2835420009291097d-05,
     4      0.3963682469761385d-06,-.4955931637637966d-07,
     5      0.5612307265248144d-08,-.5813221903158579d-09,
     6      0.5551431053832078d-10,-.4919805855300792d-11,
     7      0.4074292702367887d-12,-.3117253377915488d-13,
     8      0.2559105749752458d-14,0.4286983058902757d-15/
         data arr1160/
     1      0.2710401438067151d-15,-.2582460131172023d-16,
     2      -.3710851110310518d-15,0.1735556842345812d-15,
     3      0.1640441611737748d-15,0.1077312955747240d-01,
     4      -.6492319488735452d-02,0.2624606143386796d-02,
     5      -.8260121329757734d-03,0.2155485289668667d-03,
     6      -.4833565859733821d-04,0.9534704828191565d-05,
     7      -.1682255120939061d-05,0.2688228193269420d-06,
     8      -.3929159651115316d-07,0.5294718233520794d-08/
         data arr1161/
     1      -.6621382034082329d-09,0.7727483521361755d-10,
     2      -.8453261325559333d-11,0.8717293156001408d-12,
     3      -.8236922128256143d-13,0.7958259701217136d-14,
     4      -.1661642322029252d-14,-.2925126771737954d-14,
     5      -.2349903422459147d-15,0.4087949086549724d-15,
     6      0.2482916321002147d-01,-.1984799674508231d-01,
     7      0.1064333014500787d-01,-.4443205656515651d-02,
     8      0.1537983400426452d-02,-.4574786399454602d-03/
         data arr1162/
     1      0.1197035498615310d-03,-.2801484550746625d-04,
     2      0.5938258496839404d-05,-.1151301936019772d-05,
     3      0.2057921729103126d-06,-.3413748285340124d-07,
     4      0.5284485387228122d-08,-.7669892074072330d-09,
     5      0.1048089631273673d-09,-.1351746839458154d-10,
     6      0.1652333691022300d-11,-.1933133911456417d-12,
     7      0.4030142317212730d-14,-.2511209916542664d-14,
     8      0.1834340903321017d-15,0.4664952318760293d-01/
         data arr1163/
     1      -.4732734267317428d-01,0.3220944849630321d-01,
     2      -.1706524331696992d-01,0.7496836377468395d-02,
     3      -.2830137396385995d-02,0.9398402557857919d-03,
     4      -.2791550955223159d-03,0.7509771811681077d-04,
     5      -.1847852030821842d-04,0.4191959796080084d-05,
     6      -.8825313090074454d-06,0.1733847080852893d-06,
     7      -.3193853095524447d-07,0.5538941940257293d-08,
     8      -.9075746244534397d-09,0.1409590637708189d-09/
         data arr1164/
     1      -.2082213130977994d-10,0.2866843178120555d-11,
     2      -.4035019653542420d-12,0.5059089777691757d-13,
     3      0.7497284579555702d-01,-.9339935768000007d-01,
     4      0.7805307907527408d-01,-.5078017793757260d-01,
     5      0.2739269411706496d-01,-.1269811388829140d-01,
     6      0.5177984226947624d-02,-.1888544496962160d-02,
     7      0.6238546053299305d-03,-.1884945587891631d-03,
     8      0.5250778701514074d-04,-.1357412078889185d-04/
         data arr1165/
     1      0.3274667915046333d-05,-.7407072831872911d-06,
     2      0.1577366855191043d-06,-.3173715291225346d-07,
     3      0.6052950460076572d-08,-.1095951948223307d-08,
     4      0.1891672700576083d-09,-.3017966275459501d-10,
     5      0.4766765697168229d-11,0.1065122331525463d+00,
     6      -.1588291848375540d+00,0.1588793229877902d+00,
     7      -.1237264300136203d+00,0.7989027843275073d-01,
     8      -.4432914223851057d-01,0.2163723471643645d-01/
         data arr1166/
     1      -.9446244406968804d-02,0.3735134668497222d-02,
     2      -.1350867082648417d-02,0.4504311728072326d-03,
     3      -.1393822004029055d-03,0.4024887892754192d-04,
     4      -.1089740076637549d-04,0.2777794202422039d-05,
     5      -.6689580008219138d-06,0.1527191642615162d-06,
     6      -.3305052262445749d-07,0.6836288479804362d-08,
     7      -.1280167025237588d-08,0.2427914785044965d-09,
     8      0.1369376558145007d+00,-.2395201726024730d+00/
         data arr1167/
     1      0.2810396265840148d+00,-.2567148852845137d+00,
     2      0.1944334106178908d+00,-.1265478227708057d+00,
     3      0.7245285378391182d-01,-.3710234059456173d-01,
     4      0.1720825309100845d-01,-.7300145571772588d-02,
     5      0.2855194730150395d-02,-.1036341309752740d-02,
     6      0.3510247386597944d-03,-.1114785393186831d-03,
     7      0.3333172278197473d-04,-.9414073733099943d-05,
     8      0.2521003016166864d-05,-.6384632587079879d-06/
         data arr1168/
     1      0.1549652970888292d-06,-.3337244411023786d-07,
     2      0.7436076539084086d-08,0.1621115435883955d+00,
     3      -.3271751106218818d+00,0.4429480883088679d+00,
     4      -.4668565252602540d+00,0.4079908151843710d+00,
     5      -.3063947216749124d+00,0.2024087151024043d+00,
     6      -.1195975070423781d+00,0.6400364607389458d-01,
     7      -.3132899864145113d-01,0.1413832149855975d-01,
     8      -.5921221373020044d-02,0.2314160860321028d-02/
         data arr1169/
     1      -.8479743200711140d-03,0.2925493659884930d-03,
     2      -.9530638749204962d-04,0.2945048383297920d-04,
     3      -.8574454486528508d-05,0.2402537506270268d-05,
     4      -.5833251904985271d-06,0.1502347469822460d-06,
     5      0.1790643446321788d+00,-.4113655030602811d+00,
     6      0.6339468928565644d+00,-.7605642607932082d+00,
     7      0.7565807750047857d+00,-.6467532627443802d+00,
     8      0.4863388819914441d+00,-.3271028524406855d+00/
         data arr1170/
     1      0.1992596484136770d+00,-.1110231098979509d+00,
     2      0.5703182046982478d-01,-.2718821044431549d-01,
     3      0.1209528364526047d-01,-.5044615931293885d-02,
     4      0.1981091028550457d-02,-.7341711361167136d-03,
     5      0.2582705126560163d-03,-.8512417975009932d-04,
     6      0.2717034060945728d-04,-.7310221727925295d-05,
     7      0.2147581810007376d-05,0.1864529482368262d+00,
     8      -.4820640669548035d+00,0.8360774741709611d+00/
         data arr1171/
     1      -.1128876188517334d+01,0.1263811940241364d+01,
     2      -.1215857081628835d+01,0.1028962740578581d+01,
     3      -.7788640732152478d+00,0.5339658491840692d+00,
     4      -.3348293233222635d+00,0.1935728138040021d+00,
     5      -.1038525316085956d+00,0.5199619291015945d-01,
     6      -.2440234163126734d-01,0.1078554491158918d-01,
     7      -.4493011376208320d-02,0.1779232995971998d-02,
     8      -.6548156780151504d-03,0.2354790738323120d-03/
         data arr1172/
     1      -.6915952236363772d-04,0.2292339978550093d-04,
     2      0.1845114921566256d+00,-.5317325465398206d+00,
     3      0.1027943684836752d+01,-.1547046712283725d+01,
     4      0.1930518139946058d+01,-.2070180652765094d+01,
     5      0.1952808680987366d+01,-.1647615012103094d+01,
     6      0.1259047126933077d+01,-.8800020610991284d+00,
     7      0.5670741193983138d+00,-.3390993557852395d+00,
     8      0.1892439086630816d+00,-.9896204409952719d-01/
         data arr1173/
     1      0.4875863957712383d-01,-.2259450564583943d-01,
     2      0.9977189078688373d-02,-.4049122552837786d-02,
     3      0.1625529471482506d-02,-.5143011387799478d-03,
     4      0.1905815051239171d-03,0.1746632478892257d+00,
     5      -.5564491216215547d+00,0.1189202039667504d+01,
     6      -.1978535478818418d+01,0.2729407706507861d+01,
     7      -.3235614171162078d+01,0.3374134199805162d+01,
     8      -.3147106228595877d+01,0.2658595100417485d+01/
         data arr1174/
     1      -.2054187638935067d+01,0.1463366922297815d+01,
     2      -.9672654944246536d+00,0.5967742649423634d+00,
     3      -.3447602988677512d+00,0.1878153658272120d+00,
     4      -.9589972413478146d-01,0.4684538597499799d-01,
     5      -.2072083951383182d-01,0.9215170086875946d-02,
     6      -.3104319515922173d-02,0.1276221988307735d-02,
     7      0.1589997861832474d+00,-.5560110005128159d+00,
     8      0.1304296929013704d+01,-.2381921870622164d+01/
         data arr1175/
     1      0.3606741520737760d+01,-.4693163041872688d+01,
     2      0.5371980665675461d+01,-.5499747453106837d+01,
     3      0.5099739063178960d+01,-.4324910233140433d+01,
     4      0.3381902943131599d+01,-.2453048677840776d+01,
     5      0.1661379109060629d+01,-.1052182678567855d+01,
     6      0.6293812103646750d+00,-.3509794378956935d+00,
     7      0.1883870892901828d+00,-.8981766863550704d-01,
     8      0.4396697409157713d-01,-.1560652022210719d-01/
         data arr1176/
     1      0.7072068217362781d-02,0.1397912937891265d+00,
     2      -.5332629247861851d+00,0.1364610932879738d+01,
     3      -.2718529188278660d+01,0.4490513697511997d+01,
     4      -.6374099970915687d+01,0.7959083197912423d+01,
     5      -.8888627853980369d+01,0.8991226327374529d+01,
     6      -.8317020763171952d+01,0.7094907652744213d+01,
     7      -.5610917776700525d+01,0.4146164752178550d+01,
     8      -.2858119713609068d+01,0.1866118286631624d+01/
         data arr1177/
     1      -.1126873473801375d+01,0.6608625311193606d+00,
     2      -.3360237483469733d+00,0.1800847296184462d+00,
     3      -.6673100787597368d-01,0.3314945451748530d-01,
     4      0.1191204653105022d+00,-.4930257690715795d+00,
     5      0.1368859298757978d+01,-.2958725891569894d+01,
     6      0.5302602900033879d+01,-.8166325703772507d+01,
     7      0.1106358799339091d+02,-.1340476051912087d+02,
     8      0.1471221577480656d+02,-.1476117769851415d+02/
         data arr1178/
     1      0.1366377367236558d+02,-.1171174737532069d+02,
     2      0.9393094454098808d+01,-.6999377743024611d+01,
     3      0.4963486150910338d+01,-.3218232881557380d+01,
     4      0.2052519172705369d+01,-.1101614089760390d+01,
     5      0.6435184751692247d+00,-.2468597198985238d+00,
     6      0.1338197868883353d+00,0.9866715190551893d-01,
     7      -.4409704616711675d+00,0.1322060804353700d+01,
     8      -.3085650793545135d+01,0.5971537633831401d+01/
         data arr1179/
     1      -.9930148198331922d+01,0.1452741241777592d+02,
     2      -.1900320269697073d+02,0.2252334517752219d+02,
     3      -.2438656264844593d+02,0.2438159648537288d+02,
     4      -.2252246758015549d+02,0.1951850461224493d+02,
     5      -.1561360407478080d+02,0.1197603414218942d+02,
     6      -.8266713715069431d+01,0.5712039991129207d+01,
     7      -.3203967100860841d+01,0.2032805270214043d+01,
     8      -.8012064901956739d+00,0.4721640811745988d+00/
         data arr1180/
     1      0.7962747314700629d-01,-.3826738785887919d+00,
     2      0.1233662728034361d+01,-.3096044121674270d+01,
     3      0.6442880584189797d+01,-.1151910083574824d+02,
     4      0.1812203762410494d+02,-.2547937538195101d+02,
     5      0.3247916177819453d+02,-.3776429523812051d+02,
     6      0.4062075591698594d+02,-.4021014480633896d+02,
     7      0.3751621105577917d+02,-.3198437256767409d+02,
     8      0.2644960543350351d+02,-.1926834606169455d+02/
         data arr1181/
     1      0.1438184436352887d+02,-.8349503992127287d+01,
     2      0.5737735583204453d+01,-.2307649948012386d+01,
     3      0.1473910736136096d+01,0.6273062376590628d-01,
     4      -.3229694839788616d+00,0.1115410295656395d+01,
     5      -.2998619360724585d+01,0.6685359069107813d+01,
     6      -.1280046103061917d+02,0.2157749109638494d+02,
     7      -.3247034531130210d+02,0.4436120390927743d+02,
     8      -.5511870262202353d+02,0.6358113842061255d+02/
         data arr1182/
     1      -.6704046965649410d+02,0.6714902302518630d+02,
     2      -.6054004898053525d+02,0.5384800252194583d+02,
     3      -.4103112255565834d+02,0.3301273566528647d+02,
     4      -.1965095268779196d+02,0.1459709703554970d+02,
     5      -.5953137678267086d+01,0.4111301664688927d+01,
     6      0.4831332697346005d-01,-.2656053241942403d+00,
     7      0.9794169735476812d+00,-.2810829221840335d+01,
     8      0.6692205418066631d+01,-.1367078113432687d+02/
         data arr1183/
     1      0.2461685612449763d+02,-.3947774016139886d+02,
     2      0.5764398799877549d+02,-.7612812868052953d+02,
     3      0.9395124275638061d+02,-.1048174196714272d+03,
     4      0.1124916012653814d+03,-.1063436500408644d+03,
     5      0.1015942277860769d+03,-.8022900070130382d+02,
     6      0.6949550532496733d+02,-.4202563932150731d+02,
     7      0.3370342283382850d+02,-.1385693615973888d+02,
     8      0.1033047146575608d+02,0.3641834089448157d-01/
         data arr1184/
     1      -.2131596009494816d+00,0.8367031754055251d+00,
     2      -.2554973243169619d+01,0.6478297457924939d+01,
     3      -.1406356798528456d+02,0.2698768075946928d+02,
     4      -.4590290292211315d+02,0.7149481378948153d+02,
     5      -.9973721412738935d+02,0.1315061710247966d+03,
     6      -.1540534518075874d+03,0.1769993534029722d+03,
     7      -.1738088558766660d+03,0.1782802589451559d+03,
     8      -.1445317211902683d+03,0.1347438805221067d+03/
         data arr1185/
     1      -.8203109496726481d+02,0.7100052911194277d+02,
     2      -.2926628778852768d+02,0.2353190617944150d+02,
     3      0.2689270215519071d-01,-.1671330731306024d+00,
     4      0.6962820571609484d+00,-.2254438097449081d+01,
     5      0.6074353724865372d+01,-.1394866606890773d+02,
     6      0.2848334669688473d+02,-.5108451471333372d+02,
     7      0.8479930101883244d+02,-.1240084746119196d+03,
     8      0.1746798245519474d+03,-.2129452172776821d+03/
         data arr1186/
     1      0.2620473421328889d+03,-.2645247589257295d+03,
     2      0.2915773998700355d+03,-.2402965479562635d+03,
     3      0.2412940982706710d+03,-.1465467082660490d+03,
     4      0.1369830617750205d+03,-.5630528989809947d+02,
     5      0.4882845592068834d+02,0.1946085725129632d-01,
     6      -.1280769862424629d+00,0.5645244362111594d+00,
     7      -.1930032619880040d+01,0.5518519058686398d+01,
     8      -.1332354756677915d+02,0.2895026524035156d+02/
         data arr1187/
     1      -.5433718955085337d+02,0.9621791274585041d+02,
     2      -.1460904282916722d+03,0.2202475225953666d+03,
     3      -.2764709071507788d+03,0.3652262533906151d+03,
     4      -.3746243503865177d+03,0.4449031970356130d+03,
     5      -.3689125112013878d+03,0.3999136859160040d+03,
     6      -.2400298736818869d+03,0.2428145987188033d+03,
     7      -.9898208026354693d+02,0.9269490546525245d+02,
     8      -.1800504000945113d-10,0.2011723247549604d-12/
         data arr1188/
     1      -.1521714225198614d-14,0.9029657587607902d-17,
     2      -.4471200597458193d-19,0.1913578404132123d-21,
     3      -.1888717975315490d-23,0.6453333363426999d-25,
     4      -.7616516806281524d-24,0.1052398099314750d-24,
     5      -.1164780519761305d-24,0.3051514181812593d-25,
     6      0.3116655898489839d-23,0.1066073983982877d-23,
     7      0.4939149231299608d-24,0.3592836077801631d-24,
     8      0.2537930334206721d-23,0.1145299181464378d-23/
         data arr1189/
     1      -.2479997810926930d-23,-.1285966082818339d-23,
     2      -.6252945934270115d-07,0.3623552606841294d-08,
     3      -.1421592716599414d-09,0.4375111504873624d-11,
     4      -.1123676554965349d-12,0.2493773637239338d-14,
     5      -.4892199051860430d-16,0.8626693696528945d-18,
     6      -.1676765395526796d-19,0.1869009924007007d-20,
     7      -.1550607339905443d-20,0.1835969608329754d-20,
     8      0.8833141773311102d-20,0.5075288965935621d-20/
         data arr1190/
     1      -.1449461587291630d-21,0.6360982559822270d-21,
     2      0.7455962971960051d-20,0.2475020185716102d-20,
     3      -.7585593581582405d-20,-.6469331298800717d-20,
     4      -.4315778231817596d-05,0.5991760081213806d-06,
     5      -.5631711931837235d-07,0.4152405582383908d-08,
     6      -.2555038151816685d-09,0.1358496108004586d-10,
     7      -.6384319571235086d-12,0.2694852992530474d-13,
     8      -.1034321364914723d-14,0.3674253293338580d-16/
         data arr1191/
     1      -.1420784991717896d-17,0.4863929333343043d-18,
     2      0.3683076717617797d-18,0.6270506287591302d-18,
     3      -.1702266240890318d-18,-.1445195520966238d-19,
     4      0.3629814523856906d-18,-.6254997297340786d-19,
     5      -.4462432810578675d-18,-.8240664730328087d-18,
     6      -.6754071468196204d-04,0.1686267823434942d-04,
     7      -.2850218640777743d-05,0.3779228198761350d-06,
     8      -.4181829738346193d-07,0.3998461872733223d-08/
         data arr1192/
     1      -.3379205415910653d-09,0.2565065307545490d-10,
     2      -.1770009590218573d-11,0.1120912246775818d-12,
     3      -.6568068054190966d-14,0.3716934369984668d-15,
     4      -.1464721211742597d-16,0.1777295163722219d-16,
     5      -.3162366922947196d-17,0.8476957257201085d-19,
     6      0.6163794341025877d-17,-.4361676892781447d-17,
     7      -.4228263632091938d-17,-.2111945907743026d-16,
     8      -.4775097766615560d-03,0.1844620473031678d-03/
         data arr1193/
     1      -.4824168880121625d-04,0.9897176116655912d-05,
     2      -.1694487557148298d-05,0.2506852905522231d-06,
     3      -.3278040649640380d-07,0.3850010896865018d-08,
     4      -.4110568153049805d-09,0.4027411704311061d-10,
     5      -.3648687223275417d-11,0.3077282502375452d-12,
     6      -.2421148221634871d-13,0.1964285343625946d-14,
     7      -.1206427075751688d-15,-.2158015287349588d-16,
     8      0.8445668795608442d-16,-.9221836872963659d-16/
         data arr1194/
     1      -.1911740416815893d-16,-.2597699915947761d-15,
     2      -.2053051688190350d-02,0.1119135819842832d-02,
     3      -.4130060664878723d-03,0.1195648113144176d-03,
     4      -.2888608100270219d-04,0.6030276814949745d-05,
     5      -.1112707172574121d-05,0.1844109321340424d-06,
     6      -.2778335423194046d-07,0.3841191458597734d-08,
     7      -.4910553706354316d-09,0.5841332096217350d-10,
     8      -.6499297466151828d-11,0.6808338757115581d-12/
         data arr1195/
     1      -.6710947926907997d-13,0.6270996738589518d-14,
     2      -.2979248604817691d-16,-.4590276020218477d-15,
     3      -.4100545616972421d-15,-.1784068769982535d-14,
     4      -.6276487670606732d-02,0.4538331222649865d-02,
     5      -.2221602828257840d-02,0.8531196940089385d-03,
     6      -.2733957793093933d-03,0.7570717231359261d-04,
     7      -.1853007855637783d-04,0.4073611719803683d-05,
     8      -.8140934069024917d-06,0.1492973305961611d-06/
         data arr1196/
     1      -.2531703979041813d-07,0.3994692147332168d-08,
     2      -.5895973164730349d-09,0.8177618845516440d-10,
     3      -.1069831206025397d-10,0.1323611626643958d-11,
     4      -.1523101319633088d-12,0.1359889755124977d-13,
     5      -.5169555380620395d-14,-.1052386016211945d-13,
     6      -.1496621984505107d-01,0.1373415498566148d-01,
     7      -.8532621658484981d-02,0.4158496609652963d-02,
     8      -.1691330592249712d-02,0.5944071689962144d-03/
         data arr1197/
     1      -.1846437399882682d-03,0.5151660961163256d-04,
     2      -.1306628701956976d-04,0.3041167259817182d-05,
     3      -.6545027535131308d-06,0.1310665052200213d-06,
     4      -.2455136288752874d-07,0.4321443576343738d-08,
     5      -.7175280696054326d-09,0.1127723710126757d-09,
     6      -.1680087757408356d-10,0.2376872832872390d-11,
     7      -.3361918908737258d-12,-.2175789625238119d-14,
     8      -.2953547022655406d-01,0.3328194474521692d-01/
         data arr1198/
     1      -.2539008896878594d-01,0.1519473280187925d-01,
     2      -.7588574501927295d-02,0.3274844769100721d-02,
     3      -.1249154769702680d-02,0.4279607285745477d-03,
     4      -.1332857807574085d-03,0.3809315237284244d-04,
     5      -.1006683748947015d-04,0.2475416204499704d-05,
     6      -.5693863076516318d-06,0.1230645540517288d-06,
     7      -.2509055923258114d-07,0.4842360949685578d-08,
     8      -.8861077018255992d-09,0.1545615434074619d-09/
         data arr1199/
     1      -.2490736726914011d-10,0.3800251757905631d-11,
     2      -.5022619829945624d-01,0.6774637095017584d-01,
     3      -.6186321500680757d-01,0.4431515312314551d-01,
     4      -.2649172951534508d-01,0.1368458879426653d-01,
     5      -.6248103381129696d-02,0.2562281243779623d-02,
     6      -.9552072749842650d-03,0.3267771179578514d-03,
     7      -.1033686076978530d-03,0.3042529229083189d-04,
     8      -.8376901213530857d-05,0.2167205711192636d-05/
         data arr1200/
     1      -.5288618179262344d-06,0.1221749322574781d-06,
     2      -.2672807041449582d-07,0.5581727040342372d-08,
     3      -.1056681571645546d-08,0.2009258294005624d-09,
     4      -.7574292909804849d-01,0.1198356994240323d+00,
     5      -.1283574426422241d+00,0.1078522510224828d+00,
     6      -.7562678911232346d-01,0.4582320818694473d-01,
     7      -.2454089156958265d-01,0.1180476423058775d-01,
     8      -.5161982448163451d-02,0.2071375962952101d-02/
         data arr1201/
     1      -.7685713251591408d-03,0.2653497535660408d-03,
     2      -.8569432298324198d-04,0.2600504708426130d-04,
     3      -.7442617568004725d-05,0.2016784857877341d-05,
     4      -.5163943384987114d-06,0.1265119768839346d-06,
     5      -.2756597712935677d-07,0.6164961135991451d-08,
     6      -.1034618543281996d+00,0.1888736994715189d+00,
     7      -.2334282626294801d+00,0.2263125852402871d+00,
     8      -.1831058685479852d+00,0.1280145115932385d+00/
         data arr1202/
     1      -.7910631530259407d-01,0.4390613896093443d-01,
     2      -.2215294762884732d-01,0.1025701638708196d-01,
     3      -.4391296202856863d-02,0.1749340997237206d-02,
     4      -.6518450699407400d-03,0.2282435787654942d-03,
     5      -.7534950699944733d-04,0.2355990812995994d-04,
     6      -.6936350495623447d-05,0.1961187756428871d-05,
     7      -.4822493275374850d-06,0.1245147596398623d-06,
     8      -.1300851940478359d+00,0.2703158633759778d+00/
         data arr1203/
     1      -.3802821303860957d+00,0.4196755043439810d+00,
     2      -.3865090014132467d+00,0.3075877162686594d+00,
     3      -.2163582007800118d+00,0.1366909907167959d+00,
     4      -.7850519773534330d-01,0.4137522983174380d-01,
     5      -.2016333100238250d-01,0.9143171601764782d-02,
     6      -.3877859632755063d-02,0.1545619561207427d-02,
     7      -.5804645154527772d-03,0.2066074282921493d-03,
     8      -.6888000077909393d-04,0.2217554457731741d-04/
         data arr1204/
     1      -.6049585624855773d-05,0.1778889898008604d-05,
     2      -.1524420429540756d+00,0.3565046328327189d+00,
     3      -.5644380941300305d+00,0.7010367310866359d+00,
     4      -.7266135844643815d+00,0.6507731763112737d+00,
     5      -.5151701677646985d+00,0.3662975451237797d+00,
     6      -.2367601304707034d+00,0.1404324595864519d+00,
     7      -.7701926994546889d-01,0.3930538033895277d-01,
     8      -.1875861401444852d-01,0.8414674701718054d-02/
         data arr1205/
     1      -.3552644028739480d-02,0.1423263201726949d-02,
     2      -.5300562270891594d-03,0.1921453734621686d-03,
     3      -.5729775347906566d-04,0.1897451146897627d-04,
     4      -.1681485951612444d+00,0.4383166598431857d+00,
     5      -.7735233549206466d+00,0.1070858789396499d+01,
     6      -.1237169571463069d+01,0.1235064640443593d+01,
     7      -.1089794957580175d+01,0.8636991459420031d+00,
     8      -.6222558357095634d+00,0.4113986003111340d+00/
         data arr1206/
     1      -.2514843687722672d+00,0.1430544535039123d+00,
     2      -.7607623131603690d-01,0.3803998789606667d-01,
     3      -.1786804778365659d-01,0.7980457588048204d-02,
     4      -.3279314879276679d-02,0.1325956227517744d-02,
     5      -.4266246698091953d-03,0.1576196079443593d-03,
     6      -.1759646615203248d+00,0.5070774525235635d+00,
     7      -.9892677301135748d+00,0.1514002976650334d+01,
     8      -.1933649310921313d+01,0.2133989733251594d+01/
         data arr1207/
     1      -.2081615553558009d+01,0.1823780710382241d+01,
     2      -.1452532965859176d+01,0.1061636228428143d+01,
     3      -.7173545490313732d+00,0.4511147977787124d+00,
     4      -.2650447457216272d+00,0.1465232995966683d+00,
     5      -.7585543006526420d-01,0.3746552247592325d-01,
     6      -.1679245879146520d-01,0.7513487778574607d-02,
     7      -.2578599628829203d-02,0.1054472060719583d-02,
     8      -.1758261097714796d+00,0.5561540726186377d+00/
         data arr1208/
     1      -.1190960876963943d+01,0.2000660135754812d+01,
     2      -.2804701333268203d+01,0.3397538157825021d+01,
     3      -.3637743579621490d+01,0.3498388833283424d+01,
     4      -.3058190744988202d+01,0.2453478495300105d+01,
     5      -.1819296279238639d+01,0.1255856183127929d+01,
     6      -.8089700104788975d+00,0.4909800602055138d+00,
     7      -.2777113254460130d+00,0.1506361385338141d+00,
     8      -.7284941482986670d-01,0.3582639318996839d-01/
         data arr1209/
     1      -.1298225629793672d-01,0.5836741782556609d-02,
     2      -.1686325084017550d+00,0.5818720194820335d+00,
     3      -.1359264285090812d+01,0.2490888295298792d+01,
     4      -.3809253017465560d+01,0.5033762010213703d+01,
     5      -.5879287017312282d+01,0.6167911429721041d+01,
     6      -.5881107252890390d+01,0.5147119468106671d+01,
     7      -.4161498559724433d+01,0.3134043133710082d+01,
     8      -.2197803351962393d+01,0.1455602232359753d+01/
         data arr1210/
     1      -.8920534488826903d+00,0.5282702328395890d+00,
     2      -.2728155078946282d+00,0.1466261515362599d+00,
     3      -.5559358582704878d-01,0.2732403913426751d-01,
     4      -.1559082830573910d+00,0.5836833850540640d+00,
     5      -.1479361537976581d+01,0.2941352265322637d+01,
     6      -.4880311084173023d+01,0.6997206957317792d+01,
     7      -.8866465489535070d+01,0.1009240387142692d+02,
     8      -.1043808599590531d+02,0.9912412191317985d+01/
         data arr1211/
     1      -.8687060349692267d+01,0.7099713729184362d+01,
     2      -.5383639151542305d+01,0.3870877350384796d+01,
     3      -.2549245632779368d+01,0.1639968620237694d+01,
     4      -.8954524489919227d+00,0.5234274244832822d+00,
     5      -.2059738022511962d+00,0.1101425259275908d+00,
     6      -.1394465100264859d+00,0.5637278593260312d+00,
     7      -.1542819794086131d+01,0.3312402065867153d+01,
     8      -.5934388299931254d+01,0.9187855418679995d+01/
         data arr1212/
     1      -.1256960890401608d+02,0.1545049171962154d+02,
     2      -.1724519004070740d+02,0.1768685923589181d+02,
     3      -.1670820453568409d+02,0.1475120371423420d+02,
     4      -.1201390837156364d+02,0.9336858684962971d+01,
     5      -.6553781153205612d+01,0.4560970299596551d+01,
     6      -.2607906137316571d+01,0.1651335314613623d+01,
     7      -.6695213650561616d+00,0.3879775707702118d+00,
     8      -.1210100904451021d+00,0.5260327340273265d+00/
         data arr1213/
     1      -.1548002324549217d+01,0.3573825969731331d+01,
     2      -.6883934050530707d+01,0.1146105792887989d+02,
     3      -.1685353045994361d+02,0.2227903758099232d+02,
     4      -.2670742233564918d+02,0.2946410754181227d+02,
     5      -.2983689724070738d+02,0.2834685044334014d+02,
     6      -.2462389582451609d+02,0.2061060965911188d+02,
     7      -.1529193066093976d+02,0.1147322601945102d+02,
     8      -.6806517573673374d+01,0.4653542428032781d+01/
         data arr1214/
     1      -.1931159852757377d+01,0.1208831835276548d+01,
     2      -.1021258180386402d+00,0.4756032470262278d+00,
     3      -.1499247465616375d+01,0.3708233232256543d+01,
     4      -.7649565856564784d+01,0.1364572136670015d+02,
     5      -.2147839636443693d+02,0.3042657989906428d+02,
     6      -.3898589214557440d+02,0.4610895943801457d+02,
     7      -.4976424641335853d+02,0.5071738233306896d+02,
     8      -.4664311933069147d+02,0.4192821069540651d+02/
         data arr1215/
     1      -.3260508923876607d+02,0.2630335956869108d+02,
     2      -.1604588994800186d+02,0.1181528512685267d+02,
     3      -.4988414053195792d+01,0.3364681140726010d+01,
     4      -.8397515549080474d-01,0.4175972221563289d+00,
     5      -.1405237501225833d+01,0.3711758991115649d+01,
     6      -.8169275242829590d+01,0.1556582671648991d+02,
     7      -.2611478212168070d+02,0.3952857153024306d+02,
     8      -.5385747923826389d+02,0.6810644688538623d+02/
         data arr1216/
     1      -.7784852684446071d+02,0.8490819800097981d+02,
     2      -.8201244948538393d+02,0.7901353919924011d+02,
     3      -.6384756796552990d+02,0.5527860539359985d+02,
     4      -.3437501943107331d+02,0.2721328985612343d+02,
     5      -.1162391541285693d+02,0.8433864605439883d+01,
     6      -.6736590700488682d-01,0.3566973020529702d+00,
     7      -.1277027831909921d+01,0.3592405790681570d+01,
     8      -.8402856768328570d+01,0.1705971649569927d+02/
         data arr1217/
     1      -.3036644595009360d+02,0.4900455570806039d+02,
     2      -.7058144437036148d+02,0.9526068195359564d+02,
     3      -.1145008133117488d+03,0.1334528018824492d+03,
     4      -.1342020204900614d+03,0.1384184873229898d+03,
     5      -.1152076957641225d+03,0.1069395265436417d+03,
     6      -.6721281862575786d+02,0.5715385868372133d+02,
     7      -.2456791942688907d+02,0.1915823658612400d+02,
     8      -.5275950140919350d-01,0.2967137828686153d+00/
         data arr1218/
     1      -.1126130711211788d+01,0.3366708064327975d+01,
     2      -.8331247536435614d+01,0.1799268740226623d+02,
     3      -.3379391943312194d+02,0.5807136828976736d+02,
     4      -.8779052346801495d+02,0.1263693600826445d+03,
     5      -.1584168185454658d+03,0.1972323559427769d+03,
     6      -.2045247139118262d+03,0.2258252174550275d+03,
     7      -.1918632397449248d+03,0.1909374643584974d+03,
     8      -.1202638936188653d+03,0.1098527833925850d+03/
         data arr1219/
     1      -.4727560418635353d+02,0.3962626966274220d+02,
     2      -.4030978238785050d-01,0.2403037005220941d+00,
     3      -.9626361498304944d+00,0.3054903007587548d+01,
     4      -.7950854688111940d+01,0.1826025897624219d+02,
     5      -.3593737411602444d+02,0.6577589265773631d+02,
     6      -.1034582047166508d+03,0.1589726640036547d+03,
     7      -.2058793930289425d+03,0.2741385443075155d+03,
     8      -.2900580802376224d+03,0.3433561131933305d+03/
         data arr1220/
     1      -.2950102451541235d+03,0.3152151762821296d+03,
     2      -.1972250976712418d+03,0.1938052586018512d+03,
     3      -.8305983038687692d+02,0.7494638232475019d+02,
     4      0.5807344792537314d-13,-.5968654250000030d-15,
     5      0.4179919259580301d-17,-.2309043601539103d-19,
     6      0.1069561590483557d-21,-.4012030208257578d-24,
     7      0.2216941290241098d-26,-.1900402023166733d-26,
     8      -.1854488066619740d-26,-.1103282637934157d-25/
         data arr1221/
     1      0.2348076719642786d-26,0.5865611595783832d-26,
     2      -.4322785726918862d-26,-.1079170585713408d-26,
     3      0.1905042367471881d-26,-.2846972965837542d-26,
     4      -.8017791766194864d-27,0.3610986722423328d-26,
     5      -.6317443685077772d-26,0.1046029536491191d-08,
     6      -.5575945386297467d-10,0.2025283084964350d-11,
     7      -.5802641216456292d-13,0.1394061591362308d-14,
     8      -.2906102661900076d-16,0.5374838507872007d-18/
         data arr1222/
     1      -.8990432818189116d-20,0.1092349725350734d-21,
     2      -.1972724484322293d-21,0.7037057094749876d-22,
     3      0.1119615490741986d-21,-.3231237771088135d-22,
     4      -.9183590586194732d-23,0.1065549702541702d-21,
     5      -.4271274136049767d-22,0.4609429600670715d-22,
     6      0.7733899190872554d-22,-.8652377790871769d-22,
     7      0.1729672147904093d-06,-.2208939156558340d-07,
     8      0.1922190275278032d-08,-.1319416031128826d-09/
         data arr1223/
     1      0.7594224068838147d-11,-.3792848383527737d-12,
     2      0.1680526717306957d-13,-.6709882084962801d-15,
     3      0.2442127671058440d-16,-.8512335824398865d-18,
     4      0.3881364654199003d-19,0.1650275963010805d-19,
     5      -.4709875733049050d-20,-.4225265907004123d-20,
     6      0.1918476076895437d-19,-.9096990404012594d-20,
     7      0.7761500311070414d-20,0.1145162771432454d-19,
     8      -.1398273963252077d-19,0.4867835908929506d-05/
         data arr1224/
     1      -.1117947728254583d-05,0.1749442714016382d-06,
     2      -.2159487591569108d-07,0.2235208137030381d-08,
     3      -.2007547110356229d-09,0.1599598986228241d-10,
     4      -.1148530717618923d-11,0.7518642636355772d-13,
     5      -.4529590067336564d-14,0.2532638261389359d-15,
     6      -.1273933972991917d-16,0.5749228633164262d-18,
     7      -.1613667330547537d-18,0.5695931059851998d-18,
     8      -.2897501719314137d-18,0.2797886076937478d-18/
         data arr1225/
     1      0.3484492091733660d-18,-.3994737582649575d-18,
     2      0.5324960633287316d-04,-.1892194712045215d-04,
     3      0.4581502289889692d-05,-.8750296119237281d-06,
     4      0.1401373376461193d-06,-.1947446332007250d-07,
     5      0.2400903587324045d-08,-.2667288568944549d-09,
     6      0.2701662617578279d-10,-.2517811642533632d-11,
     7      0.2174903232188716d-12,-.1751516444726034d-13,
     8      0.1320962182575487d-14,-.9527631882501511d-16/
         data arr1226/
     1      0.8336467661194159d-17,-.4193783900660380d-17,
     2      0.1585339827228559d-17,0.4190391497388696d-17,
     3      -.6626120991074137d-17,0.3230666834229851d-03,
     4      -.1619943070963718d-03,0.5534775277016894d-04,
     5      -.1491670808821051d-04,0.3371027220275187d-05,
     6      -.6610465634948088d-06,0.1150004208627658d-06,
     7      -.1802822066970244d-07,0.2576749095918128d-08,
     8      -.3388602139729864d-09,0.4130368165895674d-10/
         data arr1227/
     1      -.4694696318208160d-11,0.5001464108234051d-12,
     2      -.5015856084111429d-13,0.4753987778863097d-14,
     3      -.4522133617533444d-15,0.5458374279824297d-16,
     4      0.3773504891178331d-16,-.3648822887583086d-16,
     5      0.1310103376534210d-02,-.8713843209796860d-03,
     6      0.3949176801124991d-03,-.1411809733587798d-03,
     7      0.4232159591914370d-04,-.1100850705098990d-04,
     8      0.2540343229397232d-05,-.5282535568056915d-06/
         data arr1228/
     1      0.1001516920308898d-06,-.1747041612220182d-07,
     2      0.2824670408738668d-08,-.4258763803435613d-09,
     3      0.6018166890830759d-10,-.8005685616365714d-11,
     4      0.1006157169712649d-11,-.1201038568963921d-12,
     5      0.1373062583880571d-13,-.1224072295007910d-14,
     6      -.4414748955979214d-16,0.3964709039031600d-02,
     7      -.3346769564516090d-02,0.1925009873025838d-02,
     8      -.8733993622289099d-03,0.3322837090466464d-03/
         data arr1229/
     1      -.1096947272808658d-03,0.3212625047861572d-04,
     2      -.8478526593847362d-05,0.2040077009979310d-05,
     3      -.4516498039018754d-06,0.9267800008903079d-07,
     4      -.1773382927846181d-07,0.3180479108824301d-08,
     5      -.5369485070181811d-09,0.8565654030226729d-10,
     6      -.1294797615361533d-10,0.1862067695486549d-11,
     7      -.2477211496669503d-12,0.3164083337073027d-13,
     8      0.9607669878901966d-02,-.9958812238744256d-02/
         data arr1230/
     1      0.7033794519324934d-02,-.3918723022321859d-02,
     2      0.1830693879866230d-02,-.7421085155979424d-03,
     3      0.2668804035399301d-03,-.8648723507252174d-04,
     4      0.2555366343240487d-04,-.6946777826539830d-05,
     5      0.1750383535841263d-05,-.4112763800863233d-06,
     6      0.9057300320805250d-07,-.1877608022429093d-07,
     7      0.3678041961776191d-08,-.6822077956721534d-09,
     8      0.1204759657971900d-09,-.1959278940329553d-10/
         data arr1231/
     1      0.3152360450210938d-11,0.1955669275235043d-01,
     2      -.2426474926871230d-01,0.2051392974294863d-01,
     3      -.1368027029667932d-01,0.7649917697027594d-02,
     4      -.3711926526611093d-02,0.1597863090434626d-02,
     5      -.6198203264290231d-03,0.2192087547766394d-03,
     6      -.7133111624376639d-04,0.2151393060191726d-04,
     7      -.6050763011489752d-05,0.1595020594419691d-05,
     8      -.3957659454548008d-06,0.9279948658931579d-07/
         data arr1232/
     1      -.2057731343790621d-07,0.4350277652547679d-08,
     2      -.8350931126829994d-09,0.1609876844259708d-09,
     3      0.3459358666049128d-01,-.5034593113440866d-01,
     4      0.4992589090115324d-01,-.3905350596770379d-01,
     5      0.2561595211333586d-01,-.1457946209367808d-01,
     6      0.7361563880926869d-02,-.3349536513355062d-02,
     7      0.1389521240948726d-02,-.5303646091973287d-03,
     8      0.1876306208901560d-03,-.6189832381526962d-04/
         data arr1233/
     1      0.1913922005232821d-04,-.5569618172635652d-05,
     2      0.1531899446884956d-05,-.3975885940342767d-06,
     3      0.9861661532737233d-07,-.2181954302228448d-07,
     4      0.4936891438733250d-08,0.5452314061633846d-01,
     5      -.9155809739742145d-01,0.1047623701234599d+00,
     6      -.9455546392652739d-01,0.7156228750871164d-01,
     7      -.4699615423159549d-01,0.2738028821138867d-01,
     8      -.1437473056468325d-01,0.6880615849288027d-02/
         data arr1234/
     1      -.3030282457280465d-02,0.1236971181776510d-02,
     2      -.4708379829801451d-03,0.1679833733358057d-03,
     3      -.5638812267118223d-04,0.1789614792597951d-04,
     4      -.5341190413650640d-05,0.1529193097589247d-05,
     5      -.3823340601508394d-06,0.9988952669355566d-07,
     6      0.7803346824293345d-01,-.1491589233401754d+00,
     7      0.1942720086521171d+00,-.1995923900189757d+00,
     8      0.1719467606825227d+00,-.1285359244327143d+00/
         data arr1235/
     1      0.8524180950105623d-01,-.5094089862229086d-01,
     2      0.2775534948719922d-01,-.1391402334961454d-01,
     3      0.6465204207718941d-02,-.2801043754231610d-02,
     4      0.1137557200476400d-02,-.4344079153692850d-03,
     5      0.1569501967579609d-03,-.5304979586196647d-04,
     6      0.1729841648680577d-04,-.4805305122722306d-05,
     7      0.1430385356279186d-05,0.1029140228636887d+00,
     8      -.2213908350099037d+00,0.3245169481624052d+00/
         data arr1236/
     1      -.3752216407782572d+00,0.3637932654081048d+00,
     2      -.3060566841588690d+00,0.2284266568183767d+00,
     3      -.1536302551445718d+00,0.9420497855582856d-01,
     4      -.5314838263486593d-01,0.2779317612472204d-01,
     5      -.1354971681480651d-01,0.6193194989492595d-02,
     6      -.2658894274550338d-02,0.1081323923310227d-02,
     7      -.4083514858838635d-03,0.1499799519449983d-03,
     8      -.4561442098247089d-04,0.1529859722062925d-04/
         data arr1237/
     1      0.1265311207448984d+00,-.3034008208530352d+00,
     2      0.4957112956474151d+00,-.6388716121926885d+00,
     3      0.6904221269069660d+00,-.6474346672015726d+00,
     4      0.5386110918360117d+00,-.4037728651362700d+00,
     5      0.2759747850138811d+00,-.1735410473010437d+00,
     6      0.1011555488174593d+00,-.5495182107928780d-01,
     7      0.2799834468551495d-01,-.1337438462379074d-01,
     8      0.6064458091151678d-02,-.2527352745420216d-02/
         data arr1238/
     1      0.1035873101016729d-02,-.3405164439905227d-03,
     2      0.1274792775951931d-03,0.1463806516059970d+00,
     3      -.3880227220147584d+00,0.7008471936197938d+00,
     4      -.9985321554702475d+00,0.1192936556984609d+01,
     5      -.1236663821041157d+01,0.1137327449462026d+01,
     6      -.9425275606692468d+00,0.7121689793007432d+00,
     7      -.4950242476076449d+00,0.3189926572585094d+00,
     8      -.1914518938761210d+00,0.1078518838769215d+00/
         data arr1239/
     1      -.5678859354296211d-01,0.2848050862718148d-01,
     2      -.1294877986532526d-01,0.5876486835985892d-02,
     3      -.2064310710991417d-02,0.8558319136981879d-03,
     4      0.1605478500729492d+00,-.4671332536346049d+00,
     5      0.9261256840000701d+00,-.1448341202769250d+01,
     6      0.1899281768330180d+01,-.2161141135404645d+01,
     7      0.2181631091941592d+01,-.1984414445504754d+01,
     8      0.1645855029635194d+01,-.1255449531484077d+01/
         data arr1240/
     1      0.8880665358571393d+00,-.5843687037925831d+00,
     2      0.3614425207928333d+00,-.2079648288284134d+00,
     3      0.1145722410063658d+00,-.5621440707075209d-01,
     4      0.2806243659947921d-01,-.1042860663650495d-01,
     5      0.4755848323978684d-02,0.1679719739573630d+00,
     6      -.5331471353582454d+00,0.1153057226699509d+01,
     7      -.1967088052587346d+01,0.2813959599839425d+01,
     8      -.3492813900895737d+01,0.3846381603285869d+01/
         data arr1241/
     1      -.3816157334673582d+01,0.3452857247005737d+01,
     2      -.2871788528248473d+01,0.2216337343096285d+01,
     3      -.1587701040262503d+01,0.1071800558366437d+01,
     4      -.6682986258665273d+00,0.4021173450615685d+00,
     5      -.2107116227885815d+00,0.1150667852295790d+00,
     6      -.4483200135165508d-01,0.2236096046660252d-01,
     7      0.1684948334940928d+00,-.5802525293769006d+00,
     8      0.1361581517670952d+01,-.2520174055320733d+01/
         data arr1242/
     1      0.3911562674133885d+01,-.5267451691017792d+01,
     2      0.6293781044790634d+01,-.6773085101563010d+01,
     3      0.6649753438088752d+01,-.5995002618941205d+01,
     4      0.5021364822095607d+01,-.3889550317346235d+01,
     5      0.2851288539835245d+01,-.1910986536787066d+01,
     6      0.1249755650872628d+01,-.6924181598329090d+00,
     7      0.4117222365388327d+00,-.1668338989646549d+00,
     8      0.9056825182291206d-01,0.1627340219700524d+00/
         data arr1243/
     1      -.6051405895002360d+00,0.1533344112065727d+01,
     2      -.3064474964987338d+01,0.5136187656929980d+01,
     3      -.7467406619512263d+01,0.9635324808298016d+01,
     4      -.1119000544860393d+02,0.1186595432810127d+02,
     5      -.1153114837603182d+02,0.1043522159643039d+02,
     6      -.8681189767768219d+01,0.6881587542631982d+01,
     7      -.4917139391724898d+01,0.3481163638314399d+01,
     8      -.2019544230705075d+01,0.1302591938987036d+01/
         data arr1244/
     1      -.5449918633215167d+00,0.3206959666507974d+00,
     2      0.1518518565060485d+00,-.6071657841402053d+00,
     3      0.1654359331928376d+01,-.3554745904840018d+01,
     4      0.6406997310711967d+01,-.1001230229455856d+02,
     5      0.1389431437073940d+02,-.1732954992610031d+02,
     6      0.1976960061065345d+02,-.2059413854944024d+02,
     7      0.2006058484533533d+02,-.1779772082052518d+02,
     8      0.1520442167526337d+02,-.1148671985749688d+02/
         data arr1245/
     1      0.8775185683133628d+01,-.5280497160009474d+01,
     2      0.3683164821330557d+01,-.1580772225604851d+01,
     3      0.1004875639863084d+01,0.1372924902982175d+00,
     4      -.5880206003197114d+00,0.1716575333150535d+01,
     5      -.3949906850827093d+01,0.7628409443933418d+01,
     6      -.1275948832271520d+02,0.1897712785860338d+02,
     7      -.2529582627273029d+02,0.3094505000459903d+02,
     8      -.3435486266785369d+02,0.3591463810348364d+02/
         data arr1246/
     1      -.3372613764296717d+02,0.3097132609612085d+02,
     2      -.2453048255513881d+02,0.2017227463223077d+02,
     3      -.1247624328089548d+02,0.9388776093187019d+01,
     4      -.4109093167440685d+01,0.2814146787056117d+01,
     5      0.1205430349360383d+00,-.5510896787226196d+00,
     6      0.1718197926844161d+01,-.4217739051947179d+01,
     7      0.8702160922936500d+01,-.1551286106142766d+02,
     8      0.2465834834077651d+02,-.3494306150334053d+02/
         data arr1247/
     1      0.4572755789113131d+02,-.5375927982367249d+02,
     2      0.6018737702456019d+02,-.5933506783324919d+02,
     3      0.5847480358217987d+02,-.4813577611452891d+02,
     4      0.4253906940532973d+02,-.2680098091147659d+02,
     5      0.2172508549830276d+02,-.9643165202616990d+01,
     6      0.7100456549954071d+01,0.1029512231156467d+00,
     7      -.5006672294096456d+00,0.1662916513927216d+01,
     8      -.4337082199236924d+01,0.9538128360649978d+01/
         data arr1248/
     1      -.1803617723902488d+02,0.3057984230493849d+02,
     2      -.4578855007197439d+02,0.6400588329240401d+02,
     3      -.7910780086291771d+02,0.9474551855972558d+02,
     4      -.9717472442427555d+02,0.1027018543327714d+03,
     5      -.8709140727227815d+02,0.8264523647140238d+02,
     6      -.5257885170612583d+02,0.4587313050871290d+02,
     7      -.2054606597651165d+02,0.1624338273840245d+02,
     8      0.8560905015812256d-01,-.4411934187450659d+00/
         data arr1249/
     1      0.1558346016620448d+01,-.4297380485411700d+01,
     2      0.1006136769104905d+02,-.2006674323256867d+02,
     3      0.3625982511221966d+02,-.5694124236531400d+02,
     4      0.8500907531342658d+02,-.1095282982291607d+03,
     5      0.1403467499956578d+03,-.1482686952598992d+03,
     6      0.1681311548776612d+03,-.1455420539521449d+03,
     7      0.1483308137100001d+03,-.9446497131976065d+02,
     8      0.8871691296176860d+02,-.3990059232437235d+02/
         data arr1250/
     1      0.3385125955907921d+02,0.6926943586130838d-01,
     2      -.3765057997886713d+00,0.1413763666557723d+01,
     3      -.4095643268972756d+01,0.1021381414494500d+02,
     4      -.2132855014831579d+02,0.4111341273059890d+02,
     5      -.6707942906555701d+02,0.1071406308348219d+03,
     6      -.1424949753807439d+03,0.1957078268310396d+03,
     7      -.2106177361836797d+03,0.2567865441239644d+03,
     8      -.2247822804791327d+03,0.2464242547978177d+03/
         data arr1251/
     1      -.1557010324985538d+03,0.1576311749984856d+03,
     2      -.7084787433353004d+02,0.6454095931207227d+02,
     3      -.1595189947422988d-15,0.1526290710923279d-17,
     4      -.9998451823173779d-20,0.5188217243045299d-22,
     5      -.2265839498939316d-24,0.8592885057307030d-27,
     6      -.4172499314915718d-29,-.2803155272578734d-29,
     7      -.1251831178487980d-28,-.7487695454381240d-29,
     8      0.3307689973539606d-29,-.2864742480842362d-29/
         data arr1252/
     1      -.3639762761534597d-29,-.1387838659620364d-28,
     2      0.7945849640426858d-29,0.1787103523178711d-28,
     3      -.1950225994214695d-29,-.8427590585868642d-29,
     4      -.1490234088781753d-10,0.7395288206380928d-12,
     5      -.2512617350738649d-13,0.6762192132959718d-15,
     6      -.1531678105607441d-16,0.3020310027074610d-18,
     7      -.5299242391229725d-20,0.8362444951472290d-22,
     8      -.2240775936965715d-23,-.1035183394640637d-23/
         data arr1253/
     1      0.3212434804999868d-24,-.3522277192209835d-24,
     2      -.4667212810195942d-24,-.1710963696036990d-23,
     3      0.7547042361530149d-24,0.1874110374102511d-23,
     4      -.4300326289038650d-24,-.1136605811414512d-23,
     5      -.5903638222914472d-08,0.7018846490566540d-09,
     6      -.5713239005493398d-10,0.3683739764673573d-11,
     7      -.1999007077271939d-12,0.9443742989287493d-14,
     8      -.3969585797107292d-15,0.1507550831457606d-16/
         data arr1254/
     1      -.5235475188393489d-18,0.1617143040859146d-19,
     2      -.3696313245850687d-21,-.7520364995120605d-22,
     3      -.1437894311997652d-21,-.7245890120153199d-21,
     4      0.4072859560717968d-21,0.1035851247783568d-20,
     5      -.3087823342402059d-22,-.5194134723570159d-21,
     6      -.2987840982466894d-06,0.6388061583528853d-07,
     7      -.9350855567247154d-08,0.1084235205254765d-08,
     8      -.1058070242693284d-09,0.8988970208162855d-11/
         data arr1255/
     1      -.6794798187170890d-12,0.4640609184066355d-13,
     2      -.2896525199086513d-14,0.1666631389878146d-15,
     3      -.8904990686687461d-17,0.4426728893237372d-18,
     4      -.3018106672898565d-19,-.4286288052418973d-19,
     5      0.2523933715171232d-19,0.7091981777298414d-19,
     6      -.1187026394351586d-20,-.3218770032109307d-19,
     7      -.5057103086815438d-05,0.1672928100955769d-05,
     8      -.3788989364943069d-06,0.6797659355423296d-07/
         data arr1256/
     1      -.1026394339728395d-07,0.1349191339614552d-08,
     2      -.1577989180082040d-09,0.1667502310770825d-10,
     3      -.1610390596365859d-11,0.1434050326566447d-12,
     4      -.1185995127973435d-13,0.9163974957873369d-15,
     5      -.6672369539762404d-16,0.3764401774006854d-17,
     6      0.1333227319872309d-18,0.1696618884071669d-17,
     7      -.7099234875255176d-19,-.5784503491892645d-18,
     8      -.4329479969733205d-04,0.2021014179962540d-04/
         data arr1257/
     1      -.6459124072609691d-05,0.1635188387767569d-05,
     2      -.3484021300904110d-06,0.6462465749082909d-07,
     3      -.1066563916639178d-07,0.1590404053385079d-08,
     4      -.2167356708894150d-09,0.2723480783353337d-10,
     5      -.3178324644553104d-11,0.3465073747515243d-12,
     6      -.3546897000156121d-13,0.3413658663784288d-14,
     7      -.3089831732222585d-15,0.4447315222131549d-16,
     8      -.2654296608770005d-17,-.6129381455648027d-17/
         data arr1258/
     1      -.2328872558080961d-03,0.1442035478368126d-03,
     2      -.6113315472983847d-04,0.2052898943755082d-04,
     3      -.5801992653469233d-05,0.1427549655037707d-05,
     4      -.3125190186611994d-06,0.6181496617195123d-07,
     5      -.1117411542343049d-07,0.1862532321021988d-08,
     6      -.2883195366374286d-09,0.4169498462529325d-10,
     7      -.5660861851076182d-11,0.7245726838915800d-12,
     8      -.8773246454441671d-13,0.1022629779876892d-13/
         data arr1259/
     1      -.1095954579672913d-14,0.9492884851825136d-16,
     2      -.8944617902074082d-03,0.7029142205842709d-03,
     3      -.3781930176696068d-03,0.1611812741259025d-03,
     4      -.5781419758705365d-04,0.1805339422617273d-04,
     5      -.5015963976682665d-05,0.1259162866314436d-05,
     6      -.2888761841371939d-06,0.6111006282426505d-07,
     7      -.1200585837043393d-07,0.2203500065451768d-08,
     8      -.3796804510462257d-09,0.6168073479676194d-10/
         data arr1260/
     1      -.9476723297155456d-11,0.1383597319522217d-11,
     2      -.1878936381997972d-12,0.2479958129569690d-13,
     3      -.2661604526899677d-02,0.2568378615393685d-02,
     4      -.1696856843862660d-02,0.8880169688064532d-03,
     5      -.3911255300502844d-03,0.1499738396052794d-03,
     6      -.5116653828972830d-04,0.1577206348101853d-04,
     7      -.4443174027583623d-05,0.1154168720964680d-05,
     8      -.2784354296874905d-06,0.6275081314713496d-07/
         data arr1261/
     1      -.1327671081176879d-07,0.2648496724808142d-08,
     2      -.4993351550589756d-09,0.8948785967225517d-10,
     3      -.1476231223900823d-10,0.2405885930965688d-11,
     4      -.6485027024249821d-02,0.7490628042192840d-02,
     5      -.5923730803781111d-02,0.3710755140247169d-02,
     6      -.1956357055226215d-02,0.8979215396029504d-03,
     7      -.3666906502865423d-03,0.1352985807802383d-03,
     8      -.4562353550433621d-04,0.1418586571483699d-04/
         data arr1262/
     1      -.4096386415839652d-05,0.1105062608674574d-05,
     2      -.2798497175492980d-06,0.6682330681976229d-07,
     3      -.1506171271399300d-07,0.3231285738797501d-08,
     4      -.6291185160702833d-09,0.1228313688723958d-09,
     5      -.1345551608021963d-01,0.1823035776673370d-01,
     6      -.1691066413745123d-01,0.1242556191337764d-01,
     7      -.7684051213114085d-02,0.4136841769027961d-02,
     8      -.1981612527006424d-02,0.8576311285839385d-03/
         data arr1263/
     1      -.3392223534088026d-03,0.1237199668393890d-03,
     2      -.4190538121365025d-04,0.1326003801255517d-04,
     3      -.3938347591767306d-05,0.1103094900569410d-05,
     4      -.2910283400827221d-06,0.7324967496502631d-07,
     5      -.1644149649862358d-07,0.3768417679970060d-08,
     6      -.2446993081758856d-01,0.3825380886281948d-01,
     7      -.4094371691373669d-01,0.3471280825899029d-01,
     8      -.2476914811664901d-01,0.1538639367033385d-01/
         data arr1264/
     1      -.8504205335316138d-02,0.4246808283539589d-02,
     2      -.1938175391557160d-02,0.8156346228930226d-03,
     3      -.3187592292296261d-03,0.1163822252818720d-03,
     4      -.3987317247384363d-04,0.1288673133252886d-04,
     5      -.3909877452859081d-05,0.1135831298698371d-05,
     6      -.2881800085529424d-06,0.7629139223814217d-07,
     7      -.3986439909448190d-01,0.7093810761920596d-01,
     8      -.8642604008248880d-01,0.8340643013325252d-01/
         data arr1265/
     1      -.6774438055068396d-01,0.4790176154073203d-01,
     2      -.3013704278988236d-01,0.1713097328860859d-01,
     3      -.8899442726284026d-02,0.4263029025446517d-02,
     4      -.1896322024717511d-02,0.7881214442976512d-03,
     5      -.3071846510941580d-03,0.1130176491977277d-03,
     6      -.3883671695136087d-04,0.1284848160978914d-04,
     7      -.3623111952189951d-05,0.1093230916210603d-05,
     8      -.5916918951572545d-01,0.1184968351844409d+00/
         data arr1266/
     1      -.1624757365124212d+00,0.1764656537875436d+00,
     2      -.1613060376611830d+00,0.1283646986512385d+00,
     3      -.9088889321026336d-01,0.5814457054262102d-01,
     4      -.3399386048034173d-01,0.1832627230189848d-01,
     5      -.9173276171958678d-02,0.4290753524576004d-02,
     6      -.1880260358643597d-02,0.7786502013542619d-03,
     7      -.2989771472627790d-03,0.1113961190944502d-03,
     8      -.3440428958884824d-04,0.1170226675041054d-04/
         data arr1267/
     1      -.8108728020209297d-01,0.1810081722515995d+00,
     2      -.2766395231519980d+00,0.3349039217440341d+00,
     3      -.3412280468663925d+00,0.3026732954290054d+00,
     4      -.2388753238036251d+00,0.1703352875118791d+00,
     5      -.1109975913798021d+00,0.6669993722559643d-01,
     6      -.3720321898645561d-01,0.1939763546469959d-01,
     7      -.9458351615658160d-02,0.4366991501844639d-02,
     8      -.1850659408817869d-02,0.7693636095905919d-03/
         data arr1268/
     1      -.2569226226894437d-03,0.9760656241413618d-04,
     2      -.1037034347182519d+00,0.2559132100992749d+00,
     3      -.4323771072432140d+00,0.5786592066965536d+00,
     4      -.6517791754676113d+00,0.6391227799385045d+00,
     5      -.5576073490677447d+00,0.4395598382938501d+00,
     6      -.3166211622931159d+00,0.2103370543414774d+00,
     7      -.1296181746004574d+00,0.7472042464293545d-01,
     8      -.4016433298781612d-01,0.2050898779415592d-01/
         data arr1269/
     1      -.9483242308697144d-02,0.4364428337446644d-02,
     2      -.1558082274473498d-02,0.6560192638806264d-03,
     3      -.1248466141399066d+00,0.3381732756360944d+00,
     4      -.6271501362893812d+00,0.9212868436618091d+00,
     5      -.1139022033222739d+01,0.1225970345802653d+01,
     6      -.1173998375120155d+01,0.1015841060581976d+01,
     7      -.8030032133975555d+00,0.5855704624587500d+00,
     8      -.3956458562048002d+00,0.2504041781914064d+00/
         data arr1270/
     1      -.1471037105003445d+00,0.8250598877619339d-01,
     2      -.4117658455909511d-01,0.2084084386224516d-01,
     3      -.7873744334215716d-02,0.3650224512788069d-02,
     4      -.1424895674142072d+00,0.4210369124793542d+00,
     5      -.8517740755678317d+00,0.1364970114066780d+01,
     6      -.1840877604863787d+01,0.2161477041629619d+01,
     7      -.2257682893682406d+01,0.2131134244308389d+01,
     8      -.1836874407204671d+01,0.1461390704673312d+01/
         data arr1271/
     1      -.1075003202961387d+01,0.7425052516962488d+00,
     2      -.4728001810001551d+00,0.2895831277994966d+00,
     3      -.1543715216144010d+00,0.8545071954562045d-01,
     4      -.3385797905924257d-01,0.1718813175869388d-01,
     5      -.1550790131969503d+00,0.4971789988647362d+00,
     6      -.1091267061415848d+01,0.1897382763973937d+01,
     7      -.2776202881522673d+01,0.3536785758854833d+01,
     8      -.4007064791345254d+01,0.4104241276271428d+01/
         data arr1272/
     1      -.3834711557536585d+01,0.3310896986969209d+01,
     2      -.2633732369675760d+01,0.1975139722349593d+01,
     3      -.1352252119789040d+01,0.9000496122948997d+00,
     4      -.5073585200008045d+00,0.3057323006678287d+00,
     5      -.1260203450771370d+00,0.6973552749271827d-01,
     6      -.1617306023242311d+00,0.5598969371823302d+00,
     7      -.1326954718135006d+01,0.2491400760763840d+01,
     8      -.3935709503336773d+01,0.5414525950458930d+01/
         data arr1273/
     1      -.6620271960053874d+01,0.7323505847635165d+01,
     2      -.7376378522439661d+01,0.6880383923348040d+01,
     3      -.5878858368266297d+01,0.4766479343512003d+01,
     4      -.3480346106183562d+01,0.2507236486314760d+01,
     5      -.1479944941388796d+01,0.9671912856100269d+00,
     6      -.4116994108450463d+00,0.2474098733432553d+00,
     7      -.1622716925749335d+00,0.6040822480582917d+00,
     8      -.1539241335352490d+01,0.3107789876644989d+01/
         data arr1274/
     1      -.5277062694236745d+01,0.7807708333795589d+01,
     2      -.1025277997653891d+02,0.1220087028562622d+02,
     3      -.1317516716321793d+02,0.1322606249272723d+02,
     4      -.1205388046790346d+02,0.1052940290884650d+02,
     5      -.8132514978383938d+01,0.6320740516730983d+01,
     6      -.3869643353063113d+01,0.2734567530476326d+01,
     7      -.1194057952501223d+01,0.7769660853733509d+00,
     8      -.1571541727523859d+00,0.6267901486992450d+00/
         data arr1275/
     1      -.1710324972613181d+01,0.3700122297108725d+01,
     2      -.6725118643491005d+01,0.1066348150780835d+02,
     3      -.1496627920235969d+02,0.1909575011124522d+02,
     4      -.2198156834382253d+02,0.2367640500271711d+02,
     5      -.2284418600915116d+02,0.2144267014241511d+02,
     6      -.1737192062974880d+02,0.1453188297588181d+02,
     7      -.9141450167253359d+01,0.6970083564305715d+01,
     8      -.3102968849971190d+01,0.2181437448956554d+01/
         data arr1276/
     1      -.1472812194045563d+00,0.6273536771569329d+00,
     2      -.1826214746861956d+01,0.4220573403124695d+01,
     3      -.8176530955742612d+01,0.1385455921473216d+02,
     4      -.2067433759350271d+02,0.2821191057480750d+02,
     5      -.3440279380780402d+02,0.3967133286362222d+02,
     6      -.4019249939311728d+02,0.4046859662625015d+02,
     7      -.3409505710258006d+02,0.3064991210694333d+02,
     8      -.1962958065944810d+02,0.1612695567571237d+02/
         data arr1277/
     1      -.7277922662031889d+01,0.5520182788177415d+01,
     2      -.1337967432096976d+00,0.6070933565533100d+00,
     3      -.1877647803423419d+01,0.4625069186604698d+01,
     4      -.9506615805516052d+01,0.1717829677486121d+02,
     5      -.2709001011365740d+02,0.3947364434090731d+02,
     6      -.5063198759712394d+02,0.6243240955138710d+02,
     7      -.6581920170024665d+02,0.7103677832720069d+02,
     8      -.6168929228210979d+02,0.5956042529825469d+02/
         data arr1278/
     1      -.3848065565560881d+02,0.3404985273741899d+02,
     2      -.1549234944958782d+02,0.1267104685939842d+02,
     3      -.1178786827313107d+00,0.5687360884154963d+00,
     4      -.1859831250694513d+01,0.4876543661187855d+01,
     5      -.1057619837442202d+02,0.2036113631785696d+02,
     6      -.3368157122446298d+02,0.5239111719848992d+02,
     7      -.7010585447217470d+02,0.9244048400141328d+02,
     8      -.1003904759129184d+03,0.1162005461741014d+03/
         data arr1279/
     1      -.1030629896445742d+03,0.1069306473968426d+03,
     2      -.6904632908187334d+02,0.6584742329097571d+02,
     3      -.3004440168325428d+02,0.2651075138868071d+02,
     4      -.1005347101261040d+00,0.5155720581539428d+00,
     5      -.1771031360026703d+01,0.4945554954175625d+01,
     6      -.1123783148648957d+02,0.2306925601732133d+02,
     7      -.3965561677672427d+02,0.6595402596326630d+02,
     8      -.9118580859445856d+02,0.1288154663249611d+03/
         data arr1280/
     1      -.1424792217615419d+03,0.1772760856371528d+03,
     2      -.1590484179057914d+03,0.1777167675579864d+03,
     3      -.1135672285174138d+03,0.1169950941978345d+03,
     4      -.5323887114956266d+02,0.5078130504048119d+02,
     5      0.3815726777305586d-18,-.3429440683302052d-20,
     6      0.2118080839923686d-22,-.1039622172888689d-24,
     7      0.4307056661329178d-27,-.1674428742069132d-29,
     8      -.3733768569163613d-31,0.1341149021393495d-30/
         data arr1281/
     1      0.7367768634871718d-32,0.2497634120069501d-30,
     2      -.4293588478357616d-31,0.6590131891812663d-31,
     3      0.4750182075627670d-31,-.8090023605814679d-31,
     4      0.2064724088871876d-31,-.1968813946635400d-30,
     5      -.2777018711109281d-31,0.1848822051594957d-12,
     6      -.8618206413210885d-14,0.2760653378346487d-15,
     7      -.7027821018215320d-17,0.1510156348105371d-18,
     8      -.2832579733535083d-20,0.4736451824335737d-22/
         data arr1282/
     1      -.6530417427209701d-24,0.1282801461756084d-25,
     2      0.1208696225369572d-24,-.2168723689495973d-25,
     3      0.3167905009861501d-25,0.2276051990473982d-25,
     4      -.3931907867729965d-25,0.9095130206658857d-26,
     5      -.9583956946364952d-25,-.1179762514913016d-25,
     6      0.1754711622641507d-09,-.1959624812050830d-10,
     7      0.1503880461458649d-11,-.9172073510731559d-13,
     8      0.4721871567252839d-14,-.2121833325418642d-15/
         data arr1283/
     1      0.8503837981466403d-17,-.3085380321019708d-18,
     2      0.1025670171627665d-19,-.1999766878356726d-21,
     3      -.1172421485646296d-22,0.3030549513806694d-22,
     4      0.2046173606144314d-22,-.3671085340792968d-22,
     5      0.7564142673283664d-23,-.9061373065961135d-22,
     6      -.1371042935401196d-22,0.1597015395882141d-07,
     7      -.3207316999312812d-08,0.4426371690072238d-09,
     8      -.4854759224349513d-10,0.4494485109451786d-11/
         data arr1284/
     1      -.3631972451433734d-12,0.2617657349765505d-13,
     2      -.1708266955316315d-14,0.1020854694316534d-15,
     3      -.5625070360241097d-17,0.2874734422358891d-18,
     4      -.1119776000140710d-19,0.2445044916510882d-20,
     5      -.3258736851908805d-20,0.6636456322022303d-21,
     6      -.8345995108704670d-20,-.1226611105394540d-20,
     7      0.4182320252389299d-06,-.1299612630416157d-06,
     8      0.2775132811009835d-07,-.4709420213834852d-08/
         data arr1285/
     1      0.6745956699339094d-09,-.8434706971264424d-10,
     2      0.9405981738143541d-11,-.9497564032551822d-12,
     3      0.8781784323096809d-13,-.7500615892421832d-14,
     4      0.5959528855031458d-15,-.4423878927020027d-16,
     5      0.3147309682502175d-17,-.2790214840000393d-18,
     6      0.3498959127697675d-19,-.2217840851989651d-18,
     7      -.2579918169416073d-19,0.5052535449906261d-05,
     8      -.2215461279425612d-05,0.6675628638926955d-06/
         data arr1286/
     1      -.1598578607142721d-06,0.3231232874694676d-07,
     2      -.5701023939949015d-08,0.8971088775702177d-09,
     3      -.1278237240983377d-09,0.1667785182145499d-10,
     4      -.2010145088425129d-11,0.2253821669940061d-12,
     5      -.2364321360565253d-13,0.2332557422877195d-14,
     6      -.2178551671550541d-15,0.1942248161056305d-16,
     7      -.4337564837826478d-17,-.2014702813425234d-18,
     8      0.3605088695920294d-04,-.2096849908293441d-04/
         data arr1287/
     1      0.8380924842831568d-05,-.2662136805020684d-05,
     2      0.7137748275304542d-06,-.1670484421030174d-06,
     3      0.3486834349365026d-07,-.6590133741578809d-08,
     4      0.1140563491888267d-08,-.1823492558228071d-09,
     5      0.2712021766722737d-10,-.3773892278073524d-11,
     6      0.4937421435256249d-12,-.6097369889178000d-13,
     7      0.7136540935779016d-14,-.8048285016006590d-15,
     8      0.8205169117127495d-16,0.1757285551460695d-03/
         data arr1288/
     1      -.1297191348822389d-03,0.6580197961668385d-04,
     2      -.2652697313517614d-04,0.9026697113153345d-05,
     3      -.2681145523613668d-05,0.7102636472376960d-06,
     4      -.1703698787624803d-06,0.3742211822271254d-07,
     5      -.7593171539765256d-08,0.1433252524428364d-08,
     6      -.2531206374996515d-09,0.4202856716951962d-10,
     7      -.6584934282127595d-11,0.9779694301581555d-12,
     8      -.1355281861108379d-12,0.1820225636591550d-13/
         data arr1289/
     1      0.6420946538484412d-03,-.5820170958236903d-03,
     2      0.3625314094180942d-03,-.1794607010244009d-03,
     3      0.7498691980303459d-04,-.2734966513682048d-04,
     4      0.8896643660716620d-05,-.2620441089278093d-05,
     5      0.7067811132030153d-06,-.1760980468187265d-06,
     6      0.4081586990637879d-07,-.8851187828373064d-08,
     7      0.1804652986521979d-08,-.3469877352535275d-09,
     8      0.6328113825346431d-10,-.1065724901390293d-10/
         data arr1290/
     1      0.1758096472100761d-11,0.1872657010548355d-02,
     2      -.2031822903227844d-02,0.1514909442336037d-02,
     3      -.8976381790936299d-03,0.4489607698082482d-03,
     4      -.1960043972793942d-03,0.7631869240242525d-04,
     5      -.2690729381423769d-04,0.8687033249837288d-05,
     6      -.2590783447725450d-05,0.7187811682389760d-06,
     7      -.1865693682692862d-06,0.4553282493888466d-07,
     8      -.1046777496071819d-07,0.2285239511784391d-08/
         data arr1291/
     1      -.4550969698289174d-09,0.8982543556895501d-10,
     2      0.4557589441684939d-02,-.5800309946813095d-02,
     3      0.5072714409206230d-02,-.3525684496967059d-02,
     4      0.2068420884746427d-02,-.1059216453272628d-02,
     5      0.4837692017775978d-03,-.2000624484531766d-03,
     6      0.7576270190610003d-04,-.2650333336081194d-04,
     7      0.8624916929930340d-05,-.2625669043907451d-05,
     8      0.7516498377306438d-06,-.2023086735349178d-06/
         data arr1292/
     1      0.5181135634550917d-07,-.1192425203456589d-07,
     2      0.2759118976274435d-08,0.9563452215731983d-02,
     3      -.1404357904299846d-01,0.1417144462941575d-01,
     4      -.1136486460036572d-01,0.7693196841278033d-02,
     5      -.4545689037313119d-02,0.2395522977155501d-02,
     6      -.1143073928780945d-02,0.4994722802025974d-03,
     7      -.2016020474403330d-03,0.7570033513519898d-04,
     8      -.2658454392653070d-04,0.8781292515351537d-05/
         data arr1293/
     1      -.2718946492431770d-05,0.8035837803583494d-06,
     2      -.2096571198770790d-06,0.5593947903446950d-07,
     3      0.1773452690526611d-01,-.2964388719760806d-01,
     4      0.3405053252455562d-01,-.3108325380880106d-01,
     5      0.2395088088286045d-01,-.1610892824843909d-01,
     6      0.9663172725047896d-02,-.5248612225743607d-02,
     7      0.2610563673928539d-02,-.1199355830817725d-02,
     8      0.5126333274164934d-03,-.2048293858571519d-03/
         data arr1294/
     1      0.7701713213730703d-04,-.2702211081918162d-04,
     2      0.9093176014748948d-05,-.2645668774646907d-05,
     3      0.8029612479109639d-06,0.2962420880226986d-01,
     4      -.5572871798853407d-01,0.7204180160471810d-01,
     5      -.7401228901936779d-01,0.6418235083922698d-01,
     6      -.4858217239025982d-01,0.3279796858552311d-01,
     7      -.2004857247446145d-01,0.1122253371611657d-01,
     8      -.5801887862402240d-02,0.2790957254817109d-02/
         data arr1295/
     1      -.1253984165703178d-02,0.5306762460581577d-03,
     2      -.2081902127441455d-03,0.7887559497855943d-04,
     3      -.2523135546065508d-04,0.8611953961026875d-05,
     4      0.4525204312587525d-01,-.9488657478796401d-01,
     5      0.1367239547537628d+00,-.1565661934802905d+00,
     6      0.1513366632675851d+00,-.1276843749813118d+00,
     7      0.9608213702805894d-01,-.6546361991683368d-01,
     8      0.4084550851048247d-01,-.2353122925565312d-01/
         data arr1296/
     1      0.1261772551188480d-01,-.6310004513963944d-02,
     2      0.2976790915350323d-02,-.1290117132055220d-02,
     3      0.5451173783979722d-03,-.1893583467815217d-03,
     4      0.7198940285165802d-04,0.6397830303536935d-01,
     5      -.1483041328607495d+00,0.2362366418697917d+00,
     6      -.2990570028213799d+00,0.3195615164933484d+00,
     7      -.2980547322473284d+00,0.2479458114206712d+00,
     8      -.1867390065457812d+00,0.1288071013674158d+00/
         data arr1297/
     1      -.8199146890065934d-01,0.4860676921252398d-01,
     2      -.2680918349990442d-01,0.1398418458258778d-01,
     3      -.6620728187261490d-02,0.3095019245795291d-02,
     4      -.1154834007611264d-02,0.4850323044857385d-03,
     5      0.8454332228263554d-01,-.2151107743280811d+00,
     6      0.3761138447067347d+00,-.5226204145653978d+00,
     7      0.6129860118467468d+00,-.6275350454062422d+00,
     8      0.5730157677034982d+00,-.4736222988660090d+00/
         data arr1298/
     1      0.3586037165874261d+00,-.2503123724401345d+00,
     2      0.1629092428493264d+00,-.9827041694383420d-01,
     3      0.5628246197185538d-01,-.2880348222764895d-01,
     4      0.1479568150808809d-01,-.5873050310370494d-02,
     5      0.2706081909836372d-02,0.1052592467163240d+00,
     6      -.2921563649173073d+00,0.5572470769805115d+00,
     7      -.8446590525699218d+00,0.1080743163674539d+01,
     8      -.1206815750470873d+01,0.1202144676496819d+01/
         data arr1299/
     1      -.1083518631856902d+01,0.8950068335403872d+00,
     2      -.6803233230398444d+00,0.4831539485887705d+00,
     3      -.3162337353775799d+00,0.1976725811792298d+00,
     4      -.1082537495079153d+00,0.6074888674532070d-01,
     5      -.2543412532261079d-01,0.1277951625640694d-01,
     6      0.1242948368860012d+00,-.3743026849862002d+00,
     7      0.7746049575599157d+00,-.1273837711722639d+01,
     8      0.1768414744078272d+01,-.2142013598543346d+01/
         data arr1300/
     1      0.2315211762088133d+01,-.2262422154386054d+01,
     2      0.2027933278851827d+01,-.1667619824773101d+01,
     3      0.1285640800482935d+01,-.9060495745311956d+00,
     4      0.6149530059882113d+00,-.3568990838279615d+00,
     5      0.2177196066691707d+00,-.9541253492423062d-01,
     6      0.5201083011323882d-01,0.1399745872514072d+00,
     7      -.4551461726749600d+00,0.1017116905816326d+01,
     8      -.1805936189205523d+01,0.2707351999228104d+01/
         data arr1301/
     1      -.3539248613950022d+01,0.4131451485647476d+01,
     2      -.4353539262038362d+01,0.4215116051855829d+01,
     3      -.3725404671191596d+01,0.3104087865416057d+01,
     4      -.2337645288984845d+01,0.1715209586570927d+01,
     5      -.1045070983093672d+01,0.6901478916548272d+00,
     6      -.3144182070888564d+00,0.1851359522492166d+00,
     7      0.1510218124180037d+00,-.5279703706641776d+00,
     8      0.1268773883579398d+01,-.2421648887559833d+01/
         data arr1302/
     1      0.3904171661552163d+01,-.5482246050210358d+01,
     2      0.6883775816878106d+01,-.7781049754519721d+01,
     3      0.8105560177299461d+01,-.7648166596631976d+01,
     4      0.6862202461987261d+01,-.5480438085850222d+01,
     5      0.4331195376641078d+01,-.2745375601711332d+01,
     6      0.1955863828042548d+01,-.9206426721942446d+00,
     7      0.5834158564544296d+00,0.1567014529923190d+00,
     8      -.5866811781589775d+00,0.1510643217643365d+01/
         data arr1303/
     1      -.3086794593426033d+01,0.5332743136049084d+01,
     2      -.8005535054994125d+01,0.1077636365471726d+02,
     3      -.1299635460396955d+02,0.1451866536386626d+02,
     4      -.1452201508292040d+02,0.1398963309736349d+02,
     5      -.1175783942324330d+02,0.9978766985478563d+01,
     6      -.6522133663311866d+01,0.4998714058990184d+01,
     7      -.2417600558652675d+01,0.1643900046525543d+01,
     8      0.1568493467462589d+00,-.6265054933403719d+00/
         data arr1304/
     1      0.1723248454635551d+01,-.3754605461217860d+01,
     2      0.6930104962592688d+01,-.1106633283260968d+02,
     3      0.1592747305901336d+02,-.2037690369065349d+02,
     4      0.2434985476259142d+02,-.2562013848757397d+02,
     5      0.2644208431885049d+02,-.2320642912541054d+02,
     6      0.2110178570300455d+02,-.1409953804554053d+02,
     7      0.1160094064749325d+02,-.5735814905150432d+01,
     8      0.4175215829412050d+01,0.1518006706960565d+00/
         data arr1305/
     1      -.6443144648832095d+00,0.1888688135418097d+01,
     2      -.4369119462876034d+01,0.8596304332465557d+01,
     3      -.1451783867207316d+02,0.2230103918245931d+02,
     4      -.3007390566789674d+02,0.3837482979767236d+02,
     5      -.4211666447942385d+02,0.4650848300835774d+02,
     6      -.4228818304284223d+02,0.4113584688572467d+02,
     7      -.2786178928353307d+02,0.2457662549389935d+02,
     8      -.1236439716654016d+02,0.9619330736583759d+01/
         data arr1306/
     1      0.1422455081039952d+00,-.6385415680031704d+00,
     2      0.1991976556447256d+01,-.4868547583427068d+01,
     3      0.1019692808787936d+02,-.1808681254521777d+02,
     4      0.2963215498367716d+02,-.4181764995403556d+02,
     5      0.5693640782961542d+02,-.6457761575968550d+02,
     6      0.7627576100249055d+02,-.7128367750938673d+02,
     7      0.7412883637762721d+02,-.5047036407449804d+02,
     8      0.4770319200614971d+02,-.2431320156910549d+02/
         data arr1307/
     1      0.2019977009052005d+02,0.1290176599129095d+00,
     2      -.6086950690621012d+00,0.2021277024494838d+01,
     3      -.5188166504388951d+01,0.1156851276408868d+02,
     4      -.2136484219305035d+02,0.3736735943335734d+02,
     5      -.5473173544866035d+02,0.7956769216885199d+02,
     6      -.9230966914223636d+02,0.1167483634756466d+03,
     7      -.1112405666797016d+03,0.1237353792451792d+03,
     8      -.8396360361838229d+02,0.8509382564138360d+02/
         data arr1308/
     1      -.4375198067529351d+02,0.3883013965656498d+02,
     2      -.8083269209378886d-21,0.6871961678934675d-23,
     3      -.4026439883717350d-25,0.1879841153064870d-27,
     4      -.7427582095125360d-30,0.2103415507549528d-32,
     5      0.3270957558538093d-33,0.1287963446257056d-33,
     6      0.2252494502159523d-33,-.3188849006027190d-33,
     7      0.9816206899480391d-33,0.1265051885793432d-32,
     8      0.1066682364006412d-32,0.8860855010935685d-33/
         data arr1309/
     1      0.5300393114077939d-33,0.4746340405116783d-35,
     2      -.2031330732144997d-14,0.8956742285723756d-16,
     3      -.2721863378843103d-17,0.6590863018003011d-19,
     4      -.1350353169621700d-20,0.2420036791056846d-22,
     5      -.3872750208768393d-24,0.5506434695334499d-26,
     6      -.6182648053940591d-27,-.1686690315814549d-26,
     7      0.2393997418360031d-27,0.1420426062336345d-26,
     8      0.6904668403394026d-27,0.7652608636183100d-27/
         data arr1310/
     1      -.5735685406429716d-27,-.1307994870340761d-26,
     2      -.4618879977272013d-11,0.4879232513375069d-12,
     3      -.3552328795939710d-13,0.2060793705410222d-14,
     4      -.1011544112109977d-15,0.4343374331334606d-17,
     5      -.1666616515991213d-18,0.5800782137767667d-20,
     6      -.1864804056311119d-21,0.1709316690052356d-23,
     7      0.3267596570831976d-24,0.2983616773477685d-23,
     8      0.1481352345911888d-23,0.1878285260206022d-23/
         data arr1311/
     1      -.1206590335403125d-23,-.2831131612175983d-23,
     2      -.7559718665427851d-09,0.1436104612033202d-09,
     3      -.1880240162590481d-10,0.1961554116700984d-11,
     4      -.1731474909423767d-12,0.1336978771188961d-13,
     5      -.9225723822712505d-15,0.5774817604798055d-16,
     6      -.3315831751513460d-17,0.1755262358349688d-18,
     7      -.8647988914085246d-20,0.8304797803199557d-21,
     8      0.2132447317646113d-21,0.3304665685675357d-21/
         data arr1312/
     1      -.1661510725853681d-21,-.4385807949760786d-21,
     2      -.3063216346276265d-07,0.9003719768572511d-08,
     3      -.1823950605849463d-08,0.2944176877110629d-09,
     4      -.4021088769997807d-10,0.4804142026312839d-11,
     5      -.5129271491451097d-12,0.4967727227488708d-13,
     6      -.4413144021296792d-14,0.3626915090638691d-15,
     7      -.2776980811080162d-16,0.2006833410472871d-17,
     8      -.1256928516994977d-18,0.2266282865864433d-19/
         data arr1313/
     1      -.5581612026289959d-20,-.1623212664774927d-19,
     2      -.5221892313793768d-06,0.2165859929495775d-06,
     3      -.6191268323065865d-07,0.1410225641549781d-07,
     4      -.2717856523222714d-08,0.4582018743384446d-09,
     5      -.6903270165952449d-10,0.9434417680390366d-11,
     6      -.1182667737187906d-11,0.1371632075627730d-12,
     7      -.1481965495532971d-13,0.1500316591449902d-14,
     8      -.1427848044975450d-15,0.1311880598786914d-16/
         data arr1314/
     1      -.1147089661411380d-17,-.1530557361319185d-18,
     2      -.4942322630949471d-05,0.2719131076788286d-05,
     3      -.1031041151116656d-05,0.3115168739337330d-06,
     4      -.7963722006760206d-07,0.1780914306730486d-07,
     5      -.3559079000274967d-08,0.6452001430064501d-09,
     6      -.1072849090766878d-09,0.1650483784239424d-10,
     7      -.2365415463176686d-11,0.3176071192489681d-12,
     8      -.4013428759293479d-13,0.4796851595367999d-14/
         data arr1315/
     1      -.5372164478468009d-15,0.5594319717777132d-16,
     2      -.3057509330829919d-04,0.2134898129326991d-04,
     3      -.1027385251777927d-04,0.3939573599656140d-05,
     4      -.1278185976548695d-05,0.3627699409473721d-06,
     5      -.9201025061921703d-07,0.2116914684454268d-07,
     6      -.4467430438231885d-08,0.8722497064967771d-09,
     7      -.1586518252498341d-09,0.2703563205548769d-10,
     8      -.4334723338091270d-11,0.6572491666670538d-12/
         data arr1316/
     1      -.9281130889286671d-13,0.1269935097332437d-13,
     2      -.1371827450744996d-03,0.1176207208806730d-03,
     3      -.6950483063664772d-04,0.3272697486940583d-04,
     4      -.1303844126809723d-04,0.4543995610815074d-05,
     5      -.1415199935805772d-05,0.3998157750109023d-06,
     6      -.1036070047841894d-06,0.2483974869035593d-07,
     7      -.5547782761544959d-08,0.1160878810942833d-08,
     8      -.2284158454682195d-09,0.4252988756295219d-10/
         data arr1317/
     1      -.7308404032465470d-11,0.1229301966039353d-11,
     2      -.4789052510141195d-03,0.4915015252403185d-03,
     3      -.3476537718577270d-03,0.1959425439742810d-03,
     4      -.9344143005818943d-04,0.3898007120217794d-04,
     5      -.1453159957883241d-04,0.4914128148209537d-05,
     6      -.1524283275923664d-05,0.4374363877036067d-06,
     7      -.1169389775504447d-06,0.2929009293164893d-07,
     8      -.6890766920457022d-08,0.1535986460660348d-08/
         data arr1318/
     1      -.3123316329608658d-09,0.6292456886180270d-10,
     2      -.1367146165453184d-02,0.1645805880905090d-02,
     3      -.1365491734174900d-02,0.9027328832611550d-03,
     4      -.5049616307277882d-03,0.2470870157155404d-03,
     5      -.1080460734909484d-03,0.4285785847589531d-04,
     6      -.1559319259587224d-04,0.5248961495095969d-05,
     7      -.1645740891611347d-05,0.4835248627361795d-06,
     8      -.1331770275246921d-06,0.3482917996773614d-07/
         data arr1319/
     1      -.8191031739869752d-08,0.1937218311426112d-08,
     2      -.3310103324348468d-02,0.4597823774555015d-02,
     3      -.4401593135270445d-02,0.3357586369997932d-02,
     4      -.2167072211857168d-02,0.1223522754931708d-02,
     5      -.6173305355929940d-03,0.2825442500638944d-03,
     6      -.1186122104955258d-03,0.4606987074464338d-04,
     7      -.1666311158636247d-04,0.5649070138578322d-05,
     8      -.1789854877549718d-05,0.5403187589580766d-06/
         data arr1320/
     1      -.1441771185309849d-06,0.3938432717584192d-07,
     2      -.6987131217239205d-02,0.1104745155344876d-01,
     3      -.1203849247297171d-01,0.1045302143307605d-01,
     4      -.7679630086874811d-02,0.4935503475842693d-02,
     5      -.2834575510048955d-02,0.1476758958263348d-02,
     6      -.7056385265466690d-03,0.3119808333037671d-03,
     7      -.1283895878085080d-03,0.4954914325556835d-04,
     8      -.1778850751325277d-04,0.6116280540602054d-05/
         data arr1321/
     1      -.1821770439818811d-05,0.5671829649313287d-06,
     2      -.1313538477255131d-01,0.2337344688329128d-01,
     3      -.2866483673581218d-01,0.2801147495235931d-01,
     4      -.2316064029515296d-01,0.1675169290551487d-01,
     5      -.1082747783488744d-01,0.6348439243034923d-02,
     6      -.3413524237279397d-02,0.1698551481597643d-02,
     7      -.7860480611080191d-03,0.3414556841196865d-03,
     8      -.1370516404626433d-03,0.5308070960949860d-04/
         data arr1322/
     1      -.1740082152306776d-04,0.6106551361690976d-05,
     2      -.2236497990973566d-01,0.4435910857924431d-01,
     3      -.6063783020682875d-01,0.6604874069369919d-01,
     4      -.6087112152627665d-01,0.4907434813832098d-01,
     5      -.3535449859366224d-01,0.2310587023959225d-01,
     6      -.1384448927049860d-01,0.7679205680688106d-02,
     7      -.3955672055963806d-02,0.1915799505516241d-02,
     8      -.8492919423495792d-03,0.3671092026994189d-03/
         data arr1323/
     1      -.1308253063170161d-03,0.5127266907634705d-04,
     2      -.3495561745265284d-01,0.7664528830686673d-01,
     3      -.1158243101578588d+00,0.1394681289526195d+00,
     4      -.1420918956407113d+00,0.1266394615243239d+00,
     5      -.1008513473307085d+00,0.7286563417833805d-01,
     6      -.4823897624017569d-01,0.2958364222221927d-01,
     7      -.1680849745512170d-01,0.9003234796632124d-02,
     8      -.4358500843825148d-02,0.2086366475941568d-02/
         data arr1324/
     1      -.7995037090309771d-03,0.3472033306228771d-03,
     2      -.5070208394114688d-01,0.1220274499892607d+00,
     3      -.2024102035294805d+00,0.2675293595704534d+00,
     4      -.2991648114159757d+00,0.2926711761458956d+00,
     5      -.2557898424502023d+00,0.2028659079335001d+00,
     6      -.1472671132443362d+00,0.9916035388068919d-01,
     7      -.6162445655326496d-01,0.3625645853247336d-01,
     8      -.1896175155959979d-01,0.9986637651323821d-02/
         data arr1325/
     1      -.4075521853712859d-02,0.1948225814979887d-02,
     2      -.6886185341286703d-01,0.1807948547642734d+00,
     3      -.3271359949577420d+00,0.4716768540584127d+00,
     4      -.5753226186921877d+00,0.6140064827348264d+00,
     5      -.5851900697026554d+00,0.5063432560425835d+00,
     6      -.4002462431538032d+00,0.2941340950969676d+00,
     7      -.1983650543738036d+00,0.1274491256818092d+00,
     8      -.7126489297209485d-01,0.4107158485738498d-01/
         data arr1326/
     1      -.1769665136767094d-01,0.9259878731218335d-02,
     2      -.8822370748303900d-01,0.2513151745743141d+00,
     3      -.4933593522613298d+00,0.7718084613172799d+00,
     4      -.1021145407778328d+01,0.1182534280692737d+01,
     5      -.1221947851546176d+01,0.1147417974715011d+01,
     6      -.9810420885099220d+00,0.7828799651338040d+00,
     7      -.5685790282007194d+00,0.3969921079797722d+00,
     8      -.2349485015944118d+00,0.1475063189382708d+00/
         data arr1327/
     1      -.6658621831949431d-01,0.3795816952281333d-01,
     2      -.1072778704981503d+00,0.3299968845033753d+00,
     3      -.6994516563596299d+00,0.1181622823314322d+01,
     4      -.1687191810677680d+01,0.2110284057955925d+01,
     5      -.2351557491288003d+01,0.2385457544530793d+01,
     6      -.2191424264261796d+01,0.1891033178058233d+01,
     7      -.1467811972750453d+01,0.1109252342915170d+01,
     8      -.6879560283797518d+00,0.4688015730252370d+00/
         data arr1328/
     1      -.2201699750998639d+00,0.1361994250701041d+00,
     2      -.1244399327589861d+00,0.4116467414603285d+00,
     3      -.9379523159869432d+00,0.1704057956958460d+01,
     4      -.2613277240769215d+01,0.3516390672427376d+01,
     5      -.4203498906656642d+01,0.4588977698822003d+01,
     6      -.4498282877472809d+01,0.4183377970192594d+01,
     7      -.3443888798701366d+01,0.2807880092389759d+01,
     8      -.1807152418870120d+01,0.1332847247233325d+01/
         data arr1329/
     1      -.6471449287045641d+00,0.4330298740061460d+00,
     2      -.1382699989406194d+00,0.4901243103437766d+00,
     3      -.1195663171924304d+01,0.2327849169956783d+01,
     4      -.3815593804792528d+01,0.5505626099496141d+01,
     5      -.7022524681368492d+01,0.8225359247498707d+01,
     6      -.8539109913251433d+01,0.8537347881912634d+01,
     7      -.7396277268347291d+01,0.6490220041340605d+01,
     8      -.4292876440090840d+01,0.3419789946919911d+01/
         data arr1330/
     1      -.1706757567198357d+01,0.1232223050770902d+01,
     2      -.1476348460880649d+00,0.5591157658376230d+00,
     3      -.1454556869402809d+01,0.3025860087529650d+01,
     4      -.5273098365585358d+01,0.8139592076454548d+01,
     5      -.1101454789295658d+02,0.1381062870319392d+02,
     6      -.1505925330078376d+02,0.1616139185710890d+02,
     7      -.1461772460214693d+02,0.1378313554343906d+02,
     8      -.9279267163992008d+01,0.7974266551398042d+01/
         data arr1331/
     1      -.4069243083789695d+01,0.3163982146297421d+01,
     2      -.1517799865656647d+00,0.6128241185721641d+00,
     3      -.1693118772297551d+01,0.3755209885626908d+01,
     4      -.6914423567308789d+01,0.1140249218460983d+02,
     5      -.1626508007728861d+02,0.2180429613323061d+02,
     6      -.2474139914919697d+02,0.2848849394048766d+02,
     7      -.2668331709030634d+02,0.2701623097923284d+02,
     8      -.1833365711532859d+02,0.1699023527637912d+02/
         data arr1332/
     1      -.8821213793974396d+01,0.7378552699330712d+01,
     2      -.1503048823600272d+00,0.6464078733128237d+00,
     3      -.1887672451762111d+01,0.4458658327767931d+01,
     4      -.8606686529202966d+01,0.1516409800438575d+02,
     5      -.2263464695445123d+02,0.3244024651360690d+02,
     6      -.3790298488196544d+02,0.4686637951939197d+02,
     7      -.4507775594752533d+02,0.4902445061623620d+02,
     8      -.3320365861916099d+02,0.3320587184021903d+02/
         data arr1333/
     1      -.1745872749434468d+02,0.1570583209581606d+02,
     2      -.1430423926358385d+00,0.6560599095642293d+00,
     3      -.2013491799155474d+01,0.5067282675566664d+01,
     4      -.1015076074931080d+02,0.1915044696960892d+02,
     5      -.2965837882335325d+02,0.4552292234203678d+02,
     6      -.5410956380714721d+02,0.7204063964080051d+02,
     7      -.7054170105320728d+02,0.8255581871917711d+02,
     8      -.5522364874700845d+02,0.5973058557765196d+02/
         data arr1334/
     1      -.3165739039175293d+02,0.3065682574792272d+02,
     2      0.1536617343157340d-23,-.1242586379685608d-25,
     3      0.6941047265041380d-28,-.3127805233374020d-30,
     4      -.3704965360922120d-31,-.2173417886662027d-31,
     5      -.1804106344689478d-30,-.4414309788511435d-31,
     6      -.3691391168669177d-30,-.1194858097017712d-30,
     7      -.7949194673014351d-30,-.9958428272566721d-31,
     8      -.6789426895593661d-30,-.1277353242973357d-30/
         data arr1335/
     1      -.7275294646168266d-30,0.2002788460784323d-16,
     2      -.8399852750231839d-18,0.2433837477707701d-19,
     3      -.5631359696100170d-21,0.1104648884930941d-22,
     4      -.1899008689144112d-24,0.2933479749187020d-26,
     5      -.3312813679445557d-28,0.2690975663199006d-28,
     6      0.1981600352937926d-29,-.4728328413131759d-29,
     7      0.1386786168278640d-29,0.3844437967906657d-28,
     8      -.4038520744022860d-29,-.3811035816326346d-28/
         data arr1336/
     1      0.1091029557794214d-12,-.1096272466769129d-13,
     2      0.7609985095829801d-15,-.4218430501222473d-16,
     3      0.1982471401036238d-17,-.8164765319929009d-19,
     4      0.3010103496136452d-20,-.1007769043686891d-21,
     5      0.3249018198231519d-23,-.7690584527543482d-25,
     6      -.2335133358191961d-25,0.4933826912152569d-26,
     7      0.2142976733256317d-24,-.2037398174857142d-25,
     8      -.2104414300203038d-24,0.3211227535309606d-10/
         data arr1337/
     1      -.5802547116434454d-11,0.7243518626017339d-12,
     2      -.7220749514134400d-13,0.6102445480819322d-14,
     3      -.4519664034080047d-15,0.2996410596166162d-16,
     4      -.1804782152838506d-17,0.9989678216868325d-19,
     5      -.5114242018367486d-20,0.2369018820690276d-21,
     6      -.1056111464591841d-22,0.6438706453127146d-22,
     7      -.5252664280499355d-23,-.6268876612032731d-22,
     8      0.2013292945290240d-08,-.5628833772965083d-09/
         data arr1338/
     1      0.1087209364532192d-09,-.1676909937068059d-10,
     2      0.2192780806387027d-11,-.2512819621626920d-12,
     3      0.2577627337695119d-13,-.2402205724406979d-14,
     4      0.2056426120238324d-15,-.1630802362532131d-16,
     5      0.1205840689323061d-17,-.8375769413394070d-19,
     6      0.9460397972312607d-20,-.6033716921917584d-21,
     7      -.3873924905739686d-20,0.4843010032099418d-07,
     8      -.1910666885527331d-07,0.5207603305058590d-08/
         data arr1339/
     1      -.1133424520782732d-08,0.2091395855348608d-09,
     2      -.3381897900497731d-10,0.4895279011549232d-11,
     3      -.6437626731633978d-12,0.7776450055441138d-13,
     4      -.8702411272955368d-14,0.9083495581006690d-15,
     5      -.8893138940296453d-16,0.8297099980649524d-17,
     6      -.7169174913651004d-18,-.3020980565552151d-19,
     7      0.6080161927436136d-06,-.3181862071321852d-06,
     8      0.1150352294329381d-06,-.3321101655825984d-07/
         data arr1340/
     1      0.8128724491198313d-08,-.1743585501906384d-08,
     2      0.3347779161263564d-09,-.5839850677747377d-10,
     3      0.9357366016746787d-11,-.1389020342132390d-11,
     4      0.1923195984660286d-12,-.2497184371633528d-13,
     5      0.3057131272943305d-14,-.3504733455299113d-15,
     6      0.3748202775538741d-16,0.4773777342216771d-05,
     7      -.3170579721019834d-05,0.1454783964611201d-05,
     8      -.5330403999089902d-06,0.1655810665429632d-06/
         data arr1341/
     1      -.4507563305164523d-07,0.1098413094787984d-07,
     2      -.2431761158702004d-08,0.4945191157632709d-09,
     3      -.9316369657856284d-10,0.1637088857163615d-10,
     4      -.2697072524626415d-11,0.4189179466358314d-12,
     5      -.6060994757003577d-13,0.8442133319853613d-14,
     6      0.2630079274519752d-04,-.2144965641161116d-04,
     7      0.1208523639574902d-04,-.5437405882711961d-05,
     8      0.2074040747749128d-05,-.6933035479008778d-06/
         data arr1342/
     1      0.2074542192428924d-06,-.5639651556639107d-07,
     2      0.1408281400786696d-07,-.3257786436686045d-08,
     3      0.7029480325522832d-09,-.1421287222809998d-09,
     4      0.2710799008661642d-10,-.4778884525161010d-11,
     5      0.8176548726299024d-12,0.1099030821483209d-03,
     6      -.1072882832522648d-03,0.7235657965280165d-04,
     7      -.3896777009065725d-04,0.1779188690948423d-04,
     8      -.7119000977122067d-05,0.2549815908090729d-05/
         data arr1343/
     1      -.8297150567293989d-06,0.2480031333969182d-06,
     2      -.6866992273078963d-07,0.1773610730996351d-07,
     3      -.4288148830188158d-08,0.9790313332818734d-09,
     4      -.2045702894776557d-09,0.4187881386025395d-10,
     5      0.3680133827471356d-03,-.4213998979686557d-03,
     6      0.3333562096965484d-03,-.2105835576887935d-03,
     7      0.1127792768338557d-03,-.5293155529657918d-04,
     8      0.2223785147876881d-04,-.8487870987913802d-05/
         data arr1344/
     1      0.2975881971150116d-05,-.9664479480374641d-06,
     2      0.2927920151585463d-06,-.8289169830330391d-07,
     3      0.2220049900429719d-07,-.5375973141761893d-08,
     4      0.1290250911558528d-08,0.1028104650833515d-02,
     5      -.1358361134487715d-02,0.1239870937842606d-02,
     6      -.9037315985543553d-03,0.5584591776291856d-03,
     7      -.3024290924170433d-03,0.1466050303762340d-03,
     8      -.6456459002069963d-04,0.2611917531008506d-04/
         data arr1345/
     1      -.9785747288204053d-05,0.3420766965052355d-05,
     2      -.1114360812100905d-05,0.3444176278686333d-06,
     3      -.9486030010715313d-07,0.2625460741742741d-07,
     4      0.2470285264889712d-02,-.3715159476650081d-02,
     5      0.3860033993614234d-02,-.3202627356672684d-02,
     6      0.2252738831203612d-02,-.1388654837996196d-02,
     7      0.7662529263425713d-03,-.3841055277902373d-03,
     8      0.1768767516115715d-03,-.7540650415176176d-04/
         data arr1346/
     1      0.3000506910309851d-04,-.1107994248360129d-04,
     2      0.3898931154370253d-05,-.1202085963430721d-05,
     3      0.3784948110651298d-06,0.5226461606068789d-02,
     4      -.8846161181470897d-02,0.1034392282916475d-01,
     5      -.9658657334788842d-02,0.7646066844118474d-02,
     6      -.5304384592151846d-02,0.3294047798171894d-02,
     7      -.1858142094120491d-02,0.9629913426628852d-03,
     8      -.4617462163797080d-03,0.2067828904804817d-03/
         data arr1347/
     1      -.8541910270382443d-04,0.3383966037168569d-04,
     2      -.1152001518484970d-04,0.4079979251530924d-05,
     3      0.9918998178616360d-02,-.1871324544130485d-01,
     4      0.2439011576662734d-01,-.2538503703375326d-01,
     5      0.2239927385234660d-01,-.1732033243973244d-01,
     6      0.1198909286938315d-01,-.7536493743027506d-02,
     7      0.4353731444885708d-02,-.2324362427265077d-02,
     8      0.1160292569452829d-02,-.5297904411430933d-03/
         data arr1348/
     1      0.2340586542628747d-03,-.8693712952738019d-04,
     2      0.3430405114704209d-04,0.1713840712244937d-01,
     3      -.3574419361779275d-01,0.5150203502634734d-01,
     4      -.5925659814509278d-01,0.5780274763168426d-01,
     5      -.4940862097835475d-01,0.3780849176978518d-01,
     6      -.2626173515134630d-01,0.1677258680653835d-01,
     7      -.9881498634264539d-02,0.5453510229277592d-02,
     8      -.2721986575930781d-02,0.1330360228551833d-02/
         data arr1349/
     1      -.5335213865839234d-03,0.2326562553839374d-03,
     2      0.2728616481194776d-01,-.6246536197893843d-01,
     3      0.9879186487966855d-01,-.1247614511966533d+00,
     4      0.1335855325169319d+00,-.1253216131308075d+00,
     5      0.1052644132437407d+00,-.8018493732772125d-01,
     6      0.5622010445598155d-01,-.3625541403455779d-01,
     7      0.2196622057872460d-01,-.1185977776490283d-01,
     8      0.6368764116775102d-02,-.2732225833442998d-02/
         data arr1350/
     1      0.1307725695307124d-02,0.4042694367980369d-01,
     2      -.1009574762617690d+00,0.1741787888989819d+00,
     3      -.2399317243221097d+00,0.2802544087951789d+00,
     4      -.2867382738824838d+00,0.2627422713704680d+00,
     5      -.2179833210714050d+00,0.1667657676526373d+00,
     6      -.1168336897461838d+00,0.7724007860460119d-01,
     7      -.4465728864519532d-01,0.2619630338930144d-01,
     8      -.1192354495289500d-01,0.6227385897229834d-02/
         data arr1351/
     1      0.5619570650393672d-01,-.1522589234386992d+00,
     2      0.2850118604531827d+00,-.4258715147598787d+00,
     3      0.5397504863456437d+00,-.5988708334655871d+00,
     4      0.5954304400294925d+00,-.5345227720873572d+00,
     5      0.4438822181022895d+00,-.3354150794458190d+00,
     6      0.2407019969576766d+00,-.1475700983266962d+00,
     7      0.9409639258733249d-01,-.4510778568360663d-01,
     8      0.2558040318760130d-01,0.7378921776846609d-01/
         data arr1352/
     1      -.2158743525882498d+00,0.4363542561569840d+00,
     2      -.7037001775801701d+00,0.9632059563800333d+00,
     3      -.1152944888591261d+01,0.1238016592839359d+01,
     4      -.1194803211507856d+01,0.1072222829292259d+01,
     5      -.8677807636106253d+00,0.6729607208648651d+00,
     6      -.4333167367583261d+00,0.2990954100083733d+00,
     7      -.1500173740844339d+00,0.9199418778999646d-01,
     8      0.9204573693973257d-01,-.2895222425600159d+00/
         data arr1353/
     1      0.6293052655874734d+00,-.1090120146392379d+01,
     2      0.1604987492810643d+01,-.2062389851999909d+01,
     3      0.2382047139057067d+01,-.2455055470175350d+01,
     4      0.2372060334898714d+01,-.2041982774686524d+01,
     5      0.1704836494150683d+01,-.1142055210702762d+01,
     6      0.8504418580549793d+00,-.4436647993921892d+00,
     7      0.2932051400768430d+00,0.1095907359721675d+00,
     8      -.3691820902749279d+00,0.8597440907271213d+00/
         data arr1354/
     1      -.1592124099274843d+01,0.2512873311777077d+01,
     2      -.3449627495519376d+01,0.4270924081339561d+01,
     3      -.4667437606803521d+01,0.4840910907279272d+01,
     4      -.4402027209342528d+01,0.3944618152622338d+01,
     5      -.2723538326405163d+01,0.2182125572809074d+01,
     6      -.1177708638682781d+01,0.8365728238753194d+00,
     7      0.1250084498517386d+00,-.4494067299081952d+00,
     8      0.1117742834552080d+01,-.2201446728154736d+01/
         data arr1355/
     1      0.3714834558577718d+01,-.5421050111269881d+01,
     2      0.7174481761494050d+01,-.8248760144130863d+01,
     3      0.9163650582804307d+01,-.8741514277783150d+01,
     4      0.8387719352285083d+01,-.5913604350831257d+01,
     5      0.5087946446874483d+01,-.2826980085003982d+01,
     6      0.2154324047669041d+01,0.1369932404584456d+00,
     7      -.5237821975512926d+00,0.1387661403069765d+01,
     8      -.2889262478878536d+01,0.5203240646420354d+01/
         data arr1356/
     1      -.8029123458830973d+01,0.1133540708295158d+02,
     2      -.1359139897722232d+02,0.1615114574614669d+02,
     3      -.1605099627880250d+02,0.1646611803683765d+02,
     4      -.1174400410648718d+02,0.1083814927751152d+02,
     5      -.6171597446121921d+01,0.5039963085337822d+01,
     6      0.1444425024480014d+00,-.5853833231906760d+00,
     7      0.1648720174642550d+01,-.3601608953113992d+01,
     8      0.6917595387641924d+01,-.1122308289552961d+02/
         data arr1357/
     1      0.1688263202689063d+02,-.2090142354557424d+02,
     2      0.2656208644881563d+02,-.2731029451522756d+02,
     3      0.2993510850545993d+02,-.2139293058660218d+02,
     4      0.2117267579864981d+02,-.1230393637906842d+02,
     5      0.1076552507886676d+02,0.1464663207221867d+00,
     6      -.6271367651729222d+00,0.1876043137087639d+01,
     7      -.4257269526796811d+01,0.8730500661456858d+01,
     8      -.1480013403525669d+02,0.2372631284689221d+02/
         data arr1358/
     1      -.2998678615768882d+02,0.4080469759898919d+02,
     2      -.4310544377772855d+02,0.5051984283426884d+02,
     3      -.3581252416397550d+02,0.3805562835558197d+02,
     4      -.2247813538539938d+02,0.2109582742499083d+02,
     5      -.2647246164188497d-26,0.2072587601656514d-28,
     6      -.3762655025207015d-30,0.1408540781973981d-29,
     7      -.3691064701025266d-29,0.1065670010021427d-28,
     8      -.7022748911349954d-29,0.2090113090002688d-28/
         data arr1359/
     1      -.2620431551872768d-28,0.5902607727810877d-28,
     2      -.2128832886589254d-28,0.4852759733836321d-28,
     3      -.3461683175343788d-28,0.6421551969823546d-28,
     4      -.1790854623641175d-18,0.7176995175472460d-20,
     5      -.1990986316296398d-21,0.4418591941176634d-23,
     6      -.8327492028731863d-25,0.1377470753065145d-26,
     7      -.2044476973281772d-28,0.4819166490578134d-30,
     8      -.1410432793500644d-31,0.1380314308525807d-30/
         data arr1360/
     1      -.2675846459247379d-30,-.1680824369994137d-30,
     2      0.1982115900925356d-30,-.4775141053305092d-31,
     3      -.2337260752367366d-14,0.2244062177781006d-15,
     4      -.1491440406712044d-16,0.7929885415036816d-18,
     5      -.3580485358767804d-19,0.1418948303143776d-20,
     6      -.5040911341155629d-22,0.1631777883112665d-23,
     7      -.4861519158701533d-25,0.3457656310711415d-26,
     8      -.4326862991491606d-26,-.2207695276736287d-26/
         data arr1361/
     1      0.2547434032079891d-26,-.8415957559932509d-27,
     2      -.1237107201913168d-11,0.2135997111358098d-12,
     3      -.2552920473317549d-13,0.2440978187106853d-14,
     4      -.1982003763081823d-15,0.1412520742885510d-16,
     5      -.9023971166009906d-18,0.5244671400638127d-19,
     6      -.2803221738666301d-20,0.1403029013124585d-21,
     7      -.9140378603222467d-23,-.9280337675761723d-24,
     8      0.1486189118314399d-23,-.6240335959747719d-24/
         data arr1362/
     1      -.1200071392644432d-09,0.3206005509148100d-10,
     2      -.5928771939652658d-11,0.8771123222611109d-12,
     3      -.1101944298410675d-12,0.1215105139099130d-13,
     4      -.1201103252453204d-14,0.1080075066468454d-15,
     5      -.8932401822476790d-17,0.6853084680996423d-18,
     6      -.4938514796941065d-19,0.3177730613841660d-20,
     7      -.4574354159533076d-22,-.6905338741151543d-22,
     8      -.4073555487118469d-08,0.1535638436356750d-08/
         data arr1363/
     1      -.4007260823023397d-09,0.8365583420806389d-10,
     2      -.1483060336686230d-10,0.2307656649049889d-11,
     3      -.3218813468644372d-12,0.4084388936330347d-13,
     4      -.4766510275451386d-14,0.5159207851259801d-15,
     5      -.5215126601443759d-16,0.4943149687227559d-17,
     6      -.4348493783783383d-18,0.3380349263455170d-19,
     7      -.6783752729513155d-07,0.3392203850867671d-07,
     8      -.1174186750918388d-07,0.3251489796427225d-08/
         data arr1364/
     1      -.7646128233948498d-09,0.1578158230735131d-09,
     2      -.2919925356882900d-10,0.4914729156515463d-11,
     3      -.7607981557126079d-12,0.1092304358990523d-12,
     4      -.1464143682687701d-13,0.1842835527307871d-14,
     5      -.2171870592356135d-15,0.2433067739321783d-16,
     6      -.6759698677848911d-06,0.4289923870503279d-06,
     7      -.1884582407102019d-06,0.6623242661716666d-07,
     8      -.1976697273275143d-07,0.5177968987857642d-08/
         data arr1365/
     1      -.1215880589506970d-08,0.2597341671817004d-09,
     2      -.5102795590899102d-10,0.9298056155278783d-11,
     3      -.1581355941810867d-11,0.2526241889120657d-12,
     4      -.3764689933284820d-13,0.5361200396328743d-14,
     5      -.4573082112560052d-05,0.3563741789573689d-05,
     6      -.1922413285812669d-05,0.8296162991241389d-06,
     7      -.3040337196093311d-06,0.9779485711872967d-07,
     8      -.2819825883216431d-07,0.7396656878425616d-08/
         data arr1366/
     1      -.1784374722779182d-08,0.3992497509666285d-09,
     2      -.8333687339174302d-10,0.1634849793376093d-10,
     3      -.2975252330571753d-11,0.5198593827074838d-12,
     4      -.2287393884705006d-04,0.2133679128984000d-04,
     5      -.1377718723639272d-04,0.7116754765548784d-05,
     6      -.3121888531729525d-05,0.1201994768867937d-05,
     7      -.4148575923044364d-06,0.1302576703870151d-06,
     8      -.3761277777550473d-07,0.1007358484757128d-07/
         data arr1367/
     1      -.2514549843727033d-08,0.5905090933435477d-09,
     2      -.1277382096282953d-09,0.2668578524287282d-10,
     3      -.8984276015807779d-04,0.9830138332803653d-04,
     4      -.7445253071557125d-04,0.4511171080736773d-04,
     5      -.2321202554509108d-04,0.1048302467619086d-04,
     6      -.4243937811310265d-05,0.1563011614057495d-05,
     7      -.5293711071373657d-06,0.1663011553990934d-06,
     8      -.4861404600455028d-07,0.1339295139674674d-07/
         data arr1368/
     1      -.3369183924447211d-08,0.8244586669521032d-09,
     2      -.2896035678558264d-03,0.3656179934514167d-03,
     3      -.3195173683111796d-03,0.2233836730455835d-03,
     4      -.1326240014218083d-03,0.6911029996317976d-04,
     5      -.3228234965497595d-04,0.1371851241994672d-04,
     6      -.5360480398703782d-05,0.1943039930618756d-05,
     7      -.6536929812756620d-06,0.2078416529290696d-06,
     8      -.5971388665556409d-07,0.1683280382362697d-07/
         data arr1369/
     1      -.7920746767962328d-03,0.1138261935789085d-02,
     2      -.1132299719054943d-02,0.9010955696270953d-03,
     3      -.6089665983360959d-03,0.3612155761050052d-03,
     4      -.1920536653196046d-03,0.9290114340910936d-04,
     5      -.4131180371295926d-04,0.1704499375801996d-04,
     6      -.6501809675384214d-05,0.2353940358842995d-05,
     7      -.7606863686052055d-06,0.2436276199814283d-06,
     8      -.1886008083071403d-02,0.3050256570316268d-02/
         data arr1370/
     1      -.3414850543947833d-02,0.3058427243314729d-02,
     2      -.2326140711479698d-02,0.1552835601222817d-02,
     3      -.9290820501653295d-03,0.5058003958475108d-03,
     4      -.2530299134556190d-03,0.1174891964106362d-03,
     5      -.5014983911443552d-04,0.2044417552962948d-04,
     6      -.7334639026418885d-05,0.2638210590397209d-05,
     7      -.3989679043437484d-02,0.7192254197314081d-02,
     8      -.8974961183878270d-02,0.8959714805698894d-02/
         data arr1371/
     1      -.7595601500060214d-02,0.5651781164714868d-02,
     2      -.3768350725951567d-02,0.2286822710499351d-02,
     3      -.1274243449190629d-02,0.6594646478707540d-03,
     4      -.3112619657534344d-03,0.1415395876344567d-03,
     5      -.5574193255083779d-04,0.2229761962856385d-04,
     6      -.7620700529322546d-02,0.1518713349173040d-01,
     7      -.2095033578076403d-01,0.2312114252698546d-01,
     8      -.2166811533314462d-01,0.1782366134675504d-01/
         data arr1372/
     1      -.1313165258952696d-01,0.8810476539285701d-02,
     2      -.5420874456611271d-02,0.3101211136912938d-02,
     3      -.1600768717027190d-02,0.8055180292646936d-03,
     4      -.3448210915796581d-03,0.1521148167012484d-03,
     5      -.1331773933804978d-01,0.2913221222211660d-01,
     6      -.4410961599701946d-01,0.5343450619630038d-01,
     7      -.5496336102994250d-01,0.4962595537714942d-01,
     8      -.4009735672612107d-01,0.2953555476530230d-01/
         data arr1373/
     1      -.1991086213806093d-01,0.1250180949121880d-01,
     2      -.6983610769951800d-02,0.3862659490583656d-02,
     3      -.1781793946536020d-02,0.8606035116890971d-03,
     4      -.2152461984364686d-01,0.5136297920152622d-01,
     5      -.8482754387907966d-01,0.1121034172986308d+00,
     6      -.1257753556685545d+00,0.1238795853460559d+00,
     7      -.1090173164021793d+00,0.8763096799377182d-01,
     8      -.6426855596920591d-01,0.4401539211425112d-01/
         data arr1374/
     1      -.2634070429822443d-01,0.1592208554400781d-01,
     2      -.7854163772341568d-02,0.4127724225209073d-02,
     3      -.3246356018147372d-01,0.8404761921059410d-01,
     4      -.1505632889481881d+00,0.2159081507770889d+00,
     5      -.2627667515643327d+00,0.2807932944338055d+00,
     6      -.2673770549018060d+00,0.2333374183846740d+00,
     7      -.1849501446581103d+00,0.1374133363448080d+00,
     8      -.8723089270779408d-01,0.5734526044023051d-01/
         data arr1375/
     1      -.3004545655687563d-01,0.1708919980348919d-01,
     2      -.4603176977759323d-01,0.1286831050345852d+00,
     3      -.2487760987568332d+00,0.3853155590244000d+00,
     4      -.5061634008485624d+00,0.5840448945695090d+00,
     5      -.5978565725651553d+00,0.5639909857219887d+00,
     6      -.4801245839469542d+00,0.3851585693636738d+00,
     7      -.2568381651506502d+00,0.1828811664808584d+00,
     8      -.1011602492045683d+00,0.6198370143688853d-01/
         data arr1376/
     1      -.6175113290419112d-01,0.1856061286211783d+00,
     2      -.3853490588531411d+00,0.6421165084194567d+00,
     3      -.9063588051751612d+00,0.1124520667902941d+01,
     4      -.1229109207258256d+01,0.1248922799474115d+01,
     5      -.1135051672804066d+01,0.9790954096180100d+00,
     6      -.6792275154039736d+00,0.5220893552339755d+00,
     7      -.3032558465872370d+00,0.1993829236184729d+00,
     8      -.7878598426342741d-01,0.2536366226298027d+00/
         data arr1377/
     1      -.5626977821498662d+00,0.1005544528465094d+01,
     2      -.1518727412740012d+01,0.2018609110277911d+01,
     3      -.2338628757489857d+01,0.2552542997866009d+01,
     4      -.2462166230283564d+01,0.2275708821753532d+01,
     5      -.1626611538917212d+01,0.1346066587798710d+01,
     6      -.8170902349878999d+00,0.5745407551315618d+00,
     7      -.9602419078532998d-01,0.3299337853078096d+00,
     8      -.7777719962416858d+00,0.1487085484723319d+01/
         data arr1378/
     1      -.2393794154808922d+01,0.3397567767466897d+01,
     2      -.4138114760533847d+01,0.4842164906183484d+01,
     3      -.4929302785329525d+01,0.4867359654427892d+01,
     4      -.3550117768854425d+01,0.3156499372615979d+01,
     5      -.1993828059740071d+01,0.1495334366280626d+01,
     6      -.1121979133430657d+00,0.4100757851436601d+00,
     7      -.1020124947913049d+01,0.2084324774291531d+01,
     8      -.3562409354668872d+01,0.5384639432900018d+01/
         data arr1379/
     1      -.6830561495097098d+01,0.8560123179940408d+01,
     2      -.9146255109660723d+01,0.9625990015864550d+01,
     3      -.7095044113117878d+01,0.6769184340933966d+01,
     4      -.4432369505107460d+01,0.3538239746994886d+01,
     5      -.1260086376269048d+00,0.4883044670017229d+00,
     6      -.1270230230419765d+01,0.2774264695357422d+01,
     7      -.5016334826722491d+01,0.8057641297664915d+01,
     8      -.1053145471297471d+02,0.1413630025906620d+02/
         data arr1380/
     1      -.1576995610622473d+02,0.1766103941221526d+02,
     2      -.1302532293276811d+02,0.1332850370620241d+02,
     3      -.9016086095069339d+01,0.7650170799718381d+01,
     4      -.1362288643734498d+00,0.5579236672195655d+00,
     5      -.1498683572183559d+01,0.3507930043526067d+01,
     6      -.6688767002553793d+01,0.1140339298936991d+02,
     7      -.1516497935712616d+02,0.2183809401826535d+02,
     8      -.2531110693410167d+02,0.3014373918589812d+02/
         data arr1381/
     1      -.2201652724930681d+02,0.2417966952141121d+02,
     2      -.1684736006454967d+02,0.1518788956296745d+02,
     3      0.1980600426638097d-21,-.1539287277979764d-23,
     4      0.2745244076069528d-22,-.1739441400222542d-23,
     5      0.2204018229127990d-21,-.3674194263285450d-23,
     6      0.4886505346990029d-21,-.1417384434422141d-22,
     7      0.1329428154885585d-20,-.1129120673010495d-22,
     8      0.1129840643627508d-20,-.1859465253362510d-22/
         data arr1382/
     1      0.1456334719577596d-20,0.1464998005873360d-20,
     2      -.5631359671103333d-22,0.1500921423750751d-23,
     3      -.3205948765194463d-25,0.6051777511638850d-27,
     4      -.1190318969655780d-28,0.2969981367423543d-28,
     5      -.5973227793251658d-28,0.1650940454120786d-27,
     6      -.2535977433663991d-28,0.1093074014029561d-27,
     7      -.9967288663994124d-28,0.2353391139853164d-27,
     8      0.4580672738889174d-16,-.4218430501638042d-17/
         data arr1383/
     1      0.2693648135665654d-18,-.1378129378654768d-19,
     2      0.5996152618153814d-21,-.2292882711846029d-22,
     3      0.7869080666724472d-24,-.2464850548388946d-25,
     4      0.8405665450495014d-27,-.5460300435191787d-28,
     5      -.8271140267029849d-28,0.2698048416187779d-28,
     6      -.7056771020280105d-28,0.4360085845750883d-13,
     7      -.7220749514254521d-14,0.8291590623029136d-15,
     8      -.7628735998458844d-16,0.5968989629446301d-17/
         data arr1384/
     1      -.4104631311534050d-18,0.2533346541812440d-19,
     2      -.1424083490363136d-20,0.7382182359661187d-22,
     3      -.3587805984102198d-23,0.7403285799581014d-25,
     4      0.1669764306862331d-25,-.6206246075285692d-25,
     5      0.6544231341651285d-11,-.1676909937076667d-11,
     6      0.2979402416244393d-12,-.4241385577818731d-13,
     7      0.5134756391867463d-14,-.5463323950320611d-15,
     8      0.5217251182399389d-16,-.4537676370217736d-17/
         data arr1385/
     1      0.3633753337789349d-18,-.2702266496273575d-19,
     2      0.1863155796695693d-20,-.1193370949688080d-21,
     3      -.8824560961818640d-24,0.3134608832071974d-09,
     4      -.1133424520785511d-09,0.2841647395254241d-10,
     5      -.5708301895849644d-11,0.9751629175496451d-12,
     6      -.1464105707921895d-12,0.1972947042055982d-13,
     7      -.2421390393324575d-14,0.2736058271031238d-15,
     8      -.2870201587337568d-16,0.2813423837765622d-17/
         data arr1386/
     1      -.2583864193065620d-18,0.2213174811020394d-19,
     2      0.6924307115120214d-08,-.3321101655828545d-08,
     3      0.1104476166951432d-08,-.2942996129292909d-09,
     4      0.6668935716390770d-10,-.1328153816728358d-10,
     5      0.2374039680880190d-11,-.3864859797801966d-12,
     6      0.5792815849531663d-13,-.8059702375052734d-14,
     7      0.1048230424429996d-14,-.1274292597131229d-15,
     8      0.1469379717171155d-16,0.8756770431781893d-07/
         data arr1387/
     1      -.5330403999023707d-07,0.2249803667193195d-07,
     2      -.7608311356426115d-08,0.2188091261309084d-08,
     3      -.5530540110321456d-09,0.1254635216619931d-09,
     4      -.2592226045333841d-10,0.4931045562960389d-11,
     5      -.8704986472392491d-12,0.1436938913066310d-12,
     6      -.2209783869711582d-13,0.3234827677198059d-14,
     7      0.7274457466275391d-06,-.5437405881857280d-06,
     8      0.2818066447799080d-06,-.1170226337774600d-06/
         data arr1388/
     1      0.4132586992787435d-07,-.1282622612582409d-07,
     2      0.3572924685050663d-08,-.9064671704987257d-09,
     3      0.2117352037310627d-09,-.4587447530381923d-10,
     4      0.9299249083605816d-11,-.1748486627318068d-11,
     5      0.3142592271762434d-12,0.4355354284200546d-05,
     6      -.3896777003776980d-05,0.2417441392622948d-05,
     7      -.1201615489320491d-05,0.5079355065768543d-06,
     8      -.1887015888634781d-06,0.6292043048714736d-07/
         data arr1389/
     1      -.1910755006319881d-07,0.5342402610623747d-08,
     2      -.1384154600659125d-08,0.3359001325675864d-09,
     3      -.7518639459903933d-10,0.1617302333174471d-10,
     4      0.2006568585385784d-04,-.2105835557659195d-04,
     5      0.1532368619429855d-04,-.8934314001988485d-05,
     6      0.4429886880963319d-05,-.1930390796621215d-05,
     7      0.7550062531399586d-06,-.2689294814870870d-06,
     8      0.8819780310654370d-07,-.2675896006562613d-07/
         data arr1390/
     1      0.7618743348704358d-08,-.1986956644736004d-08,
     2      0.5012599877891226d-09,0.7463146058145549d-04,
     3      -.9037315530952079d-04,0.7587965971974802d-04,
     4      -.5104703032416155d-04,0.2920444364732254d-04,
     5      -.1468386948083100d-04,0.6626668749871128d-05,
     6      -.2723331454266591d-05,0.1030542230298111d-05,
     7      -.3597935114626881d-06,0.1182435960540011d-06,
     8      -.3529892300699593d-07,0.1027368200699921d-07/
         data arr1391/
     1      0.2323467481937647d-03,-.3202626604602644d-03,
     2      0.3060869247375315d-03,-.2343918207133081d-03,
     3      0.1526416584985407d-03,-.8735660217526189d-04,
     4      0.4487547246748263d-04,-.2098978918103209d-04,
     5      0.9041156909220125d-05,-.3578241737284756d-05,
     6      0.1339364844535515d-05,-.4509235441480568d-06,
     7      0.1493771242048060d-06,0.6226310631830492d-03,
     8      -.9658648124142947d-03,0.1038895790404361d-02/
         data arr1392/
     1      -.8953376814173180d-03,0.6561957998573515d-03,
     2      -.4225925009349853d-03,0.2443242140901986d-03,
     3      -.1285804190373914d-03,0.6233118356030351d-04,
     4      -.2759549454834209d-04,0.1163480337020660d-04,
     5      -.4362010270647215d-05,0.1626245437997455d-05,
     6      0.1468113244982804d-02,-.2538494976669169d-02,
     7      0.3043460763102679d-02,-.2923602166653557d-02,
     8      0.2388344904276050d-02,-.1713984747387182d-02/
         data arr1393/
     1      0.1104634168256570d-02,-.6477035316136886d-03,
     2      0.3499772371298674d-03,-.1712366759800953d-03,
     3      0.8057300952202359d-04,-.3327442658607782d-04,
     4      0.1382940055649637d-04,0.3100064854306746d-02,
     5      -.5925593567407727d-02,0.7853836307918782d-02,
     6      -.8340467613816143d-02,0.7532134258369626d-02,
     7      -.5972413315091573d-02,0.4255813629670377d-02,
     8      -.2756728470470066d-02,0.1646698598035418d-02/
         data arr1394/
     1      -.8803588042536276d-03,0.4587282075451560d-03,
     2      -.2067110419389577d-03,0.9500615268649769d-04,
     3      0.5946616670466740d-02,-.1247573062978821d-01,
     4      0.1815062643032994d-01,-.2115793368336633d-01,
     5      0.2097258764391062d-01,-.1823462441084203d-01,
     6      0.1426668470831314d-01,-.1013288462580846d-01,
     7      0.6643983826076245d-02,-.3838986972355463d-02,
     8      0.2200863948302669d-02,-.1073250204936199d-02/
         data arr1395/
     1      0.5417570762245904d-03,0.1048458867222445d-01,
     2      -.2399098524144878d-01,0.3807864823277488d-01,
     3      -.4842420180197295d-01,0.5235894635476079d-01,
     4      -.4956608336246322d-01,0.4232783770786922d-01,
     5      -.3274357218411800d-01,0.2342230060306499d-01,
     6      -.1447098943387593d-01,0.9078310688560663d-02,
     7      -.4756231106179128d-02,0.2621439683959385d-02,
     8      0.1715695214907328d-01,-.4257723197322229d-01/
         data arr1396/
     1      0.7333551404720914d-01,-.1011986235276086d+00,
     2      0.1187070378534372d+00,-.1215205923793267d+00,
     3      0.1127033340414569d+00,-.9438276827188995d-01,
     4      0.7326419783808119d-01,-.4788327964364126d-01,
     5      0.3272567298055225d-01,-.1830305286066804d-01,
     6      0.1095995142687076d-01,0.2627074074128841d-01,
     7      -.7033074434403318d-01,0.1308646360436940d+00,
     8      -.1950568149300759d+00,0.2470173428212738d+00/
         data arr1397/
     1      -.2715466211743508d+00,0.2723945550261401d+00,
     2      -.2455840249116448d+00,0.2059188914527993d+00,
     3      -.1408313091738093d+00,0.1044846333312910d+00,
     4      -.6203249387632645d-01,0.4018650026134962d-01,
     5      0.3789944507961308d-01,-.1088745067618536d+00,
     6      0.2180392782556681d+00,-.3496719992398358d+00,
     7      0.4759947330503408d+00,-.5576746469497232d+00,
     8      0.6031444662077758d+00,-.5824392324278823d+00/
         data arr1398/
     1      0.5254522018634731d+00,-.3719057571752194d+00,
     2      0.2987098578339679d+00,-.1873237459308062d+00,
     3      0.1308275362183477d+00,0.5181580402054982d-01,
     4      -.1587820482888823d+00,0.3413106039427535d+00,
     5      -.5870857705787935d+00,0.8556764923595775d+00,
     6      -.1059315718865003d+01,0.1232533059030528d+01,
     7      -.1268868123461070d+01,0.1227585029913606d+01,
     8      -.8889787771712980d+00,0.7715231548394247d+00/
         data arr1399/
     1      -.5088305002559418d+00,0.3820123696251642d+00,
     2      0.6747444076299217d-01,-.2189299803127834d+00,
     3      0.5043721202453297d+00,-.9284421772111898d+00,
     4      0.1443695753967784d+01,-.1869577503173855d+01,
     5      0.2337647087186329d+01,-.2554649715412606d+01,
     6      0.2643404696953871d+01,-.1935532310919082d+01,
     7      0.1813246815167140d+01,-.1252862515098145d+01,
     8      0.1008869020386836d+01,0.8405055687767327d-01/
         data arr1400/
     1      -.2858118394832882d+00,0.7059347485634999d+00,
     2      -.1389131738676183d+01,0.2297025990935975d+01,
     3      -.3073956494346725d+01,0.4131432882275595d+01,
     4      -.4774657196427575d+01,0.5273669148913491d+01,
     5      -.3856152709537234d+01,0.3899352895764357d+01,
     6      -.2813349058236150d+01,0.2426026110618776d+01,
     7      0.1005252896305311d+00,-.3528645077212770d+00,
     8      0.9372446724577131d+00,-.1972453236732733d+01/
         data arr1401/
     1      0.3458412881619211d+01,-.4711895723575380d+01,
     2      0.6820222519193162d+01,-.8308787454264754d+01,
     3      0.9784184710579357d+01,-.7050585441511768d+01,
     4      0.7704418784334440d+01,-.5788036307882837d+01,
     5      0.5340359166185131d+01,0.1158149714936074d+00,
     6      -.4100138371669063d+00,0.1179966007905409d+01,
     7      -.2663311290200272d+01,0.4940164622415101d+01,
     8      -.6726435263015535d+01,0.1053110239220420d+02/
         data arr1402/
     1      -.1349230524994140d+02,0.1693682833248400d+02,
     2      -.1185428986160997d+02,0.1403781594065040d+02,
     3      -.1095658242147602d+02,0.1081784648882560d+02,
     4      -.1230709881235790d-23,0.8985452302249637d-26,
     5      -.1837246377421826d-24,0.8404116314473061d-26,
     6      -.2083299224569488d-24,0.1373460276153095d-25,
     7      -.2084533988056504d-23,0.6967956065131122d-25,
     8      -.1354188650100838d-23,0.4881410725056927d-25/
         data arr1403/
     1      -.3461410063169849d-23,0.9627365640657339d-25,
     2      -.1104400099134945d-22,0.4084831688100613d-24,
     3      -.1052939539407785d-25,0.4053681168567820d-27,
     4      0.6262309449924403d-28,-.5240752888923238d-28,
     5      -.3127905359029012d-27,0.1495764149642467d-26,
     6      0.6308916389673477d-28,0.3511242513869006d-27,
     7      -.5347565092393426d-27,0.2475309673876260d-26,
     8      -.8273022863214243d-18,0.7331181644221133d-19/
         data arr1404/
     1      -.4510987298691910d-20,0.2226914885660453d-21,
     2      -.9360620245319469d-23,0.3461992149101838d-24,
     3      -.1150430845628232d-25,0.3490792319650190d-27,
     4      -.9627027936716864d-29,-.3685766004711617d-29,
     5      0.4517974286708577d-30,-.1317380656706653d-29,
     6      -.1416105487528095d-14,0.2256685131474318d-15,
     7      -.2497090013766671d-16,0.2216827069167281d-17,
     8      -.1675708358116021d-18,0.1114524433892517d-19/
         data arr1405/
     1      -.6660340854229558d-21,0.3628780723665478d-22,
     2      -.1821871550362634d-23,0.7813726787079053d-25,
     3      -.3690179465766474d-26,-.1783969263000464d-26,
     4      -.3288690958330303d-12,0.8108906287041046d-13,
     5      -.1388319318964985d-13,0.1907000645577510d-14,
     6      -.2230392602239799d-15,0.2295284575212602d-16,
     7      -.2122301362070787d-17,0.1789051109950317d-18,
     8      -.1389802967239018d-19,0.1001593322873975d-20/
         data arr1406/
     1      -.6768144179495438d-22,0.3839232592264599d-23,
     2      -.2222828364866927d-10,0.7733984608156099d-11,
     3      -.1868480394959690d-11,0.3621664153451621d-12,
     4      -.5977186488651626d-13,0.8679809774386722d-14,
     5      -.1132501685459697d-14,0.1347138197222471d-15,
     6      -.1476676260352470d-16,0.1504097128697940d-17,
     7      -.1430971010500810d-18,0.1278210670123356d-19,
     8      -.6513216211400416d-09,0.3006003380118925d-09/
         data arr1407/
     1      -.9633216095914044d-10,0.2476780546092649d-10,
     2      -.5422165235213387d-11,0.1044438208886037d-11,
     3      -.1807623613206237d-12,0.2852185385681101d-13,
     4      -.4146697921759619d-14,0.5603068033457749d-15,
     5      -.7061839395138627d-16,0.8382559830595949d-17,
     6      -.1045378230990962d-07,0.6123190006699648d-08,
     7      -.2490404481482556d-08,0.8126366938551104d-09,
     8      -.2257833522838725d-09,0.5519658995363597d-10/
         data arr1408/
     1      -.1212405423426454d-10,0.2427881770859590d-11,
     2      -.4478746886767392d-12,0.7680730053270503d-13,
     3      -.1226474751011070d-13,0.1846441932847979d-14,
     4      -.1066363026475311d-06,0.7669805397381428d-07,
     5      -.3830464870742848d-07,0.1534804284492891d-07,
     6      -.5236284633471678d-08,0.1571877216716118d-08,
     7      -.4239644208667516d-09,0.1042516248364789d-09,
     8      -.2360305040419436d-10,0.4970603308440949d-11/
         data arr1409/
     1      -.9724255452091771d-12,0.1795839712407899d-12,
     2      -.7642208439294287d-06,0.6579442099573996d-06,
     3      -.3933210156061032d-06,0.1886425158701017d-06,
     4      -.7703708532350270d-07,0.2768129327409318d-07,
     5      -.8936936265708335d-08,0.2630447947928154d-08,
     6      -.7121923467365875d-09,0.1795420343488783d-09,
     7      -.4192386040610824d-10,0.9255697027921759d-11,
     8      -.4129883251792881d-05,0.4170579102662532d-05/
         data arr1410/
     1      -.2924441460582700d-05,0.1645218878150902d-05,
     2      -.7880781676629697d-06,0.3321582284264502d-06,
     3      -.1257874252551063d-06,0.4342690376419342d-07,
     4      -.1376919632232703d-07,0.4072207267245343d-08,
     5      -.1111472915512213d-08,0.2873891716326477d-09,
     6      -.1772363260768146d-04,0.2065182687317982d-04,
     7      -.1670908017604761d-04,0.1084626334370233d-04,
     8      -.5994650925374558d-05,0.2915339009400764d-05/
         data arr1411/
     1      -.1273890779534030d-05,0.5074394853663972d-06,
     2      -.1851548790720183d-06,0.6319869164667658d-07,
     3      -.1982139531543234d-07,0.5903149969831662d-08,
     4      -.6280865312241931d-04,0.8330629591423976d-04,
     5      -.7672301840444846d-04,0.5668978780293286d-04,
     6      -.3566295514913558d-04,0.1974245097409293d-04,
     7      -.9819861998712447d-05,0.4452225642685088d-05,
     8      -.1841685822305260d-05,0.7158189359745495d-06/
         data arr1412/
     1      -.2543433931089917d-06,0.8605204133187291d-07,
     2      -.1894214030872271d-03,0.2827514366715686d-03,
     3      -.2930715396682819d-03,0.2437063646659140d-03,
     4      -.1725198417133954d-03,0.1074865825667497d-03,
     5      -.6017196227791915d-04,0.3069892443375614d-04,
     6      -.1420614202224465d-04,0.6217592789473190d-05,
     7      -.2473067688473553d-05,0.9396329698537287d-06,
     8      -.4978372493642935d-03,0.8283231526903933d-03/
         data arr1413/
     1      -.9570064386086272d-03,0.8870233993154988d-03,
     2      -.6997042746969221d-03,0.4859555954683732d-03,
     3      -.3032558349645103d-03,0.1724133656077447d-03,
     4      -.8817834618409621d-04,0.4305170573104278d-04,
     5      -.1897489347297766d-04,0.8017736123147709d-05,
     6      -.1162084901978445d-02,0.2137527029272181d-02,
     7      -.2730308733164168d-02,0.2797484851551689d-02,
     8      -.2438019315182315d-02,0.1872149374020500d-02/
         data arr1414/
     1      -.1291758360343448d-02,0.8115847572140861d-03,
     2      -.4535178011769113d-03,0.2450550793293787d-03,
     3      -.1186415974248627d-03,0.5529200531765856d-04,
     4      -.2446568938450145d-02,0.4939860864907048d-02,
     5      -.6927118683447288d-02,0.7789849326527930d-02,
     6      -.7442931811001814d-02,0.6275392890728027d-02,
     7      -.4754242432611353d-02,0.3276785955332348d-02,
     8      -.1978654368183089d-02,0.1175350645190511d-02/
         data arr1415/
     1      -.6203812834474954d-03,0.3166416050189359d-03,
     2      -.4704366698784481d-02,0.1036303386340730d-01,
     3      -.1585874483197211d-01,0.1945037241296138d-01,
     4      -.2022817095559175d-01,0.1861523989735269d-01,
     5      -.1539306883355957d-01,0.1156394695482743d-01,
     6      -.7463208139200699d-02,0.4846061069252502d-02,
     7      -.2770624514755367d-02,0.1539400646465504d-02,
     8      -.8347107452808727d-02,0.1995611204849520d-01/
         data arr1416/
     1      -.3316211838038734d-01,0.4411002845841965d-01,
     2      -.4957776213406791d-01,0.4955004046594277d-01,
     3      -.4449731521365371d-01,0.3622762120712132d-01,
     4      -.2471412893889100d-01,0.1745847388537473d-01,
     5      -.1075126080067657d-01,0.6469500346574000d-02,
     6      -.1378114725601017d-01,0.3560263483523755d-01,
     7      -.6399370793017788d-01,0.9183967836882705d-01,
     8      -.1107257226847298d+00,0.1196939618219715d+00/
         data arr1417/
     1      -.1162494500853617d+00,0.1020465248666910d+00,
     2      -.7275405957179214d-01,0.5569333227423106d-01,
     3      -.3676473244920671d-01,0.2385629174823509d-01,
     4      -.2131028908689619d-01,0.5928860895106462d-01,
     5      -.1149677672074003d+00,0.1771555503820745d+00,
     6      -.2271937817192571d+00,0.2647931146819713d+00,
     7      -.2772220642372109d+00,0.2611861778065983d+00,
     8      -.1923308928912896d+00,0.1590377373534625d+00/
         data arr1418/
     1      -.1120799590780558d+00,0.7814561926812463d-01,
     2      -.3100801002633167d-01,0.9270876349539466d-01,
     3      -.1937616090955010d+00,0.3190504971507643d+00,
     4      -.4309340584411560d+00,0.5403279328773075d+00,
     5      -.6083495933722661d+00,0.6126780114917629d+00,
     6      -.4602790382649949d+00,0.4101320692607778d+00,
     7      -.3075182458334250d+00,0.2297229651999270d+00,
     8      -.4256059503441261d-01,0.1367084439710760d+00/
         data arr1419/
     1      -.3083825030150193d+00,0.5399802668941391d+00,
     2      -.7588040470753374d+00,0.1022478230490395d+01,
     3      -.1236347229491003d+01,0.1326336447972383d+01,
     4      -.1003427089443196d+01,0.9618862986221702d+00,
     5      -.7652429118602914d+00,0.6111474234413172d+00,
     6      -.5508050905749153d-01,0.1905620468925341d+00,
     7      -.4661384132315375d+00,0.8635140267579207d+00,
     8      -.1243150320054915d+01,0.1800793630999699d+01/
         data arr1420/
     1      -.2338173762957617d+01,0.2664186305945127d+01,
     2      -.2001758920844097d+01,0.2062732820527938d+01,
     3      -.1737615622999654d+01,0.1481453459154264d+01,
     4      -.6689797959474431d-01,0.2510981555764732d+00,
     5      -.6723295540852526d+00,0.1310472617983198d+01,
     6      -.1894969257628407d+01,0.2957147527566199d+01,
     7      -.4128523903864893d+01,0.4985531705899099d+01,
     8      -.3664602694148483d+01,0.4060306950207701d+01/
         data arr1421/
     1      -.3616927833780841d+01,0.3289970291371692d+01,
     2      -.7537651581230174d-01,0.3118184123342648d+00,
     3      -.9290312516579665d+00,0.1894605257075418d+01,
     4      -.2681726613325914d+01,0.4530014321501061d+01,
     5      -.6824008547206657d+01,0.8723369495305372d+01,
     6      -.6167600804637527d+01,0.7360573471884245d+01,
     7      -.6931674233536903d+01,0.6730131342654865d+01,
     8      0.1997503068912111d-20,-.1602600434984341d-22/
         data arr1422/
     1      0.2521817900726354d-21,0.3064609252710480d-23,
     2      0.7662651251395298d-22,-.3144252705877205d-22,
     3      0.2738112268805805d-20,-.5775310485607140d-23,
     4      0.1341278565747657d-20,-.6748358898399974d-22,
     5      0.4774242591850453d-20,-.6394705802227858d-23,
     6      -.2910499684249945d-22,0.7652890680560042d-22,
     7      0.6608301318265732d-22,-.8359595875831065d-22,
     8      -.3378592267525047d-21,0.6962127280779968d-21/
         data arr1423/
     1      0.4445065256298618d-22,0.5051749774978362d-22,
     2      -.6626131976752408d-21,0.1193556478304934d-20,
     3      0.1385463103362777d-19,-.1184643301457656d-20,
     4      0.7042122856730058d-22,-.3362434662717039d-23,
     5      0.1368507886019602d-24,-.4902162673144932d-26,
     6      0.1298940090958919d-27,-.4814087372079373d-29,
     7      -.5331509241622024d-29,0.6904714881891408d-29,
     8      -.4915941096614806d-28,0.4264734032331040d-16/
         data arr1424/
     1      -.6557679644735451d-17,0.7010222709140089d-18,
     2      -.6019322124266809d-19,0.4405547106631223d-20,
     3      -.2839978832222057d-21,0.1646486293902384d-22,
     4      -.8710228957570441d-24,0.4253571805837045d-25,
     5      -.1959441554026292d-26,0.9805814533949280d-28,
     6      0.1532439245732805d-13,-.3645905148867241d-14,
     7      0.6030465537377828d-15,-.8011806741292425d-16,
     8      0.9072909523665274d-17,-.9049523567157936d-18/
         data arr1425/
     1      0.8117677619628435d-19,-.6644519580601753d-20,
     2      0.5016512575220912d-21,-.3524628484733892d-22,
     3      0.2318900856411663d-23,0.1461585708343175d-11,
     4      -.4906869910682104d-12,0.1145270764360521d-12,
     5      -.2147068767056813d-13,0.3430996111128205d-14,
     6      -.4829004304921641d-15,0.6112540026084742d-16,
     7      -.7059824110927948d-17,0.7521116929099754d-18,
     8      -.7458575814526866d-19,0.6906500338834481d-20/
         data arr1426/
     1      0.5680812417153812d-10,-.2529806485718707d-10,
     2      0.7832267790288928d-11,-.1947699229709072d-11,
     3      0.4128504523503319d-12,-.7707740796745777d-13,
     4      0.1294158727318192d-13,-.1982467290804767d-14,
     5      0.2801559560984109d-15,-.3687920911955994d-16,
     6      0.4524124181214809d-17,0.1157174141986216d-08,
     7      -.6540122595791157d-09,0.2569782865408586d-09,
     8      -.8110376883132055d-10,0.2181836759122119d-10/
         data arr1427/
     1      -.5169735943933442d-11,0.1101635914829587d-11,
     2      -.2141156991977671d-12,0.3840386972856671d-13,
     3      -.6422660079845164d-14,0.9982402445778894d-15,
     4      0.1449456977196115d-07,-.1005929379403141d-07,
     5      0.4853477340942609d-08,-.1880928305907719d-08,
     6      0.6213389748349601d-09,-.1807816462289562d-09,
     7      0.4730377196469603d-10,-.1128329999594841d-10,
     8      0.2485328704994928d-11,-.5110968568059718d-12/
         data arr1428/
     1      0.9732286595572176d-13,0.1243397680282155d-06,
     2      -.1032911730398147d-06,0.5965400428009154d-07,
     3      -.2767249722098257d-07,0.1094198812886092d-07,
     4      -.3810883462935100d-08,0.1193573428080748d-08,
     5      -.3404242740232741d-09,0.8977297320775677d-10,
     6      -.2213808018567365d-10,0.5031498203343438d-11,
     7      0.7881653550215131d-06,-.7679964620854052d-06,
     8      0.5202640146509287d-06,-.2830845512221218d-06/
         data arr1429/
     1      0.1312969063524859d-06,-.5364180489341695d-07,
     2      0.1970579227502133d-07,-.6580433185430219d-08,
     3      0.2036186363178627d-08,-.5903199659062613d-09,
     4      0.1568239085451673d-09,0.3902828120909911d-05,
     5      -.4388031509518676d-05,0.3429893017926983d-05,
     6      -.2153307023898610d-05,0.1152384502836440d-05,
     7      -.5433279393695686d-06,0.2302784306396638d-06,
     8      -.8846177672004427d-07,0.3160158414121580d-07/
         data arr1430/
     1      -.1060085179924618d-07,0.3236007003672830d-08,
     2      0.1574340427252544d-04,-.2014865230664026d-04,
     3      0.1792694888544974d-04,-.1280992833748478d-04,
     4      0.7803805388409059d-05,-.4189512015769559d-05,
     5      0.2020757765091452d-05,-.8795142216127602d-06,
     6      0.3579512065129473d-06,-.1371439828094565d-06,
     7      0.4742564639196675d-07,0.5343491805908342d-04,
     8      -.7696682349850994d-04,0.7706760169027607d-04/
         data arr1431/
     1      -.6196378830084564d-04,0.4248664639314111d-04,
     2      -.2568579708327658d-04,0.1393758485084780d-04,
     3      -.6779821256056589d-05,0.3109364817657747d-05,
     4      -.1346146038165611d-05,0.5210597838641721d-06,
     5      0.1565375050859824d-03,-.2513456832931797d-03,
     6      0.2805107631784927d-03,-.2512730166718615d-03,
     7      0.1920785553710265d-03,-.1295788597632147d-03,
     8      0.7831759797996604d-04,-.4204337048958229d-04/
         data arr1432/
     1      0.2153176884046263d-04,-.1043997425244174d-04,
     2      0.4477268730160713d-05,0.4039474141670810d-03,
     3      -.7171933873751422d-03,0.8847208929784824d-03,
     4      -.8752425826750851d-03,0.7399286031122985d-03,
     5      -.5528684678494731d-03,0.3689747366704876d-03,
     6      -.2159570626622734d-03,0.1225763164116039d-03,
     7      -.6606869472268391d-04,0.3111798008873732d-04,
     8      0.9334960660136338d-03,-.1820278217895167d-02/
         data arr1433/
     1      0.2463907208261574d-02,-.2670312069328705d-02,
     2      0.2479852295275474d-02,-.2040180635006592d-02,
     3      0.1491790193475147d-02,-.9405537799243499d-03,
     4      0.5880032058876768d-03,-.3501384241687019d-03,
     5      0.1797455896779930d-03,0.1958140283818379d-02,
     6      -.4170699976864561d-02,0.6153869195180845d-02,
     7      -.7248837603158511d-02,0.7354176753722957d-02,
     8      -.6632450587294010d-02,0.5275682812638656d-02/
         data arr1434/
     1      -.3539442010934939d-02,0.2424869561790904d-02,
     2      -.1586987518877063d-02,0.8821303485389220d-03,
     3      0.3769917668961649d-02,-.8736156891402034d-02,
     4      0.1396423316005819d-01,-.1772977930179252d-01,
     5      0.1956581333681759d-01,-.1928788986456322d-01,
     6      0.1657892563524949d-01,-.1168551401641333d-01,
     7      0.8738004744492238d-02,-.6258535613804062d-02,
     8      0.3745306024965201d-02,0.6722084740387746d-02/
         data arr1435/
     1      -.1691472873987087d-01,0.2910847022547290d-01,
     2      -.3945879404429401d-01,0.4722440908787238d-01,
     3      -.5082154845743313d-01,0.4690566135075637d-01,
     4      -.3426744969722424d-01,0.2788272816847375d-01,
     5      -.2178106204592758d-01,0.1396350703165750d-01,
     6      0.1118098257714579d-01,-.3057743140306741d-01,
     7      0.5627216308965295d-01,-.8049978695171120d-01,
     8      0.1043304412330506d+00,-.1226267247312186d+00/
         data arr1436/
     1      0.1207831621215228d+00,-.9014456311806436d-01,
     2      0.7964829935824058d-01,-.6767795000342113d-01,
     3      0.4628141421633201d-01,0.1744052373776262d-01,
     4      -.5210154564055794d-01,0.1017386118020984d+00,
     5      -.1512945923397728d+00,0.2124334805074624d+00,
     6      -.2733420632753754d+00,0.2856273072351381d+00,
     7      -.2143946721320059d+00,0.2054747639531342d+00,
     8      -.1895523786901975d+00,0.1377686492509362d+00/
         data arr1437/
     1      0.2559159392694537d-01,-.8445478308306532d-01,
     2      0.1733267102500999d+00,-.2626093107729048d+00,
     3      0.4006472733216812d+00,-.5668644871703790d+00,
     4      0.6248597299607889d+00,-.4637416961580344d+00,
     5      0.4820842775235226d+00,-.4822908772426424d+00,
     6      0.3714255028103946d+00,0.3533599143712063d-01,
     7      -.1314045894556168d+00,0.2801501722613815d+00,
     8      -.4207949205540886d+00,0.7020218456327245d+00/
         data arr1438/
     1      -.1099670058001637d+01,0.1271956757775645d+01,
     2      -.9160130885585540d+00,0.1034184218353254d+01,
     3      -.1121742367688414d+01,0.9131405824448393d+00,
     4      0.4573576917225318d-01,-.1978690221820987d+00,
     5      0.4322368957765982d+00,-.6197906464951465d+00,
     6      0.1143954109206501d+01,-.2003245673933356d+01,
     7      0.2419809992791258d+01,-.1655922372834814d+01,
     8      0.2036268058728312d+01,-.2396548108860259d+01/
         data arr1439/
     1      0.2058392554012434d+01,0.5491581464049901d-01,
     2      -.2904399748978772d+00,0.6404039146991265d+00,
     3      -.8308265161649516d+00,0.1732080103780140d+01,
     4      -.3438047690753970d+01,0.4320057098345888d+01,
     5      -.2741783234666594d+01,0.3691725791372216d+01,
     6      -.4725469339493661d+01,0.4278167390846908d+01,
     7      -.2773973267972092d-22,0.2089089274042614d-24,
     8      0.4049405930327822d-23,-.6689802442267534d-25/
         data arr1440/
     1      -.1428960353578551d-22,0.3717573207052624d-24,
     2      0.9382078675280981d-23,-.3834285981545339d-25,
     3      -.3069331511585867d-22,0.7798831746424028d-24,
     4      -.2567963921315988d-22,0.1003088853495806d-23,
     5      0.3743914149638719d-23,-.3211610768587582d-24,
     6      -.1328173661524499d-22,0.1786842292611813d-23,
     7      0.8720357992471872d-23,-.1842988815924346d-24,
     8      -.2852842995337132d-22,0.3748485202298211d-23/
         data arr1441/
     1      -.2162856628759780d-21,0.1788841967137573d-22,
     2      -.1027701431916901d-23,0.4359804300568376d-25,
     3      -.6953146661360953d-26,0.1277651988347337d-25,
     4      0.4069522372419610d-26,-.6011882193954517d-26,
     5      -.8946686270128779d-26,0.2178270709714933d-25,
     6      -.1197263022112165d-17,0.1780598348842635d-18,
     7      -.1843033474240614d-19,0.1533814608873230d-20,
     8      -.1089082152260588d-21,0.6817084503449058d-23/
         data arr1442/
     1      -.3840914029158230d-24,0.1976423406015214d-25,
     2      -.9323474184334974d-27,0.3583036480651025d-28,
     3      -.6656481641899500d-15,0.1531739778286170d-15,
     4      -.2453104803354869d-16,0.3158781638068390d-17,
     5      -.3470334012426300d-18,0.3361037343169878d-19,
     6      -.2929946237740641d-20,0.2332566261948592d-21,
     7      -.1717144821747455d-22,0.1173445094916876d-23,
     8      -.8958677789841765d-13,0.2908990650569404d-13/
         data arr1443/
     1      -.6574028631086580d-14,0.1194519519098052d-14,
     2      -.1851839176631123d-15,0.2530832405432017d-16,
     3      -.3113032007706338d-17,0.3497211887289237d-18,
     4      -.3638952402369585d-19,0.3505939263311075d-20,
     5      -.4618773598018058d-11,0.1989398008685832d-11,
     6      -.5963586423770565d-12,0.1437360762769921d-12,
     7      -.2955788532741531d-13,0.5358331478771591d-14,
     8      -.8741353559551181d-15,0.1302663468297253d-15/
         data arr1444/
     1      -.1802736660153405d-16,0.2301063940176283d-17,
     2      -.1194057568013635d-09,0.6527255024221743d-10,
     3      -.2483285111308352d-10,0.7596179966985655d-11,
     4      -.1982516873502970d-11,0.4561224887411115d-12,
     5      -.9440197234803554d-13,0.1785619282921642d-13,
     6      -.3147988631408586d-14,0.5090971053047212d-15,
     7      -.1836567492275769d-08,0.1232784504956641d-08,
     8      -.5759137104560816d-09,0.2163223754949139d-09/
         data arr1445/
     1      -.6932823149440274d-10,0.1958589949862770d-10,
     2      -.4973767857509670d-11,0.1155471833401633d-11,
     3      -.2514074635731764d-12,0.4981289753047270d-13,
     4      -.1885830912051421d-07,0.1515213427892707d-07,
     5      -.8472899227067826d-08,0.3809504699195869d-08,
     6      -.1461508437201386d-08,0.4942068600327210d-09,
     7      -.1500076013053295d-09,0.4173008619005998d-10,
     8      -.1093966939125360d-10,0.2587136779146430d-11/
         data arr1446/
     1      -.1402165961793264d-06,0.1321472792228383d-06,
     2      -.8667519449206594d-07,0.4571143316853415d-07,
     3      -.2057440598902303d-07,0.8159851618567704d-08,
     4      -.2897835706063489d-08,0.9462297339612561d-09,
     5      -.2933662937332013d-09,0.8109608408782357d-10,
     6      -.8011476625931806d-06,0.8711960940996075d-06,
     7      -.6592796657499633d-06,0.4012010461516975d-06,
     8      -.2084453823711860d-06,0.9536842735358939d-07/
         data arr1447/
     1      -.3891573843794622d-07,0.1467860515029112d-07,
     2      -.5304221037469793d-08,0.1684857072696866d-08,
     3      -.3678730583939086d-05,0.4553495003933523d-05,
     4      -.3921666764170210d-05,0.2716789601820430d-05,
     5      -.1608087658465764d-05,0.8371301004505247d-06,
     6      -.3862850999577220d-06,0.1661440780220116d-06,
     7      -.6917355664320680d-07,0.2489186382887718d-07,
     8      -.1405348034691692d-04,0.1957582160299376d-04/
         data arr1448/
     1      -.1896554809555076d-04,0.1478991436148871d-04,
     2      -.9868460047134149d-05,0.5777055810400293d-05,
     3      -.2970446353949477d-05,0.1441664952784205d-05,
     4      -.6853028518944109d-06,0.2760359690260012d-06,
     5      -.4590197898293042d-04,0.7125653229977858d-04,
     6      -.7686986480188261d-04,0.6685146605317922d-04,
     7      -.4986827597587234d-04,0.3249421361542526d-04,
     8      -.1835485415800773d-04,0.9967796904012253d-05/
         data arr1449/
     1      -.5371282425059996d-05,0.2397084395293570d-05,
     2      -.1310394016343776d-03,0.2247763802340421d-03,
     3      -.2674739256693054d-03,0.2574261160701013d-03,
     4      -.2133825282427933d-03,0.1533436923088065d-03,
     5      -.9380241997679956d-04,0.5662204906022236d-04,
     6      -.3439840402387918d-04,0.1685944533722252d-04,
     7      -.3329631930166473d-03,0.6262295163128273d-03,
     8      -.8143395133397729d-03,0.8620960760538616d-03/
         data arr1450/
     1      -.7910914644091803d-03,0.6216459798459399d-03,
     2      -.4056486748710138d-03,0.2708166564647772d-03,
     3      -.1847295326636711d-03,0.9868051407022799d-04,
     4      -.7648423124011578d-03,0.1565397108211137d-02,
     5      -.2201854941903232d-02,0.2552947211956615d-02,
     6      -.2590407489185816d-02,0.2207590974789590d-02,
     7      -.1511698617331483d-02,0.1112413181458918d-02,
     8      -.8496295693079997d-03,0.4914014115206214d-03/
         data arr1451/
     1      -.1610680595337719d-02,0.3558470148712311d-02,
     2      -.5346750464264727d-02,0.6774767137086715d-02,
     3      -.7614594798074893d-02,0.6980437228011720d-02,
     4      -.4925058817206111d-02,0.3987726212187927d-02,
     5      -.3404967793635620d-02,0.2119931098816695d-02,
     6      -.3151854356580901d-02,0.7443772106157931d-02,
     7      -.1174937898521771d-01,0.1627996713373686d-01,
     8      -.2037436080595665d-01,0.1992540408765894d-01/
         data arr1452/
     1      -.1418524979098741d-01,0.1263856437158355d-01,
     2      -.1206016378427266d-01,0.8042196456958837d-02,
     3      -.5811660640501717d-02,0.1448572477804774d-01,
     4      -.2345207363308860d-01,0.3570452959961058d-01,
     5      -.5021031189018894d-01,0.5194376112109119d-01,
     6      -.3641883777472141d-01,0.3578708981069177d-01,
     7      -.3819786818992398d-01,0.2716239049047215d-01,
     8      -.1025045920230895d-01,0.2650076851233319d-01/
         data arr1453/
     1      -.4246957458762838d-01,0.7184459421818037d-01,
     2      -.1150897503249687d+00,0.1248805357639928d+00,
     3      -.8379512135444886d-01,0.9128614075118113d-01,
     4      -.1092371299903184d+00,0.8251977188594969d-01,
     5      -.1756956785417351d-01,0.4605762516412197d-01,
     6      -.6917493384045742d-01,0.1329722963915204d+00,
     7      -.2473061793134514d+00,0.2791197530879087d+00,
     8      -.1731663912568697d+00,0.2110900337999156d+00/
         data arr1454/
     1      -.2843131132928794d+00,0.2274225586254328d+00,
     2      -.2969691517498464d-01,0.7685083120335881d-01,
     3      -.9903265774269868d-01,0.2261899616418808d+00,
     4      -.5011306573351682d+00,0.5837473492773089d+00,
     5      -.3207522673504633d+00,0.4444413992528682d+00,
     6      -.6778273543352322d+00,0.5725638370963726d+00,
     7      -.5000066832991371d-01,0.1243652686108540d+00,
     8      -.1172792774237996d+00,0.3516807698391277d+00/
         data arr1455/
     1      -.9614122534698896d+00,0.1148013640745308d+01,
     2      -.5278419507108583d+00,0.8540227589899154d+00,
     3      -.1487909630250644d+01,0.1324344995726581d+01,
     4      -.8414889724573142d-01,0.1970380074493901d+00,
     5      -.9178290970856211d-01,0.4933441109267763d+00,
     6      -.1751931667629222d+01,0.2132890711364851d+01,
     7      -.7549739821001400d+00,0.1499067331577474d+01,
     8      -.3023101780278091d+01,0.2831020331165521d+01/
        do 1200 i=1,7280
        arr(i)=arr1001(i)
 1200 continue
        return
        end
c
c///////////////////////////////////////////////////////////////////////
      subroutine mptoxf(ndigit,mpole,nterms,nlambs,numtts,nxtot,mexpup)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer *4 ndigit,nterms,nlambs,numtts(nlambs),nxtot
      complex *16 mpole(0:nterms,0:nterms)
c
      complex *16 mexpup(nxtot)
      if (ndigit .eq. 1) then
         call mptoxf1(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      if (ndigit .eq. 2) then
         call mptoxf2(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      if (ndigit .eq. 3) then
         call mptoxf3(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      if (ndigit .eq. 6) then
         call mptoxf6(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      if (ndigit .eq. 9) then
         call mptoxf9(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      if (ndigit .eq. 12) then
         call mptoxf12(mpole,nterms,nlambs,numtts,nxtot,mexpup)
         return
      endif
c
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine xftota(ndigit,local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
      integer *4 nlambs,numtts(nlambs),nxtot,nthmax,nterms,ndigit
      real *8 rlams(nlambs),whts(nlambs)
      complex *16 local(0:nterms,0:nterms)
c
      complex *16 mexpup(nxtot)
      if (ndigit.eq.1) then
         call xftota1(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      if (ndigit.eq.2) then
         call xftota2(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      if (ndigit.eq.3) then
         call xftota3(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      if (ndigit.eq.6) then
         call xftota6(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      if (ndigit.eq.9) then
         call xftota9(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      if (ndigit.eq.12) then
         call xftota12(local,nterms,rlams,whts,nlambs,numtts,
     1                      nthmax,nxtot,mexpup,scale)
         return
      endif
c
      return
      end
c
c
c
c
c
c
c
c
      subroutine mkexps3d(rlams,nlambs,nmphys,nxtotp,xs,ys,zs)
c
c purpose:
c     this subroutine computes the tables of exponentials needed
c     for translating exponential representations of harmonic
c     functions, discretized via norman's quadratures.
c
c     u   = \int_0^\infty e^{-\lambda z}
c           \int_0^{2\pi} e^{i\lambda(x cos(u)+y sin(u))}
c           mexpphys(lambda,u) du dlambda
c
c     mexpphys(*):  discrete values of the moment function 
c                   m(\lambda,u), ordered as follows.
c
c         mexpphys(1),...,mexpphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mexpphys(nmphys(1)+1),...,mexpphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)).
c         etc.
c
c input:
c     rlams(nlambs)   discretization points in lambda integral 
c     nlambs          number of discret. pts. in lambda integral
c     nmphys(j)     number of nodes in u integral needed 
c                    for corresponding lambda =  lambda_j. 
c     nxtotp        sum_j nmphys(j)
c
c output:
c     xs(1,nxtotp)   e^{i \lambda_j (cos(u_k)}  in above ordering
c     xs(2,nxtotp)   e^{i \lambda_j (2 cos(u_k)}  in above ordering.
c     xs(3,nxtotp)   e^{i \lambda_j (3 cos(u_k)}  in above ordering.
c     ys(1,nxtotp)   e^{i \lambda_j (sin(u_k)}  in above ordering.
c     ys(2,nxtotp)   e^{i \lambda_j (2 sin(u_k)}  in above ordering.
c     ys(3,nxtotp)   e^{i \lambda_j (3 sin(u_k)}  in above ordering.
c     zs(1,nxtotp)   e^{-\lambda_j}     in above ordering.
c     zs(2,nxtotp)   e^{-2 \lambda_j}   in above ordering. 
c     zs(3,nxtotp)   e^{-3 \lambda_j}   in above ordering. 
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer *4  nlambs,nmphys(nlambs),nxtotp
c
      real *8  rlams(nlambs), u, zs(3,nxtotp)
c
      complex *16 xs(3,nxtotp), ys(3,nxtotp), eye
c
c ... loop over each lambda value:
c
      data eye/(0.0d0,1.0d0)/
      pi = 4*datan(1.0d0)
      ntot = 0
      do 102 nl = 1,nlambs
         hu=2*pi/nmphys(nl)
         do 101 mth = 1,nmphys(nl)/2
            u = (mth-1)*hu
            ncrrnt = ntot+mth
            zs(1,ncrrnt) = dexp( -rlams(nl) )
            zs(2,ncrrnt) = dexp( - 2.0d0*rlams(nl) )
            zs(3,ncrrnt) = dexp( - 3.0d0*rlams(nl) )
            xs(1,ncrrnt) = cdexp(eye*rlams(nl)*dcos(u))
            xs(2,ncrrnt) = cdexp(eye*rlams(nl)*2.0d0*dcos(u))
            xs(3,ncrrnt) = cdexp(eye*rlams(nl)*3.0d0*dcos(u))
            ys(1,ncrrnt) = cdexp(eye*rlams(nl)*dsin(u))
            ys(2,ncrrnt) = cdexp(eye*rlams(nl)*2.0d0*dsin(u))
            ys(3,ncrrnt) = cdexp(eye*rlams(nl)*3.0d0*dsin(u))
 101     continue
         ntot = ntot+nmphys(nl)/2
 102  continue
c
      return
      end
c
c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c
c this subroutine generates the exponential expansions in one of the 
c six directions (u,d,n,s,e,w) for a parent cube due to the multipole
c expansions of its children.
c
c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c
c
c
c
c
      subroutine mkuexp(mybox,box,nterms,n22,mpole,mwork,rlams,nlambs,
     1    ndigit,nmfour,nmphys,nthmax,nxtot,nxtotp,mexpup,mxupys,mxuall,
     2    mx1234,xs,ys,zs)
      implicit real *8(a-h,o-z)
c
c
      integer *4  mybox, box(15), ndigit, nlambs, nmfour(nlambs),
     1   nxtot, nthmax, n22, nmphys(nlambs), nxtotp, ifinit
c
      real *8  zs(3,nxtotp), rlams(nlambs)
c
      complex *16 mpole(((nterms+1)*(nterms+2))/2,*),
     1  mwork(0:nterms,0:nterms), mexpup(nxtot),
     2  mxupys(nxtotp), mxuall(nxtotp), mx1234(nxtotp),
     3  xs(3,nxtotp), ys(3,nxtotp), xyz2(1404), xyz3(1404),
     4  xyz4(1404), xyz6(1404), xyz7(1404), xyz8(1404)
      save
c
c-----------------------------------------------------------------------
c
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz2(jj) = dconjg(xs(1,jj))
            xyz3(jj) = dconjg(ys(1,jj))
            xyz4(jj) = xyz2(jj)*xyz3(jj)
            xyz6(jj) = (1.0d0/zs(1,jj))/xs(1,jj)
            xyz7(jj) = (1.0d0/zs(1,jj))/ys(1,jj)
            xyz8(jj) = xyz6(jj)/ys(1,jj)
 111     continue
ccc         ifinit = 1
      endif
c
c ... initialization:
c
      do 112 jj = 1,nxtotp
         mx1234(jj) = 0.0d0
         mxuall(jj) = 0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 101 jj = 1,nxtotp
            mx1234(jj) = mx1234(jj) + mxupys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 102 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz2(jj)
            mx1234(jj) = mx1234(jj) + mxupys(jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 103 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz3(jj)
            mx1234(jj) = mx1234(jj) + mxupys(jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 104 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz4(jj)
            mx1234(jj) = mx1234(jj) + mxupys(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 105 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)/zs(1,jj)
            mxuall(jj) = mxuall(jj) + mxupys(jj)
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 106 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz6(jj)
            mxuall(jj) = mxuall(jj) + mxupys(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 107 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz7(jj)
            mxuall(jj) = mxuall(jj) + mxupys(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork,nterms)
         call mptoxf(ndigit,mwork,nterms,nlambs,nmfour,nxtot,mexpup)
         call ftphys(ndigit,mexpup,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxupys)
         do 108 jj = 1,nxtotp
            mxupys(jj) = mxupys(jj)*xyz8(jj)
            mxuall(jj) = mxuall(jj) + mxupys(jj)
 108     continue
      endif
c
c ... add mx1234(*) to mxuall(*):
c
      do 113 jj = 1,nxtotp
         mxuall(jj) = mxuall(jj) + mx1234(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mkdexp(mybox,box,nterms,n22,mpole,rlams,nlambs,ndigit,
     1    nmfour,nmphys,nthmax,nxtot,nxtotp,mexpdn,mxdpys,mxdall,md5678,
     2    xs,ys,zs,mptemp,mwork,mwork2,rdplus,rdminu)
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4  mybox, box(15), ndigit, nlambs, nmfour(nlambs),
     1  nxtot, nthmax, nmphys(nlambs), nxtotp, ifinit
c
      real *8  zs(3,nxtotp), rlams(nlambs),
     1  rdplus(0:nterms,0:nterms,-nterms:nterms),
     2  rdminu(0:nterms,0:nterms,-nterms:nterms)
c
      complex *16 mpole(((nterms+1)*(nterms+2))/2,*),
     1  mptemp(0:nterms,0:nterms), mwork(0:nterms,0:nterms),
     2  mwork2(0:nterms,0:nterms), mexpdn(nxtot), mxdpys(nxtotp),
     3  mxdall(nxtotp),md5678(nxtotp), xs(3,nxtotp), ys(3,nxtotp),
     4  xyz4(1404), xyz6(1404), xyz7(1404), xyz8(1404)
      save
c
c-----------------------------------------------------------------------
c
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz4(jj) = xs(1,jj)*ys(1,jj)
            xyz6(jj) = xs(1,jj)*zs(1,jj)
            xyz7(jj) = ys(1,jj)*zs(1,jj)
            xyz8(jj) = xyz6(jj)*ys(1,jj)
 111     continue
ccc         ifinit = 1
      endif
c
c ... intialization:
c
      dir = 'd'
      do 112 jj = 1,nxtotp
         mxdall(jj) =  0.0d0
         md5678(jj) =  0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 101 jj = 1,nxtotp
            mxdall(jj) = mxdall(jj) + mxdpys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 102 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*xs(1,jj)
            mxdall(jj) = mxdall(jj) + mxdpys(jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 103 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*ys(1,jj)
            mxdall(jj) = mxdall(jj) + mxdpys(jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 104 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*xyz4(jj)
            mxdall(jj) = mxdall(jj) + mxdpys(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 105 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*zs(1,jj)
            md5678(jj) = md5678(jj) + mxdpys(jj)
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 106 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*xyz6(jj)
            md5678(jj) = md5678(jj) + mxdpys(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 107 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*xyz7(jj)
            md5678(jj) = md5678(jj) + mxdpys(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mptemp,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mptemp,nterms,nlambs,nmfour,nxtot,mexpdn)
         call ftphys(ndigit,mexpdn,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxdpys)
         do 108 jj = 1,nxtotp
            mxdpys(jj) = mxdpys(jj)*xyz8(jj)
            md5678(jj) = md5678(jj) + mxdpys(jj)
 108     continue
      endif
c
c ... add md5678(*) to medall(*):
c
      do 113 jj = 1,nxtotp
         mxdall(jj) = mxdall(jj) + md5678(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mknexp(mybox,box,nterms,n22,mpole,mrotat,mwork,mwork2,
     1    rlams,nlambs,ndigit,nmfour,nmphys,nthmax,nxtot,nxtotp,mxpnof,
     2    mxnpys,rdplus,rdminu,mxnall,mn1256,mexn12,mexn56,xs,ys,zs)
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4  mybox, box(15), ndigit, nlambs, nmfour(nlambs),
     1  nxtot, nthmax, nmphys(nlambs), nxtotp, n22, ifinit
c
      real *8  zs(3,nxtotp), rlams(nlambs),
     1  rdplus(0:nterms,0:nterms,-nterms:nterms),
     2  rdminu(0:nterms,0:nterms,-nterms:nterms)
c
      complex *16  mpole(((nterms+1)*(nterms+2))/2,*),
     1  mrotat(0:nterms,0:nterms), mwork(0:nterms,0:nterms),
     2  mwork2(0:nterms,0:nterms), mxpnof(nxtot),
     3  mxnpys(nxtotp), mxnall(nxtotp), mn1256(nxtotp),
     4  mexn12(nxtotp), mexn56(nxtotp),
     5  xs(3,nxtotp), ys(3,nxtotp), xyz2(1404), xyz4(1404),
     6  xyz5(1404), xyz6(1404), xyz7(1404), xyz8(1404)
      save
c-----------------------------------------------------------------------
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz2(jj) = dconjg(ys(1,jj))
            xyz4(jj) = (1.0d0/zs(1,jj))/ys(1,jj)
            xyz5(jj) = dconjg(xs(1,jj))
            xyz6(jj) = xyz2(jj)*xyz5(jj)
            xyz7(jj) = (1.0d0/zs(1,jj))/xs(1,jj)
            xyz8(jj) = xyz7(jj)/ys(1,jj)
 111     continue
ccc         ifinit = 1
      endif
c
c ... initialization:
c
      dir = 'n'
      do 112 jj = 1,nxtotp
         mxnall(jj) = 0.0d0
         mexn12(jj) = 0.0d0
         mexn56(jj) = 0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 101 jj = 1,nxtotp
            mexn12(jj) = mexn12(jj) + mxnpys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 102 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz2(jj)
            mexn12(jj) = mexn12(jj) + mxnpys(jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 103 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)/zs(1,jj)
            mxnall(jj) = mxnall(jj) + mxnpys(jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 104 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz4(jj)
            mxnall(jj) = mxnall(jj) + mxnpys(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 105 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz5(jj)
            mexn56(jj) = mexn56(jj) + mxnpys(jj)
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 106 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz6(jj)
            mexn56(jj) = mexn56(jj) + mxnpys(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 107 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz7(jj)
            mxnall(jj) = mxnall(jj) + mxnpys(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxpnof)
         call ftphys(ndigit,mxpnof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxnpys)
         do 108 jj = 1,nxtotp
            mxnpys(jj) = mxnpys(jj)*xyz8(jj)
            mxnall(jj) = mxnall(jj) + mxnpys(jj)
 108     continue
      endif
c
c ... adding:
c
      do 113 jj = 1,nxtotp
         mn1256(jj) = mexn12(jj) + mexn56(jj)
         mxnall(jj) = mxnall(jj) + mn1256(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mksexp(mybox,box,nterms,n22,mpole,mrotat,mwork,mwork2,
     1    rlams,nlambs,ndigit,nmfour,nmphys,nthmax,nxtot,nxtotp,mxsof,
     2    mxspys,rdplus,rdminu,mxsall,ms3478,mexs34,mexs78,xs,ys,zs)
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4  mybox, box(15),ndigit,nlambs,nmfour(nlambs),
     1  nxtot,nthmax,nmphys(nlambs),nxtotp,n22, ifinit
c
      real *8  zs(3,nxtotp), rlams(nlambs),
     1  rdplus(0:nterms,0:nterms,-nterms:nterms),
     2  rdminu(0:nterms,0:nterms,-nterms:nterms)
c
      complex *16 mpole(((nterms+1)*(nterms+2))/2,*),
     1  mwork2(0:nterms,0:nterms), mrotat(0:nterms,0:nterms),
     2  mwork(0:nterms,0:nterms), mxsof(nxtot),
     3  mxspys(nxtotp), mxsall(nxtotp), ms3478(nxtotp),
     4  mexs34(nxtotp), mexs78(nxtotp), xs(3,nxtotp),
     5  ys(3,nxtotp), xyz4(1404), xyz6(1404),
     6  xyz7(1404), xyz8(1404)
      save
c-----------------------------------------------------------------------
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz4(jj) = ys(1,jj)*zs(1,jj)
            xyz6(jj) = ys(1,jj)*xs(1,jj)
            xyz7(jj) = zs(1,jj)*xs(1,jj)
            xyz8(jj) = xyz6(jj)*zs(1,jj)
 111     continue
ccc         ifinit = 1
      endif
c
c ... initialization:
c
      dir = 's'
      do 112 jj = 1,nxtotp
         mxsall(jj) = 0.0d0
         mexs34(jj) = 0.0d0
         mexs78(jj) = 0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 101 jj = 1,nxtotp
            mxsall(jj) = mxsall(jj) + mxspys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 102 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*ys(1,jj)
            mxsall(jj) = mxsall(jj) + mxspys(jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 103 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*zs(1,jj)
            mexs34(jj) = mexs34(jj) + mxspys(jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 104 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*xyz4(jj)
            mexs34(jj) = mexs34(jj) + mxspys(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 105 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*xs(1,jj)
            mxsall(jj) = mxsall(jj) + mxspys(jj)
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 106 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*xyz6(jj)
            mxsall(jj) = mxsall(jj) + mxspys(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 107 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*xyz7(jj)
            mexs78(jj) = mexs78(jj) + mxspys(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mxsof)
         call ftphys(ndigit,mxsof,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxspys)
         do 108 jj = 1,nxtotp
            mxspys(jj) = mxspys(jj)*xyz8(jj)
            mexs78(jj) = mexs78(jj) + mxspys(jj)
 108     continue
      endif
c
c ... adding:
c
      do 113 jj = 1,nxtotp
         ms3478(jj) = mexs78(jj) + mexs34(jj)
         mxsall(jj) = mxsall(jj) + ms3478(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mkeexp(mybox,box,nterms,n22,mpole,mrotat,mwork,mwork2,
     1    rlams,nlambs,ndigit,nmfour,nmphys,nthmax,nxtot,nxtotp,mexpef,
     2    mxepys,rdplus,rdminu,mxeall,me1357,mexe13,mexe57,mexe1,mexe3,
     3    mexe5,mexe7,xs,ys,zs)
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4  mybox, box(15), ndigit, nlambs, nmfour(nlambs),
     1  nxtot, nthmax, nmphys(nlambs), nxtotp, n22, ifinit
c
      real *8  rdplus(0:nterms,0:nterms,-nterms:nterms),
     1  rdminu(0:nterms,0:nterms,-nterms:nterms),
     2  zs(3,nxtotp), rlams(nlambs)
c
      complex *16 mpole(((nterms+1)*(nterms+2))/2,*),
     1  mwork2(0:nterms,0:nterms), mrotat(0:nterms,0:nterms),
     2  mwork(0:nterms,0:nterms), mexpef(nxtot), mxepys(nxtotp),
     3  mxeall(nxtotp),me1357(nxtotp), mexe13(nxtotp),mexe57(nxtotp),
     4  mexe1(nxtotp),mexe3(nxtotp), mexe5(nxtotp),mexe7(nxtotp),
     5  xs(3,nxtotp),ys(3,nxtotp), xyz3(1404), xyz4(1404),
     6  xyz6(1404), xyz7(1404), xyz8(1404)
      save
c-----------------------------------------------------------------------
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz3(jj) = dconjg(ys(1,jj))
            xyz4(jj) = 1.0d0/(ys(1,jj)*zs(1,jj))
            xyz6(jj) = xs(1,jj)/zs(1,jj)
            xyz7(jj) = xs(1,jj)*xyz3(jj)
            xyz8(jj) = xyz7(jj)/zs(1,jj)
 111     continue
ccc         ifinit = 1
      endif
c
c ... initialization:
c
      dir = 'e'
      do 112 jj = 1,nxtotp
         mexe1(jj) = 0.0d0
         mexe3(jj) = 0.0d0
         mexe5(jj) = 0.0d0
         mexe7(jj) = 0.0d0
         mxeall(jj) = 0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 101 jj = 1,nxtotp
            mexe1(jj) = mxepys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 102 jj = 1,nxtotp
            mxeall(jj) = mxeall(jj) + mxepys(jj)/zs(1,jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 103 jj = 1,nxtotp
            mexe3(jj) = mxepys(jj)*xyz3(jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 104 jj = 1,nxtotp
            mxepys(jj) = mxepys(jj)*xyz4(jj)
            mxeall(jj) = mxeall(jj) + mxepys(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 105 jj = 1,nxtotp
            mexe5(jj) = mxepys(jj)*xs(1,jj) 
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 106 jj = 1,nxtotp
            mxepys(jj) = mxepys(jj)*xyz6(jj)
            mxeall(jj) = mxeall(jj) + mxepys(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 107 jj = 1,nxtotp
            mexe7(jj) = mxepys(jj)*xyz7(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpef)
         call ftphys(ndigit,mexpef,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxepys)
         do 108 jj = 1,nxtotp
            mxepys(jj) = mxepys(jj)*xyz8(jj)
            mxeall(jj) = mxeall(jj) + mxepys(jj)
 108     continue
      endif
c
c ... adding:
c
      do 113 jj = 1,nxtotp
         mexe13(jj) = mexe1(jj) + mexe3(jj)
         mexe57(jj) = mexe5(jj) + mexe7(jj)
         me1357(jj) = mexe13(jj) + mexe57(jj)
         mxeall(jj) = mxeall(jj) + me1357(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mkwexp(mybox,box,nterms,n22,mpole,mrotat,mwork,mwork2,
     1    rlams,nlambs,ndigit,nmfour,nmphys,nthmax,nxtot,nxtotp,mexpwf,
     2    mxwpys,rdplus,rdminu,mxwall,mw2468,mexw24,mexw68,mexw2,mexw4,
     3    mexw6,mexw8,xs,ys,zs)
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4 mybox, box(15), ndigit, nlambs, nmfour(nlambs),
     1  nxtot, nthmax, nmphys(nlambs), nxtotp, n22, ifinit
c
      real *8  rdplus(0:nterms,0:nterms,-nterms:nterms),
     1  rdminu(0:nterms,0:nterms,-nterms:nterms),
     2  zs(3,nxtotp), rlams(nlambs)
c
      complex *16 mpole(((nterms+1)*(nterms+2))/2,*),
     1  mwork2(0:nterms,0:nterms), mrotat(0:nterms,0:nterms),
     2  mwork(0:nterms,0:nterms), mexpwf(nxtot), mxwpys(nxtotp),
     3  mxwall(nxtotp),mw2468(nxtotp), mexw24(nxtotp),mexw68(nxtotp),
     4  mexw2(nxtotp),mexw4(nxtotp), mexw6(nxtotp),mexw8(nxtotp),
     5  xs(3,nxtotp),ys(3,nxtotp), xyz4(1404), xyz5(1404),
     6  xyz6(1404), xyz7(1404), xyz8(1404)
      save
c-----------------------------------------------------------------------
      data ifinit/0/
      if (ifinit .eq. 0) then
         do 111 jj = 1, nxtotp
            xyz4(jj) = ys(1,jj)*zs(1,jj)
            xyz5(jj) = dconjg(xs(1,jj))
            xyz6(jj) = zs(1,jj)/xs(1,jj)
            xyz7(jj) = xyz5(jj)*ys(1,jj)
            xyz8(jj) = xyz6(jj)/dconjg(ys(1,jj))
 111     continue
ccc         ifinit = 1
      endif
c
c ... initialization:
c
      dir = 'w'
      do 112 jj = 1,nxtotp
         mxwall(jj) = 0.0d0
         mexw2(jj) = 0.0d0
         mexw4(jj) = 0.0d0
         mexw6(jj) = 0.0d0
         mexw8(jj) = 0.0d0
 112  continue
c
c ... from kid 1:
c
      if (box(6) .gt. 0) then
         call maptmp3d(mpole(1,box(6)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 101 jj = 1,nxtotp
            mxwall(jj) = mxwall(jj) + mxwpys(jj)
 101     continue
      endif
c
c ... from kid 2:
c
      if (box(7) .gt. 0) then
         call maptmp3d(mpole(1,box(7)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 102 jj = 1,nxtotp
            mexw2(jj) = mxwpys(jj)*zs(1,jj)
 102     continue
      endif
c
c ... from kid 3:
c
      if (box(8) .gt. 0) then
         call maptmp3d(mpole(1,box(8)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 103 jj = 1,nxtotp
            mxwall(jj) = mxwall(jj) + mxwpys(jj)*ys(1,jj)
 103     continue
      endif
c
c ... from kid 4:
c
      if (box(9) .gt. 0) then
         call maptmp3d(mpole(1,box(9)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 104 jj = 1,nxtotp
            mexw4(jj) = mxwpys(jj)*xyz4(jj)
 104     continue
      endif
c
c ... from kid 5:
c
      if (box(10) .gt. 0) then
         call maptmp3d(mpole(1,box(10)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 105 jj = 1,nxtotp
            mxwall(jj) = mxwall(jj) + mxwpys(jj)*xyz5(jj)
 105     continue
      endif
c
c ... from kid 6:
c
      if (box(11) .gt. 0) then
         call maptmp3d(mpole(1,box(11)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 106 jj = 1,nxtotp
            mexw6(jj) = mxwpys(jj)*xyz6(jj)
 106     continue
      endif
c
c ... from kid 7:
c
      if (box(12) .gt. 0) then
         call maptmp3d(mpole(1,box(12)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 107 jj = 1,nxtotp
            mxwall(jj) = mxwall(jj) + mxwpys(jj)*xyz7(jj)
 107     continue
      endif
c
c ... from kid 8:
c
      if (box(13) .gt. 0) then
         call maptmp3d(mpole(1,box(13)),mwork2,nterms)
         call mprtt(dir,mwork2,nterms,n22,mrotat,mwork,rdplus,rdminu)
         call mptoxf(ndigit,mrotat,nterms,nlambs,nmfour,nxtot,mexpwf)
         call ftphys(ndigit,mexpwf,nlambs,rlams,nmfour,nmphys,nthmax,
     &               mxwpys)
         do 108 jj = 1,nxtotp
            mexw8(jj) = mxwpys(jj)*xyz8(jj)
 108     continue
      endif
c
c ... adding:
c
      do 113 jj = 1,nxtotp
         mexw24(jj) = mexw2(jj) + mexw4(jj)
         mexw68(jj) = mexw8(jj) + mexw6(jj)
         mw2468(jj) = mexw68(jj) + mexw24(jj)
         mxwall(jj) = mxwall(jj) + mw2468(jj)
 113  continue
c
      return
      end
c
c
c
c
c
      subroutine mprtt(dir,mpole,nterms,n22,mpout,mwork,rdplus,rdminu)
c
c this subroutine is to rotate the incoming multiple expansion into
c the proper direction indicated by the direction "dir"
c
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4  nterms, n22
c
      real *8  rdplus(0:nterms,0:nterms,-nterms:nterms),
     1  rdminu(0:nterms,0:nterms,-nterms:nterms)
c
c up direction:
c
      complex *16  mpole(0:nterms,0:nterms),
     1  mwork(0:nterms,0:nterms), mpout(0:nterms,0:nterms)
      if ((dir .eq. 'u') .or. (dir .eq. 'U')) then
         do 102 i = 0, nterms
            do 101 j = 0, i
               mpout(i,j) = mpole(i,j)
 101        continue
 102     continue
         return
      endif
c
c down direction:
c
      if ((dir .eq. 'd') .or. (dir .eq. 'D')) then
         do 104 i = 0, nterms, 2
            do 103 j = 0, i
               mpout(i,j) = mpole(i,j)
 103        continue
 104     continue
         do 106 i = 1, nterms, 2
            do 105 j = 0, i
               mpout(i,j) = -mpole(i,j)
 105        continue
 106     continue
         return
      endif
c
c north direction:
c
      if ((dir .eq. 'n') .or. (dir .eq. 'N')) then
         call rtztoy(nterms,n22,mpole,mwork,mpout,rdminu)
         return
      endif
c
c south direction:
c
      if ((dir .eq. 's') .or. (dir .eq. 'S')) then
         call rtztoy(nterms,n22,mpole,mwork,mpout,rdminu)
         do 108 i = 1, nterms, 2
            do 107 j = 0, i
               mpout(i,j) = -mpout(i,j)
 107        continue
 108     continue
         return
      endif
c
c east direction:
c
      if ((dir .eq. 'e') .or. (dir .eq. 'E')) then
         call rtztox(nterms,n22,mpole,mpout,rdplus)
         return
      endif
c
c west direction:
c
      if ((dir .eq. 'w') .or. (dir .eq. 'W')) then
         call rtztox(nterms,n22,mpole,mpout,rdplus)
         do 110 i = 1, nterms, 2
            do 109 j = 0, i
               mpout(i,j) = -mpout(i,j)
 109        continue
 110     continue
         return
      endif
c
      return
      end
c
c
c
c
c
      subroutine mprttb(dir,mpole,nterms,n22,mpout,mwork,rdplus,rdminu)
c
c this subroutine is to rotate back the multiple expansion into
c the proper direction indicated by the direction "dir"
c
      implicit real *8(a-h,o-z)
c
c
      character *1 dir
c
      integer *4 nterms,n22
c
      real *8  rdplus(0:nterms,0:nterms,-nterms:nterms),
     1         rdminu(0:nterms,0:nterms,-nterms:nterms)
c
c up direction:
c
      complex *16 mpole(0:nterms,0:nterms),
     1  mwork(0:nterms,0:nterms), mpout(0:nterms,0:nterms)
      if ((dir .eq. 'u') .or. (dir .eq. 'U')) then
         do 102 i = 0, nterms
            do 101 j = 0, i
               mpout(i,j) = mpole(i,j)
 101        continue
 102     continue
         return
      endif
c
c down direction:
c
      if ((dir .eq. 'd') .or. (dir .eq. 'D')) then
         do 104 i = 0, nterms, 2
            do 103 j = 0, i
               mpout(i,j) = mpole(i,j)
 103        continue
 104     continue
         do 106 i = 1, nterms, 2
            do 105 j = 0, i
               mpout(i,j) = -mpole(i,j)
 105        continue
 106     continue
         return
      endif
c
c north direction:
c
      if ((dir .eq. 'n') .or. (dir .eq. 'N')) then
         call rtytoz(nterms,n22,mpole,mwork,mpout,rdplus)
         return
      endif
c
c south direction:
c
      if ((dir .eq. 's') .or. (dir .eq. 'S')) then
         do 108 i = 1, nterms, 2
            do 107 j = 0, i
               mpole(i,j) = -mpole(i,j)
 107        continue
 108     continue
         call rtytoz(nterms,n22,mpole,mwork,mpout,rdplus)
         return
      endif
c
c east direction:
c
      if ((dir .eq. 'e') .or. (dir .eq. 'E')) then
         call rtztox(nterms,n22,mpole,mpout,rdminu)
         return
      endif
c
c west direction:
c
      if ((dir .eq. 'w') .or. (dir .eq. 'W')) then
         do 110 i = 1, nterms, 2
            do 109 j = 0, i
               mpole(i,j) = -mpole(i,j)
 109        continue
 110     continue
         call rtztox(nterms,n22,mpole,mpout,rdminu)
         return
      endif
c
      return
      end
c
c
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c	This group of subroutines produce the interaction lists for
c	ADAPTIVE data structures in 3d FMM codes
c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c
c
      subroutine mkulst3d(mybox,box,iuall,nuall,ixuall,iyuall,
     1                iu1234,nu1234,ix1234,iy1234,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the uplists: IUALL and IU1234.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     IUALL(*) (INTEGER)
c		boxes at child level receiving UP expansion from all
c               eight source box children.
c     IU1234(*) (INTEGER)
c		boxes at child level receiving UP expansion from lower
c               set of source box children (i.e. 1,2,3,4).
c     NUALL    (INTEGER)   
c               number of boxes in IUALL list.
c     NU1234    (INTEGER)   
c               number of boxes in IU1234 lists.
c     IXUALL(*)  (INTEGER)
c               integer x offset of target boxes in IUALL.
c     IYUALL(*)  (INTEGER)
c               integer y offset of target boxes in IUALL.
c     IX1234(*)  (INTEGER)
c               integer x offset of target boxes in IU1234.
c     IY1234(*)  (INTEGER)
c               integer y offset of target boxes in IU1234.
c
c---------------------------------------------------------------------------
c
c
      integer  mybox, box(15), w(1), list(1), iuall(36), nuall,
     1  ixuall(36), iyuall(36), iu1234(16), nu1234, ix1234(16),
     2  iy1234(16), ikid, boxc(15), ier
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      nuall = 0
      nu1234 = 0
      mybox_lev = box(1)
      mybox_dim = 2**mybox_lev
      if (mybox_pla .ge. mybox_dim) return
c
c ... The bounding limit for IUALL boxes:
c
      meqpla = kid1_pla + 3
      minrow = kid1_row - 2
      maxrow = kid1_row + 3
      mincol = kid1_col - 2
      maxcol = kid1_col + 3
c
c ... Compute IUALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      nuall = 0
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(4) .ne. meqpla) goto 1040
            if (boxc(3) .lt. minrow) goto 1040
            if (boxc(3) .gt. maxrow) goto 1040
            if (boxc(2) .lt. mincol) goto 1040
            if (boxc(2) .gt. maxcol) goto 1040
ccc            call d3mifin(ifin,list(i),iuall,nuall)
ccc            if (ifin .eq. 1) goto 1040
            nuall = nuall + 1
            iuall(nuall) = list(i)
            ixuall(nuall) = boxc(2) - kid1_col
            iyuall(nuall) = boxc(3) - kid1_row
 1040 continue
      endif
c
c ... The bounding limit for IU1234 boxes:
c
      meqpla = kid1_pla + 2
      minrow = kid1_row - 1
      maxrow = kid1_row + 2
      mincol = kid1_col - 1
      maxcol = kid1_col + 2
c
c ... Compute IU1234 from LIST 2 of the first nonempty kid from
c       kids 1,2,3,4:
c
      do 1060 kk = 1, 4
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1070
 1060 continue
 1070 continue
c
      nu1234 = 0
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(4) .ne. meqpla) goto 1080
            if (boxc(3) .lt. minrow) goto 1080
            if (boxc(3) .gt. maxrow) goto 1080
            if (boxc(2) .lt. mincol) goto 1080
            if (boxc(2) .gt. maxcol) goto 1080
ccc            call d3mifin(ifin,list(i),iu1234,nu1234)
ccc            if (ifin .eq. 1) goto 1080
            nu1234 = nu1234 + 1
            iu1234(nu1234) = list(i)
            ix1234(nu1234) = boxc(2) - kid1_col
            iy1234(nu1234) = boxc(3) - kid1_row
 1080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine mkdlst3d(mybox,box,idall,ndall,ixdall,iydall,
     1                id5678,nd5678,ix5678,iy5678,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the downlists: IDALL and ID5678.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     IDALL(*) (INTEGER)
c		boxes at child level receiving DOWN expansion from all
c               eight source box children.
c     ID5678(*) (INTEGER)
c		boxes at child level receiving DOWN expansion from 
c               upper set of source box children (i.e. 5,6,7,8).
c     NDALL    (INTEGER)   
c               number of boxes in IDNALL list.
c     ND5678    (INTEGER)   
c               number of boxes in ID5678 list.
c     IXDALL(*)  (INTEGER)
c               integer x offset of target boxes in IDNALL.
c     IYDALL(*)  (INTEGER)
c               integer y offset of target boxes in IDNALL.
c     IX5678(*)  (INTEGER)
c               integer x offset of target boxes in ID5678.
c     IY5678(*)  (INTEGER)
c               integer y offset of target boxes in ID5678.
c
c
      integer  mybox, box(15), w(1), list(1), ikid, boxc(15), ier,
     1  idall(36), ndall, ixdall(36), iydall(36),
     2  id5678(16), nd5678, ix5678(16), iy5678(16)
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      ndall = 0
      nd5678 = 0
      if (mybox_pla .le. 1) return
c
c ... The bounding limit for IDALL boxes:
c
      meqpla = kid1_pla - 2
      minrow = kid1_row - 2
      maxrow = kid1_row + 3
      mincol = kid1_col - 2
      maxcol = kid1_col + 3
c
c ... Compute IDALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(4) .ne. meqpla) goto 1040
            if (boxc(3) .lt. minrow) goto 1040
            if (boxc(3) .gt. maxrow) goto 1040
            if (boxc(2) .lt. mincol) goto 1040
            if (boxc(2) .gt. maxcol) goto 1040
            ndall = ndall + 1
            idall(ndall) = list(i)
            ixdall(ndall) = boxc(2) - kid1_col
            iydall(ndall) = boxc(3) - kid1_row
 1040 continue
      endif
c
c ... The bounding limit for ID5678 boxes:
c
      meqpla = kid1_pla - 1
      minrow = kid1_row - 1
      maxrow = kid1_row + 2
      mincol = kid1_col - 1
      maxcol = kid1_col + 2
c
c ... Compute ID5678 from LIST 2 of the first nonempty kid from
c       kids 5,6,7,8
c
      do 1060 kk = 5, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1070
 1060 continue
 1070 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(4) .ne. meqpla) goto 1080
            if (boxc(3) .lt. minrow) goto 1080
            if (boxc(3) .gt. maxrow) goto 1080
            if (boxc(2) .lt. mincol) goto 1080
            if (boxc(2) .gt. maxcol) goto 1080
            nd5678 = nd5678 + 1
            id5678(nd5678) = list(i)
            ix5678(nd5678) = boxc(2) - kid1_col
            iy5678(nd5678) = boxc(3) - kid1_row
 1080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine mknlst3d(mybox,box,inall,nnall,ixnall,iynall,
     1        in1256,nn1256,ix1256,iy1256,in12,nn12,ix12,iy12,
     2        in56,nn56,ix56,iy56,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the north lists: INALL, IN1256, IN12 and IN56.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     INALL(*) (INTEGER)
c		boxes at child level receiving NORTH expansion from all
c               eight source box children.
c     NNALL    (INTEGER)
c               number of boxes in INALL list.
c     IXNALL(*) (INTEGER)
c               integer x offset of target boxes in INALL.
c     IYNALL(*) (INTEGER)
c               integer y offset of target boxes in INALL.
c    
c     likewise for all other lists (see algorithm description)...
c
c---------------------------------------------------------------------------
c
c
      integer *4  mybox, box(15), w(1), list(1), inall(24), nnall,
     1  ixnall(24), iynall(24), in1256(8), nn1256, ix1256(8),
     2  iy1256(8), in12(4), nn12, ix12(4), iy12(4), in56(4), nn56,
     3  ix56(4), iy56(4), ikid, boxc(15), ier
c
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      nnall = 0
      nn1256 = 0
      nn12 = 0
      nn56 = 0
      mybox_lev = box(1)
      mybox_dim = 2**mybox_lev
      if (mybox_row .ge. mybox_dim) return
c
c ... The bounding limit for INALL boxes:
c
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 2
      meqrow = kid1_row + 3
      mincol = kid1_col - 2
      maxcol = kid1_col + 3
c
c ... Compute INALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 1040
            if (boxc(4) .lt. minpla) goto 1040
            if (boxc(4) .gt. maxpla) goto 1040
            if (boxc(2) .lt. mincol) goto 1040
            if (boxc(2) .gt. maxcol) goto 1040
            nnall = nnall + 1
            inall(nnall) = list(i)
            ixnall(nnall) = boxc(4) - kid1_pla
            iynall(nnall) = boxc(2) - kid1_col
 1040 continue
      endif
c
c ... The bounding limit for IN1256 boxes:
c
      minpla = kid1_pla
      maxpla = kid1_pla + 1
      meqrow = kid1_row + 2
      mincol = kid1_col - 1
      maxcol = kid1_col + 2
c
c ... Compute IN1256 from LIST 2 of the first nonempty kid from
c       kids 1,2,5,6: 
c 
      do 1050 kk = 1, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1060
         ikid = box(kk+9)
         if (ikid .gt. 0) goto 1060
 1050 continue
 1060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 1080
            if (boxc(4) .lt. minpla) goto 1080
            if (boxc(4) .gt. maxpla) goto 1080
            if (boxc(2) .lt. mincol) goto 1080
            if (boxc(2) .gt. maxcol) goto 1080
            nn1256 = nn1256 + 1
            in1256(nn1256) = list(i)
            ix1256(nn1256) = boxc(4) - kid1_pla
            iy1256(nn1256) = boxc(2) - kid1_col
 1080 continue
      endif
c
c ... The bounding limit for IN12 boxes:
c
      meqpla = kid1_pla - 1
c
c ... Compute IN12 from LIST 2 of from kids 1,2: 
c 
      do 2010 kk = 1, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2020
 2010 continue
 2020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 2040
            if (boxc(4) .ne. meqpla) goto 2040
            if (boxc(2) .lt. mincol) goto 2040
            if (boxc(2) .gt. maxcol) goto 2040
            nn12 = nn12 + 1
            in12(nn12) = list(i)
            ix12(nn12) = boxc(4) - kid1_pla
            iy12(nn12) = boxc(2) - kid1_col
 2040 continue
      endif
c
c ... The bounding limit for IN56 boxes:
c 
      meqpla = kid1_pla + 2
c
c ... Compute IN12 from LIST 2 of from kids 5,6: 
c 
      do 2050 kk = 5, 6
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2060
 2050 continue
 2060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 2080
            if (boxc(4) .ne. meqpla) goto 2080
            if (boxc(2) .lt. mincol) goto 2080
            if (boxc(2) .gt. maxcol) goto 2080
            nn56 = nn56 + 1
            in56(nn56) = list(i)
            ix56(nn56) = boxc(4) - kid1_pla
            iy56(nn56) = boxc(2) - kid1_col
 2080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine mkslst3d(mybox,box,isall,nsall,ixsall,iysall,
     1           is3478,ns3478,ix3478,iy3478,is34,ns34,ix34,iy34,
     2           is78,ns78,ix78,iy78,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the south lists: ISALL, IS3478, IS34 and IS78.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     ISALL(*) (INTEGER)
c		boxes at child level receiving SOUTH expansion from all
c               eight source box children.
c     NSALL    (INTEGER)
c               number of boxes in ISALL list.
c     IXSALL(*) (INTEGER)
c               integer x offset of target boxes in ISALL.
c     IYSALL(*) (INTEGER)
c               integer y offset of target boxes in ISALL.
c    
c     likewise for all other lists (see algorithm description)...
c
c---------------------------------------------------------------------------
c
c
      integer *4  mybox, box(15), w(1), list(1), isall(24), nsall,
     1  ixsall(24), iysall(24), is3478(8), ns3478, ix3478(8),
     2  iy3478(8), is34(4), ns34, ix34(4), iy34(4), is78(4), ns78,
     3  ix78(4), iy78(4), ikid, boxc(15), ier
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      nsall = 0
      ns3478 = 0
      ns34 = 0
      ns78 = 0
      if (mybox_row .le. 1) return
c
c ... The bounding limit for ISALL boxes:
c
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 2
      meqrow = kid1_row - 2
      mincol = kid1_col - 2
      maxcol = kid1_col + 3
c
c ... Compute INALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 1040
            if (boxc(4) .lt. minpla) goto 1040
            if (boxc(4) .gt. maxpla) goto 1040
            if (boxc(2) .lt. mincol) goto 1040
            if (boxc(2) .gt. maxcol) goto 1040
            nsall = nsall + 1
            isall(nsall) = list(i)
            ixsall(nsall) = boxc(4) - kid1_pla
            iysall(nsall) = boxc(2) - kid1_col
 1040 continue
      endif
c
c ... The bounding limit for IS3478 boxes:
c
      minpla = kid1_pla
      maxpla = kid1_pla + 1
      meqrow = kid1_row - 1
      mincol = kid1_col - 1
      maxcol = kid1_col + 2
c
c ... Compute IN1256 from LIST 2 of the first nonempty kid from
c       kids 3,4,7,8:
c 
      do 1050 kk = 3, 4
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1060
         ikid = box(kk+9)
         if (ikid .gt. 0) goto 1060
 1050 continue
 1060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 1080
            if (boxc(4) .lt. minpla) goto 1080
            if (boxc(4) .gt. maxpla) goto 1080
            if (boxc(2) .lt. mincol) goto 1080
            if (boxc(2) .gt. maxcol) goto 1080
            ns3478 = ns3478 + 1
            is3478(ns3478) = list(i)
            ix3478(ns3478) = boxc(4) - kid1_pla
            iy3478(ns3478) = boxc(2) - kid1_col
 1080 continue
      endif
c
c ... The bounding limit for IS34 boxes:
c
      meqpla = kid1_pla - 1
c
c ... Compute IS34 from LIST 2 of from kids 3,4: 
c 
      do 2010 kk = 3, 4
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2020
 2010 continue
 2020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 2040
            if (boxc(4) .ne. meqpla) goto 2040
            if (boxc(2) .lt. mincol) goto 2040
            if (boxc(2) .gt. maxcol) goto 2040
            ns34 = ns34 + 1
            is34(ns34) = list(i)
            ix34(ns34) = boxc(4) - kid1_pla
            iy34(ns34) = boxc(2) - kid1_col
 2040 continue
      endif
c
c ... The bounding limit for IS78 boxes:
c 
      meqpla = kid1_pla + 2
c
c ... Compute IS78 from LIST 2 of from kids 7,8: 
c 
      do 2050 kk = 7, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2060
 2050 continue
 2060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(3) .ne. meqrow) goto 2080
            if (boxc(4) .ne. meqpla) goto 2080
            if (boxc(2) .lt. mincol) goto 2080
            if (boxc(2) .gt. maxcol) goto 2080
            ns78 = ns78 + 1
            is78(ns78) = list(i)
            ix78(ns78) = boxc(4) - kid1_pla
            iy78(ns78) = boxc(2) - kid1_col
 2080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine mkelst3d(mybox,box,ieall,neall,ixeall,iyeall,
     1           ie1357,ne1357,ix1357,iy1357,ie13,ne13,ix13,iy13,
     2           ie57,ne57,ix57,iy57,ie1,ne1,ix1,iy1,ie3,ne3,ix3,iy3, 
     3           ie5,ne5,ix5,iy5,ie7,ne7,ix7,iy7,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the east lists: IEALL, IE1357, IE12, IE57, IE1, IE3,
c     IE5 and IE7.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     IEALL(*) (INTEGER)
c		boxes at child level receiving EAST expansion from all
c               eight source box children.
c     NEALL    (INTEGER)
c               number of boxes in IEALL list.
c     IXEALL(*) (INTEGER)
c               integer x offset of target boxes in IEALL list.
c     IYEALL(*) (INTEGER)
c               integer y offset of target boxes in IEALL list.
c    
c     likewise for all other lists (see algorithm description)...
c
c--------------------------------------------------------------------------
c
c
      integer *4  mybox, box(15), w(1), list(1), ieall(16), neall,
     1  ixeall(16), iyeall(16), ie1357(4), ne1357, ix1357(4),
     2  iy1357(4), ie13(2), ne13, ix13(2), iy13(2), ie57(2), ne57, 
     3  ix57(2), iy57(2), ie1(3), ne1, ix1(3), iy1(3), ie3(3), ne3,
     4  ix3(3), iy3(3), ie5(3), ne5, ix5(3), iy5(3), ie7(3), ne7,
     5  ix7(3), iy7(3), ikid, boxc(15), ier
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      neall = 0
      ne1357 = 0
      ne13 = 0
      ne57 = 0
      ne1 = 0
      ne3 = 0
      ne5 = 0
      ne7 = 0
      mybox_lev = box(1)
      mybox_dim = 2**mybox_lev
      if (mybox_col .ge. mybox_dim) return
c
c ... The bounding limit for IEALL boxes:
c
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 2
      minrow = kid1_row - 1
      maxrow = kid1_row + 2
      meqcol = kid1_col + 3
c
c ... Compute IEALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 1040
            if (boxc(4) .lt. minpla) goto 1040
            if (boxc(4) .gt. maxpla) goto 1040
            if (boxc(3) .lt. minrow) goto 1040
            if (boxc(3) .gt. maxrow) goto 1040
            neall = neall + 1
            ieall(neall) = list(i)
            ixeall(neall) = -(boxc(4) - kid1_pla)
            iyeall(neall) = boxc(3) - kid1_row
 1040 continue
      endif
c
c ... The bounding limit for IE1357 boxes:
c
      minpla = kid1_pla
      maxpla = kid1_pla + 1
      minrow = kid1_row
      maxrow = kid1_row + 1
      meqcol = kid1_col + 2
c
c ... Compute IE1357 from LIST 2 of the first nonempty kid from
c       kids 1,3,5,7: 
c 
      do 1050 kk = 1, 7, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1060
 1050 continue
 1060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 1080
            if (boxc(4) .lt. minpla) goto 1080
            if (boxc(4) .gt. maxpla) goto 1080
            if (boxc(3) .lt. minrow) goto 1080
            if (boxc(3) .gt. maxrow) goto 1080
            ne1357 = ne1357 + 1
            ie1357(ne1357) = list(i)
            ix1357(ne1357) = -(boxc(4) - kid1_pla)
            iy1357(ne1357) = boxc(3) - kid1_row
 1080 continue
      endif
c
c ... The bounding limit for IE13 boxes:
c
      meqpla = kid1_pla - 1
c
c ... Compute IE13 from LIST 2 of from kids 1,3: 
c 
      do 2010 kk = 1, 3, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2020
 2010 continue
 2020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 2040
            if (boxc(4) .ne. meqpla) goto 2040
            if (boxc(3) .lt. minrow) goto 2040
            if (boxc(3) .gt. maxrow) goto 2040
            ne13 = ne13 + 1
            ie13(ne13) = list(i)
            ix13(ne13) = -(boxc(4) - kid1_pla)
            iy13(ne13) = boxc(3) - kid1_row
 2040 continue
      endif
c
c ... The bounding limit for IE57 boxes:
c 
      meqpla = kid1_pla + 2
c
c ... Compute IE57 from LIST 2 of from kids 5,7: 
c 
      do 2050 kk = 5, 7, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2060
 2050 continue
 2060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 2080
            if (boxc(4) .ne. meqpla) goto 2080
            if (boxc(3) .lt. minrow) goto 2080
            if (boxc(3) .gt. maxrow) goto 2080
            ne57 = ne57 + 1
            ie57(ne57) = list(i)
            ix57(ne57) = -(boxc(4) - kid1_pla)
            iy57(ne57) = boxc(3) - kid1_row
 2080 continue
      endif
c
c ... Compute IE1, IE3, IE5 and IE7:
c 
      meqrow = kid1_row - 1
      meqcol = kid1_col + 2
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 1
      ikid = box(1+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3020 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3020
            if (boxc(3) .ne. meqrow) goto 3020
            if (boxc(4) .lt. minpla) goto 3020
            if (boxc(4) .gt. maxpla) goto 3020
            ne1 = ne1 + 1
            ie1(ne1) = list(i)
            ix1(ne1) = -(boxc(4) - kid1_pla)
            iy1(ne1) = boxc(3) - kid1_row
 3020 continue
      endif
c
      meqrow = kid1_row + 2
      ikid = box(3+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3040
            if (boxc(3) .ne. meqrow) goto 3040
            if (boxc(4) .lt. minpla) goto 3040
            if (boxc(4) .gt. maxpla) goto 3040
            ne3 = ne3 + 1
            ie3(ne3) = list(i)
            ix3(ne3) = -(boxc(4) - kid1_pla)
            iy3(ne3) = boxc(3) - kid1_row
 3040 continue
      endif
c
      meqrow = kid1_row - 1
      meqcol = kid1_col + 2
      minpla = kid1_pla
      maxpla = kid1_pla + 2
      ikid = box(5+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3060 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3060
            if (boxc(3) .ne. meqrow) goto 3060
            if (boxc(4) .lt. minpla) goto 3060
            if (boxc(4) .gt. maxpla) goto 3060
            ne5 = ne5 + 1
            ie5(ne5) = list(i)
            ix5(ne5) = -(boxc(4) - kid1_pla)
            iy5(ne5) = boxc(3) - kid1_row
 3060 continue
      endif
c
      meqrow = kid1_row + 2
      ikid = box(7+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3080
            if (boxc(3) .ne. meqrow) goto 3080
            if (boxc(4) .lt. minpla) goto 3080
            if (boxc(4) .gt. maxpla) goto 3080
            ne7 = ne7 + 1
            ie7(ne7) = list(i)
            ix7(ne7) = -(boxc(4) - kid1_pla)
            iy7(ne7) = boxc(3) - kid1_row
 3080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine mkwlst3d(mybox,box,iwall,nwall,ixwall,iywall,
     1           iw2468,nw2468,ix2468,iy2468,iw24,nw24,ix24,iy24,
     2           iw68,nw68,ix68,iy68,iw2,nw2,ix2,iy2,iw4,nw4,ix4,iy4,
     3           iw6,nw6,ix6,iy6,iw8,nw8,ix8,iy8,centers,w,list)
      implicit real *8(a-h, o-z)
c
c Purpose:
c     Compute the west lists: IWALL, IW1357, IW12, IW57, IW1, IW3,
c     IW5 and IW7.
c
c Input:
c     mybox: box under consideration.
c     box(15): information relates to "mybox".
c
c Output:
c     IWALL(*) (INTEGER)
c		boxes at child level receiving WEST expansion from all
c               eight source box children.
c     NWALL    (INTEGER)
c               number of boxes in IWALL list.
c     IXWALL(*) (INTEGER)
c               integer x offset of target boxes in IWALL list.
c     IYWALL(*) (INTEGER)
c               integer y offset of target boxes in IWALL list.
c    
c     likewise for all other lists (see algorithm description)...
c
c---------------------------------------------------------------------------
c
c
      integer  mybox, box(15), w(1), list(1), iwall(16),
     1  nwall, ixwall(16), iywall(16), iw2468(4), nw2468, ix2468(4),
     2  iy2468(4), iw24(2), nw24, ix24(2), iy24(2), iw68(2), nw68,
     3  ix68(2), iy68(2), iw2(3), nw2, ix2(3), iy2(3),
     4  iw4(3), nw4, ix4(3), iy4(3), iw6(3), nw6, ix6(3), iy6(3),
     5  iw8(3), nw8, ix8(3), iy8(3), ikid, boxc(15), ier
c
c Execution starts:
c
c ... Initialization: the row, column and plane number of mybox, and 
c       the row, column and plane number of FIRST KID of mybox.
c
      real *8 centers(3,1), center0(3)
      mybox_col = box(2)
      mybox_row = box(3)
      mybox_pla = box(4)
      kid1_col = mybox_col*2 - 1
      kid1_row = mybox_row*2 - 1
      kid1_pla = mybox_pla*2 - 1

      nwall = 0
      nw2468 = 0
      nw24 = 0
      nw68 = 0
      nw2 = 0
      nw4 = 0
      nw6 = 0
      nw8 = 0
      if (mybox_col .le. 1) return
c
c ... The bounding limit for IWALL boxes:
c
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 2
      minrow = kid1_row - 1
      maxrow = kid1_row + 2
      meqcol = kid1_col - 2
c
c ... Compute IWALL from LIST 2 of one of the nonempty kids:
c
      do 1010 kk = 1, 8
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1020
 1010 continue
 1020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 1040
            if (boxc(4) .lt. minpla) goto 1040
            if (boxc(4) .gt. maxpla) goto 1040
            if (boxc(3) .lt. minrow) goto 1040
            if (boxc(3) .gt. maxrow) goto 1040
            nwall = nwall + 1
            iwall(nwall) = list(i)
            ixwall(nwall) = -(boxc(4) - kid1_pla)
            iywall(nwall) = boxc(3) - kid1_row
 1040 continue
      endif
c
c ... The bounding limit for IW2468 boxes:
c
      minpla = kid1_pla
      maxpla = kid1_pla + 1
      minrow = kid1_row
      maxrow = kid1_row + 1
      meqcol = kid1_col - 1
c
c ... Compute IW2468 from LIST 2 of the first nonempty kid from
c       kids 2,4,6,8: 
c 
      do 1050 kk = 2, 8, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 1060
 1050 continue
 1060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 1080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 1080
            if (boxc(4) .lt. minpla) goto 1080
            if (boxc(4) .gt. maxpla) goto 1080
            if (boxc(3) .lt. minrow) goto 1080
            if (boxc(3) .gt. maxrow) goto 1080
            nw2468 = nw2468 + 1
            iw2468(nw2468) = list(i)
            ix2468(nw2468) = -(boxc(4) - kid1_pla)
            iy2468(nw2468) = boxc(3) - kid1_row
 1080 continue
      endif
c
c ... The bounding limit for IE24 boxes:
c
      meqpla = kid1_pla - 1
c
c ... Compute IE24 from LIST 2 of from kids 1,3: 
c 
      do 2010 kk = 2, 4, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2020
 2010 continue
 2020 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 2040
            if (boxc(4) .ne. meqpla) goto 2040
            if (boxc(3) .lt. minrow) goto 2040
            if (boxc(3) .gt. maxrow) goto 2040
            nw24 = nw24 + 1
            iw24(nw24) = list(i)
            ix24(nw24) = -(boxc(4) - kid1_pla)
            iy24(nw24) = boxc(3) - kid1_row
 2040 continue
      endif
c
c ... The bounding limit for IW68 boxes:
c 
      meqpla = kid1_pla + 2
c
c ... Compute IW68 from LIST 2 of from kids 5,7: 
c 
      do 2050 kk = 6, 8, 2
         ikid = box(kk+5)
         if (ikid .gt. 0) goto 2060
 2050 continue
 2060 continue
c
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 2080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 2080
            if (boxc(4) .ne. meqpla) goto 2080
            if (boxc(3) .lt. minrow) goto 2080
            if (boxc(3) .gt. maxrow) goto 2080
            nw68 = nw68 + 1
            iw68(nw68) = list(i)
            ix68(nw68) = -(boxc(4) - kid1_pla)
            iy68(nw68) = boxc(3) - kid1_row
 2080 continue
      endif
c
c ... Compute IW2, IW4, IW6 and IW8:
c 
      meqrow = kid1_row - 1
      meqcol = kid1_col - 1
      minpla = kid1_pla - 1
      maxpla = kid1_pla + 1
      ikid = box(2+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3020 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3020
            if (boxc(3) .ne. meqrow) goto 3020
            if (boxc(4) .lt. minpla) goto 3020
            if (boxc(4) .gt. maxpla) goto 3020
            nw2 = nw2 + 1
            iw2(nw2) = list(i)
            ix2(nw2) = -(boxc(4) - kid1_pla)
            iy2(nw2) = boxc(3) - kid1_row
 3020 continue
      endif
c
      meqrow = kid1_row + 2
      ikid = box(4+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3040 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3040
            if (boxc(3) .ne. meqrow) goto 3040
            if (boxc(4) .lt. minpla) goto 3040
            if (boxc(4) .gt. maxpla) goto 3040
            nw4 = nw4 + 1
            iw4(nw4) = list(i)
            ix4(nw4) = -(boxc(4) - kid1_pla)
            iy4(nw4) = boxc(3) - kid1_row
 3040 continue
      endif
c
      meqrow = kid1_row - 1
      meqcol = kid1_col - 1
      minpla = kid1_pla
      maxpla = kid1_pla + 2
      ikid = box(6+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3060 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3060
            if (boxc(3) .ne. meqrow) goto 3060
            if (boxc(4) .lt. minpla) goto 3060
            if (boxc(4) .gt. maxpla) goto 3060
            nw6 = nw6 + 1
            iw6(nw6) = list(i)
            ix6(nw6) = -(boxc(4) - kid1_pla)
            iy6(nw6) = boxc(3) - kid1_row
 3060 continue
      endif
c
      meqrow = kid1_row + 2
      ikid = box(8+5)
      if (ikid .gt. 0) then
         mytype = 2
         call d3mgetl(ier,ikid,mytype,list,nlist,w)
         do 3080 i = 1, nlist
            call d3mgetbk(ier,list(i),boxc,center0,nkids,w)
            if (boxc(2) .ne. meqcol) goto 3080
            if (boxc(3) .ne. meqrow) goto 3080
            if (boxc(4) .lt. minpla) goto 3080
            if (boxc(4) .gt. maxpla) goto 3080
            nw8 = nw8 + 1
            iw8(nw8) = list(i)
            ix8(nw8) = -(boxc(4) - kid1_pla)
            iy8(nw8) = boxc(3) - kid1_row
 3080 continue
      endif
c
      return
      end
c
c
c
c
c
      subroutine d3mifin(ifin,mybox,iuall,nuall)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c 	Check to see if box "mybox" is in the list iuall.
c
c Input:
c 	mybox: box number
c	iuall(*): an array of box numbers
c	nuall: number of elements in iuall(*)
c
c Output:
c	ifin: 0---mybox not in iuall
c	      1---mybox in iuall
c
c
      integer mybox, iuall(1), nuall, ifin
      ifin = 0
      do 1200 i = 1, nuall
         if (iuall(i) .eq. mybox) then
            ifin = 1
            return
         endif
 1200 continue
c
      return
      end
c
c
	subroutine mkninire(ninire,ier)
	implicit real*8 (a-h,o-z)
c
c	This subroutine figures out the number of integers that can
c	be stored in a real*8 storage location.  It has no input parameters,
c	and returns the following output parameters:
c
c	ninire - the number of integers that can be stored in a
c		real*8 storage location.
c
c	ier - this takes on the values:
c		IER=0: successful return
c		IER=1: not even one integer will fit in a real*8 storage
c			location
c		IER=2: attempting to put integers in real*8 storage
c			locations, by means of subroutine calls, results
c			in the integers not ending up in the right place.
c
c
	dimension a(3)
c
c	fill A with zeros
c
	a(1)=0
	a(2)=0
	a(3)=0
c
c	try to stuff integers in, until something breaks...
c
	a2old=a(2)
	do 1000 i=1,100000
c
c	passing A to a routine that treats it as an integer, add a
c	large number to the i'th element
c
	call mknradd(a(2),i)
c
c	check if A(1) was clobbered -- if so, return error 2.
c
	if(a(1).ne.0) then
	  ier=2
	  ninire=0
	  return
	endif
c
c	check if A(3) was modified -- if so, we are done, but may have an
c	error code.
c
	if(a(3).ne.0 .and. i.eq.1 .and. a(2).eq.a2old) then
	  ier=2
	  ninire=0
	  return
	endif
	if(a(3).ne.0 .and. i.eq.1) then
	  ier=1
	  ninire=0
	  return
	endif
	if(a(3).ne.0) then
	  ier=0
	  ninire=i-1
	  return
	endif
c
c	check that A(2) was modified -- if not, return error 2.
c
	if(a(2).eq.a2old) then
	  ier=2
	  ninire=0
	  return
	endif

	a2old=a(2)
 1000	continue
ccc	stop 'bug in routine mkninire'
	end
c
c
c
c	utility routine to add a large number to an array element
c
	subroutine mknradd(k,i)
	dimension k(*)
c
c	make the large number (should have ones in the top half, even if
c	a 64-bit number)
c
	m=0
	do 1000 j=1,100
	m=m*2+1
 1000	continue
	k(i)=k(i)+m
	end

c
c
c
c
c
      subroutine mpshft3d(ier,zrotan,nmultson,mpolson,nmultdad,mpoldad,
     1                    rdp,rdm,arr,imap,w,lw)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine shifts the center of a child box multipole 
c	expansion to the parent center, via the rotation scheme.
c	we rotate the coordinate system, shift along the z-axis using
c	the compression scheme, and then rotate back.
c	Note this is only a memory management routine, actual code
c	is in "mpshft0"(see below).
c
c Inputs:
c	zrotan: the z-direction rotation angle.
c	mpolson: coefficients of sonny multipole exp.
c	nmultson: the order of "mpolson"
c	nmultdad: the order of "mpoldad"
c	rdp,rdm: precomputed rotation matrix about y-axis.
c              rdm is the inverse of rdp.
c	arr(1),imap(1): data for the z-direction shift, it is
c	       provided by rokhlin's new scheme.
c
c Outputs:
c	ier: error reporting code
c		=0 no error
c		=8 not enough memory in w(lw)
c	mpoldad: coefficients of shifted daddy multipole exp.
c
c Workspace:
c	(w,lw)
c
c
	integer imap(1)
c
	real *8 arr(1), w(1),
     1       rdp(0:nmultdad,0:nmultdad,-nmultdad:nmultdad),
     2       rdm(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
c
	complex *16 mpolson(0:nmultson,0:nmultson),
     1              mpoldad(0:nmultdad,0:nmultdad)
	ier=0
c
c ... Memory management:
c
	iat=1
c
	iephi=iat
	lephi=2*(2*nmultdad+1)+7
	iat=iephi+lephi
c
	impson2=iat
	lmpson2=2*(nmultson+1)*(2*nmultson+1)+7
	iat=impson2+lmpson2
c
	impson4=iat
	lmpson4=2*(nmultson+1)*(2*nmultson+1)+7
	iat=impson4+lmpson4
c
	impdad2=iat
	lmpdad2=2*(nmultdad+1)*(2*nmultdad+1)+7
	iat=impdad2+lmpdad2
c
	impdad4=iat
	lmpdad4=2*(nmultdad+1)*(2*nmultdad+1)+7
	iat=impdad4+lmpdad4
c
	lrem=lw-iat+1
	if (lrem.le.0) then
	   ier=8
	   return
	endif
c
	call mpshft3d0(zrotan,nmultson,mpolson,nmultdad,mpoldad,rdp,
     1          rdm,arr,imap,w(iephi),w(impson2),w(impson4),
     2		w(impdad2),w(impdad4))
c
	return
	end
c
c
c
c
c
      subroutine mpshft3d0(zrotan,nmultson,mpolson,nmultdad,mpoldad,rdp,
     1                  rdm,arr,imap,ephi,mpson2,mpson4,mpdad2,mpdad4)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine shifts the center of a child box multipole 
c	expansion to the parent center, via the rotation scheme.
c	we rotate the coordinate system, shift along the z-axis using
c	the compression scheme, and then rotate back.
c
c Inputs:
c	zrotan: the z-direction rotation angle.
c	mpolson: coefficients of sonny multipole exp.
c	nmultson: the order of "mpolson"
c	nmultdad: the order of "mpoldad"
c	rdp,rdm: precomputed rotation matrix about y-axis.
c              rdm is the inverse of rdp.
c	arr(1),imap(1): data for the z-direction shift, it is
c	       provided by rokhlin's new scheme.
c
c Outputs:
c	mpoldad: coefficients of shifted daddy multipole exp.
c
c Workspace:
c	ephi,mpson2,mpson4,mpdad2,mpdad4
c
c-----------------------------------------------------------------------------
c
c
	integer imap(1)
	real *8 arr(1)
	real *8 rdp(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
c
	real *8 rdm(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
	complex *16 mpolson(0:nmultson,0:nmultson)
	complex *16 mpoldad(0:nmultdad,0:nmultdad)
	complex *16 mpson2(0:nmultson,0:nmultson)
	complex *16 mpson4(0:nmultson,0:nmultson)
	complex *16 mpdad2(0:nmultdad,0:nmultdad)
	complex *16 mpdad4(0:nmultdad,0:nmultdad)
c
	complex *16 ephi(-nmultdad:nmultdad),eye
c
c----- create array of powers of r and e^(i*m*phi).
c
	data eye/(0.0d0,1.0d0)/
	ephi(0)=1.0d0
	ephi(1)=exp(eye*zrotan)
	ephi(-1)=1.0d0/ephi(1)
	do 1010 l=1,nmultdad-1
	   ephi(l+1)=ephi(l)*ephi(1)
	   ephi(-l-1)=ephi(-l)*ephi(-1)
 1010 continue
c
c----- A rotation of phi radians about the z-axis in the
c      original coordinate system.
c      Note in new version: the scaling of dd is because in previous
c      version, every mpole expansion believes itself living in a unit
c      cell, however in the new scheme the son's mpole needs to live
c      in one of the eight son's of the unit cell, that's cause the
c      scaling before shifting.
c
        dd=2.0d0
        do 1030 l=0,nmultson
	   dd=dd*0.5d0
        do 1020 m=0,l
	   mpson2(l,m)=(mpolson(l,m)*ephi(-m))*dd
 1020 continue
 1030 continue
c
c----- A rotation about the y'-axis  in the rotated system.
c
        do 1060 l=0,nmultson
        do 1050 m=0,l
	   mpson4(l,m)=mpson2(l,0)*rdp(l,0,m)
        do 1040 mp=1,l
	   mpson4(l,m)=mpson4(l,m)+mpson2(l,mp)*rdp(l,mp,m)+
     1          dconjg(mpson2(l,mp))*rdp(l,mp,-m)
 1040 continue
 1050 continue
 1060 continue
c
c----- Shift along z-axis, using rokhlin's new scheme:
c
	nnshrt=nmultson - 1
        do 1070 m=0, nnshrt
	   iarr=imap(m+1)
	   ls=nmultson - m + 1
	   ll=nmultdad - m + 1
	   call mtvc12(arr(iarr),ll,mpdad2(m,m),ls,mpson4(m,m))
 1070 continue
c
c----- Reverse rotation about the y'-axis.
c
        do 1140 l=0,nmultdad
	   ll=min0(l, nnshrt)
        do 1130 m=0,l
	   mpdad4(l,m)=mpdad2(l,0)*rdm(l,0,m)
        do 1120 mp=1,ll
	   mpdad4(l,m)=mpdad4(l,m)+mpdad2(l,mp)*rdm(l,mp,m)+
     1          dconjg(mpdad2(l,mp))*rdm(l,mp,-m)
 1120 continue
 1130 continue
 1140 continue
c
c----- Rotate back phi radians about the z-axis in the above system.
c
        do 1160 l=0,nmultdad
        do 1150 m=0,l
	   mpoldad(l,m)=ephi(m)*mpdad4(l,m)
 1150 continue
 1160 continue
c
	return
	end
c
c
c
c
c
      subroutine mtvc12(arr,nout,vecout,nin,vecin)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This is a matrix and vector multiplication routine, used
c	by LOLO (mpshift), it has the form of A[i,j]*V[j]
c
c Inputs:
c	arr(1): the matrix
c	nout: the order of outgoing vector
c	nin: the order of incoming vector
c	vecin(1): the incoming vector
c
c Outputs:
c	vecout(1): the outgoing vector
c
      complex *16 vecout(1), vecin(1), temp
c
      real *8 arr(nout,nin)
      do 1020 i=1, nout
         temp=0.0d0
      do 1010 j=1, nin
         temp=temp + arr(i,j)*vecin(j)
 1010 continue
         vecout(i)=temp
 1020 continue
c
      return
      end
c
c
c
c
c
      subroutine lcshft(ier,zrotan,nmultdad,locadad,nmultson,locason,
     1                  rdp,rdm,arr,imap,w,lw)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine shifts the local expansion of a parent cell
c	to the center of one of its children, via the rotation scheme.
c	That is, we rotate the coordinate system, shift along the 
c	z-axis, then rotate back.
c	Note this is only a memory management routine, actual code
c	is in "lcshft0"(see below).
c
c Inputs:
c	zrotan: the z-axis rotation angle
c	nmultdad: the order of expansion in daddy box
c	locadad: the expansion coefs of daddy box (input)
c	nmultson: the order of expansion in sonny box
c	rdp,rdm: precomputed array containing rotation matrix
c                about y-axis. rdm is the inverse of rdp
c	arr(1),imap(1): the z-direction shifts data
c
c Outputs:
c	ier: error reporting code
c		=0 no error
c		=8 not enough memory in w(lw)
c	locason: the output expansion in sonny box
c
c Workspaces:
c	(w,lw)
c
c
c
        integer imap(1)
        real *8 arr(1),w(1)
        real *8 rdp(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
c
        real *8 rdm(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
        complex *16 locadad(0:nmultdad,0:nmultdad)
c
        complex *16 locason(0:nmultson,0:nmultson)
	ier=0
c
c ... Memory management:
c
	iat=1
c
	iephi=iat
	lephi=2*(2*nmultdad+1)+7
	iat=iephi+lephi
c
	ilcdad2=iat
	llcdad2=2*(nmultdad+1)*(2*nmultdad+1)+7
	iat=ilcdad2+llcdad2
c
	ilcdad4=iat
	llcdad4=2*(nmultdad+1)*(2*nmultdad+1)+7
	iat=ilcdad4+llcdad4
c
	ilcson2=iat
	llcson2=2*(nmultson+1)*(2*nmultson+1)+7
	iat=ilcson2+llcson2
c
	ilcson4=iat
	llcson4=2*(nmultson+1)*(2*nmultson+1)+7
	iat=ilcson4+llcson4
c
	lrem=lw-iat+1
	if (lrem.le.0) then
	   ier=8
	   return
	endif
c
	call lcshft0(zrotan,nmultdad,locadad,nmultson,locason,rdp,
     1          rdm,arr,imap,w(iephi),w(ilcdad2),w(ilcdad4),
     2		w(ilcson2),w(ilcson4))
c
      return
      end
c
c
c
c
c
      subroutine lcshft0(zrotan,nmultdad,locadad,nmultson,locason,rdp,
     1                   rdm,arr,imap,ephi,lcdad2,lcdad4,lcson2,lcson4)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine shifts the local expansion of a parent cell
c	to the center of one of its children, via the rotation scheme.
c	That is, we rotate the coordinate system, shift along the 
c	z-axis, then rotate back.
c
c Inputs:
c	zrotan: the z-axis rotation angle
c	nmultdad: the order of expansion in daddy box
c	locadad: the expansion coefs of daddy box (input)
c	nmultson: the order of expansion in sonny box
c	rdp,rdm: precomputed array containing rotation matrix
c                about y-axis. rdm is the inverse of rdp
c	arr(1),imap(1): the z-direction shifts data
c
c Outputs:
c	locason: the output expansion in sonny box
c
c Workspaces:
c	lcdad2,lcdad4,lcson2,lcson4,ephi
c
c
c
      integer imap(1)
      real *8 arr(1)
      real *8 rdp(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
c
      real *8 rdm(0:nmultdad,0:nmultdad,-nmultdad:nmultdad)
      complex *16 locadad(0:nmultdad,0:nmultdad)
      complex *16 locason(0:nmultson,0:nmultson)
      complex *16 lcdad2(0:nmultdad,0:nmultdad)
      complex *16 lcdad4(0:nmultdad,0:nmultdad)
      complex *16 lcson2(0:nmultson,0:nmultson)
      complex *16 lcson4(0:nmultson,0:nmultson)
c
      complex *16 ephi(-nmultdad:nmultdad),eye
c
c----- create array of powers of r and e^(i*m*phi).
c
      data eye/(0.0d0,1.0d0)/
        ephi(0)=1.0d0
        ephi(1)=exp(eye*zrotan)
        ephi(-1)=1.0d0/ephi(1)
        do 1010 l=1,nmultdad-1
         ephi(l+1)=ephi(l)*ephi(1)
         ephi(-1-l)=ephi(-l)*ephi(-1)
 1010 continue
c
c----- a rotation of phi radians about the z-axis in the
c      original coordinate system.
c
        do 1050 l=0,nmultdad
        do 1040 m=0,l
	   lcdad2(l,m)=ephi(-m)*locadad(l,m)
 1040 continue
 1050 continue
c
c----- a rotation about the y'-axis to align z' axis. 
c
	nnshrt=nmultson-1
        do 1080 l=0,nmultdad
	   ll=min0(l,nnshrt)
        do 1070 m=0,ll
	   lcdad4(l,m)=lcdad2(l,0)*rdp(l,0,m)
        do 1060 mp=1,l
	   lcdad4(l,m)=lcdad4(l,m)+lcdad2(l,mp)*rdp(l,mp,m)+
     1          dconjg(lcdad2(l,mp))*rdp(l,mp,-m)
 1060 continue
 1070 continue
 1080 continue
c
c----- shift along z'-axis, using rokhlin's compressed scheme:
c
        do 1090 m=0, nnshrt
	   iarr=imap(m+1)
	   ls=nmultson - m + 1
	   ll=nmultdad - m + 1
	   call mtvc43(arr(iarr),ls,lcson2(m,m),ll,lcdad4(m,m))
 1090 continue
c
c----- rotate back about the y'-axis.
c
        do 1160 l=0,nmultson
           ll=min0(l,nnshrt)
        do 1140 m=0,l
	   lcson4(l,m)=lcson2(l,0)*rdm(l,0,m)
        do 1120 mp=1,ll
	   lcson4(l,m)=lcson4(l,m)+lcson2(l,mp)*rdm(l,mp,m)+
     1          dconjg(lcson2(l,mp))*rdm(l,mp,-m)
 1120 continue
 1140 continue
 1160 continue
c
c----- rotate back about the z-axis and rescale expansion to unit cube: 
c
        dd=2.0d0
        do 1240 l=0,nmultson
	   dd=dd*0.5d0
        do 1220 m=0,l
	   locason(l,m)=lcson4(l,m)*ephi(m)*dd
 1220 continue
 1240 continue
c
      return
      end
c
c
c
c
c
      subroutine mtvc43(arr,nout,vecout,nin,vecin)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This is a matrix and vector multiplication routine, used
c	by TATA (lcshift), it has the form of A[j,i]*V[j]
c
c Inputs:
c	arr(1): the matrix
c	nout: the order of outgoing vector
c	nin: the order of incoming vector
c	vecin(1): the incoming vector
c
c Outputs:
c	vecout(1): the outgoing vector
c
      complex *16 vecout(1), vecin(1), temp
c
      real *8 arr(nin,nout)
      do 1020 i=1, nout
         temp=0.0d0
      do 1010 j=1, nin
         temp=temp + arr(j,i)*vecin(j)
 1010 continue
         vecout(i)=temp
 1020 continue
c
      return
      end
c
c
c
c
c
      subroutine direct3d(i, iflagtype, iderivonoff, nparts,
     1    zparts, monocharge, dipstr, dipvec, point, ptfrc,
     2    rpot, eps, close)
      implicit real *8(a-h,o-z)
c
c purpose:
c     direct evaluation of potential and electric field (-gradient)
c     due to a collection of monocharges.
c
c input:
c     nparts =         number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     dipstr(3,nparts) = array of strengths of dipstrs
c     point(3) =       coordinates of evaluation point
c     close =  a user provided subroutine handles near approach
c
c output:
c     rpot = potential due to sources at point. 
c     ptfrc(3) = field at point (- gradient of potential).
c
c----------------------------------------------------------------------------
c
c
      integer *4  nparts, iflagtype, iderivonoff, iflag(2), i
c
      real *8  zparts(3,1), monocharge(1), dipstr(1), dipvec(3,1),
     1   point(3), ptfrc(3), rpot, xinfo1(8), xinfo2(8), xout(4)
      external  close
c
c executions starts:
c
      rpot = 0.0d0
      ptfrc(1) = 0.0d0
      ptfrc(2) = 0.0d0
      ptfrc(3) = 0.0d0
c
      do 1000 j = 1, nparts
c
        if(i .eq. j) goto 1000
c
        rx = point(1) - zparts(1,j)
        ry = point(2) - zparts(2,j)
        rz = point(3) - zparts(3,j)
        rr = rx*rx + ry*ry + rz*rz
        rdis = dsqrt(rr)
c
c ... the if statement takes care of two points getting too close, also
c     eliminates the case of point and one of zparts(*,j) coincides:
c
        if(rdis .gt. eps)then
c
          if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
            rpot = rpot + monocharge(j)/rdis
c
            if(iderivonoff .eq. 1)then
              rmul = monocharge(j)/(rdis*rr)
c
              ptfrc(1) = ptfrc(1) + rmul*rx
              ptfrc(2) = ptfrc(2) + rmul*ry
              ptfrc(3) = ptfrc(3) + rmul*rz
            endif
c
          endif
c
          if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
            rtmp = dipstr(j) * (dipvec(1,j) * rx
     1                           + dipvec(2,j) * ry
     2                           + dipvec(3,j) * rz)
            rrr = rdis*rr
            rpot = rpot + rtmp/rrr
c
            if(iderivonoff .eq. 1)then
              rrrrr = rrr*rr
              rtttt = 3.0d0*rtmp/rrrrr
              rtmp2 = dipstr(j) / rrr
c
              ptfrc(1) = ptfrc(1)
     1                 - dipvec(1,j) * rtmp2 + rx * rtttt
              ptfrc(2) = ptfrc(2)
     1                 - dipvec(2,j) * rtmp2 + ry * rtttt
              ptfrc(3) = ptfrc(3)
     1                 - dipvec(3,j) * rtmp2 + rz * rtttt
            endif
c
          endif
c
        endif
c
        if(rdis .le. eps)then
c
          iflag(1) = iflagtype
          iflag(2) = iderivonoff
c
          if(iflagtype .eq. 0)then
            xinfo1(1) = zparts(1,i)
            xinfo1(2) = zparts(2,i)
            xinfo1(3) = zparts(3,i)
            xinfo1(4) = monocharge(i)
            xinfo1(5) = 0d0
            xinfo1(6) = 0d0 
            xinfo1(7) = 0d0 
            xinfo1(8) = 0d0 
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = monocharge(j)
            xinfo2(5) = 0d0 
            xinfo2(6) = 0d0 
            xinfo2(7) = 0d0 
            xinfo2(8) = 0d0 
          endif
c
          if(iflagtype .eq. 1)then
            xinfo1(1) = zparts(1,i)
            xinfo1(2) = zparts(2,i)
            xinfo1(3) = zparts(3,i)
            xinfo1(4) = 0d0
            xinfo1(5) = dipstr(i)
            xinfo1(6) = dipvec(1,i)
            xinfo1(7) = dipvec(2,i)
            xinfo1(8) = dipvec(3,i)
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = 0d0
            xinfo2(5) = dipstr(j)
            xinfo2(6) = dipvec(1,j)
            xinfo2(7) = dipvec(2,j)
            xinfo2(8) = dipvec(3,j)
          endif
c
          if(iflagtype .eq. 2)then
            xinfo1(1) = zparts(1,i)
            xinfo1(2) = zparts(2,i) 
            xinfo1(3) = zparts(3,i)
            xinfo1(4) = monocharge(i)
            xinfo1(5) = dipstr(i)
            xinfo1(6) = dipvec(1,i)
            xinfo1(7) = dipvec(2,i)
            xinfo1(8) = dipvec(3,i)
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = monocharge(j)
            xinfo2(5) = dipstr(j)
            xinfo2(6) = dipvec(1,j)
            xinfo2(7) = dipvec(2,j)
            xinfo2(8) = dipvec(3,j)
          endif
c
          call close(i, j, eps, xinfo1, xinfo2, iflag, xout)
c
          rpot = rpot + xout(1)
c
          if(iderivonoff .eq. 1)then
            ptfrc(1) = ptfrc(1) + xout(2)
            ptfrc(2) = ptfrc(2) + xout(3)
            ptfrc(3) = ptfrc(3) + xout(4)
          endif
c
        endif
c
 1000 continue
c
      return
      end
c
c
c
c
c
      subroutine formta3d(iflagtype, x0y0z0, zparts,
     1    monocharge, dipstr, dipvec, nparts, local,
     2    nterms, nntrms, scale, dc, pp, iz, istart)
      implicit real *8(a-h,o-z)
c
c purpose:
c     forming taylor expansion due to a collection of points.
c
c input:
c     x0y0z0 = center of the expansion
c     nparts = number of sources
c     zparts(3,nparts) = array of z-coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     nterms = order of desired expansion
c
c output:
c     local  =  coefficients of local expansion
c
c---------------------------------------------------------------------------
c
c
      integer *4  nterms, nparts, iflagtype, iz(1), istart, jj
c
      real *8  pp(0:nntrms,0:nntrms), powers(0:53), x0y0z0(3),
     1   zparts(3,1), monocharge(1), dipstr(1),
     2   dipvec(3,1), dc(0:4*nterms,0:4*nterms)
c
      complex *16  local(0:nterms,0:nterms),
     1   eye, ephi(-53:53), c11, c12, ctmp
c
c ***  set local to zero
c
      data sq2/0.70710678118655d0/
      data eye/(0.0d0,1.0d0)/
      data precis/1.0d-19/
      do 1500 l = 0,nterms
        do 1000 m = 0, l
          local(l,m) = 0.0d0
 1000   continue
 1500 continue
c
      do 5500 jj = 1, nparts
c
         i = iz(istart+jj)
c
         rx = zparts(1,i) - x0y0z0(1)
         ry = zparts(2,i) - x0y0z0(2)
         rz = zparts(3,i) - x0y0z0(3)
c
c ***  compute  distance rr
c              ctheta = cos(theta)
c              ephi(1)=e^(i*phi)
c
         proj = rx*rx+ry*ry
         rr = proj+rz*rz
         proj = dsqrt(proj)
         d = dsqrt(rr)
c
c ***  note: here is a heck. when computing cos(theta) as
c              rz/d, we have to be careful about the possibility
c              of d  being 0 (in which case ctheta is not well
c              defined - we arbitrarily set it to 1.)
c
         if(d .le. precis) ctheta = 1.0d0
c
         if(d .gt. precis) ctheta = rz/d
c
         if(proj .le. precis*d)then
           ephi(1) = 1.0d0
           ephi(-1) = 1.0d0
         endif
c
         if(proj .gt. precis*d)then
           ephi(1) = rx/proj + eye*ry/proj
           ephi(-1) = dconjg(ephi(1))
         endif
c
c ***  create array of powers of r and powers of e^(i*phi).
c
         ephi(0) = 1.0d0
         powers(0) = monocharge(i)
         powers(1) = monocharge(i)/d
         dd = 1/(d*scale)
         do 2000 l = 2,nntrms+3
           powers(l) = powers(l-1)*dd
           ephi(l) = ephi(l-1)*ephi(1)
           ephi(-l) = dconjg(ephi(l))
 2000    continue
c
c ***  compute legendre polynomials of argument cos(theta) = ctheta
c      and add contributions from legendre polynomials
c
         call sclgdr(nntrms,ctheta,pp)
c
         if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c 
           local(0,0) = local(0,0) + powers(1)
           do 3000 l = 1,nntrms
             local(l,0) = local(l,0) + powers(l+1)*pp(l,0)
             do 2500 m=1,l
               cp = powers(l+1)*pp(l,m)/dc(l+m,2*m)
               local(l,m) = local(l,m) + cp*ephi(-m)
 2500        continue
 3000      continue
c
         endif
c
c *** now calculate the contribution from the dipstr
c
         if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
            c10 = dipvec(3,i) * dipstr(i) * scale
            c11 = dipstr(i) * dcmplx(-dipvec(1,i) * sq2,
     1                                dipvec(2,i) * sq2) * scale
c
            c12 = dconjg(c11)
            if (abs(monocharge(i)) .gt. 1.0d-20) then
              do 3500 l = 0,nntrms+3
                powers(l) = powers(l)/monocharge(i)
 3500         continue
            endif
c
            if (abs(monocharge(i)) .le. 1.0d-20) then
              powers(0) = 1.0d0
              powers(1) = 1.0d0/d
              do 4000 l = 2,nntrms+3
                powers(l) = powers(l-1)*dd
 4000         continue
            endif

            do 5000 l = 0,nntrms-1
              lp1 = l + 1
              dtmp=lp1*pp(lp1,0)*c10+2.0d0*pp(lp1,1)*dreal(ephi(1)*c11)
              local(l,0) = local(l,0) - powers(l+2)*dtmp
              do 4500 m=1,l
                dtmp = dc(lp1+m,1)*dc(lp1-m,1)/dc(lp1+m,m+m)*pp(lp1,m)
                ctmp = (dtmp*c10)*ephi(-m)
                dtmp = dc(l-m+2,2)/dc(l+m,m+m-2)*pp(lp1,m-1)
                ctmp = ctmp - dtmp*c11*ephi(1-m)
                dtmp = dc(l+m+2,2)/dc(l+m+2,m+m+2)*pp(lp1,m+1)
                ctmp = ctmp + dtmp*c12*ephi(-1-m)
                local(l,m) = local(l,m) - powers(l+2)*ctmp
 4500         continue
 5000       continue
c
         endif
c
 5500 continue
c
      return
      end
c
c
c
c
c
      subroutine brtaev3d(iderivonoff, local, x0y0z0, point,
     1     nterms, nntrms, rpot, field, scale, dc, pp)
      implicit real *8(a-h,o-z)
c
c purpose:
c	evaluates a local expansion at an arbitrary point.
c	this subroutine is a corrected version of the old one
c	"brtaev_err" (see below).
c
c input:
c	local  =  coefficients of local expansion
c	x0y0z0 = the center of the expansion
c	point = point of evaluation
c	nterms = order of expansion
c
c output:
c	rpot  = computed potential
c	field = computed electrostatic field
c
c-----------------------------------------------------------------------------
c
c
      integer *4  nterms, iderivonoff
c
      real *8  x0y0z0(3), precis, point(3), rpot, field(3),
     1    pp(0:nntrms,0:nntrms), dc(0:4*nterms,0:4*nterms),
     2    powers(0:51), rea(2)
c
      complex *16  ephi(-52:52), eye, com, dplus,
     1    locallm, local((nterms+1)*(nterms+2)/2)
      equivalence (rea(1),com)
c
c
c execution starts:
c
      data eye/(0.0d0,1.0d0)/
      data precis/1.0d-19/
	two=2.0d0
	sq2=sqrt(two)
	rpot = 0.0d0
	field(1) = 0.0d0
	field(2) = 0.0d0
	field(3) = 0.0d0
c
c *** compute relevant functions of spherical coordinates
c      d = distance, ctheta = cos(theta), ephi = exp(i*phi)
c
	rx = point(1) - x0y0z0(1)
	ry = point(2) - x0y0z0(2)
	rz = point(3) - x0y0z0(3)
	proj2 = rx*rx+ry*ry
	rr = proj2+rz*rz
	proj = sqrt(proj2)
	d = sqrt(rr)
c
c *** it is actually very tricky when calculating at the expansion
c     centre in the sense that it is not obvious from the formula:
c
	if (d .le. precis) then
	   com=local(2)
	   dr = scale*rea(1)
	   com = sq2*scale*local(3)
	   field(1) = rea(1)
	   field(2) = -rea(2)
	   field(3) = -dr
c
	   com=local(1)
	   rpot = rea(1)
	   return
	endif
c
	ctheta = rz/d
	drx = rx/d
	dry = ry/d
	drz = rz/d
c
	if ( proj .le. precis*d ) then
	   ephi(1) = 1.0d0
	   ephi(-1) = 1.0d0
	endif
c
	if ( proj .gt. precis*d ) then
	   rea(1)=rx/proj
	   rea(2)=ry/proj
	   ephi(1) = com
	   rea(2)=-rea(2)
	   ephi(-1) = com
	endif
c
c *** create array of powers of r and e^(i*m*phi).
c
        d = d*scale
        dd = d
        powers(0) = 1.0d0
        ephi(0)=1.0d0
        do 1000 l = 1,nntrms+1
	   powers(l) = dd
	   dd = dd*d
	   com = ephi(l)*ephi(1)
	   ephi(l+1) = com
	   rea(2)=-rea(2)
	   ephi(-1-l) = com
 1000 continue
c
c ***  compute values of legendre functions
c
	call sclgdr(nntrms,ctheta,pp)
c
c *** the term local(0,0) only contributes to potential:
c
	com=local(1)
	rpot = rpot + rea(1)
        dz=0.0d0
	dplus=0.0d0
c
c *** add contributions from terms with local(l,0):
c
        do 2000 l = 1,nntrms
	   com=local(l*(l+1)/2+1)
	   tmp=rea(1)
c
	   rpot = rpot+tmp*powers(l)*pp(l,0)
c
	   if(iderivonoff .eq. 1)then
	      dz=dz+l*powers(l-1)*pp(l-1,0)*tmp
c
              rtmp = 0d0
              
	      if(l .gt. 1) rtmp=sq2*powers(l-1)*pp(l-1,1)*tmp
c
	      dplus=dplus+rtmp*ephi(1)
c
	   endif
 2000 continue
c
c *** add contributions from terms with local(l,m) (m not zero):
c
	prpot=0
	pdz=0
        do 4000 l = 1,nntrms
	   do 3000 m = 1,l
	      locallm=local(l*(l+1)/2+m+1)
	      com=locallm*ephi(m)
	      prpot=prpot+rea(1)*powers(l)*pp(l,m)/dc(l+m,2*m)
c
	      if(iderivonoff .eq. 1)then
		 if (m.le.l-1) then
		    pdz=pdz+rea(1)*powers(l-1)
     1			*dc(l-m,1)*dc(l+m,1)*pp(l-1,m)/dc(l-1+m,2*m)
		 endif
c
		 rtmp=sq2*dc(l+m,2)*powers(l-1)*pp(l-1,m-1)
     1			/dc(l+m-2,2*m-2)
		 com=locallm*ephi(m-1)
	 	 rea(2)=-rea(2)
		 dplus=dplus-rtmp*com
c
		 if (m+1.le.l-1) then
		    com=locallm*ephi(m+1)
	 	    rtmp=sq2*dc(l-m,2)*powers(l-1)*pp(l-1,m+1)
     1			/dc(l+m,2*m+2)
		    dplus=dplus+rtmp*com
		 endif
	      endif
 3000 continue
 4000 continue
c
	rpot=rpot+two*prpot
	if(iderivonoff .eq. 1)then
	   com=dplus
c
	   field(1)=-scale*rea(1)
	   field(2)=-scale*rea(2)
	   field(3)=-scale*(dz+two*pdz)
	endif
c
	return
	end
c
c
c
c
c
      subroutine mpeval3d(iderivonoff, mpole, x0y0z0, point,
     1     nterms, nntrms, rpot, field, scale, dc, pp)
c
c purpose:
c     evaluates multipole expansion at arbitrary point.
c
c input:
c     mpole  =  coefficients of multipole expansion
c     x0y0z0 = the center of the expansion
c     point = point of evaluation
c     nterms = order of expansion
c
c output:
c     rpot  = computed potential
c     field  = computed field
c  
c-----------------------------------------------------------------------
c
      implicit real *8(a-h,o-z)
c
c
      integer *4  nterms, iderivonoff
c
      real *8  x0y0z0(3), precis, point(3), rpot, field(3),
     1  pp(0:nntrms+1,0:nntrms+1), dc(0:4*nterms,0:4*nterms),
     2  powers(0:51)
c
      complex *16  ephi(-52:52), eye, dplus,
     1  ctmp1, ctmp2, mpole(0:nterms,0:nterms)
c
c execution starts:
c
      data eye/(0.0,1.0)/
      data precis/1.0d-19/
      sq2 = dsqrt(2.0d0)
      rpot = 0.0d0
      field(1) = 0.0d0
      field(2) = 0.0d0
      field(3) = 0.0d0
      dplus = 0.0d0
c
c ... compute  distance rr:
c              ctheta = cos(theta)
c              ephi(1)=e^(i*phi)
c
      rx = point(1) - x0y0z0(1)
      ry = point(2) - x0y0z0(2)
      rz = point(3) - x0y0z0(3)
c
      proj = rx*rx+ry*ry
      rr = proj+rz*rz
      proj = dsqrt(proj)
      d = 1.0d0/dsqrt(rr)
      ctheta = rz*d
      if ( proj .le. precis/d ) then
         ephi(1) = 1.0d0
         ephi(-1) = 1.0d0
      endif
c
      if ( proj .gt. precis/d ) then
         ephi(1) = rx/proj + eye*ry/proj
         ephi(-1) = dconjg(ephi(1))
      endif
c
c ... create array of inverse powers of r and e^(i*m*phi):
c
      ephi(0) = 1.0d0
      powers(0) = 1.0d0
      powers(1) = d
      d = d/scale
      do 100 l = 2,nntrms+2
         powers(l) = powers(l-1)*d
         ephi(l) = ephi(l-1)*ephi(1)
         ephi(-l) = dconjg(ephi(l))
 100  continue
c
c ... compute legendre polynomials of argument cos(theta) = ctheta
c
      call sclgdr(nntrms+1,ctheta,pp)
c
c ... add contribution from monopole moment:
c
      rtmp = dreal(mpole(0,0))

      rpot = rpot + rtmp*powers(1)

      rtmp = rtmp*powers(2)
      rtmp1 = rtmp*pp(1,1)*sq2
      dplus = dplus - ephi(1)*rtmp1

      if(iderivonoff .eq. 1)then
         field(3) = field(3) + rtmp*pp(1,0)
      endif
c
c ... add contributions from legendre polynomials:
c
      do 101 l = 1,nntrms

         rmpole = dreal(mpole(l,0))
         lp1 = l + 1

         rtmp = rmpole*powers(lp1)*pp(l,0)
         rpot = rpot + rtmp

         if(iderivonoff .eq. 1)then
           rmpole = rmpole*powers(l+2)
           rtmp = rmpole*pp(lp1,1)*sq2
           dplus = dplus - rtmp*ephi(1)

           field(3) = field(3) + rmpole*pp(lp1,0)*lp1
         endif
 101  continue
c
c ... add contributions from associated legendre functions:
c
      do 103 l = 1,nntrms
         lp1 = l+1
         lp2 = l+2
         do 102 m=1,l
            m2 = 2*m
            mm1 = m-1
            mp1 = m+1
            lpm = l+m
            lpmp1 = lpm+1
            lpmp2 = lpm+2

            rtmp = 2.0d0*dreal(mpole(l,m)*ephi(m))
            rpot = rpot + rtmp*powers(lp1)*pp(l,m)/dc(lpm,m2)

            if(iderivonoff .eq. 1)then
               ctmp1 = mpole(l,m)*ephi(mp1)
               ctmp2 = dconjg(mpole(l,m)*ephi(mm1))
               ptmp = sq2*powers(lp2)
               rtmp1 = ptmp*pp(lp1,mp1)/dc(lpmp2,m2+2)*dc(lpmp2,2)
               rtmp2 = ptmp*pp(lp1,mm1)/dc(lpm,m2-2)*dc(lp1-mm1,2)
               dplus = dplus - ctmp1*rtmp1 + ctmp2*rtmp2

               rtmp3 = rtmp*pp(lp1,m)*powers(lp2)/dc(lpmp1,m2)
               field(3) = field(3) + rtmp3*dc(lp1-m,1)*dc(lpmp1,1)
            endif

 102     continue
 103  continue
c
c ... the x and y derivative are sought from the operator d_x + i*d_y:
c
      if(iderivonoff .eq. 1)then
         field(1) = dreal(dplus)
         field(2) = dimag(dplus)
c
         field(1) = field(1)*scale
         field(2) = field(2)*scale
         field(3) = field(3)*scale
      endif
c
      return
      end
c
c
c
c
c
      subroutine xcp21(nterms,a,n2,b)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine trims a long multipole expansion a
c	to a short multipole expansion b.
c
c Inputs:  
c	a: multipole expansion
c	nterms: order of a
c	n2: order of b
c
c Outputs:
c	b: the shorted multipole expansion
c
c----------------------------------------------------------------------------
c
c
	complex *16  b(0:n2,0:n2), a(0:nterms,0:nterms)
        do 2000 i = 0, n2
        do 1000 j = 0, i
          b(i,j) = a(i,j)
 1000   continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine addexp3d(b,a,nterms)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine add to multipole expansion a (which is 
c	stored optimally) the multipole expansion b (which is stored
c	plainly)
c
c Inputs:  
c	a: multipole expansion (stored optimally)
c	nterms: order of a and b
c	b: multipole expansion (stored plainly)
c
c Outputs:
c	a: on output, it was added b
c
c-----------------------------------------------------------------------------
c
c
      complex *16  b(0:nterms,0:nterms), a(((nterms+1)*(nterms+2))/2)
        ncrrnt = 0
        do 2000 i = 0, nterms
        do 1000 j = 0, i
          ncrrnt = ncrrnt + 1
          a(ncrrnt) = a(ncrrnt) + b(i,j)
 1000   continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine addx123d(b, nshort, a, nterms)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine adds to multipole expansion a (which is 
c	stored optimally) the multipole expansion b (which is stored
c	plainly)
c
c Inputs:  
c	a: multipole expansion (stored optimally)
c	nterms: order of a
c	b: a short multipole expansion (stored plainly)
c	nshort: order of b
c
c Outputs:
c	a: on output, it was added b
c
c-----------------------------------------------------------------------------
c
c
      complex *16  b(0:nshort,0:nshort), a(((nterms+1)*(nterms+2))/2)
	ncrrnt = 0
        do 2000 i = 0,nshort
          do 1000 j = 0,i
            ncrrnt = ncrrnt + 1
            a(ncrrnt) = a(ncrrnt) + b(i,j)
 1000     continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine maptmp3d(mpin, mpole, nterms)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine maps a multipole expansion from its optimized
c	storage plan to that of unoptimized one.
c
c Inputs:
c	nterms: order of multpole expansion
c	mpin: the output expansion allocated with only necessary 
c	      storage space ((nterms+1)*(nterms+2))/2
c
c Outputs:
c	mpole: the multipole expansion stored as (0:nterms,0:nterms)
c
c-----------------------------------------------------------------------------
c
c
	complex *16 mpole(0:nterms,0:nterms),
     1        mpin(((nterms+1)*(nterms+2))/2)
	ncrrnt=0
        do 2000 i=0, nterms
          do 1000 j=0, i
            ncrrnt=ncrrnt + 1
            mpole(i,j)=mpin(ncrrnt)
 1000     continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine directtarg3d(iflagtype, iderivonoff, nparts, zparts,
     1    monocharge, dipstr, dipvec, point, ip, ptfrc, rpot, eps, close)
      implicit real *8(a-h,o-z)
c
c purpose:
c     direct evaluation of potential and electric field (-gradient)
c     due to a collection of monocharges.
c
c input:
c     nparts =         number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     dipstr(3,nparts) = array of strengths of dipstrs
c     point(3) =       coordinates of evaluation point
c     ip = index of evaluation point
c
c output:
c     rpot = potential due to sources at point. 
c     ptfrc(3) = field at point (- gradient of potential).
c
c----------------------------------------------------------------------------
c
c
      integer *4  nparts, iflagtype, iderivonoff, iflag(2), i, ip
c
      real *8  zparts(3,1), monocharge(1), dipstr(1), dipvec(3,1),
     1   point(3), ptfrc(3), rpot, xinfo1(8), xinfo2(8), xout(4)
      external close
c
c executions starts:
c
      rpot = 0.0d0
      ptfrc(1) = 0.0d0
      ptfrc(2) = 0.0d0
      ptfrc(3) = 0.0d0
c
      do 1000 j = 1, nparts
c
        rx = point(1) - zparts(1,j)
        ry = point(2) - zparts(2,j)
        rz = point(3) - zparts(3,j)
        rr = rx*rx + ry*ry + rz*rz
        rdis = dsqrt(rr)
c
        if(rdis .gt. eps)then
c
          if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
            rpot = rpot + monocharge(j)/rdis
c
            if(iderivonoff .eq. 1)then
              rmul = monocharge(j)/(rdis*rr)
c
              ptfrc(1) = ptfrc(1) + rmul*rx
              ptfrc(2) = ptfrc(2) + rmul*ry
              ptfrc(3) = ptfrc(3) + rmul*rz
            endif
c
          endif
c
          if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
            rtmp = dipstr(j) * (dipvec(1,j) * rx
     1                        + dipvec(2,j) * ry
     2                        + dipvec(3,j) * rz)
            rrr = rdis*rr
            rpot = rpot + rtmp/rrr
c
            if(iderivonoff .eq. 1)then
              rrrrr = rrr * rr
              rtttt = 3.0d0 * rtmp / rrrrr
              rtmp2 = dipstr(j) / rrr
c
              ptfrc(1) = ptfrc(1)
     1                 - dipvec(1,j) * rtmp2 + rx * rtttt
              ptfrc(2) = ptfrc(2)
     1                 - dipvec(2,j) * rtmp2 + ry * rtttt
              ptfrc(3) = ptfrc(3)
     1                 - dipvec(3,j) * rtmp2 + rz * rtttt
            endif
c
          endif
c
        endif
c
        if(rdis .le. eps)then
c
          iflag(1) = iflagtype
          iflag(2) = iderivonoff
c
          if(iflagtype .eq. 0)then
            xinfo1(1) = point(1)
            xinfo1(2) = point(2)
            xinfo1(3) = point(3)
            xinfo1(4) = 0d0
            xinfo1(5) = 0d0
            xinfo1(6) = 0d0 
            xinfo1(7) = 0d0 
            xinfo1(8) = 0d0 
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = monocharge(j)
            xinfo2(5) = 0d0 
            xinfo2(6) = 0d0 
            xinfo2(7) = 0d0 
            xinfo2(8) = 0d0 
          endif
c
          if(iflagtype .eq. 1)then
            xinfo1(1) = point(1)
            xinfo1(2) = point(2)
            xinfo1(3) = point(3)
            xinfo1(4) = 0d0
            xinfo1(5) = 0d0
            xinfo1(6) = 0d0
            xinfo1(7) = 0d0
            xinfo1(8) = 0d0
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = 0d0
            xinfo2(5) = dipstr(j)
            xinfo2(6) = dipvec(1,j)
            xinfo2(7) = dipvec(2,j)
            xinfo2(8) = dipvec(3,j)
          endif
c
          if(iflagtype .eq. 2)then
            xinfo1(1) = point(1)
            xinfo1(2) = point(2)
            xinfo1(3) = point(3)
            xinfo1(4) = 0d0
            xinfo1(5) = 0d0
            xinfo1(6) = 0d0
            xinfo1(7) = 0d0
            xinfo1(8) = 0d0
c
            xinfo2(1) = zparts(1,j)
            xinfo2(2) = zparts(2,j)
            xinfo2(3) = zparts(3,j)
            xinfo2(4) = monocharge(j)
            xinfo2(5) = dipstr(j)
            xinfo2(6) = dipvec(1,j)
            xinfo2(7) = dipvec(2,j)
            xinfo2(8) = dipvec(3,j)
          endif
c
          call close(ip, j, eps, xinfo1, xinfo2, iflag, xout)
c
          rpot = rpot + xout(1)
c
          if(iderivonoff .eq. 1)then
            ptfrc(1) = ptfrc(1) + xout(2)
            ptfrc(2) = ptfrc(2) + xout(3)
            ptfrc(3) = ptfrc(3) + xout(4)
          endif
c
        endif
c
 1000 continue
c
      return
      end
c
c
c
c
c
      subroutine formtatarg3d(iflagtype, x0y0z0, zparts,
     1    monocharge, dipstr, dipvec, local, nterms, nntrms,
     2    scale, dc, pp, izsour, zboxsour, ilbox)
      implicit real *8(a-h,o-z)
c
c purpose:
c     forming taylor expansion due to a collection of points.
c
c input:
c     x0y0z0 = center of the expansion
c     nparts = number of sources
c     zparts(3,nparts) = array of z-coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     nterms = order of desired expansion
c
c output:
c     local  =  coefficients of local expansion
c
c---------------------------------------------------------------------------
c
c
      integer *4  nterms, iflagtype, jj, izsour(1), zboxsour(2,1)
c
      real *8  pp(0:nntrms,0:nntrms), powers(0:53),
     1   x0y0z0(3), zparts(3,1), monocharge(1), dipstr(1),
     2   dipvec(3,1), dc(0:4*nterms,0:4*nterms)
c
      complex *16  local(0:nterms,0:nterms),
     1   eye, ephi(-53:53), c11, c12, ctmp
c
c ***  set local to zero
c
      data sq2/0.70710678118655d0/
      data eye/(0.0d0,1.0d0)/
      data precis/1.0d-19/
      do 1500 l = 0, nterms
        do 1000 m = 0, l
          local(l,m) = 0.0d0
 1000   continue
 1500 continue
c
      istartsource = zboxsour(1,ilbox)
      iendsource = zboxsour(1,ilbox) + zboxsour(2,ilbox) - 1
c
      do 5500 jj = istartsource, iendsource
c
        i = izsour(jj)
c
        rx = zparts(1,i) - x0y0z0(1)
        ry = zparts(2,i) - x0y0z0(2)
        rz = zparts(3,i) - x0y0z0(3)
c
c ***  compute  distance rr
c              ctheta = cos(theta)
c              ephi(1)=e^(i*phi)
c
        proj = rx*rx+ry*ry
        rr = proj+rz*rz
        proj = dsqrt(proj)
        d = dsqrt(rr)
c
c ***  note: here is a heck. when computing cos(theta) as
c              rz/d, we have to be careful about the possibility
c              of d  being 0 (in which case ctheta is not well
c              defined - we arbitrarily set it to 1.)
c
        if(d .le. precis) ctheta = 1.0d0
c
        if(d .gt. precis) ctheta = rz/d
c
        if(proj .le. precis*d)then
          ephi(1)  = 1.0d0
          ephi(-1) = 1.0d0
        endif
c
        if(proj .gt. precis*d)then
          ephi(1)  = rx/proj + eye*ry/proj
          ephi(-1) = dconjg(ephi(1))
        endif
c
c ***  create array of powers of r and powers of e^(i*phi).
c
        ephi(0) = 1.0d0
        powers(0) = monocharge(i)
        powers(1) = monocharge(i)/d
        dd = 1/(d*scale)
        do 2000 l = 2, nntrms+3
          powers(l) = powers(l-1)*dd
          ephi(l)   = ephi(l-1)*ephi(1)
          ephi(-l)  = dconjg(ephi(l))
 2000   continue
c
c ***  compute legendre polynomials of argument cos(theta) = ctheta
c      and add contributions from legendre polynomials
c
        call sclgdr(nntrms,ctheta,pp)
c
        if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
          local(0,0) = local(0,0) + powers(1)
          do 3000 l = 1, nntrms
            local(l,0) = local(l,0) + powers(l+1)*pp(l,0)
            do 2500 m = 1, l
              cp = powers(l+1)*pp(l,m)/dc(l+m,2*m)
              local(l,m) = local(l,m) + cp*ephi(-m)
 2500       continue
 3000     continue
c
        endif
c
c *** now calculate the contribution from the dipstr
c
        if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
          c10 = dipvec(3,i) * dipstr(i) * scale
          c11 = dipstr(i) * dcmplx(-dipvec(1,i) * sq2,
     1                              dipvec(2,i) * sq2) * scale
c
          c12 = dconjg(c11)
          if (abs(monocharge(i)) .gt. 1.0d-20) then
            do 3500 l = 0, nntrms+3
              powers(l) = powers(l)/monocharge(i)
 3500       continue
          endif
c
          if (abs(monocharge(i)) .le. 1.0d-20) then
            powers(0) = 1.0d0
            powers(1) = 1.0d0/d
            do 4000 l = 2, nntrms+3
              powers(l) = powers(l-1)*dd
 4000       continue
          endif
c
          do 5000 l = 0, nntrms-1
            lp1 = l + 1
            dtmp=lp1*pp(lp1,0)*c10+2.0d0*pp(lp1,1)*dreal(ephi(1)*c11)
            local(l,0) = local(l,0) - powers(l+2)*dtmp
            do 4500 m = 1, l
              dtmp = dc(lp1+m,1)*dc(lp1-m,1)/dc(lp1+m,m+m)*pp(lp1,m)
              ctmp = (dtmp*c10)*ephi(-m)
              dtmp = dc(l-m+2,2)/dc(l+m,m+m-2)*pp(lp1,m-1)
              ctmp = ctmp - dtmp*c11*ephi(1-m)
              dtmp = dc(l+m+2,2)/dc(l+m+2,m+m+2)*pp(lp1,m+1)
              ctmp = ctmp + dtmp*c12*ephi(-1-m)
              local(l,m) = local(l,m) - powers(l+2)*ctmp
 4500       continue
 5000     continue
c
        endif
c
 5500 continue
c
      return
      end
c
C///////////////////////////////////////////////////////////////////////
      subroutine phystof12(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1)
      real *8     rlams(nlambs),pi
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      complex *16 eye,ztheta
C-----------------------------------------------------------------------
      data eye/(0.0d0,1.0d0)/
      pi=4.0d0*datan(1.0d0)
      nftot = 1
      nptot  = 1
C_lambda_1
      call ptf8to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+4
C_lambda_2
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_3
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_4
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_5
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_6
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_7
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+16
C_lambda_8
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_9
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_10
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_11
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+24
C_lambda_12
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_13
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_14
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+32
C_lambda_15
      call ptf72tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+36
C_lambda_16
      call ptf72tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+36
C_lambda_17
      call ptf80tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+40
C_lambda_18
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),20)
      nftot = nftot+20
      nptot = nptot+44
C_lambda_19
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+44
C_lambda_20
      call ptf96tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+48
C_lambda_21
      call ptf96tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+48
C_lambda_22
      call ptf104tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_23
      call ptf104tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_24
      call ptf104tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+52
C_lambda_25
      call ptf124tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_26
      call ptf124tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_27
      call ptf124tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_28
      call ptf124tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_29
      call ptf132tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_30
      call ptf132tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_31
      call ptf132tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+66
C_lambda_32
      call ptf124tonnfft(mexpf(nftot),mexpphys(nptot),23)
      nftot = nftot+23
      nptot = nptot+62
C_lambda_33
      call ptf104tonnfft(mexpf(nftot),mexpphys(nptot),20)
cc      do iii = 1, 52
cc         print *, mexpphys(nptot+iii-1)
cc      enddo
cc      print *, 'out fourier modes:***'
cc      do iii = 1, 20
cc         print *, mexpf(nftot+iii-1)
cc      enddo
cc      pause 'check'
      nftot = nftot+20
      nptot = nptot+52
C_lambda_34
ccc      call ptf4tonnfft(mexpf(nftot),mexpphys(nptot),16)
      rtmp1=dreal(mexpphys(nptot))
      rtmp2=dreal(mexpphys(nptot+1))
      ritmp1=dimag(mexpphys(nptot))
      ritmp2=dimag(mexpphys(nptot+1))
      ztheta=-eye*pi*0.5d0
c
      mexpf(nftot)=(rtmp1+rtmp2)/2
c ... odd:
      do j=2,15,2
         mexpf(nftot+j)=(rtmp1+rtmp2*cdexp(j*ztheta))*0.5d0
      enddo
c ... even:
      do j=1,15,2
         mexpf(nftot+j)=(ritmp1+ritmp2*cdexp(j*ztheta))*0.5d0*eye
      enddo
      nftot = nftot+16
      nptot = nptot+2
C_lambda_35
      mexpf(nftot)=dreal((mexpphys(nptot)+mexpphys(nptot+1))/2)
C
      return
      end
C
C
C
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf96tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 48)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 eye, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data eye/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -eye*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf104tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 52)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 eye, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data eye/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -eye*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf124tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 62)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 eye, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data eye/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -eye*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf132tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 66)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 eye, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data eye/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -eye*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
c
c
c
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine phystof1(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine converts the discretized exponential moment 
c     function into its fourier expansion.
c
c input:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows:
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)), etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2
c               etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer  nlambs,nmfour(nlambs),nmphys(nlambs),nthmax
c
      real *8     rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      mexpf(1)=0.5d0*dreal(mxphys(1)+mxphys(2))
ccc      call pf4t1(mexpf(nftot),mxphys(nptot))
      nftot = nftot+1
      nptot = nptot+2
c_lambda_2
      call pf4t2(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_3
      call pf4t2(mexpf(nftot),mxphys(nptot))
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf4t1(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8 mexpf(2,1), mxphys(2,2)
      mexpf(1,1) = (mxphys(1,1)+mxphys(1,2))*0.5d0
      mexpf(2,1) = 0.0d0
c=======================================================================
      return
      end
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine phystof2(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine converts the discretized exponential moment 
c     function into its fourier expansion.
c
c input:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows:
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)), etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2
c               etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer  nlambs,nmfour(nlambs),nmphys(nlambs),nthmax
c
      real *8     rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      call pf4t2(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_2
      call pf8t2(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+4
c_lambda_3
      call pf8t3(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_4
      call pf8t3(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_5
ccc      call pf4t1(mexpf(nftot),mxphys(nptot))
      mexpf(nftot)=0.5d0*dreal(mxphys(nptot)+mxphys(nptot+1))
c=======================================================================
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf8t2(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,2), mxphys(2,4)
c
      data hsq2/0.70710678118655d0/
      xa = mxphys(1,1)+mxphys(1,3)
      xb = mxphys(1,2)+mxphys(1,4)
c
      mexpf(1,1) = (xa+xb)*0.25d0
      mexpf(2,1) = 0.0d0
c
      xc = hsq2*mxphys(2,2)
      xd = hsq2*mxphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
c
      mexpf(1,2) = (mxphys(2,3)+xcpd)*0.25d0
      mexpf(2,2) = (mxphys(2,1)+xcmd)*0.25d0
c=======================================================================
      return
      end
c
c
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine phystof3(mexpf,nlambs,rlams,nmfour,nmphys,
     $                    nthmax,mxphys)
c///////////////////////////////////////////////////////////////////////
c
c purpose:
c     this subroutine converts the discretized exponential moment 
c     function into its fourier expansion.
c
c input:
c     mxphys(*):  discrete values of the moment function 
c                   m(\lambda,\alpha), ordered as follows:
c         mxphys(1),...,mxphys(nmphys(1)) = m(\lambda_1,0),..., 
c              m(\lambda_1, 2*pi*(nmphys(1)-1)/nmphys(1)).
c         mxphys(nmphys(1)+1),...,mxphys(nmphys(2)) = 
c              m(\lambda_2,0),...,
c                  m(\lambda_2, 2*pi*(nmphys(2)-1)/nmphys(2)), etc.
c     nlambs:        number of discretization pts. in lambda integral
c     rlams(nlambs): discretization points in lambda integral.
c     nmfour(j):   number of fourier modes in the expansion
c                      of the function m(\lambda_j,\alpha)
c     nthmax =      max_j nmfour(j)
c
c output:
c     mexpf(*):     fourier coefficients of the function 
c                   mexp(lambda,alpha) for discrete lambda values. 
c                   they are ordered as follows:
c               mexpf(1,...,nmfour(1)) = fourier modes for lambda_1
c               mexpf(nmfour(1)+1,...,nmfour(2)) = fourier modes
c                                              for lambda_2
c               etc.
c
c-----------------------------------------------------------------------
      implicit real *8(a-h,o-z)
c
c
      integer  nlambs,nmfour(nlambs),nmphys(nlambs),nthmax
c
      real *8     rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      nftot = 1
      nptot  = 1
c_lambda_1
      call pf4t2(mexpf(nftot),mxphys(nptot))
      nftot = nftot+2
      nptot = nptot+2
c_lambda_2
      call pf8t3(mexpf(nftot),mxphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
c_lambda_3
      call pf16t4(mexpf(nftot),mxphys(nptot))
      nftot = nftot+4
      nptot = nptot+8
c_lambda_4
      call pf16t4(mexpf(nftot),mxphys(nptot))
      nftot = nftot+4
      nptot = nptot+8
c_lambda_5
      call pf24t5(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+12
c_lambda_6
      call pf24t5(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+12
c_lambda_7
      call pf8t5(mexpf(nftot),mxphys(nptot))
      nftot = nftot+5
      nptot = nptot+4
c_lambda_8
      call pf4t3(mexpf(nftot),mxphys(nptot))
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf4t2(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8 mexpf(2,2), mxphys(2,2)
      mexpf(1,1) = (mxphys(1,1)+mxphys(1,2))/2
      mexpf(2,1) = 0.0d0
c
      mexpf(1,2) = mxphys(2,2)/2
      mexpf(2,2) = mxphys(2,1)/2
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf4t3(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8 mexpf(2,3), mxphys(2,2)
      mexpf(1,1) = (mxphys(1,1)+mxphys(1,2))/2
      mexpf(2,1) = 0.0d0
c
      mexpf(1,2) = mxphys(2,2)/2
      mexpf(2,2) = mxphys(2,1)/2
c
      mexpf(1,3) = (mxphys(1,1)-mxphys(1,2))/2
      mexpf(2,3) = 0.0d0
c=======================================================================
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf8t3(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,3), mxphys(2,4)
c
      data hsq2/0.70710678118655d0/
      xa = mxphys(1,1)+mxphys(1,3)
      xb = mxphys(1,2)+mxphys(1,4)
c
      mexpf(1,1) = (xa+xb)/4
      mexpf(2,1) = 0.0d0
c
      mexpf(1,3) = (mxphys(1,1)-mxphys(1,3))/4
      mexpf(2,3) = (mxphys(1,4)-mxphys(1,2))/4
c
      xc = hsq2*mxphys(2,2)
      xd = hsq2*mxphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
c
      mexpf(1,2) = (mxphys(2,3)+xcpd)/4
      mexpf(2,2) = (mxphys(2,1)+xcmd)/4
c=======================================================================
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf8t5(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,5), mxphys(2,4)
c
      data hsq2/0.70710678118655d0/
      xa = mxphys(1,1)+mxphys(1,3)
      xb = mxphys(1,2)+mxphys(1,4)
c
      mexpf(1,1) = (xa+xb)/4
      mexpf(2,1) = 0.0d0
      mexpf(1,5) = (xa-xb)/4
      mexpf(2,5) = 0.0d0
c
      mexpf(1,3) = (mxphys(1,1)-mxphys(1,3))/4
      mexpf(2,3) = (mxphys(1,4)-mxphys(1,2))/4
c
      xc = hsq2*mxphys(2,2)
      xd = hsq2*mxphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
c
      mexpf(2,2) = (mxphys(2,1)+xcmd)/4
      mexpf(1,2) = (mxphys(2,3)+xcpd)/4
      mexpf(2,4) = (mxphys(2,3)-xcpd)/4
      mexpf(1,4) = (xcmd-mxphys(2,1))/4
c=======================================================================
      return
      end
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf16t4(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,4), mxphys(2,8)
c
      data hsq2/0.70710678118655d0/
      data c8pi/0.92387953251129d0/
      data s8pi/0.38268343236509d0/
      xa = mxphys(1,1)+mxphys(1,3)
      xb = mxphys(1,2)+mxphys(1,4)
      xc = mxphys(1,5)+mxphys(1,7)
      xd = mxphys(1,6)+mxphys(1,8)
c
      mexpf(1,1) = (xa+xb+xc+xd)/8
      mexpf(2,1) = 0.0d0
c
      xa = mxphys(1,1)-mxphys(1,5)
      xb = mxphys(1,7)-mxphys(1,3)
      xc = mxphys(1,8)-mxphys(1,4)
      xd = mxphys(1,6)-mxphys(1,2)
c
      mexpf(1,3) = (xa+hsq2*(xc-xd))/8
      mexpf(2,3) = (xb+hsq2*(xc+xd))/8
c
      x4p6 = mxphys(2,4)+mxphys(2,6)
      x4m6 = mxphys(2,4)-mxphys(2,6)
      x3p7 = hsq2*(mxphys(2,3)+mxphys(2,7))
      x3m7 = hsq2*(mxphys(2,3)-mxphys(2,7))
      x2p8 = mxphys(2,2)+mxphys(2,8)
      x2m8 = mxphys(2,2)-mxphys(2,8)
c
      mexpf(1,2) = (mxphys(2,5)+x3p7+c8pi*x4p6+s8pi*x2p8)/8
      mexpf(2,2) = (mxphys(2,1)+x3m7+c8pi*x2m8+s8pi*x4m6)/8
c
      mexpf(1,4) = (-mxphys(2,5)+x3p7+c8pi*x2p8-s8pi*x4p6)/8
      mexpf(2,4) = (mxphys(2,1)-x3m7-c8pi*x4m6+s8pi*x2m8)/8
c=======================================================================
      return
      end
c
c
c///////////////////////////////////////////////////////////////////////
      subroutine pf24t5(mexpf,mxphys)
c///////////////////////////////////////////////////////////////////////
      implicit real *8(a-h,o-z)
c
c
      real *8  mexpf(2,5), mxphys(2,12)
c
      data hsq2/0.70710678118655d0/
      data hsq3/0.86602540378444d0/
      data c12pi/0.96592582628907d0/
      data s12pi/0.25881904510252d0/
      r1p7 = mxphys(1,1)+mxphys(1,7)
      r1m7 = mxphys(1,1)-mxphys(1,7)
      r2p8 = mxphys(1,2)+mxphys(1,8)
      r2m8 = mxphys(1,2)-mxphys(1,8)
      r3p9 = mxphys(1,3)+mxphys(1,9)
      r3m9 = mxphys(1,3)-mxphys(1,9)
      r4p10 = mxphys(1,4)+mxphys(1,10)
      r4m10 = mxphys(1,4)-mxphys(1,10)
      r5p11 = mxphys(1,5)+mxphys(1,11)
      r5m11 = mxphys(1,5)-mxphys(1,11)
      r6p12 = mxphys(1,6)+mxphys(1,12)
      r6m12 = mxphys(1,6)-mxphys(1,12)
c
      mexpf(1,1) = (r1p7+r2p8+r3p9+r4p10+r5p11+r6p12)/12
      mexpf(2,1) = 0.0d0
c
      mexpf(1,3) = (r1m7+0.5d0*(r3m9-r5m11)+hsq3*(r2m8-r6m12))/12
      mexpf(2,3) = -(r4m10+0.5d0*(r2m8+r6m12)+hsq3*(r3m9+r5m11))/12
c
      mexpf(1,5) = (r1p7-r4p10+0.5d0*(r2p8-r3p9-r5p11+r6p12))/12
      mexpf(2,5) = hsq3*(-r2p8-r3p9+r5p11+r6p12)/12
c
      x1 = mxphys(2,1)
      x7 = mxphys(2,7)
      x2p12 = mxphys(2,2)+mxphys(2,12)
      x2m12 = mxphys(2,2)-mxphys(2,12)
      x3p11 = mxphys(2,3)+mxphys(2,11)
      x3m11 = mxphys(2,3)-mxphys(2,11)
      x4p10 = hsq2*(mxphys(2,4)+mxphys(2,10))
      x4m10 = hsq2*(mxphys(2,4)-mxphys(2,10))
      x5p9 = mxphys(2,5)+mxphys(2,9)
      x5m9 = mxphys(2,5)-mxphys(2,9)
      x6p8 = mxphys(2,6)+mxphys(2,8)
      x6m8 = mxphys(2,6)-mxphys(2,8)
c
      mexpf(1,2) = (x7+x4p10+0.5d0*x3p11+hsq3*x5p9+
     1               c12pi*x6p8+s12pi*x2p12)/12
      mexpf(2,2) = (x1+x4m10+0.5d0*x5m9+hsq3*x3m11+
     1               c12pi*x2m12+s12pi*x6m8)/12
c
      mexpf(1,4) = (-x7+x3p11+x4p10+hsq2*(x2p12-x6p8))/12
ccc      mexpf(2,4) = (x1-x5m11-x4m10+hsq2*(x2m12-x6m8))/12
      mexpf(2,4) = (x1-x3m11-x4m10+hsq2*(x2m12-x6m8))/12
c=======================================================================
      return
      end
c
C
C///////////////////////////////////////////////////////////////////////
      subroutine phystof6(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C Purpose:
C     This subroutine converts the discretized exponential moment 
C     function into its Fourier expansion.
C
C Input:
C     MEXPPHYS(*):  Discrete values of the moment function 
C                   M(\lambda,\alpha), ordered as follows.
C
C         MEXPPHYS(1),...,MEXPPHYS(NUMPHYS(1)) = M(\lambda_1,0),..., 
C              M(\lambda_1, 2*PI*(NUMPHYS(1)-1)/NUMPHYS(1)).
C         MEXPPHYS(NUMPHYS(1)+1),...,MEXPPHYS(NUMPHYS(2)) = 
C              M(\lambda_2,0),...,
C                  M(\lambda_2, 2*PI*(NUMPHYS(2)-1)/NUMPHYS(2)).
C         etc.
C
C     NLAMBS:        number of discretization pts. in lambda integral
C     RLAMS(NLAMBS): discretization points in lambda integral.
C     NUMFOUR(j):   number of Fourier modes in the expansion
C                      of the function M(\lambda_j,\alpha)
C     NTHMAX =      max_j NUMFOUR(j)
C
C Output:
C     MEXPF(*):     Fourier coefficients of the function 
C                   MEXP(lambda,alpha) for discrete lambda values. 
C                   They are ordered as follows:
C
C               MEXPF(1,...,NUMFOUR(1)) = Fourier modes for lambda_1
C               MEXPF(NUMFOUR(1)+1,...,NUMFOUR(2)) = Fourier modes
C                                              for lambda_2
C               etc.
C
C-----------------------------------------------------------------------
      implicit real *8 (a-h,o-z)
c
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      real *8     rlams(nlambs)
      complex *16 mexpf(1)
c
      complex *16 mexpphys(1)
      nftot = 1
      nptot  = 1
C
      call ptf8to3(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
C
      call ptf8to4(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+4
      nptot = nptot+4
C
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C
      call ptf24to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+12
C
      call ptf32to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+16
C
      call ptf32to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+16
C
      call ptf32to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+16
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf48to11fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+11
      nptot = nptot+24
C
      call ptf8to8(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+4
C
      mexpf(nftot)=dreal((mexpphys(nptot)+mexpphys(nptot+1))/2)
c=======================================================================
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf8to3(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,3)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data hsq2/0.70710678118655d0/
      xa = mexpphys(1,1)+mexpphys(1,3)
      xb = mexpphys(1,2)+mexpphys(1,4)
C
      mexpf(1,1) = (xa+xb)/4
      mexpf(2,1) = 0.0d0
C
      mexpf(1,3) = (mexpphys(1,1)-mexpphys(1,3))/4
      mexpf(2,3) = (mexpphys(1,4)-mexpphys(1,2))/4
C
      xc = hsq2*mexpphys(2,2)
      xd = hsq2*mexpphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
C
      mexpf(1,2) = (mexpphys(2,3)+xcpd)/4
      mexpf(2,2) = (mexpphys(2,1)+xcmd)/4
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf8to4(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,4)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data hsq2/0.70710678118655d0/
      xa = mexpphys(1,1)+mexpphys(1,3)
      xb = mexpphys(1,2)+mexpphys(1,4)
C
      mexpf(1,1) = (xa+xb)/4
      mexpf(2,1) = 0.0d0
C
      mexpf(1,3) = (mexpphys(1,1)-mexpphys(1,3))/4
      mexpf(2,3) = (mexpphys(1,4)-mexpphys(1,2))/4
C
      xc = hsq2*mexpphys(2,2)
      xd = hsq2*mexpphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
C
      mexpf(2,2) = (mexpphys(2,1)+xcmd)/4
      mexpf(1,2) = (mexpphys(2,3)+xcpd)/4
C
      mexpf(2,4) = (mexpphys(2,1)-xcmd)/4
      mexpf(1,4) = -(mexpphys(2,3)-xcpd)/4
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf8to8(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      real *8 mexpf(2,8)
      real *8 mexpphys(2,4)
C***********************************************************************
C
      data hsq2/0.70710678118655d0/
      xa = mexpphys(1,1)+mexpphys(1,3)
      xb = mexpphys(1,2)+mexpphys(1,4)
C
      mexpf(1,1) = (xa+xb)/4
      mexpf(2,1) = 0.0d0
      mexpf(1,5) = (xa-xb)/4
      mexpf(2,5) = 0.0d0
C
      mexpf(1,3) = (mexpphys(1,1)-mexpphys(1,3))/4
      mexpf(2,3) = (mexpphys(1,4)-mexpphys(1,2))/4
      mexpf(1,7) = mexpf(1,3)
      mexpf(2,7) = -mexpf(2,3)
C
      xc = hsq2*mexpphys(2,2)
      xd = hsq2*mexpphys(2,4)
      xcpd = xc + xd
      xcmd = xc - xd
C
      mexpf(2,2) = (mexpphys(2,1)+xcmd)/4
      mexpf(1,2) = (mexpphys(2,3)+xcpd)/4
      mexpf(2,6) = (mexpphys(2,1)-xcmd)/4
      mexpf(1,6) = (mexpphys(2,3)-xcpd)/4
C
      mexpf(1,4) = -mexpf(1,6)
      mexpf(2,4) = mexpf(2,6)
      mexpf(1,8) = -mexpf(1,2)
      mexpf(2,8) = mexpf(2,2)
ccc      mexpf(2,4) = mexpf(1,6)
ccc      mexpf(1,4) = -mexpf(2,6)
ccc      mexpf(2,8) = mexpf(1,2)
ccc      mexpf(1,8) = -mexpf(2,2)
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf48to11fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 11)
      parameter (MM = 24)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf32to11fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 11)
      parameter (MM = 16)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf32to8fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 8)
      parameter (MM = 16)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf24to8fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 8)
      parameter (MM = 12)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf16to8fft(mexpf,mexpphys)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (NN = 8)
      parameter (MM = 8)
      parameter (NM = (nn-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
c
C///////////////////////////////////////////////////////////////////////
      subroutine phystof9(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
C///////////////////////////////////////////////////////////////////////
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1)
      real *8     rlams(nlambs)
C-----------------------------------------------------------------------
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
      nftot = 1
      nptot  = 1
C_lambda_1
      call ptf8to3(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+3
      nptot = nptot+4
C_lambda_2
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_3
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_4
      call ptf16to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+8
C_lambda_5
      call ptf24to8fft(mexpf(nftot),mexpphys(nptot))
      nftot = nftot+8
      nptot = nptot+12
C_lambda_6
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),10)
      nftot = nftot+10
      nptot = nptot+16
C_lambda_7
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),10)
      nftot = nftot+10
      nptot = nptot+16
C_lambda_8
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),12)
      nftot = nftot+12
      nptot = nptot+16
C_lambda_9
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),12)
      nftot = nftot+12
      nptot = nptot+24
C_lambda_10
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),13)
      nftot = nftot+13
      nptot = nptot+24
C_lambda_11
      call ptf48tonnfft(mexpf(nftot),mexpphys(nptot),14)
      nftot = nftot+14
      nptot = nptot+24
C_lambda_12
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),14)
      nftot = nftot+14
      nptot = nptot+32
C_lambda_13
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),15)
      nftot = nftot+15
      nptot = nptot+32
C_lambda_14
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+32
C_lambda_15
      call ptf64tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+32
C_lambda_16
      call ptf72tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_17
      call ptf72tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_18
      call ptf80tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+40
C_lambda_19
      call ptf80tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+40
C_lambda_20
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_21
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_22
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_23
      call ptf88tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+44
C_lambda_24
      call ptf72tonnfft(mexpf(nftot),mexpphys(nptot),16)
      nftot = nftot+16
      nptot = nptot+36
C_lambda_25
      call ptf32tonnfft(mexpf(nftot),mexpphys(nptot),13)
      nftot = nftot+13
      nptot = nptot+16
C_lambda_26
      mexpf(nftot)=dreal((mexpphys(nptot)+mexpphys(nptot+1))/2)
C
      return
      end
C
c
c
c
C///////////////////////////////////////////////////////////////////////
      subroutine ptf32tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 16)
      parameter (MM = 16)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf48tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 16)
      parameter (MM = 24)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
c
c
c
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf64tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 20)
      parameter (MM = 32)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf72tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 20)
      parameter (MM = 36)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf80tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 20)
      parameter (MM = 40)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
C
C///////////////////////////////////////////////////////////////////////
      subroutine ptf88tonnfft(mexpf,mexpphys,nn)
C///////////////////////////////////////////////////////////////////////
C
C *** parameter nn and mm are to be changed for different input and
C     output length. NOTE: here mm is half of the physical modes,
C     and we require that mm is divisible by 4 in this code.
C
      implicit real *8 (a-h,o-z)
      parameter (Nmax = 23)
      parameter (MM = 44)
      parameter (NM = (nmax-1)*(mm/2-1))
      real *8 mexpf(2,nn)
      real *8 mexpphys(2,mm)
      real *8 exps48(2,nm)
      complex *16 ima, ctmp, ctmp1
C***********************************************************************
C
C   code  to generate exps48 at the first time it is called:
C
      data ima/(0.0d0,1.0d0)/
      data ifinit/0/
      if (ifinit .eq. 0) then
         pi=4.0d0*datan(1.0d0)
         ctmp1 = -ima*pi/mm
         do i = 1, nm
            ctmp = cdexp(i*ctmp1)
            exps48(1,i) = dreal(ctmp)
            exps48(2,i) = dimag(ctmp)
         enddo
         ifinit = 1
      endif
C
C   code for mexpf(*,1):
C
      x2 = 0.0d0
      do i = 1, mm
         x2 = x2 + mexpphys(1,i)
      enddo
      mexpf(1,1) = x2/mm
      mexpf(2,1) = 0.0d0
C
C**** the even fourier modes:
C
      mhm = mm/2
      do i = 3, nn, 4
         x2 = mexpphys(1,1) - mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) - mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
      do i = 5, nn, 4
         x2 = mexpphys(1,1) + mexpphys(1, 1+mhm)
         x3 = 0.0d0
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(1,j) + mexpphys(1, j+mhm)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp*exps48(2,ij)
         enddo
         mexpf(1,i) = x2/mm
         mexpf(2,i) = x3/mm
      enddo
C
C**** the odd fourier modes:
C
      mm2 = mm+2
      do i = 2, nn, 4
         x2 = mexpphys(2,1)
         x3 = -mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      do i = 4, nn, 4
         x2 = mexpphys(2,1)
         x3 = mexpphys(2,mhm+1)
         do j = 2, mhm
            ij = (i-1)*(j-1)
            tmp = mexpphys(2,j) - mexpphys(2,mm2-j)
            tmp1 = mexpphys(2,j) + mexpphys(2,mm2-j)
            x2 = x2 + tmp*exps48(1,ij)
            x3 = x3 + tmp1*exps48(2,ij)
         enddo
         mexpf(2,i) = x2/mm
         mexpf(1,i) = -x3/mm
      enddo
C
      return
      end
C
C
c
c
c
      subroutine phystf(ndigit,mexpf,nlambs,rlams,nmfour,nmphys,nthmax,
     &        mxphys)
c
      implicit real *8 (a-h,o-z)
c
c
      integer *4 nlambs,nmfour(nlambs),nmphys(nlambs),nthmax
c
      real *8 rlams(nlambs)
c
      complex *16 mexpf(1), mxphys(1)
      if (ndigit .eq. 1) then
**         call phystofsl(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         call phystof1(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      if (ndigit .eq. 2) then
**         call phystofsl(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         call phystof2(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      if (ndigit .eq. 3) then
**         call phystofsl(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         call phystof3(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      if (ndigit .eq. 6) then
         call phystof6(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      if (ndigit .eq. 9) then
         call phystof9(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      if (ndigit .eq. 12) then
**         call phystofsl(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         call phystof12(mexpf,nlambs,rlams,nmfour,nmphys,nthmax,mxphys)
         return
      endif
c
      return
      end
c
c
c
c
c
c
c
      subroutine prcssu(scale,lexp1,iuall,nuall,ixuall,
     1           iyuall,iu1234,nu1234,ix1234,iy1234,mexuall,
     2           mexu1234,xs,ys,zs,nexptotp)
c***********************************************************************
c
c     this subroutine processes the up interaction lists.
c
c     input:
c
c     iuall(nuall), ixuall(nuall), iyuall(nuall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     iu1234(nu1234), ix1234(nu1234), iy1234(nu1234) are the boxes 
c          receiving data from child boxes 1,2,3,4 and the x and y 
c          offsets from child 1, respectively.
c
c     mexuall is the exponential expansion for all eight children.
c     mexu1234(nexptotp) is the exponential expansion for 
c          children 1,2,3,4.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp1, which contains the local up expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
      implicit real *8 (a-h,o-z)
      integer *4 iuall(nuall),nuall,ixuall(nuall),iyuall(nuall)
c
      integer *4 iu1234(nu1234),nu1234,ix1234(nu1234),iy1234(nu1234)
c
      real *8 zs(3,nexptotp)
      complex *16 lexp1(nexptotp,*)
      complex *16 mexuall(nexptotp)
      complex *16 mexu1234(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
      complex *16 zmul
      do i = 1,nuall
         do jj = 1,nexptotp
            zmul = zs(3,jj)*scale
            if (ixuall(i).gt.0) 
     1            zmul = zmul*xs(ixuall(i),jj)
            if (ixuall(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ixuall(i),jj))
            if (iyuall(i).gt.0) 
     1            zmul = zmul*ys(iyuall(i),jj)
            if (iyuall(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iyuall(i),jj))
            lexp1(jj,iuall(i)) = lexp1(jj,iuall(i)) +
     1            mexuall(jj)*zmul
         enddo
      enddo
c
      do i = 1,nu1234
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix1234(i).gt.0) 
     1            zmul = zmul*xs(ix1234(i),jj)
            if (ix1234(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix1234(i),jj))
            if (iy1234(i).gt.0) 
     1            zmul = zmul*ys(iy1234(i),jj)
            if (iy1234(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy1234(i),jj))
            lexp1(jj,iu1234(i)) = lexp1(jj,iu1234(i)) +
     1            mexu1234(jj)*zmul
         enddo
      enddo
      return
      end
c
c
c
c
c
      subroutine prcssd(scale,lexp2,idall,ndall,ixdall,
     1           iydall,id5678,nd5678,ix5678,iy5678,mexdall,
     2           mexd5678,xs,ys,zs,nexptotp)
c
c*****************************************************************
c
c     this subroutine processes the down interaction lists.
c
c     input:
c
c     idall(ndall), ixdall(ndall), iydall(ndall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     id5678(nd5678), ix5678(nd5678), iy5678(nd5678) are the boxes 
c          receiving data from child boxes 5,6,7,8 and the x and y 
c          offsets from child 1, respectively.
c
c     mexdall is the exponential expansion for all eight children.
c     mexd5678(nexptotp) is the exponential expansion for 
c          children 5,6,7,8.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp2, which contains the local down expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
c
      implicit real *8 (a-h,o-z)
      integer *4 idall(ndall),ndall,ixdall(ndall),iydall(ndall)
c
      integer *4 id5678(nd5678),nd5678,ix5678(nd5678),iy5678(nd5678)
      real *8 zs(3,nexptotp)
      complex *16 lexp2(nexptotp,*)
      complex *16 mexdall(nexptotp)
      complex *16 mexd5678(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
      complex *16 zmul
      do i = 1,ndall
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ixdall(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ixdall(i),jj))
            if (ixdall(i).lt.0) 
     1            zmul = zmul*xs(-ixdall(i),jj)
            if (iydall(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iydall(i),jj))
            if (iydall(i).lt.0) 
     1            zmul = zmul*ys(-iydall(i),jj)
            lexp2(jj,idall(i)) = lexp2(jj,idall(i)) +
     1            mexdall(jj)*zmul
         enddo
      enddo
c
      do i = 1,nd5678
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix5678(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix5678(i),jj))
            if (ix5678(i).lt.0) 
     1            zmul = zmul*xs(-ix5678(i),jj)
            if (iy5678(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy5678(i),jj))
            if (iy5678(i).lt.0) 
     1            zmul = zmul*ys(-iy5678(i),jj)
            lexp2(jj,id5678(i)) = lexp2(jj,id5678(i)) +
     1            mexd5678(jj)*zmul
         enddo
      enddo
c
      return
      end
c
c
c
c
c
      subroutine prcssn(scale,lexp1,inall,nnall,ixnall,iynall,
     1           in1256,nn1256,ix1256,iy1256,
     1           in12,nn12,ix12,iy12,in56,nn56,ix56,iy56,
     2           mexnall,mexn1256,mexn12,mexn56,xs,ys,zs,nexptotp)
c
c***********************************************************************
c
c     this subroutine processes the north interaction lists.
c
c     input:
c
c     inall(nnall), ixnall(nnall), iynall(nnall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     the other north lists are similarly defined (see mknolist).
c
c     mexnall is the exponential expansion for all eight children, etc.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp1, which contains the local north expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
c
      implicit real *8 (a-h,o-z)
c
      integer *4 inall(nnall),nnall,ixnall(nnall),iynall(nnall)
      integer *4 in1256(nn1256),nn1256,ix1256(nn1256),iy1256(nn1256)
      integer *4 in12(nn12),nn12,ix12(nn12),iy12(nn12)
c
      integer *4 in56(nn56),nn56,ix56(nn56),iy56(nn56)
c
      real *8 zs(3,nexptotp)
      complex *16 lexp1(nexptotp,*)
      complex *16 mexnall(nexptotp)
      complex *16 mexn1256(nexptotp)
      complex *16 mexn12(nexptotp)
      complex *16 mexn56(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
ccc      call prin2(' mexnall is *',mexnall,2*nexptotp)
      complex *16 zmul
      do i = 1,nnall
         do jj = 1,nexptotp
            zmul = zs(3,jj)*scale
            if (ixnall(i).gt.0) 
     1            zmul = zmul*xs(ixnall(i),jj)
            if (ixnall(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ixnall(i),jj))
            if (iynall(i).gt.0) 
     1            zmul = zmul*ys(iynall(i),jj)
            if (iynall(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iynall(i),jj))
            lexp1(jj,inall(i)) = lexp1(jj,inall(i)) +
     1            mexnall(jj)*zmul
         enddo
      enddo
c
      do i = 1,nn1256
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix1256(i).gt.0) 
     1            zmul = zmul*xs(ix1256(i),jj)
            if (ix1256(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix1256(i),jj))
            if (iy1256(i).gt.0) 
     1            zmul = zmul*ys(iy1256(i),jj)
            if (iy1256(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy1256(i),jj))
            lexp1(jj,in1256(i)) = lexp1(jj,in1256(i)) +
     1            mexn1256(jj)*zmul
         enddo
      enddo
c
      do i = 1,nn12
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix12(i).gt.0) 
     1            zmul = zmul*xs(ix12(i),jj)
            if (ix12(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix12(i),jj))
            if (iy12(i).gt.0) 
     1            zmul = zmul*ys(iy12(i),jj)
            if (iy12(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy12(i),jj))
            lexp1(jj,in12(i)) = lexp1(jj,in12(i)) +
     1            mexn12(jj)*zmul
         enddo
      enddo
c
      do i = 1,nn56
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix56(i).gt.0) 
     1            zmul = zmul*xs(ix56(i),jj)
            if (ix56(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix56(i),jj))
            if (iy56(i).gt.0) 
     1            zmul = zmul*ys(iy56(i),jj)
            if (iy56(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy56(i),jj))
            lexp1(jj,in56(i)) = lexp1(jj,in56(i)) +
     1            mexn56(jj)*zmul
         enddo
      enddo
      return
      end
c
c
c
c
c
      subroutine prcsss(scale,lexp2,isall,nsall,ixsall,iysall,
     1           is3478,ns3478,ix3478,iy3478,
     2           is34,ns34,ix34,iy34,is78,ns78,ix78,iy78,
     3           mexsall,mexs3478,mexs34,mexs78,xs,ys,zs,nexptotp)
c***********************************************************************
c
c     this subroutine processes the south interaction lists.
c
c     input:
c
c     isall(nsall), ixsall(nsall), iysall(nsall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     the other south lists are similarly defined (see mksolist).
c
c     mexsall is the exponential expansion for all eight children, etc.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp2, which contains the local north expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
      implicit real *8 (a-h,o-z)
c
      integer *4 isall(nsall),nsall,ixsall(nsall),iysall(nsall)
      integer *4 is3478(ns3478),ns3478,ix3478(ns3478),iy3478(ns3478)
      integer *4 is34(ns34),ns34,ix34(ns34),iy34(ns34)
c
      integer *4 is78(ns78),ns78,ix78(ns78),iy78(ns78)
c
      real *8 zs(3,nexptotp)
      complex *16 lexp2(nexptotp,*)
      complex *16 mexsall(nexptotp)
      complex *16 mexs3478(nexptotp)
      complex *16 mexs34(nexptotp)
      complex *16 mexs78(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
      complex *16 zmul
      do i = 1,nsall
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ixsall(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ixsall(i),jj))
            if (ixsall(i).lt.0) 
     1            zmul = zmul*xs(-ixsall(i),jj)
            if (iysall(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iysall(i),jj))
            if (iysall(i).lt.0) 
     1            zmul = zmul*ys(-iysall(i),jj)
            lexp2(jj,isall(i)) = lexp2(jj,isall(i)) +
     1            mexsall(jj)*zmul
         enddo
      enddo
c
      do i = 1,ns3478
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix3478(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix3478(i),jj))
            if (ix3478(i).lt.0) 
     1            zmul = zmul*xs(-ix3478(i),jj)
            if (iy3478(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy3478(i),jj))
            if (iy3478(i).lt.0) 
     1            zmul = zmul*ys(-iy3478(i),jj)
            lexp2(jj,is3478(i)) = lexp2(jj,is3478(i)) +
     1            mexs3478(jj)*zmul
         enddo
      enddo
c
      do i = 1,ns34
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix34(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix34(i),jj))
            if (ix34(i).lt.0) 
     1            zmul = zmul*xs(-ix34(i),jj)
            if (iy34(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy34(i),jj))
            if (iy34(i).lt.0) 
     1            zmul = zmul*ys(-iy34(i),jj)
            lexp2(jj,is34(i)) = lexp2(jj,is34(i)) +
     1            mexs34(jj)*zmul
         enddo
      enddo
c
      do i = 1,ns78
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix78(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix78(i),jj))
            if (ix78(i).lt.0) 
     1            zmul = zmul*xs(-ix78(i),jj)
            if (iy78(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy78(i),jj))
            if (iy78(i).lt.0) 
     1            zmul = zmul*ys(-iy78(i),jj)
            lexp2(jj,is78(i)) = lexp2(jj,is78(i)) +
     1            mexs78(jj)*zmul
         enddo
      enddo
      return
      end
c
c
c
c
c
      subroutine prcsse(scale,lexp1,ieall,neall,ixeall,iyeall,
     1           ie1357,ne1357,ix1357,iy1357,
     2           ie13,ne13,ix13,iy13,ie57,ne57,ix57,iy57,
     3           ie1,ne1,ix1,iy1,ie3,ne3,ix3,iy3,
     4           ie5,ne5,ix5,iy5,ie7,ne7,ix7,iy7,
     5           mexeall,mexe1357,mexe13,mexe57,
     6           mexe1,mexe3,mexe5,mexe7,
     7           xs,ys,zs,nexptotp)
c***********************************************************************
c
c     this subroutine processes the east interaction lists.
c
c     input:
c
c     ieall(neall), ixeall(neall), iyeall(neall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     the other east lists are similarly defined (see mkealist).
c
c     mexeall is the exponential expansion for all eight children, etc.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp1, which contains the local east expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
      implicit real *8 (a-h,o-z)
c
      integer *4 ieall(neall),neall,ixeall(neall),iyeall(neall)
      integer *4 ie1357(ne1357),ne1357,ix1357(ne1357),iy1357(ne1357)
      integer *4 ie13(ne13),ne13,ix13(ne13),iy13(ne13)
      integer *4 ie57(ne57),ne57,ix57(ne57),iy57(ne57)
      integer *4 ie1(ne1),ne1,ix1(ne1),iy1(ne1)
      integer *4 ie3(ne3),ne3,ix3(ne3),iy3(ne3)
      integer *4 ie5(ne5),ne5,ix5(ne5),iy5(ne5)
c
      integer *4 ie7(ne7),ne7,ix7(ne7),iy7(ne7)
c
      real *8 zs(3,nexptotp)
      complex *16 lexp1(nexptotp,*)
      complex *16 mexeall(nexptotp)
      complex *16 mexe1357(nexptotp)
      complex *16 mexe13(nexptotp)
      complex *16 mexe57(nexptotp)
      complex *16 mexe1(nexptotp)
      complex *16 mexe3(nexptotp)
      complex *16 mexe5(nexptotp)
      complex *16 mexe7(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
      complex *16 zmul
      do i = 1,neall
         do jj = 1,nexptotp
            zmul = zs(3,jj)*scale
            if (ixeall(i).gt.0) 
     1            zmul = zmul*xs(ixeall(i),jj)
            if (ixeall(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ixeall(i),jj))
            if (iyeall(i).gt.0) 
     1            zmul = zmul*ys(iyeall(i),jj)
            if (iyeall(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iyeall(i),jj))
            lexp1(jj,ieall(i)) = lexp1(jj,ieall(i)) +
     1            mexeall(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne1357
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix1357(i).gt.0) 
     1            zmul = zmul*xs(ix1357(i),jj)
            if (ix1357(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix1357(i),jj))
            if (iy1357(i).gt.0) 
     1            zmul = zmul*ys(iy1357(i),jj)
            if (iy1357(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy1357(i),jj))
            lexp1(jj,ie1357(i)) = lexp1(jj,ie1357(i)) +
     1            mexe1357(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne13
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix13(i).gt.0) 
     1            zmul = zmul*xs(ix13(i),jj)
            if (ix13(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix13(i),jj))
            if (iy13(i).gt.0) 
     1            zmul = zmul*ys(iy13(i),jj)
            if (iy13(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy13(i),jj))
            lexp1(jj,ie13(i)) = lexp1(jj,ie13(i)) +
     1            mexe13(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne57
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix57(i).gt.0) 
     1            zmul = zmul*xs(ix57(i),jj)
            if (ix57(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix57(i),jj))
            if (iy57(i).gt.0) 
     1            zmul = zmul*ys(iy57(i),jj)
            if (iy57(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy57(i),jj))
            lexp1(jj,ie57(i)) = lexp1(jj,ie57(i)) +
     1            mexe57(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne1
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix1(i).gt.0) 
     1            zmul = zmul*xs(ix1(i),jj)
            if (ix1(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix1(i),jj))
            if (iy1(i).gt.0) 
     1            zmul = zmul*ys(iy1(i),jj)
            if (iy1(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy1(i),jj))
            lexp1(jj,ie1(i)) = lexp1(jj,ie1(i)) +
     1            mexe1(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne3
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix3(i).gt.0) 
     1            zmul = zmul*xs(ix3(i),jj)
            if (ix3(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix3(i),jj))
            if (iy3(i).gt.0) 
     1            zmul = zmul*ys(iy3(i),jj)
            if (iy3(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy3(i),jj))
            lexp1(jj,ie3(i)) = lexp1(jj,ie3(i)) +
     1            mexe3(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne5
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix5(i).gt.0) 
     1            zmul = zmul*xs(ix5(i),jj)
            if (ix5(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix5(i),jj))
            if (iy5(i).gt.0) 
     1            zmul = zmul*ys(iy5(i),jj)
            if (iy5(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy5(i),jj))
            lexp1(jj,ie5(i)) = lexp1(jj,ie5(i)) +
     1            mexe5(jj)*zmul
         enddo
      enddo
c
      do i = 1,ne7
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ix7(i).gt.0) 
     1            zmul = zmul*xs(ix7(i),jj)
            if (ix7(i).lt.0) 
     1            zmul = zmul*dconjg(xs(-ix7(i),jj))
            if (iy7(i).gt.0) 
     1            zmul = zmul*ys(iy7(i),jj)
            if (iy7(i).lt.0) 
     1            zmul = zmul*dconjg(ys(-iy7(i),jj))
            lexp1(jj,ie7(i)) = lexp1(jj,ie7(i)) +
     1            mexe7(jj)*zmul
         enddo
      enddo
c
      return
      end
c
c
c
c
c
      subroutine prcssw(scale,lexp2,iwall,nwall,ixwall,iywall,
     1           iw2468,nw2468,ix2468,iy2468,
     2           iw24,nw24,ix24,iy24,iw68,nw68,ix68,iy68,
     3           iw2,nw2,ix2,iy2,iw4,nw4,ix4,iy4,
     4           iw6,nw6,ix6,iy6,iw8,nw8,ix8,iy8,
     5           mexwall,mexw2468,mexw24,mexw68,
     6           mexw2,mexw4,mexw6,mexw8,
     7           xs,ys,zs,nexptotp)
c***********************************************************************
c
c     this subroutine processes the west interaction lists.
c
c     input:
c
c     iwall(nwall), ixwall(nwall), iywall(nwall) are the boxes 
c          receiving all child box data and the x and y offsets from
c          child 1, respectively.
c     the other west lists are similarly defined (see mkwelist).
c
c     mexeall is the exponential expansion for all eight children, etc.
c     xs,ys,zs are the shift coefficients computed by subroutine
c          mkexps.
c
c     output:
c
c     lexp1, which contains the local west expansion information for
c            all boxes, is incremented for each box in the 
c            interaction lists.
c
c
c***********************************************************************
      implicit real *8 (a-h,o-z)
      integer *4 iwall(nwall),nwall,ixwall(nwall),iywall(nwall)
      integer *4 iw2468(nw2468),nw2468,ix2468(nw2468),iy2468(nw2468)
      integer *4 iw24(nw24),nw24,ix24(nw24),iy24(nw24)
      integer *4 iw68(nw68),nw68,ix68(nw68),iy68(nw68)
      integer *4 iw2(nw2),nw2,ix2(nw2),iy2(nw2)
      integer *4 iw4(nw4),nw4,ix4(nw4),iy4(nw4)
      integer *4 iw6(nw6),nw6,ix6(nw6),iy6(nw6)
c
      integer *4 iw8(nw8),nw8,ix8(nw8),iy8(nw8)
c
      real *8 zs(3,nexptotp)
      complex *16 lexp2(nexptotp,*)
      complex *16 mexwall(nexptotp)
      complex *16 mexw2468(nexptotp)
      complex *16 mexw24(nexptotp)
      complex *16 mexw68(nexptotp)
      complex *16 mexw2(nexptotp)
      complex *16 mexw4(nexptotp)
      complex *16 mexw6(nexptotp)
      complex *16 mexw8(nexptotp)
      complex *16 xs(3,nexptotp)
      complex *16 ys(3,nexptotp)
c
      complex *16 zmul
      do i = 1,nwall
         do jj = 1,nexptotp
            zmul = zs(2,jj)*scale
            if (ixwall(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ixwall(i),jj))
            if (ixwall(i).lt.0) 
     1            zmul = zmul*xs(-ixwall(i),jj)
            if (iywall(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iywall(i),jj))
            if (iywall(i).lt.0) 
     1            zmul = zmul*ys(-iywall(i),jj)
            lexp2(jj,iwall(i)) = lexp2(jj,iwall(i)) +
     1            mexwall(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw2468
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix2468(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix2468(i),jj))
            if (ix2468(i).lt.0) 
     1            zmul = zmul*xs(-ix2468(i),jj)
            if (iy2468(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy2468(i),jj))
            if (iy2468(i).lt.0) 
     1            zmul = zmul*ys(-iy2468(i),jj)
            lexp2(jj,iw2468(i)) = lexp2(jj,iw2468(i)) +
     1            mexw2468(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw24
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix24(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix24(i),jj))
            if (ix24(i).lt.0) 
     1            zmul = zmul*xs(-ix24(i),jj)
            if (iy24(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy24(i),jj))
            if (iy24(i).lt.0) 
     1            zmul = zmul*ys(-iy24(i),jj)
            lexp2(jj,iw24(i)) = lexp2(jj,iw24(i)) +
     1            mexw24(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw68
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix68(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix68(i),jj))
            if (ix68(i).lt.0) 
     1            zmul = zmul*xs(-ix68(i),jj)
            if (iy68(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy68(i),jj))
            if (iy68(i).lt.0) 
     1            zmul = zmul*ys(-iy68(i),jj)
            lexp2(jj,iw68(i)) = lexp2(jj,iw68(i)) +
     1            mexw68(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw2
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix2(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix2(i),jj))
            if (ix2(i).lt.0) 
     1            zmul = zmul*xs(-ix2(i),jj)
            if (iy2(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy2(i),jj))
            if (iy2(i).lt.0) 
     1            zmul = zmul*ys(-iy2(i),jj)
            lexp2(jj,iw2(i)) = lexp2(jj,iw2(i)) +
     1            mexw2(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw4
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix4(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix4(i),jj))
            if (ix4(i).lt.0) 
     1            zmul = zmul*xs(-ix4(i),jj)
            if (iy4(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy4(i),jj))
            if (iy4(i).lt.0) 
     1            zmul = zmul*ys(-iy4(i),jj)
            lexp2(jj,iw4(i)) = lexp2(jj,iw4(i)) +
     1            mexw4(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw6
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix6(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix6(i),jj))
            if (ix6(i).lt.0) 
     1            zmul = zmul*xs(-ix6(i),jj)
            if (iy6(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy6(i),jj))
            if (iy6(i).lt.0) 
     1            zmul = zmul*ys(-iy6(i),jj)
            lexp2(jj,iw6(i)) = lexp2(jj,iw6(i)) +
     1            mexw6(jj)*zmul
         enddo
      enddo
c
      do i = 1,nw8
         do jj = 1,nexptotp
            zmul = zs(1,jj)*scale
            if (ix8(i).gt.0) 
     1            zmul = zmul*dconjg(xs(ix8(i),jj))
            if (ix8(i).lt.0) 
     1            zmul = zmul*xs(-ix8(i),jj)
            if (iy8(i).gt.0) 
     1            zmul = zmul*dconjg(ys(iy8(i),jj))
            if (iy8(i).lt.0) 
     1            zmul = zmul*ys(-iy8(i),jj)
            lexp2(jj,iw8(i)) = lexp2(jj,iw8(i)) +
     1            mexw8(jj)*zmul
         enddo
      enddo
      return
      end
c
c
c
c
c
c
c
      subroutine setupall3d(sources, nsources, targets,
     1                      ntargets, all, nall, idivideon)
      implicit none
c
c     idivideon = 0 just divide on the sources
c     idivideon = 1 just divide on the targets
c     idivideon = 2 divide on both sources and targets
c
c--------------------------------------------------------------------------
c
c
      integer *4  nsources, ntargets, nall, i, ncntr, idivideon
c
      real *8  sources(3,1), targets(3,1), all(3,1),
     1         xmax(3), xmin(3)
        if(idivideon .eq. 0)then
c
          call getcornersofbox(targets,ntargets,xmax,xmin)
c
          ncntr = 0
c         
          do 1000 i = 1, nsources
c           
            ncntr = ncntr + 1
            all(1,ncntr) = sources(1,i)
            all(2,ncntr) = sources(2,i)
            all(3,ncntr) = sources(3,i)
c
 1000     continue
c
          ncntr = ncntr + 1
          all(1,ncntr) = xmax(1)
          all(2,ncntr) = xmax(2)
          all(3,ncntr) = xmax(3)
c         
          ncntr = ncntr + 1
          all(1,ncntr) = xmin(1)
          all(2,ncntr) = xmin(2)
          all(3,ncntr) = xmin(3)
c
          nall = nsources + 2
c
        endif
c
        if(idivideon .eq. 1)then
c
          call getcornersofbox(sources,nsources,xmax,xmin)
c
          ncntr = 0
c
          do 2000 i = 1, ntargets
c
            ncntr = ncntr + 1
            all(1,ncntr) = targets(1,i)
            all(2,ncntr) = targets(2,i)
            all(3,ncntr) = targets(3,i)
c
 2000     continue
c
          ncntr = ncntr + 1
          all(1,ncntr) = xmax(1)
          all(2,ncntr) = xmax(2)
          all(3,ncntr) = xmax(3)
c
          ncntr = ncntr + 1
          all(1,ncntr) = xmin(1)
          all(2,ncntr) = xmin(2)
          all(3,ncntr) = xmin(3)
c
          nall = ntargets + 2
c
        endif
c
        if(idivideon .eq. 2)then
c
          ncntr = 0
c
          do 3000 i = 1, nsources
c
            ncntr = ncntr + 1
            all(1,ncntr) = sources(1,i)
            all(2,ncntr) = sources(2,i)
            all(3,ncntr) = sources(3,i)
c
 3000     continue
c
          do 4000 i = 1, ntargets
c
            ncntr = ncntr + 1
            all(1,ncntr) = targets(1,i)
            all(2,ncntr) = targets(2,i)
            all(3,ncntr) = targets(3,i)
c
 4000     continue
c
          nall = nsources + ntargets
c
        endif
c
      return
      end
c
c
c
c
c
      subroutine getcornersofbox(zpos,npos,xmax,xmin)
      implicit none
c
c
      integer *4  i, npos
c
      real *8  xmax(3), xmin(3), zpos(3,1), xxmax, yymax,
     1         zzmax, xxmin, yymin, zzmin
        xxmax = zpos(1,1)
        yymax = zpos(2,1)
        zzmax = zpos(3,1)
c
        xxmin = zpos(1,1)
        yymin = zpos(2,1)
        zzmin = zpos(3,1)
c
        do 1000 i = 2, npos 
c
          if(zpos(1,i) .ge. xxmax) xxmax = zpos(1,i)
          if(zpos(2,i) .ge. yymax) yymax = zpos(2,i)
          if(zpos(3,i) .ge. zzmax) zzmax = zpos(3,i)
c
          if(zpos(1,i) .le. xxmin) xxmin = zpos(1,i)
          if(zpos(2,i) .le. yymin) yymin = zpos(2,i)
          if(zpos(3,i) .le. zzmin) zzmin = zpos(3,i)
c
 1000   continue
c
        xmax(1) = xxmax
        xmax(2) = yymax
        xmax(3) = zzmax
c
        xmin(1) = xxmin
        xmin(2) = yymin
        xmin(3) = zzmin
c
      return
      end
c
c
c
c
c
      subroutine riv3dlic(ier)
      implicit none
c
c
      integer *4  ier
        ier = 0
c
      return
      end
c
c
c
c
c
c
	subroutine rotgen(nterms,rdpi2,rdmpi2,rdsq3,rdsq3inv,
     1		rdmsq3,rdmsq3inv,dc)
	implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine generates all the rotation matrices that are
c	necessary (these rotations are all about y-axis).
c
c Inputs:
c	nterms: the number of terms for multipole expansions for fmm.
c	dc: the square root of binomial coef.
c
c Outputs:
c	rdpi2: rotation matrix for an angle of pi/2.
c	rdmpi2: rotation matrix for an angle of -pi/2, which is also
c		the inverse of rdpi2.
c	rdsq3: rotation matrix for an angle of arccos(1/sqrt(3))
c	rdsq3inv: the inverse of rdsq3
c	rdmsq3: rotation matrix for an angle of arccos(-1/sqrt(3))
c	rdmsq3inv: the inverse of rdmsq3
c
	real *8 dc(0:4*nterms,0:4*nterms)
	real *8 rdpi2(0:nterms,0:nterms,-nterms:nterms) 
	real *8 rdmpi2(0:nterms,0:nterms,-nterms:nterms) 
	real *8 rdsq3(0:nterms,0:nterms,-nterms:nterms) 
	real *8 rdsq3inv(0:nterms,0:nterms,-nterms:nterms) 
	real *8 rdmsq3(0:nterms,0:nterms,-nterms:nterms) 
c
	real *8 rdmsq3inv(0:nterms,0:nterms,-nterms:nterms) 
	pi = 4*datan(1.0d0)
c
	theta = pi/2.0d0
	call fstrtn(nterms,rdpi2,dc,theta)
	theta = -theta
	call fstrtn(nterms,rdmpi2,dc,theta)
c
	theta = dacos(dsqrt(3.0d0)/3.0d0)
	call fstrtn(nterms,rdsq3,dc,theta)
	theta = -theta
	call fstrtn(nterms,rdsq3inv,dc,theta)
c
	theta = dacos(-dsqrt(3.0d0)/3.0d0)
	call fstrtn(nterms,rdmsq3,dc,theta)
	theta = -theta
	call fstrtn(nterms,rdmsq3inv,dc,theta)
c
	return
	end
c
c
c
c
c
      subroutine rtztoy(nterms,nmid,mpole,mwork,mrotat,rdminu)
c
      implicit real *8 (a-h,o-z)
      real *8 rdminu(0:nterms,0:nterms,-nterms:nterms) 
      complex *16 mpole(0:nterms,0:nterms)
      complex *16 mwork(0:nterms,0:nterms)
      complex *16 mrotat(0:nterms,0:nterms)
      complex *16 ephi(0:100),meye
      save
c
      data ifinit/0/
      data meye/(0.0d0,-1.0d0)/
      if (ifinit .eq. 0) then
         ephi(0) = 1.0d0
         do 101 m=1,nmid
            ephi(m)=ephi(m-1)*meye
 101     continue
ccc         ifinit = 1
      endif
c
c----- a rotation of -pi/2 radians about the z-axis in the
c      original coordinate system.
c
      do 103 l=0,nmid
         do 102 m=0,l
            mwork(l,m)=ephi(m)*mpole(l,m)
 102     continue
 103  continue
c
c----- a rotation of -pi/2 radians about the y'-axis in the
c      new coordinate system, bringing the +z-axis in line 
c      with the original +y axis.
c
      do 106 l=0,nmid
         do 105 m=0,l
            mrotat(l,m)=mwork(l,0)*rdminu(l,0,m)
            do 104 mp=1,l
               mrotat(l,m)=mrotat(l,m)+mwork(l,mp)*rdminu(l,mp,m)+
     1          dconjg(mwork(l,mp))*rdminu(l,mp,-m)
 104        continue
 105     continue
 106  continue
c
      return
      end
c
c
c
c
c
      subroutine rtytoz(nterms,nmid,mpole,mwork,mrotat,rdplus)
      implicit real *8 (a-h,o-z)
c
c
      real *8 rdplus(0:nterms,0:nterms,-nterms:nterms) 
      complex *16 mpole(0:nterms,0:nterms)
      complex *16 mwork(0:nterms,0:nterms)
      complex *16 mrotat(0:nterms,0:nterms)
c
      complex *16 ephi(0:100),eye
      save
c
      data ifinit/0/
      data eye/(0.0d0,1.0d0)/
      if (ifinit .eq. 0) then
         ephi(0) = 1.0d0
         do 101 m=1,nmid
            ephi(m)=ephi(m-1)*eye
 101     continue
ccc         ifinit = 1
      endif
c
c----- a rotation of pi/2 radians about the y'-axis in the
c      new coordinate system, bringing the +z-axis in line 
c      with the original +z axis.
c
      do 104 l=0,nmid
         do 103 m=0,l
            mwork(l,m)=mpole(l,0)*rdplus(l,0,m)
            do 102 mp=1,l
               mwork(l,m)=mwork(l,m)+mpole(l,mp)*rdplus(l,mp,m)+
     1          dconjg(mpole(l,mp))*rdplus(l,mp,-m)
 102        continue
 103     continue
 104  continue
c
c----- a rotation of pi/2 radians about the z-axis in the
c      original coordinate system.
c
      do 106 l=0,nmid
         do 105 m=0,l
            mrotat(l,m)=ephi(m)*mwork(l,m)
 105     continue
 106  continue
c
      return
      end
c
c
c
c
c
      subroutine rtztox(nterms,nmid,mpole,mrotat,rd)
      implicit real *8 (a-h,o-z)
c
c
      real *8 rd(0:nterms,0:nterms,-nterms:nterms) 
      complex *16 mpole(0:nterms,0:nterms)
c
      complex *16 mrotat(0:nterms,0:nterms)
      do 103 l=0,nmid
         do 102 m=0,l
            mrotat(l,m)=mpole(l,0)*rd(l,0,m)
            do 101 mp=1,l
               mrotat(l,m)=mrotat(l,m)+mpole(l,mp)*rd(l,mp,m)+
     1          dconjg(mpole(l,mp))*rd(l,mp,-m)
 101        continue
 102     continue
 103  continue
c
      return
      end

c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c  a bunch of old tools used in the code, no need to change from
c  accuracy to accuracy.
c$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
c
c
c
c
c
      subroutine bnlcft(c, sqc, nterms)
c
c     usage:
c           computes the binomial coefficients c_nterms^n, where
c           n=0,1,2,...,nterms.
c     input:
c           nterms: an integer indicates the number we are going
c                 to choose from.
c     output:
c           c:    an array consists of the binomial coefficients.
c           sqc:   an array consists of the square root of the
c                 binormial coefficients.
c
c***********************************************************************
c
c---------------declares of bnlcft--------------------------------------
c
      implicit real *8(a-h,o-z)
c
c
      integer *4 nterms,n,m
c
c---------------executions of bnlcft------------------------------------
c
      real *8  c(0:nterms,0:nterms), sqc(0:nterms,0:nterms)
      do 100 n=0,nterms
            c(n,0)=1.0d0
 100  continue
      do 102 m=1,nterms
         c(m,m)=1.0d0
         do 101 n=m+1,nterms
            c(n,m)=c(n-1,m)+c(n-1,m-1)
 101     continue
 102  continue
c
      do 200 n=0,nterms
            sqc(n,0)=1.0d0
 200  continue
      do 202 m=1,nterms
         sqc(m,m)=1.0d0
         do 201 n=m+1,nterms
            sqc(n,m)=dsqrt(c(n,m))
 201     continue
 202  continue
c
      return
      end
c
c
c
c
c
      subroutine sclgdr(nmax,x,pp)
c
c     usage: evaluate the scaled legendre function pp_n^m(x),
c            where n=0,1,...,nmax; m=0,...,n-1,n.
c            here scaled means the following:
c                pp_n^m(x)=p_n^m(x)/dsqrt((2m)!),
c            where p_n^m(x) are the usual legendre functions,
c            by doing this, we could avoid the overflow in
c            computing the legendre functions for large nmax.
c            and we skipped the usual lower part of the
c            legendre functions, i.e. for m=-n,-(n-1),...,-1,
c            this part is not needed in the application of computing
c            the spherical harmonics.
c
c     input:
c            nmax: an integer indicates the highest degree of
c                  legendre polynomial.
c            x:    the point where the legendre function need
c                  to be evaluated.
c
c     output:
c            pp:   an array which contain the function value
c                  pp_n^m(x) for n,m ranging as indicated above.
c-----------------------------------------------------------------------
c
      implicit real *8(a-h,o-z)
c
c
      integer *4 nmax, m, n
c
c executions starts:
c
      real *8  x, pp(0:nmax, 0:nmax), u
      u=-dsqrt(1-x*x)
      pp(0,0)=1
      do 102 m=0, nmax
         if (m.gt.0) then
            pp(m,m)=pp(m-1,m-1)*u*dsqrt(1.0d0-0.5d0/m)
         endif
         if (m.lt.nmax) then
            pp(m+1,m)=(2.0d0*m+1.0d0)*x*pp(m,m)
         endif
         do 101 n=m+2, nmax
            pp(n,m)=((2*n-1)*x*pp(n-1,m)-(n+m-1)*pp(n-2,m))/(n-m)
 101     continue
 102  continue
c
      return
      end
c
c
c
c
c
      subroutine fstrtn(nterms,d,sqc,theta)
      implicit real *8(a-h,o-z)
c
c     usage:
c           implement the fast version of rotation matrices from
c           the recurrences formulas.
c     input:
c           nterms: an integer indicates the dimension of d.
c           sqc:    an array contains the square root of the
c                   binormial coefficients.
c           theta:  the rotate angle about the y-axis.
c     output:
c           d:      an array which contains the rotation matrix.
c                   note: only half of d are evaluated, the other
c                   half can be obtained by using the symmetricity.
c
c---------------declares of fstrtn--------------------------------------
c
c
      integer *4 nterms
c
      real *8  d(0:nterms,0:nterms,-nterms:nterms),
     1   sqc(0:4*nterms, 0:4*nterms), ctheta, stheta, hsthta,
     2   cthtap, cthtan, theta, precis
c
c---------------executions of fstrtn------------------------------------
c
      data precis/1.0d-19/
      data ww/0.7071067811865476d+00/
      ctheta=dcos(theta)
      if (dabs(ctheta).le.precis) ctheta = 0.0d0
      stheta=dsin(-theta)
      if (dabs(stheta).le.precis) stheta = 0.0d0
c     stheta=dsqrt(1.0-ctheta*ctheta)
      hsthta=ww*stheta
      cthtap=ww*(1.0d0+ctheta)
      cthtan=-ww*(1.0d0-ctheta)
c
c     initial setup for some coefficient matrix.
c
c     call bnlcft(c, sqc, 4*nterms)
c
      d(0,0,0)=1.0d0
c
      do 106 ij=1,nterms
c
c     compute the result for m'=0 case, use formula (1).
c
         do 101 im=-ij,-1
            d(ij,0,im)=-sqc(ij-im,2)*d(ij-1,0,im+1)
            if (im.gt.(1-ij)) then
               d(ij,0,im)=d(ij,0,im)+sqc(ij+im,2)*d(ij-1,0,im-1)
            endif
            d(ij,0,im)=d(ij,0,im)*hsthta
            if (im.gt.-ij) then
               d(ij,0,im)=d(ij,0,im)+
     1           d(ij-1,0,im)*ctheta*sqc(ij+im,1)*sqc(ij-im,1)
            endif
            d(ij,0,im)=d(ij,0,im)/ij
 101     continue
c
         d(ij,0,0)=d(ij-1,0,0)*ctheta
         if (ij.gt.1) then
            d(ij,0,0)=d(ij,0,0)+hsthta*sqc(ij,2)*(d(ij-1,0,-1)+
     1                 d(ij-1,0,1))/ij
         endif
c
         do 102 im=1,ij
            d(ij,0,im)=-sqc(ij+im,2)*d(ij-1,0,im-1)
            if (im.lt.(ij-1)) then
               d(ij,0,im)=d(ij,0,im)+sqc(ij-im,2)*d(ij-1,0,im+1)
            endif
            d(ij,0,im)=d(ij,0,im)*hsthta
            if (im.lt.ij) then
               d(ij,0,im)=d(ij,0,im)+
     1           d(ij-1,0,im)*ctheta*sqc(ij+im,1)*sqc(ij-im,1)
            endif
            d(ij,0,im)=d(ij,0,im)/ij
 102     continue
c
c     compute the result for 0<m'<=j case, use formula (2).
c
         ijm1 = ij-1
         do 105 imp=1,ij
            impm1 = imp-1
            ijpimp = ij+imp
            do 103 im=-ij,-1
               ijmim = ij-im
               ijpim = ij+im
               d(ij,imp,im)=d(ijm1,impm1,im+1)*cthtan*sqc(ijmim,2)
               if (im.gt.(-ijm1)) then
                  d(ij,imp,im)=d(ij,imp,im)-
     1             d(ijm1,impm1,im-1)*cthtap*sqc(ijpim,2)
               endif
               if (im.gt.-ij) then
                  d(ij,imp,im)=d(ij,imp,im)+
     1             d(ijm1,impm1,im)*stheta*sqc(ijpim,1)*sqc(ijmim,1)
               endif
               d(ij,imp,im)=d(ij,imp,im)*ww/sqc(ijpimp,2)
 103        continue
c
            d(ij,imp,0)=ij*stheta*d(ijm1,impm1,0)
            if (ij.gt.1) then
               d(ij,imp,0)=d(ij,imp,0)-sqc(ij,2)*(
     1            d(ijm1,impm1,-1)*cthtap+d(ijm1,impm1,1)*cthtan)
            endif
            d(ij,imp,0)=d(ij,imp,0)*ww/sqc(ijpimp,2)
c
            do 104 im=1,ij
               ijmim = ij-im
               ijpim = ij+im
               d(ij,imp,im)=d(ijm1,impm1,im-1)*cthtap*sqc(ijpim,2)
               if (im.lt.(ijm1)) then
                  d(ij,imp,im)=d(ij,imp,im)-
     1             d(ijm1,impm1,im+1)*cthtan*sqc(ijmim,2)
               endif
               if (im.lt.ij) then
                  d(ij,imp,im)=d(ij,imp,im)+
     1             d(ijm1,impm1,im)*stheta*sqc(ijpim,1)*sqc(ijmim,1)
               endif
               d(ij,imp,im)=d(ij,imp,im)*ww/sqc(ijpimp,2)
 104        continue
c
c     use symmetricity, i.e. formula (3.80) in biedenharn & louck's
c     book, to compute the lower part of the matrix
c
c           do 111 im=-ij,ij
c              d(ij,-imp,im)=d(ij,imp,-im)
c 111       continue
c
 105     continue
 106  continue
c
      return
      end
c
c
c
c
c
      subroutine d3lota(x0y0z0,xnynzn,mpole,local,marray,nterms,scale0,
     1                  scalen,dbc,rd)
c
c
c     usage:
c	   this is rotation based slow lota.
c          convert multipole expansion to taylor series by first
c          rotating the coordinate system, then doing the conversion
c          along the z'-axis, and then rotating back to the original
c          co-ords, thus achieve the whole conversion in just
c          constant*nterms^3 operations rather than the usual
c          constant*nterms^4 operations.
c
c     input:
c
c          x0y0z0 = original expansion center
c          mpole  = original expansion coefficients
c          xnynzn = new expansion center
c          nterms = integer indicates the terms retained in the
c                   expansion.
c	 ****warning: this code will bomb if nterms exceeds 50!!*******
c	   scale0 = the scale of the input multipole expansion.
c	   scalen = the scale of the output local expansion.
c
c     output:
c
c          local  = local expansion coefficients
c
c     working arrays:
c
c          dbc    = work arrays contain the square root of the
c                   binormial coefficients.
c          rd     = working arrays contain the rotation matrix
c                   about y-axis.
c          marray = working array to store the intermediate
c                   value of local.
c-----------------------------------------------------------------------
c
      implicit real *8(a-h,o-z)
c
c
      integer *4 nterms, l, m, jnew, knew, ll, msign
c
      real *8  x0y0z0(3), xnynzn(3),
     1  dbc(0:4*nterms,0:4*nterms),
     2  rd(0:nterms,0:nterms,-nterms:nterms),
     3  scale0, scalen, scale,
     4  powers(0:110), precis, theta,
     5  rx, ry, rz, proj, rr, d, dd, ctheta
c
      complex *16 mpole(0:nterms,0:nterms),
     1  local(0:nterms,0:nterms), marray(0:nterms,0:nterms),
     2  ephi(-55:55), eye
c
c executions starts:
c
      data eye/(0.0d0,1.0d0)/
      precis = 1.0d-19
c
      rx = xnynzn(1) - x0y0z0(1)
      ry = xnynzn(2) - x0y0z0(2)
      rz = xnynzn(3) - x0y0z0(3)
      proj = rx*rx + ry*ry
      rr = proj + rz*rz
      proj = dsqrt(proj)
      d = 1.0d0/dsqrt(rr)
      ctheta = rz*d
      theta=dacos(ctheta)
c
      ephi(0)=1.0d0
      if ( proj .le. precis/d) then
         ephi(1) = 1.0d0
         ephi(-1) = 1.0d0
      endif
c
      if ( proj .gt. precis/d) then
         ephi(1) = rx/proj + eye*ry/proj
         ephi(-1) = dconjg(ephi(1))
      endif
c
c----- create array of powers of r and e^(i*m*phi).
c
      dd = d
      powers(0) = 1.0d0
      powers(1) = d
      do 101 l = 2,2*nterms+1
         powers(l) = powers(l-1)*dd
 101  continue
      do 102 l = 2,nterms
         ephi(l) = ephi(l-1)*ephi(1)
         ephi(-l) = dconjg(ephi(l))
 102  continue
c
c----- a rotation of phi radians about the z-axis in the
c      co-ords at the original expansion center x0y0z0.
c
      scale = 1.0d0
      do 104 l=0,nterms
         do 103 m=0,l
            local(l,m)=ephi(m)*mpole(l,m)/scale
***            local(l,m)=ephi(-m)*mpole(l,m)
 103     continue
         scale = scale*scale0
 104  continue
c
c----- a rotation of theta radians about the y'-axis  in the
c      above just rotated system.
c
      call fstrtn(nterms,rd,dbc,theta)
c
      do 107 l=0,nterms
         do 106 m=0,l
            marray(l,m)=local(l,0)*rd(l,0,m)
            do 105 mp=1,l
               marray(l,m)=marray(l,m)+local(l,mp)*rd(l,mp,m)+
     1          dconjg(local(l,mp))*rd(l,mp,-m)
 105        continue
 106     continue
 107  continue
c
c----- convert the multipole expansion to a local expansion at
c      the xnynzn along the z-axis.
c
      do 110 jnew=0,nterms
         do 109 knew=0,jnew
            local(jnew,knew) = 0.0d0
            kk=iabs(knew)
            msign=(-1)**(jnew+knew)
            do 108 l=kk,nterms
               ll=l+jnew
               local(jnew,knew) = local(jnew,knew)+marray(l,knew)*
     1          powers(ll+1)*dbc(ll,l-knew)*dbc(ll,l+knew)*msign
 108        continue
 109     continue
 110  continue
c
c----- rotate back theta radians about the y-axis in the coordinate
c      system sitting at the new expansion centre.
c
      do 113 l=0,nterms
         do 112 m=0,l
            marray(l,m)=local(l,0)*rd(l,0,m)*(-1)**m
            do 111 mp=1,l
               marray(l,m)=marray(l,m)+(local(l,mp)*rd(l,mp,m)+
     1          dconjg(local(l,mp))*rd(l,mp,-m))*(-1)**(m+mp)
 111        continue
 112     continue
 113  continue
c
c----- rotate back phi radians about the z-axis in the above system.
c
      scale = 1.0d0
      do 115 l=0,nterms
         do 114 m=0,l
***            local(l,m)=ephi(m)*marray(l,m)
            local(l,m)=ephi(-m)*marray(l,m)/scale
 114     continue
         scale = scale*scalen
 115  continue
c
      return
      end
c
c
c
c
c
      subroutine ftophyssl(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
c
c  this is a slow ftophys, useful in testing new ftophys.
c
c  the formula is:
c
c   mexpphys(k)=mexpf(1) + 2*dreal(sum_{j=3,n,2}{mexpf(j)*exp(eye*
c          (j-1)*(k-1)*2*pi/m)}) + 2*eye*dimag(sum_{j=2,n,2}{mexpf(j)*
c          exp(eye*(j-1)*(k-1)*2*pi/m)})
c    where k=1,2,...,m/2 (m/2+1,...,m are conj of the former half)
c          n: number of fourier modes
c          m: number of physical modes
c          n <= m, and m(mod4) = 0 (a must!).
c
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1),eye,ztmp
      real *8     rlams(nlambs)
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
c
      data eye/(0.0d0,1.0d0)/
      done=1.0d0
c
      pi=datan(done)*4
      nftot = 0
      nptot  = 0
      do 2000 i=1,nlambs
        nalpha = numphys(i)
        halpha = 2*pi/nalpha
        ztmp = eye*halpha
        do 1200 ival=1,numphys(i)/2
           mexpphys(nptot+ival) = mexpf(nftot+1)
c ... odd part:
           do mm = 3,numfour(i),2
              ntmp = (mm-1)*(ival-1)
              mexpphys(nptot+ival) = mexpphys(nptot+ival) +
     1                2.0d0*dreal(cdexp(ztmp*ntmp)*mexpf(nftot+mm))
           enddo
c ... even part:
           do mm = 2,numfour(i),2
              ntmp = (mm-1)*(ival-1)
              mexpphys(nptot+ival) = mexpphys(nptot+ival) +
     1                2.0d0*eye*dimag(cdexp(ztmp*ntmp)*mexpf(nftot+mm))
           enddo
 1200   continue
c
        nftot = nftot+numfour(i)
        nptot = nptot+numphys(i)/2
 2000 continue
c
      return
      end
c
c
c
c
c
      subroutine phystofsl(mexpf,nlambs,rlams,numfour,numphys,
     1                      nthmax,mexpphys)
c
c  this is a slow phystof, useful when implementing new phystof.
c
c  the formula is:
c    mexpf(1) = 2/m * sum_{k=1}^{m/2}{dreal(mexpphys(k))}
c    mexpf(j) = 2/m * sum_{k=1}^{m/2}{dreal(mexpphys(k))*exp(-eye*(j-1)*
c                   (k-1)*2*pi/m)} for j=3,5,... [for j odd]
c    mexpf(j) = eye * 2/m * sum_{k=1}^{m/2}{dimag(mexpphys(k))*
c                exp(-eye*(j-1)*(k-1)*2*pi/m)} for j=2,4,...[for j even]
c
      implicit real *8 (a-h,o-z)
      complex *16 mexpf(1)
      complex *16 mexpphys(1),eye,ztmp
      real *8     rlams(nlambs),rtmp
      integer *4  nlambs,numfour(nlambs),numphys(nlambs),nthmax
c
      data eye/(0.0d0,1.0d0)/
      done=1.0d0
c
      pi=datan(done)*4
      nftot = 0
      nptot  = 0
      do 2000 i=1,nlambs
	nalpha = numphys(i)
	nalpha2 = nalpha/2
        halpha=2*pi/nalpha
        ztmp = -eye*halpha
c ... mf(1):
        mexpf(nftot+1) = 0.0d0
        do ival=1,nalpha2
           mexpf(nftot+1) = mexpf(nftot+1) + 
     1          dreal(mexpphys(nptot+ival))
        enddo
        mexpf(nftot+1) = mexpf(nftot+1)/nalpha2
c ... mf(odd):
        do mm = 3,numfour(i),2
           mexpf(nftot+mm) = 0.0d0
           do ival=1,nalpha2
              ntmp = (mm-1)*(ival-1)
              rtmp = dreal(mexpphys(nptot+ival))
              mexpf(nftot+mm) = mexpf(nftot+mm) +
     1          rtmp*cdexp(ntmp*ztmp)
           enddo
           mexpf(nftot+mm) = mexpf(nftot+mm)/nalpha2
        enddo
c ... mf(even):
        do mm = 2,numfour(i),2
           mexpf(nftot+mm) = 0.0d0
           do ival=1,nalpha2
              ntmp = (mm-1)*(ival-1)
              rtmp = dimag(mexpphys(nptot+ival))
              mexpf(nftot+mm) = mexpf(nftot+mm) +
     1          rtmp*cdexp(ntmp*ztmp)
           enddo
           mexpf(nftot+mm) = (eye*mexpf(nftot+mm))/nalpha2
        enddo
c
        nftot = nftot+numfour(i)
        nptot = nptot+numphys(i)/2
 2000 continue
c
      return
      end
c
c
c
c
c
      subroutine uppassriv3d(ierout, nboxes, nterms, n22, iflagtype,
     1     centr0, sources, monocharge, dipstr, dipvec, pptmp, dc,
     2     mw3, scale, mpole, nlev, mws1, nshort, lw, w, imap,
     3     arr, rdsq3inv, rdsq3, mw1, zrot, rdmsq3inv, rdmsq3,
     4     iz, laddr, iw)
      implicit none
c
c
c
c-----------------------------------------------------------------------
c
c
      integer *4  mybox, nboxes, box(15), nkids, lw, imap(1),
     1     ier, ierout, npts, istart, ilevel, nterms, n22, 
     2     iilev, ifirstbx, ilastbx, mychld, jer, k, nlev,
     3     nshort, iflagtype, iz(1), laddr(2,1), iw(1)
c
      real *8  centr0(3), scale(0:201), dipstr(1), monocharge(1),
     1     dc(0:4*nterms,0:4*nterms), dipvec(3,1), arr(1), w(1),
     2     pptmp((n22+2)*(n22+2)), sources(3,1), zrot(8),
     3     rdsq3(0:nterms,0:nterms,-nterms:nterms),
     4     rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     5     rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     6     rdmsq3inv(0:nterms,0:nterms,-nterms:nterms)
c
c     license file check here
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1     mw1(0:nterms,0:nterms), mw3(0:nterms,0:nterms),
     2     mws1(0:nshort,0:nshort)
      call riv3dlic(ierout)
c
      if(ierout .ne. 0) return
c
c-----------------------------------------------------------------------
c step 1: form multipoles for all childless boxes:
c-----------------------------------------------------------------------
c
      do 2000 mybox = 1, nboxes
c
        call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
        if(nkids .ge. 1) goto 2000
c
        npts = box(15)
        istart = box(14) - 1
        ilevel = box(1)
c
        call formmp3d(iflagtype, centr0, sources,
     1      monocharge, dipstr, dipvec, npts, mw3, nterms,
     2      n22, scale(ilevel), dc, pptmp, iz, istart)
c
        call mapfmp3d(mw3,mpole(1,mybox),nterms)
c
 2000 continue
c
c-----------------------------------------------------------------------
c step 2: merge multipoles at all coarser mesh levels until expansion
c     for whole computational cell is obtained. in the inner loop,
c     the expansion for each box is shifted to center of parent box.
c-----------------------------------------------------------------------
c
      do 6000 iilev = nlev-1,0,-1
c
        ifirstbx = laddr(1,iilev+1)
        ilastbx = ifirstbx + laddr(2,iilev+1) - 1
c
        do 5000 mybox = ifirstbx, ilastbx
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .le. 0)  goto 5000
c
          do 3000 k = 1, 4
c
            mychld = box(5+k)
c
            if(mychld .le. 0) goto 3000
c
            call maptmp3d(mpole(1,mychld),mw3,nterms)
            call xcp21(nterms,mw3,nshort,mws1)
            call mpshft3d(jer,zrot(k),nshort,mws1,nterms,mw1,
     1                    rdsq3,rdsq3inv,arr,imap,w,lw)
            call addexp3d(mw1,mpole(1,mybox),nterms)
c
 3000     continue
c
          do 4000 k = 5, 8
            mychld = box(5+k)
c
            if(mychld .le. 0) goto 4000
c
            call maptmp3d(mpole(1,mychld),mw3,nterms)
            call xcp21(nterms,mw3,nshort,mws1)
            call mpshft3d(jer,zrot(k),nshort,mws1,nterms,mw1,
     1                    rdmsq3,rdmsq3inv,arr,imap,w,lw)
            call addexp3d(mw1,mpole(1,mybox),nterms)
c
 4000     continue
c
 5000   continue
c
 6000 continue
c
      return
      end
c
c
c
c
c
      subroutine formmp3d(iflagtype, x0y0z0, zparts,
     1          monocharge, dipstr, dipvec, nparts, mpole,
     2          nterms, nntrms, scale, dc, pp, iz, istart)
      implicit real *8(a-h,o-z)
c
c purpose:
c     forming multipole expansion due to a collection of point monocharges.
c
c input:
c     x0y0z0 =   center of the expansion
c     nparts =   number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     nterms =         order of desired expansion
c
c output:
c     mpole  =  coefficients of multipole expansion
c
c---------------------------------------------------------------------------
c
c
      integer *4  nterms, nparts, iflagtype, iz(1), istart
c
      real *8  pp(0:nntrms,0:nntrms), dipstr(1), dipvec(3,1),
     1    powers(0:51), c10, sq2, x0y0z0(3), zparts(3,1),
     2    monocharge(1), dc(0:4*nterms,0:4*nterms)
c
      complex *16  eye, ephi(-52:52), c11, c12,
     1    mpole(0:nterms,0:nterms)
c
c ***  set mpole to zero
c
      data sq2/0.70710678118655d0/
      data eye/(0.0d0,1.0d0)/
      data precis/1.0d-19/
        do 1500 l = 0, nterms
          do 1000 m = 0, l
            mpole(l,m) = 0.0d0
 1000     continue
 1500   continue
c
        do 7500 j = 1, nparts
c
          i = iz(istart + j)
c
          rx = zparts(1,i) - x0y0z0(1)
          ry = zparts(2,i) - x0y0z0(2)
          rz = zparts(3,i) - x0y0z0(3)
c
c ***    compute  distance rr
c               ctheta = cos(theta)
c               ephi(1)=e^(eye*phi)
c
          proj = rx*rx + ry*ry
          rr = proj + rz*rz
          proj = dsqrt(proj)
          d = dsqrt(rr)
c
c ***    note: here is a heck. when computing cos(theta) as
c               rz/d, we have to be careful about the possibility
c               of d  being 0 (in which case ctheta is not well
c               defined - we arbitrarily set it to 1.)
c
          if(d .le. precis) ctheta = 1.0d0
c
          if(d .gt. precis) ctheta = rz/d
c
          if(proj .le. precis*d)then
            ephi(1) = 1.0d0
            ephi(-1) = 1.0d0
          endif
c
          if(proj .gt. precis*d)then
            ephi(1) = rx/proj + eye*ry/proj
            ephi(-1) = dconjg(ephi(1))
          endif
c
c ***    create array of powers of r and powers of e^(i*phi).
c
          ephi(0) = 1.0d0
          d = d*scale
          powers(0) = monocharge(i)
          do 2000 l = 1, nntrms+1
            powers(l) = powers(l-1)*d
            ephi(l+1) = ephi(l)*ephi(1)
            ephi(-1-l) = dconjg(ephi(l+1))
 2000     continue
c
c ***    compute legendre polynomials of argument cos(theta) = ctheta
c        and add contributions from legendre polynomials
c
          call sclgdr(nntrms, ctheta, pp)
c
          if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
            mpole(0,0) = mpole(0,0) + monocharge(i)
            do 3000 l = 1, nntrms
              mpole(l,0) = mpole(l,0) + powers(l)*pp(l,0)
              do 2500 m = 1, l
                cp = powers(l)*pp(l,m)/dc(l+m,2*m)
                mpole(l,m) = mpole(l,m) + cp*ephi(-m)
 2500         continue
 3000       continue
          endif
c
c ***   now calculate the contribution from the dipstr
c
          if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
            c10 = dipvec(3,i) * dipstr(i)*scale
            c11 = dipstr(i) * dcmplx(-dipvec(1,i)*sq2,
     1                                dipvec(2,i)*sq2)*scale
            c12 = dconjg(c11)
c
            if(abs(monocharge(i)) .gt. 1.0d-30)then
              do 3500 l = 0, nntrms + 1
                powers(l) = powers(l)/monocharge(i)
 3500         continue
            endif
c
            if(abs(monocharge(i)) .le. 1.0d-30)then
              powers(0) = 1.0d0
              do 4000 l = 1, nntrms + 1
                powers(l) = powers(l-1)*d
 4000         continue
            endif
c
c ...   from c12=conjg(c11)(or c_1^(-1)):
c
            do 5000 l = 2, nntrms
              lm1 = l - 1
              dtmp = pp(lm1,1) * powers(lm1)
              mpole(l,0) = mpole(l,0) - dtmp * c12 * ephi(-1)
              do 4500 m = 1, l-2
                dtmp = dc(l-m,2)/dc(l+m,m+m+2)*pp(lm1,m+1)*powers(lm1)
                mpole(l,m) = mpole(l,m)-dtmp*ephi(-m-1)*c12
 4500         continue
 5000       continue
c
c ...   from c10:
c
            do 6000 l = 1, nntrms
              lm1 = l - 1
              do 5500 m = 0, l-1
                dtmp = dc(l+m,1)*dc(l-m,1)/dc(lm1+m,2*m)*pp(lm1,m)*c10
                dtmp = dtmp*powers(lm1)
                mpole(l,m) = mpole(l,m) + dtmp*ephi(-m)
 5500         continue
 6000       continue
c
c ...   from c11:
c
            mpole(1,1) = mpole(1,1) + c11
            do 7000 l = 2, nntrms
              lm1 = l - 1
              dtmp = pp(lm1,1) * powers(lm1)
              mpole(l,0) = mpole(l,0) - dtmp * c11 * ephi(1)
              do 6500 m = 1, l
                dtmp=dc(l+m,2)/dc(l+m-2,m+m-2)*pp(lm1,m-1)*powers(lm1)
                mpole(l,m)=mpole(l,m)+dtmp*ephi(1-m)*c11
 6500         continue
 7000       continue
          endif
 7500   continue
c
      return
      end
c
c
c
c
c
      subroutine mapfmp3d(mpole, mpout, nterms)
      implicit real *8 (a-h,o-z)
c
c Purpose:
c	This subroutine maps a multipole expansion from its nonoptimized
c	storage plan to that of optimized one.
c
c Inputs:
c	nterms: order of multpole expansion
c	mpole: the multipole expansion stored as (0:nterms,0:nterms)
c
c Outputs:
c	mpout: the output expansion allocated with only necessary 
c		storage space ((nterms+1)*(nterms+2))/2
c
c----------------------------------------------------------------------------
c
c
      complex *16  mpole(0:nterms,0:nterms),
     1     mpout(((nterms+1)*(nterms+2))/2)
	ncrrnt = 0
        do 2000 i = 0, nterms
          do 1000 j = 0, i
            ncrrnt = ncrrnt + 1
            mpout(ncrrnt) = mpole(i,j)
 1000     continue
 2000   continue
c
      return
      end
c
c
c
c
c
      subroutine uppassrivtarg3d(ierout, nboxes, nterms, n22, iflagtype,
     1    centr0, sources, monocharge, dipstr, dipvec, pptmp, dc, mw3,
     2    scale, mpole, nlev, mws1, nshort, lw, w, imap, arr, rdsq3inv,
     3    rdsq3, mw1, zrot, rdmsq3inv, rdmsq3, laddr,
     4    iw, izsour, zboxsour)
      implicit none
c
c
c
c-----------------------------------------------------------------------------
c
c
      integer *4  mybox, nboxes, box(15), nkids, lw, imap(1),
     1    ier, ilevel, nterms, n22, w(1), iilev, ifirstbx,
     2    ilastbx, mychld, jer, k, nlev, nshort, iflagtype,
     3    laddr(2,1), iw(1), izsour(1), zboxsour(2,1), ierout
c
      real *8  centr0(3), scale(0:201), dipstr(1), monocharge(1),
     1    dc(0:4*nterms,0:4*nterms), dipvec(3,1), arr(1),
     2    sources(3,1), zrot(8), pptmp((n22+2)*(n22+2)),
     3    rdsq3(0:nterms,0:nterms,-nterms:nterms),
     4    rdsq3inv(0:nterms,0:nterms,-nterms:nterms),
     5    rdmsq3(0:nterms,0:nterms,-nterms:nterms),
     6    rdmsq3inv(0:nterms,0:nterms,-nterms:nterms)
c
c     license file check here
c
      complex *16  mpole((nterms+1)*(nterms+2)/2,*),
     1    mw1(0:nterms,0:nterms), mw3(0:nterms,0:nterms),
     2    mws1(0:nshort,0:nshort)
      call riv3dlic(ierout)
c
      if(ierout .ne. 0) return
c
c-----------------------------------------------------------------------
c step 1: form multipoles for all childless boxes:
c-----------------------------------------------------------------------
c
        do 1000 mybox = 1, nboxes
c
          call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
          if(nkids .ge. 1) goto 1000
c
          ilevel = box(1)
c
          call formmptarg3d(iflagtype, centr0, sources,
     1        monocharge, dipstr, dipvec, mw3, nterms, n22,
     2        scale(ilevel), dc, pptmp, izsour, zboxsour, mybox)
c
          call mapfmp3d(mw3,mpole(1,mybox),nterms)
c
 1000   continue
c
c-----------------------------------------------------------------------
c step 2: merge multipoles at all coarser mesh levels until expansion
c     for whole computational cell is obtained. in the inner loop,
c     the expansion for each box is shifted to center of parent box.
c-----------------------------------------------------------------------
c
        do 5000 iilev = nlev-1,0,-1
c
          ifirstbx = laddr(1,iilev+1)
          ilastbx = ifirstbx + laddr(2,iilev+1) - 1
c
          do 4000 mybox = ifirstbx, ilastbx
c
            call d3mgetbk(ier,mybox,box,centr0,nkids,iw)
c
            if(nkids .le. 0)  goto 4000
c
            do 2000 k = 1, 4
c
              mychld = box(5+k)
c
              if(mychld .le. 0) goto 2000
c
              call maptmp3d(mpole(1,mychld),mw3,nterms)
              call xcp21(nterms,mw3,nshort,mws1)
              call mpshft3d(jer,zrot(k),nshort,mws1,nterms,mw1,
     1                      rdsq3,rdsq3inv,arr,imap,w,lw)
              call addexp3d(mw1,mpole(1,mybox),nterms)
c
 2000       continue
c
            do 3000 k = 5, 8
              mychld = box(5+k)
c
              if(mychld .le. 0) goto 3000
c
              call maptmp3d(mpole(1,mychld),mw3,nterms)
              call xcp21(nterms,mw3,nshort,mws1)
              call mpshft3d(jer,zrot(k),nshort,mws1,nterms,mw1,
     1                      rdmsq3,rdmsq3inv,arr,imap,w,lw)
              call addexp3d(mw1,mpole(1,mybox),nterms)
c
 3000       continue
c
 4000     continue
c
 5000   continue
c
      return
      end
c
c
c
c
c
      subroutine formmptarg3d(iflagtype, x0y0z0, zparts,
     1     monocharge, dipstr, dipvec, mpole, nterms,
     2     nntrms, scale, dc, pp, izsour, zboxsour, mybox)
      implicit real *8(a-h,o-z)
c
c purpose:
c     forming multipole expansion due to a collection of point monocharges.
c
c input:
c     x0y0z0 =   center of the expansion
c     nparts =   number of sources
c     zparts(3,nparts) = array of coordinates of sources
c     monocharge(nparts) = array of strengths of sources
c     nterms =         order of desired expansion
c
c output:
c     mpole  =  coefficients of multipole expansion
c
c-----------------------------------------------------------------------------
c
c
      integer *4  nterms, iflagtype, jj, izsour(1), zboxsour(2,1)
c
      real *8  pp(0:nntrms,0:nntrms), dipstr(1), dipvec(3,1),
     1    powers(0:51), c10, sq2, x0y0z0(3), zparts(3,1),
     2    monocharge(1), dc(0:4*nterms,0:4*nterms)
c
      complex *16  eye, ephi(-52:52), c11, c12,
     1    mpole(0:nterms,0:nterms)
c
c ***  set mpole to zero
c
      data sq2/0.70710678118655d0/
      data eye/(0.0d0,1.0d0)/
      data precis/1.0d-19/
      do 1500 l = 0, nterms
        do 1000 m = 0, l
          mpole(l,m) = 0.0d0
 1000   continue
 1500 continue
c
      istartsource = zboxsour(1,mybox)
      iendsource = zboxsour(1,mybox) + zboxsour(2,mybox) - 1
c
      do 7500 jj = istartsource, iendsource
c
        i = izsour(jj)
c
        rx = zparts(1,i) - x0y0z0(1)
        ry = zparts(2,i) - x0y0z0(2)
        rz = zparts(3,i) - x0y0z0(3)
c
c ***  compute  distance rr
c             ctheta = cos(theta)
c             ephi(1)=e^(eye*phi)
c
        proj = rx*rx+ry*ry
        rr = proj+rz*rz
        proj = dsqrt(proj)
        d = dsqrt(rr)
c
c ***  note: here is a heck. when computing cos(theta) as
c             rz/d, we have to be careful about the possibility
c             of d  being 0 (in which case ctheta is not well
c             defined - we arbitrarily set it to 1.)
c
        if(d .le. precis) ctheta = 1.0d0
c
        if(d .gt. precis) ctheta = rz/d
c
        if(proj .le. precis*d)then
          ephi(1) = 1.0d0
          ephi(-1) = 1.0d0
        endif
c
        if(proj .gt. precis*d)then
          ephi(1) = rx/proj + eye*ry/proj
          ephi(-1) = dconjg(ephi(1))
        endif
c
c ***  create array of powers of r and powers of e^(i*phi).
c
        ephi(0) = 1.0d0
        d = d * scale
        powers(0) = monocharge(i)
        do 2000 l = 1,nntrms+1
          powers(l) = powers(l-1)*d
          ephi(l+1) = ephi(l)*ephi(1)
          ephi(-1-l) = dconjg(ephi(l+1))
 2000   continue
c
c ***  compute legendre polynomials of argument cos(theta) = ctheta
c      and add contributions from legendre polynomials
c
        call sclgdr(nntrms,ctheta,pp)
c
        if(iflagtype .eq. 0 .or. iflagtype .eq. 2)then
c
          mpole(0,0) = mpole(0,0) + monocharge(i)
          do 3000 l = 1,nntrms
            mpole(l,0) = mpole(l,0) + powers(l)*pp(l,0)
            do 2500 m=1,l
              cp = powers(l)*pp(l,m)/dc(l+m,2*m)
              mpole(l,m) = mpole(l,m) + cp*ephi(-m)
 2500       continue
 3000     continue
        endif
c
c *** now calculate the contribution from the dipstr
c
        if(iflagtype .eq. 1 .or. iflagtype .eq. 2)then
c
          c10 = dipvec(3,i) * dipstr(i) * scale
          c11 = dipstr(i) * dcmplx(-dipvec(1,i)*sq2,
     1                              dipvec(2,i)*sq2) * scale
          c12 = dconjg(c11)
          if (abs(monocharge(i)) .gt. 1.0d-30) then
            do 3500 l = 0,nntrms+1
              powers(l) = powers(l)/monocharge(i)
 3500       continue
          endif
c
          if (abs(monocharge(i)) .le. 1.0d-30) then
            powers(0) = 1.0d0
            do 4000 l = 1,nntrms+1
              powers(l) = powers(l-1)*d
 4000       continue
          endif
c
c ... from c12=conjg(c11)(or c_1^(-1)):
c
          do 5000 l = 2, nntrms
            lm1 = l - 1
            dtmp = pp(lm1,1) * powers(lm1)
            mpole(l,0) = mpole(l,0) - dtmp*c12*ephi(-1)
            do 4500 m = 1, l-2
              dtmp = dc(l-m,2)/dc(l+m,m+m+2)*pp(lm1,m+1)*powers(lm1)
              mpole(l,m) = mpole(l,m) - dtmp*ephi(-m-1)*c12
 4500       continue
 5000     continue
c
c ... from c10:
c
          do 6000 l = 1, nntrms
            lm1 = l - 1
            do 5500 m = 0, l-1
              dtmp = dc(l+m,1)*dc(l-m,1)/dc(lm1+m,2*m)*pp(lm1,m)*c10
              dtmp = dtmp*powers(lm1)
              mpole(l,m) = mpole(l,m) + dtmp*ephi(-m)
 5500       continue
 6000     continue
c
c ... from c11:
c
          mpole(1,1) = mpole(1,1) + c11
          do 7000 l = 2, nntrms
            lm1 = l - 1
            dtmp=pp(lm1,1)*powers(lm1)
            mpole(l,0) = mpole(l,0) - dtmp*c11*ephi(1)
            do 6500 m = 1, l
              dtmp = dc(l+m,2)/dc(l+m-2,m+m-2)*pp(lm1,m-1)*powers(lm1)
              mpole(l,m) = mpole(l,m) + dtmp*ephi(1-m)*c11
 6500       continue
 7000     continue
        endif
c
 7500 continue
c
      return
      end
